--[[
    Character data handling
]]

local _, Internal = ...;

local UnitSex = UnitSex
local UnitRace = UnitRace
local UnitClass = UnitClass
local UnitFullName = UnitFullName
local GetRealmName = GetRealmName
local GetClassInfo = GetClassInfo
local GetNumClasses = GetNumClasses
local GetTalentInfoByID = GetTalentInfoByID
local GetSpecialization = GetSpecialization
local GetPvpTalentSlotInfo = C_SpecializationInfo.GetPvpTalentSlotInfo;
local GetNumSpecializations = GetNumSpecializations
local GetSpecializationInfo = GetSpecializationInfo
local GetTalentInfoBySpecialization = GetTalentInfoBySpecialization
local GetNumSpecializationsForClassID = GetNumSpecializationsForClassID
local GetSpecializationInfoForClassID = GetSpecializationInfoForClassID
local GetEssenceInfo = C_AzeriteEssence.GetEssenceInfo;

if select(4, GetBuildInfo()) >= 100000 then
	function Internal.IsDragonflight()
		return true
	end
else
	function Internal.IsDragonflight()
		return false
	end
end
if select(4, GetBuildInfo()) == 100000 then
	function Internal.IsDragonflightPrepatch()
		return true
	end
else
	function Internal.IsDragonflightPrepatch()
		return false
	end
end

local roles = {"TANK", "HEALER", "DAMAGER"};
local roleIndexes = {["TANK"] = 1, ["HEALER"] = 2, ["DAMAGER"] = 3};
local classInfo = {};
function Internal.Roles()
    return ipairs(roles)
end
function Internal.IsClassRoleValid(classFile, role)
	return classInfo[classFile][role] and true or false;
end
function Internal.UpdateClassInfo()
    for classIndex=1,GetNumClasses() do
		if GetNumSpecializationsForClassID(classIndex) > 0 then
			local className, classFile, classID = GetClassInfo(classIndex);
			classInfo[classFile] = {};
			for specIndex=1,GetNumSpecializationsForClassID(classID) do
				local role = select(5, GetSpecializationInfoForClassID(classID, specIndex));
				classInfo[classFile][role] = true;
			end
		end
    end
end

-- In very niche situations UnitFullName will not correctly respond with the realm
-- but since player realm cant change while logged in we can just reuse the previous value
local playerNameCache, playerRealmCache
function Internal.GetCharacterSlug()
	local name, realm = UnitFullName("player");

	playerNameCache = name or playerNameCache
	playerRealmCache = realm or playerRealmCache

	return playerRealmCache .. "-" .. playerNameCache
end

local GetSpecInfoVersion;
local VerifyTalentForSpec;
local VerifyPvPTalentForSpec;
local GetTalentInfoForSpecID;
local GetPvpTalentSlotInfoForSpecID;
do
	local specInfo
	if Internal.IsDragonflight() then
		specInfo = {
			version = 5,

			-- Warrior
			[71] = { -- Arms
				talents = {
					{22624, 22360, 22371},
					{19676, 22372, 22789},
					{22380, 22489, 19138},
					{15757, 22627, 22628},
					{22392, 22391, 22362},
					{22394, 22397, 22399},
					{21204, 22407, 21667},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							28,   29,   31,
							32,   33,   34,
							3522, 3534, 5372,
							5376, 5547,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							28,   29,   31,
							32,   33,   34,
							3522, 3534, 5372,
							5376, 5547,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							28,   29,   31,
							32,   33,   34,
							3522, 3534, 5372,
							5376, 5547,
						}
					},
				},
			},
			[72] = { -- Fury
				talents = {
					{22632, 22633, 22491},
					{19676, 22625, 23093},
					{22379, 22381, 23372},
					{23097, 22627, 22382},
					{22383, 22393, 19140},
					{22396, 22398, 22400},
					{22405, 22402, 16037},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							25,  166,  170,
							172,  177,  179,
							3528, 3533, 3735,
							5373, 5431, 5548,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							25,  166,  170,
							172,  177,  179,
							3528, 3533, 3735,
							5373, 5431, 5548,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							25,  166,  170,
							172,  177,  179,
							3528, 3533, 3735,
							5373, 5431, 5548,
						}
					},
				},
			},
			[73] = { -- Protection
				talents = {
					{15760, 15759, 15774},
					{19676, 22629, 22409},
					{22378, 22626, 23260},
					{23096, 22627, 22488},
					{22384, 22631, 22800},
					{22395, 22544, 22401},
					{23455, 22406, 23099},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							24,  167,  168,
							171,  173,  175,
							178,  831,  833,
							845, 5374, 5432,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							24,  167,  168,
							171,  173,  175,
							178,  831,  833,
							845, 5374, 5432,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							24,  167,  168,
							171,  173,  175,
							178,  831,  833,
							845, 5374, 5432,
						}
					},
				},
			},
			-- Paladin
			[65] = { -- Holy
				talents = {
					{17565, 17567, 17569},
					{22176, 17575, 17577},
					{22179, 22180, 21811},
					{22433, 22434, 17593},
					{17597, 17599, 17601},
					{23191, 23680, 22484},
					{21201, 21671, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							82,   85,   86,
							87,   88,  640,
							642,  859, 3618,
							5421, 5501, 5537,
							5553,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							82,   85,   86,
							87,   88,  640,
							642,  859, 3618,
							5421, 5501, 5537,
							5553,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							82,   85,   86,
							87,   88,  640,
							642,  859, 3618,
							5421, 5501, 5537,
							5553,
						}
					},
				},
			},
			[66] = { -- Protection
				talents = {
					{22428, 22558, 23469},
					{22431, 22604, 23468},
					{22179, 22180, 21811},
					{22433, 22434, 22435},
					{17597, 17599, 17601},
					{22189, 22438, 23087},
					{23457, 21202, 22645},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							90,   91,   92,
							93,   94,   97,
							844,  860,  861,
							3474, 3475, 5536,
							5554,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							90,   91,   92,
							93,   94,   97,
							844,  860,  861,
							3474, 3475, 5536,
							5554,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							90,   91,   92,
							93,   94,   97,
							844,  860,  861,
							3474, 3475, 5536,
							5554,
						}
					},
				},
			},
			[70] = { -- Retribution
				talents = {
					{22590, 22557, 23467},
					{22319, 22592, 23466},
					{22179, 22180, 21811},
					{22433, 22434, 22183},
					{17597, 17599, 17601},
					{23167, 22483, 23086},
					{23456, 22215, 22634},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							81,  641,  751,
							752,  753,  754,
							755,  756,  757,
							858, 5422, 5535,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							81,  641,  751,
							752,  753,  754,
							755,  756,  757,
							858, 5422, 5535,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							81,  641,  751,
							752,  753,  754,
							755,  756,  757,
							858, 5422, 5535,
						}
					},
				},
			},
			-- Hunter
			[253] = { -- Beast Mastery
				talents = {
					{22291, 22280, 22282},
					{22500, 22266, 22290},
					{19347, 19348, 23100},
					{22441, 22347, 22269},
					{22268, 22276, 22499},
					{19357, 22002, 23044},
					{22273, 21986, 22295},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							693,  824,  825,
							1214, 3599, 3600,
							3604, 3612, 3730,
							5418, 5441, 5444,
							5534,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							693,  824,  825,
							1214, 3599, 3600,
							3604, 3612, 3730,
							5418, 5441, 5444,
							5534,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							693,  824,  825,
							1214, 3599, 3600,
							3604, 3612, 3730,
							5418, 5441, 5444,
							5534,
						}
					},
				},
			},
			[254] = { -- Marksmanship
				talents = {
					{22279, 22501, 22289},
					{22495, 22497, 22498},
					{19347, 19348, 23100},
					{22267, 22286, 21998},
					{22268, 22276, 23463},
					{23063, 23104, 22287},
					{22274, 22308, 22288},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							649,  651,  653,
							658,  659,  660,
							3614, 3729, 5419,
							5440, 5442, 5531,
							5533,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							649,  651,  653,
							658,  659,  660,
							3614, 3729, 5419,
							5440, 5442, 5531,
							5533,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							649,  651,  653,
							658,  659,  660,
							3614, 3729, 5419,
							5440, 5442, 5531,
							5533,
						}
					},
				},
			},
			[255] = { -- Survival
				talents = {
					{22275, 22283, 22296},
					{21997, 22769, 22297},
					{19347, 19348, 23100},
					{22277, 19361, 22299},
					{22268, 22276, 22499},
					{22300, 22278, 22271},
					{22272, 22301, 23105},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							661,  662,  663,
							664,  665,  686,
							3607, 3609, 3610,
							5420, 5443, 5532,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							661,  662,  663,
							664,  665,  686,
							3607, 3609, 3610,
							5420, 5443, 5532,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							661,  662,  663,
							664,  665,  686,
							3607, 3609, 3610,
							5420, 5443, 5532,
						}
					},
				},
			},
			-- Rogue
			[259] = { -- Assassination
				talents = {
					{22337, 22338, 22339},
					{22331, 22332, 23022},
					{19239, 19240, 19241},
					{22340, 22122, 22123},
					{19245, 23037, 22115},
					{22343, 23015, 22344},
					{21186, 22133, 23174},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							141,  147,  830,
							3448, 3479, 3480,
							5405, 5408, 5517,
							5530, 5550,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							141,  147,  830,
							3448, 3479, 3480,
							5405, 5408, 5517,
							5530, 5550,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							141,  147,  830,
							3448, 3479, 3480,
							5405, 5408, 5517,
							5530, 5550,
						}
					},
				},
			},
			[260] = { -- Outlaw
				talents = {
					{22118, 22119, 22120},
					{23470, 19237, 19238},
					{19239, 19240, 19241},
					{22121, 22122, 22123},
					{23077, 22114, 22115},
					{21990, 23128, 19250},
					{22125, 23075, 23175},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							129,  135,  138,
							139,  145,  853,
							1208, 3421, 3483,
							3619, 5412, 5516,
							5549,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							129,  135,  138,
							139,  145,  853,
							1208, 3421, 3483,
							3619, 5412, 5516,
							5549,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							129,  135,  138,
							139,  145,  853,
							1208, 3421, 3483,
							3619, 5412, 5516,
							5549,
						}
					},
				},
			},
			[261] = { -- Subtlety
				talents = {
					{19233, 19234, 19235},
					{22331, 22332, 22333},
					{19239, 19240, 19241},
					{22128, 22122, 22123},
					{23078, 23036, 22115},
					{22335, 19249, 22336},
					{22132, 23183, 21188},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							136,  146,  153,
							846,  856, 1209,
							3447, 3462, 5406,
							5409, 5411, 5529,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							136,  146,  153,
							846,  856, 1209,
							3447, 3462, 5406,
							5409, 5411, 5529,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							136,  146,  153,
							846,  856, 1209,
							3447, 3462, 5406,
							5409, 5411, 5529,
						}
					},
				},
			},
			-- Priest
			[256] = { -- Discipline
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							98,  100,  109,
							111,  114,  117,
							123,  126,  855,
							1244, 5416, 5475,
							5480, 5483, 5487,
							5498,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							98,  100,  109,
							111,  114,  117,
							123,  126,  855,
							1244, 5416, 5475,
							5480, 5483, 5487,
							5498,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							98,  100,  109,
							111,  114,  117,
							123,  126,  855,
							1244, 5416, 5475,
							5480, 5483, 5487,
							5498,
						}
					},
				},
			},
			[257] = { -- Holy
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							101,  108,  112,
							115,  124,  127,
							1927, 5365, 5366,
							5476, 5478, 5479,
							5482, 5485, 5499,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							101,  108,  112,
							115,  124,  127,
							1927, 5365, 5366,
							5476, 5478, 5479,
							5482, 5485, 5499,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							101,  108,  112,
							115,  124,  127,
							1927, 5365, 5366,
							5476, 5478, 5479,
							5482, 5485, 5499,
						}
					},
				},
			},
			[258] = { -- Shadow
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							106,  113,  739,
							763, 5381, 5447,
							5474, 5477, 5481,
							5484, 5486, 5500,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							106,  113,  739,
							763, 5381, 5447,
							5474, 5477, 5481,
							5484, 5486, 5500,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							106,  113,  739,
							763, 5381, 5447,
							5474, 5477, 5481,
							5484, 5486, 5500,
						}
					},
				},
			},
			-- Death Knight
			[250] = { -- Blood
				talents = {
					{19165, 19166, 23454},
					{19218, 19219, 19220},
					{19221, 22134, 22135},
					{22013, 22014, 22015},
					{19227, 19226, 19228},
					{19230, 19231, 19232},
					{21207, 21208, 21209},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							204,  205,  206,
							607,  608,  609,
							841, 3441, 3511,
							5425, 5426,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							204,  205,  206,
							607,  608,  609,
							841, 3441, 3511,
							5425, 5426,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							204,  205,  206,
							607,  608,  609,
							841, 3441, 3511,
							5425, 5426,
						}
					},
				},
			},
			[251] = { -- Frost
				talents = {
					{22016, 22017, 22018},
					{22019, 22020, 22021},
					{22515, 22517, 22519},
					{22521, 22523, 22525},
					{22527, 22530, 23373},
					{22531, 22533, 22535},
					{22023, 22109, 22537},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							701,  702,  706,
							3439, 3512, 3743,
							5424, 5427, 5429,
							5435,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							701,  702,  706,
							3439, 3512, 3743,
							5424, 5427, 5429,
							5435,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							701,  702,  706,
							3439, 3512, 3743,
							5424, 5427, 5429,
							5435,
						}
					},
				},
			},
			[252] = { -- Unholy
				talents = {
					{22024, 22025, 22026},
					{22027, 22028, 22029},
					{22516, 22518, 22520},
					{22522, 22524, 22526},
					{22528, 22529, 23373},
					{22532, 22534, 22536},
					{22030, 22110, 22538},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							40,   41,  149,
							152, 3437, 3746,
							3747, 5423, 5428,
							5430, 5436,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							40,   41,  149,
							152, 3437, 3746,
							3747, 5423, 5428,
							5430, 5436,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							40,   41,  149,
							152, 3437, 3746,
							3747, 5423, 5428,
							5430, 5436,
						}
					},
				},
			},
			-- Shaman
			[262] = { -- Elemental
				talents = {
					{22356, 22357, 22358},
					{23108, 23460, 23190},
					{23162, 23163, 23164},
					{19271, 19272, 19273},
					{22144, 22172, 21966},
					{22145, 19266, 23111},
					{21198, 22153, 21675},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							727,  728,  730,
							3062, 3488, 3490,
							3491, 3620, 3621,
							5415, 5457, 5519,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							727,  728,  730,
							3062, 3488, 3490,
							3491, 3620, 3621,
							5415, 5457, 5519,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							727,  728,  730,
							3062, 3488, 3490,
							3491, 3620, 3621,
							5415, 5457, 5519,
						}
					},
				},
			},
			[263] = { -- Enhancement
				talents = {
					{22354, 22355, 22353},
					{22636, 23462, 23109},
					{23165, 19260, 23166},
					{23089, 23090, 22171},
					{22144, 22149, 21966},
					{21973, 22352, 22351},
					{21970, 22977, 21972},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							721,  722,  725,
							1944, 3487, 3489,
							3492, 3519, 3622,
							3623, 5414, 5438,
							5518, 5527,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							721,  722,  725,
							1944, 3487, 3489,
							3492, 3519, 3622,
							3623, 5414, 5438,
							5518, 5527,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							721,  722,  725,
							1944, 3487, 3489,
							3492, 3519, 3622,
							3623, 5414, 5438,
							5518, 5527,
						}
					},
				},
			},
			[264] = { -- Restoration
				talents = {
					{19262, 19263, 19264},
					{19259, 23461, 21963},
					{19275, 23110, 22127},
					{22152, 22322, 22323},
					{22144, 19269, 21966},
					{19265, 21971, 21968},
					{21969, 21199, 22359},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							707,  708,  712,
							714,  715, 1930,
							3520, 3755, 3756,
							5388, 5437, 5458,
							5528,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							707,  708,  712,
							714,  715, 1930,
							3520, 3755, 3756,
							5388, 5437, 5458,
							5528,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							707,  708,  712,
							714,  715, 1930,
							3520, 3755, 3756,
							5388, 5437, 5458,
							5528,
						}
					},
				},
			},
			-- Mage
			[62] = { -- Arcane
				talents = {
					{22458, 22461, 22464},
					{23072, 22443, 16025},
					{22444, 22445, 22447},
					{22453, 22467, 22470},
					{22907, 22448, 22471},
					{22455, 22449, 22474},
					{21630, 21144, 21145},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							61,  635,  637,
							3442, 3517, 3529,
							3531, 5397, 5488,
							5491, 5492,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							61,  635,  637,
							3442, 3517, 3529,
							3531, 5397, 5488,
							5491, 5492,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							61,  635,  637,
							3442, 3517, 3529,
							3531, 5397, 5488,
							5491, 5492,
						}
					},
				},
			},
			[63] = { -- Fire
				talents = {
					{22456, 22459, 22462},
					{23071, 22443, 23074},
					{22444, 22445, 22447},
					{22450, 22465, 22468},
					{22904, 22448, 22471},
					{22451, 23362, 22472},
					{21631, 22220, 21633},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							53,  644,  646,
							647,  648,  828,
							5389, 5489, 5493,
							5495,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							53,  644,  646,
							647,  648,  828,
							5389, 5489, 5493,
							5495,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							53,  644,  646,
							647,  648,  828,
							5389, 5489, 5493,
							5495,
						}
					},
				},
			},
			[64] = { -- Frost
				talents = {
					{22457, 22460, 22463},
					{22442, 22443, 23073},
					{22444, 22445, 22447},
					{22452, 22466, 22469},
					{22446, 22448, 22471},
					{22454, 23176, 22473},
					{21632, 22309, 21634},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							66,  632,  634,
							3443, 3532, 5390,
							5490, 5494, 5496,
							5497,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							66,  632,  634,
							3443, 3532, 5390,
							5490, 5494, 5496,
							5497,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							66,  632,  634,
							3443, 3532, 5390,
							5490, 5494, 5496,
							5497,
						}
					},
				},
			},
			-- Warlock
			[265] = { -- Affliction
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							11,   12,   15,
							16,   17,   18,
							19,   20, 5379,
							5386, 5392, 5506,
							5543, 5546,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							11,   12,   15,
							16,   17,   18,
							19,   20, 5379,
							5386, 5392, 5506,
							5543, 5546,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							11,   12,   15,
							16,   17,   18,
							19,   20, 5379,
							5386, 5392, 5506,
							5543, 5546,
						}
					},
				},
			},
			[266] = { -- Demonology
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							156,  158,  162,
							165, 1213, 3505,
							3506, 3624, 3625,
							3626, 5394, 5400,
							5505, 5545,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							156,  158,  162,
							165, 1213, 3505,
							3506, 3624, 3625,
							3626, 5394, 5400,
							5505, 5545,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							156,  158,  162,
							165, 1213, 3505,
							3506, 3624, 3625,
							3626, 5394, 5400,
							5505, 5545,
						}
					},
				},
			},
			[267] = { -- Destruction
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							157,  159,  164,
							3502, 3504, 3508,
							3509, 3510, 5382,
							5393, 5401,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							157,  159,  164,
							3502, 3504, 3508,
							3509, 3510, 5382,
							5393, 5401,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							157,  159,  164,
							3502, 3504, 3508,
							3509, 3510, 5382,
							5393, 5401,
						}
					},
				},
			},
			-- Monk
			[268] = { -- Brewmaster
				talents = {
					{23106, 19820, 20185},
					{19304, 19818, 19302},
					{22099, 22097, 19992},
					{19993, 19994, 19995},
					{20174, 23363, 20175},
					{19819, 20184, 22103},
					{22106, 22104, 22108},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							666,  667,  668,
							669,  670,  671,
							672,  673,  765,
							843, 1958, 5417,
							5538, 5541, 5542,
							5552,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							666,  667,  668,
							669,  670,  671,
							672,  673,  765,
							843, 1958, 5417,
							5538, 5541, 5542,
							5552,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							666,  667,  668,
							669,  670,  671,
							672,  673,  765,
							843, 1958, 5417,
							5538, 5541, 5542,
							5552,
						}
					},
				},
			},
			[270] = { -- Mistweaver
				talents = {
					{19823, 19820, 20185},
					{19304, 19818, 19302},
					{22168, 22167, 22166},
					{19993, 22219, 19995},
					{23371, 20173, 20175},
					{23107, 22101, 0},
					{22218, 22169, 22170},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							70,  678,  679,
							680,  682,  683,
							1928, 3732, 5395,
							5398, 5402, 5508,
							5539, 5551,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							70,  678,  679,
							680,  682,  683,
							1928, 3732, 5395,
							5398, 5402, 5508,
							5539, 5551,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							70,  678,  679,
							680,  682,  683,
							1928, 3732, 5395,
							5398, 5402, 5508,
							5539, 5551,
						}
					},
				},
			},
			[269] = { -- Windwalker
				talents = {
					{23106, 19820, 20185},
					{19304, 19818, 19302},
					{22098, 19771, 22096},
					{19993, 23364, 19995},
					{23258, 20173, 20175},
					{22093, 23122, 22102},
					{22107, 22105, 21191},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							77,  675,  852,
							3050, 3052, 3734,
							3737, 3744, 3745,
							5448, 5540,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							77,  675,  852,
							3050, 3052, 3734,
							3737, 3744, 3745,
							5448, 5540,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							77,  675,  852,
							3050, 3052, 3734,
							3737, 3744, 3745,
							5448, 5540,
						}
					},
				},
			},
			-- Druid
			[102] = { -- Balance
				talents = {
					{22385, 22386, 22387},
					{19283, 18570, 18571},
					{22155, 22157, 22159},
					{21778, 18576, 18577},
					{18580, 21706, 21702},
					{22389, 21712, 22165},
					{21648, 21193, 21655},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							180,  182,  184,
							185,  822,  834,
							836, 3058, 3728,
							3731, 5383, 5407,
							5503, 5515, 5526,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							180,  182,  184,
							185,  822,  834,
							836, 3058, 3728,
							3731, 5383, 5407,
							5503, 5515, 5526,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							180,  182,  184,
							185,  822,  834,
							836, 3058, 3728,
							3731, 5383, 5407,
							5503, 5515, 5526,
						}
					},
				},
			},
			[103] = { -- Feral
				talents = {
					{22363, 22364, 22365},
					{19283, 18570, 18571},
					{22163, 22158, 22159},
					{21778, 18576, 18577},
					{21708, 18579, 21704},
					{21714, 21711, 22370},
					{21646, 21649, 21653},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							201,  203,  601,
							602,  611,  612,
							620,  820, 3053,
							3751, 5384, 5525,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							201,  203,  601,
							602,  611,  612,
							620,  820, 3053,
							3751, 5384, 5525,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							201,  203,  601,
							602,  611,  612,
							620,  820, 3053,
							3751, 5384, 5525,
						}
					},
				},
			},
			[104] = { -- Guardian
				talents = {
					{22419, 22418, 22420},
					{19283, 18570, 18571},
					{22163, 22156, 22159},
					{21778, 18576, 18577},
					{21709, 21707, 22388},
					{22423, 21713, 22390},
					{22426, 22427, 22425},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							49,   50,   51,
							52,  192,  193,
							194,  195,  196,
							197,  842, 1237,
							3750, 5410, 5524,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							49,   50,   51,
							52,  192,  193,
							194,  195,  196,
							197,  842, 1237,
							3750, 5410, 5524,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							49,   50,   51,
							52,  192,  193,
							194,  195,  196,
							197,  842, 1237,
							3750, 5410, 5524,
						}
					},
				},
			},
			[105] = { -- Restoration
				talents = {
					{18569, 18574, 18572},
					{19283, 18570, 18571},
					{22366, 22367, 22160},
					{21778, 18576, 18577},
					{21710, 21705, 22421},
					{21716, 18585, 22422},
					{22403, 21651, 22404},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							59,  691,  692,
							697,  700,  835,
							838, 1215, 3048,
							5387, 5504, 5514,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							59,  691,  692,
							697,  700,  835,
							838, 1215, 3048,
							5387, 5504, 5514,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							59,  691,  692,
							697,  700,  835,
							838, 1215, 3048,
							5387, 5504, 5514,
						}
					},
				},
			},
			-- Demon Hunter
			[577] = { -- Havoc
				talents = {
					{21854, 22493, 22416},
					{21857, 22765, 22799},
					{22909, 22494, 21862},
					{21863, 21864, 21865},
					{21866, 21867, 21868},
					{21869, 21870, 22767},
					{21900, 21901, 22547},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							805,  806,  809,
							810,  811,  812,
							813, 1204, 1206,
							1218, 5433, 5523,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							805,  806,  809,
							810,  811,  812,
							813, 1204, 1206,
							1218, 5433, 5523,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							805,  806,  809,
							810,  811,  812,
							813, 1204, 1206,
							1218, 5433, 5523,
						}
					},
				},
			},
			[581] = { -- Vengeance
				talents = {
					{22502, 22503, 22504},
					{22505, 22766, 22507},
					{22324, 22541, 22540},
					{22508, 22509, 22770},
					{22546, 22510, 22511},
					{22512, 22513, 22768},
					{22543, 23464, 21902},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							814,  815,  816,
							819, 1220, 1948,
							3423, 3429, 3430,
							3727, 5434, 5439,
							5520, 5521, 5522,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							814,  815,  816,
							819, 1220, 1948,
							3423, 3429, 3430,
							3727, 5434, 5439,
							5520, 5521, 5522,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							814,  815,  816,
							819, 1220, 1948,
							3423, 3429, 3430,
							3727, 5434, 5439,
							5520, 5521, 5522,
						}
					},
				},
			},
			-- Evoker
			[1467] = { -- Devastation
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							5456, 5460, 5462,
							5464, 5466, 5467,
							5469, 5471, 5473,
							5509,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							5456, 5460, 5462,
							5464, 5466, 5467,
							5469, 5471, 5473,
							5509,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							5456, 5460, 5462,
							5464, 5466, 5467,
							5469, 5471, 5473,
							5509,
						}
					},
				},
			},
			[1468] = { -- Preservation
				talents = {
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
					{0, 0, 0},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							5454, 5455, 5459,
							5461, 5463, 5465,
							5468, 5470, 5472,
							5502,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							5454, 5455, 5459,
							5461, 5463, 5465,
							5468, 5470, 5472,
							5502,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							5454, 5455, 5459,
							5461, 5463, 5465,
							5468, 5470, 5472,
							5502,
						}
					},
				},
			},
		}
	else
		specInfo = {
			version = 4,

			-- Warrior
			[71] = { -- Arms
				talents = {
					{22624, 22360, 22371},
					{19676, 22372, 22789},
					{22380, 22489, 19138},
					{15757, 22627, 22628},
					{22392, 22391, 22362},
					{22394, 22397, 22399},
					{21204, 22407, 21667},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							28,   29,   31,
							32,   33,   34,
							3522, 3534, 5372,
							5376,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							28,   29,   31,
							32,   33,   34,
							3522, 3534, 5372,
							5376,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							28,   29,   31,
							32,   33,   34,
							3522, 3534, 5372,
							5376,
						}
					},
				},
			},
			[72] = { -- Fury
				talents = {
					{22632, 22633, 22491},
					{19676, 22625, 23093},
					{22379, 22381, 23372},
					{23097, 22627, 22382},
					{22383, 22393, 19140},
					{22396, 22398, 22400},
					{22405, 22402, 16037},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							25,  166,  170,
							172,  177,  179,
							3528, 3533, 3735,
							5373, 5431,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							25,  166,  170,
							172,  177,  179,
							3528, 3533, 3735,
							5373, 5431,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							25,  166,  170,
							172,  177,  179,
							3528, 3533, 3735,
							5373, 5431,
						}
					},
				},
			},
			[73] = { -- Protection
				talents = {
					{15760, 15759, 15774},
					{19676, 22629, 22409},
					{22378, 22626, 23260},
					{23096, 22627, 22488},
					{22384, 22631, 22800},
					{22395, 22544, 22401},
					{23455, 22406, 23099},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							24,  167,  168,
							171,  173,  175,
							178,  831,  833,
							845, 5374, 5432,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							24,  167,  168,
							171,  173,  175,
							178,  831,  833,
							845, 5374, 5432,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							24,  167,  168,
							171,  173,  175,
							178,  831,  833,
							845, 5374, 5432,
						}
					},
				},
			},
			-- Paladin
			[65] = { -- Holy
				talents = {
					{17565, 17567, 17569},
					{22176, 17575, 17577},
					{22179, 22180, 21811},
					{22433, 22434, 17593},
					{17597, 17599, 17601},
					{23191, 22190, 22484},
					{21201, 21671, 21203},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							82,   85,   86,
							87,   88,  640,
							642,  689,  859,
							3618, 5421,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							82,   85,   86,
							87,   88,  640,
							642,  689,  859,
							3618, 5421,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							82,   85,   86,
							87,   88,  640,
							642,  689,  859,
							3618, 5421,
						}
					},
				},
			},
			[66] = { -- Protection
				talents = {
					{22428, 22558, 23469},
					{22431, 22604, 23468},
					{22179, 22180, 21811},
					{22433, 22434, 22435},
					{17597, 17599, 17601},
					{22189, 22438, 23087},
					{23457, 21202, 22645},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							90,   91,   92,
							93,   94,   97,
							844,  860,  861,
							3474, 3475,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							90,   91,   92,
							93,   94,   97,
							844,  860,  861,
							3474, 3475,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							90,   91,   92,
							93,   94,   97,
							844,  860,  861,
							3474, 3475,
						}
					},
				},
			},
			[70] = { -- Retribution
				talents = {
					{22590, 22557, 23467},
					{22319, 22592, 23466},
					{22179, 22180, 21811},
					{22433, 22434, 22183},
					{17597, 17599, 17601},
					{23167, 22483, 23086},
					{23456, 22215, 22634},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							81,  641,  751,
							752,  753,  754,
							755,  756,  757,
							858, 5422,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							81,  641,  751,
							752,  753,  754,
							755,  756,  757,
							858, 5422,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							81,  641,  751,
							752,  753,  754,
							755,  756,  757,
							858, 5422,
						}
					},
				},
			},
			-- Hunter
			[253] = { -- Beast Mastery
				talents = {
					{22291, 22280, 22282},
					{22500, 22266, 22290},
					{19347, 19348, 23100},
					{22441, 22347, 22269},
					{22268, 22276, 22499},
					{19357, 22002, 23044},
					{22273, 21986, 22295},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							693,  824,  825,
							1214, 3599, 3600,
							3604, 3605, 3612,
							3730, 5418, 5441,
							5444,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							693,  824,  825,
							1214, 3599, 3600,
							3604, 3605, 3612,
							3730, 5418, 5441,
							5444,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							693,  824,  825,
							1214, 3599, 3600,
							3604, 3605, 3612,
							3730, 5418, 5441,
							5444,
						}
					},
				},
			},
			[254] = { -- Marksmanship
				talents = {
					{22279, 22501, 22289},
					{22495, 22497, 22498},
					{19347, 19348, 23100},
					{22267, 22286, 21998},
					{22268, 22276, 23463},
					{23063, 23104, 22287},
					{22274, 22308, 22288},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							649,  651,  653,
							656,  657,  658,
							659,  660, 3614,
							3729, 5419, 5440,
							5442,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							649,  651,  653,
							656,  657,  658,
							659,  660, 3614,
							3729, 5419, 5440,
							5442,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							649,  651,  653,
							656,  657,  658,
							659,  660, 3614,
							3729, 5419, 5440,
							5442,
						}
					},
				},
			},
			[255] = { -- Survival
				talents = {
					{22275, 22283, 22296},
					{21997, 22769, 22297},
					{19347, 19348, 23100},
					{22277, 19361, 22299},
					{22268, 22276, 22499},
					{22300, 22278, 22271},
					{22272, 22301, 23105},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							661,  662,  663,
							664,  665,  686,
							3606, 3607, 3609,
							3610, 5420, 5443,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							661,  662,  663,
							664,  665,  686,
							3606, 3607, 3609,
							3610, 5420, 5443,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							661,  662,  663,
							664,  665,  686,
							3606, 3607, 3609,
							3610, 5420, 5443,
						}
					},
				},
			},
			-- Rogue
			[259] = { -- Assassination
				talents = {
					{22337, 22338, 22339},
					{22331, 22332, 23022},
					{19239, 19240, 19241},
					{22340, 22122, 22123},
					{19245, 23037, 22115},
					{22343, 23015, 22344},
					{21186, 22133, 23174},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							130,  141,  144,
							147,  830, 3448,
							3479, 3480, 5405,
							5408,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							130,  141,  144,
							147,  830, 3448,
							3479, 3480, 5405,
							5408,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							130,  141,  144,
							147,  830, 3448,
							3479, 3480, 5405,
							5408,
						}
					},
				},
			},
			[260] = { -- Outlaw
				talents = {
					{22118, 22119, 22120},
					{23470, 19237, 19238},
					{19239, 19240, 19241},
					{22121, 22122, 22123},
					{23077, 22114, 22115},
					{21990, 23128, 19250},
					{22125, 23075, 23175},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							129,  135,  138,
							139,  145,  853,
							1208, 3421, 3483,
							3619, 5412, 5413,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							129,  135,  138,
							139,  145,  853,
							1208, 3421, 3483,
							3619, 5412, 5413,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							129,  135,  138,
							139,  145,  853,
							1208, 3421, 3483,
							3619, 5412, 5413,
						}
					},
				},
			},
			[261] = { -- Subtlety
				talents = {
					{19233, 19234, 19235},
					{22331, 22332, 22333},
					{19239, 19240, 19241},
					{22128, 22122, 22123},
					{23078, 23036, 22115},
					{22335, 19249, 22336},
					{22132, 23183, 21188},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							136,  146,  153,
							846,  856, 1209,
							3447, 3462, 5406,
							5409, 5411,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							136,  146,  153,
							846,  856, 1209,
							3447, 3462, 5406,
							5409, 5411,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							136,  146,  153,
							846,  856, 1209,
							3447, 3462, 5406,
							5409, 5411,
						}
					},
				},
			},
			-- Priest
			[256] = { -- Discipline
				talents = {
					{19752, 22313, 22329},
					{22315, 22316, 19758},
					{22440, 22094, 19755},
					{19759, 19769, 19761},
					{22330, 19765, 19766},
					{22161, 19760, 19763},
					{21183, 21184, 22976},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							98,  100,  109,
							111,  114,  117,
							123,  126,  855,
							1244, 5403, 5416,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							98,  100,  109,
							111,  114,  117,
							123,  126,  855,
							1244, 5403, 5416,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							98,  100,  109,
							111,  114,  117,
							123,  126,  855,
							1244, 5403, 5416,
						}
					},
				},
			},
			[257] = { -- Holy
				talents = {
					{22312, 19753, 19754},
					{22325, 22326, 19758},
					{22487, 22095, 22562},
					{21750, 21977, 19761},
					{19764, 22327, 21754},
					{19767, 19760, 19763},
					{21636, 21644, 23145},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							101,  108,  112,
							115,  118,  124,
							127, 1242, 1927,
							5365, 5366, 5404,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							101,  108,  112,
							115,  118,  124,
							127, 1242, 1927,
							5365, 5366, 5404,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							101,  108,  112,
							115,  118,  124,
							127, 1242, 1927,
							5365, 5366, 5404,
						}
					},
				},
			},
			[258] = { -- Shadow
				talents = {
					{22328, 22136, 22314},
					{22315, 23374, 21976},
					{23125, 23126, 23127},
					{23137, 23375, 21752},
					{22310, 22311, 21755},
					{21718, 21719, 21720},
					{21637, 21978, 21979},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							102,  106,  113,
							128,  739,  763,
							3753, 5380, 5381,
							5446, 5447,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							102,  106,  113,
							128,  739,  763,
							3753, 5380, 5381,
							5446, 5447,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							102,  106,  113,
							128,  739,  763,
							3753, 5380, 5381,
							5446, 5447,
						}
					},
				},
			},
			-- Death Knight
			[250] = { -- Blood
				talents = {
					{19165, 19166, 23454},
					{19218, 19219, 19220},
					{19221, 22134, 22135},
					{22013, 22014, 22015},
					{19227, 19226, 19228},
					{19230, 19231, 19232},
					{21207, 21208, 21209},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							204,  205,  206,
							607,  608,  609,
							841, 3441, 3511,
							5425, 5426,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							204,  205,  206,
							607,  608,  609,
							841, 3441, 3511,
							5425, 5426,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							204,  205,  206,
							607,  608,  609,
							841, 3441, 3511,
							5425, 5426,
						}
					},
				},
			},
			[251] = { -- Frost
				talents = {
					{22016, 22017, 22018},
					{22019, 22020, 22021},
					{22515, 22517, 22519},
					{22521, 22523, 22525},
					{22527, 22530, 23373},
					{22531, 22533, 22535},
					{22023, 22109, 22537},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							701,  702,  706,
							3439, 3512, 3743,
							5424, 5427, 5429,
							5435,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							701,  702,  706,
							3439, 3512, 3743,
							5424, 5427, 5429,
							5435,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							701,  702,  706,
							3439, 3512, 3743,
							5424, 5427, 5429,
							5435,
						}
					},
				},
			},
			[252] = { -- Unholy
				talents = {
					{22024, 22025, 22026},
					{22027, 22028, 22029},
					{22516, 22518, 22520},
					{22522, 22524, 22526},
					{22528, 22529, 23373},
					{22532, 22534, 22536},
					{22030, 22110, 22538},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							40,   41,  149,
							152, 3437, 3746,
							3747, 5423, 5428,
							5430, 5436,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							40,   41,  149,
							152, 3437, 3746,
							3747, 5423, 5428,
							5430, 5436,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							40,   41,  149,
							152, 3437, 3746,
							3747, 5423, 5428,
							5430, 5436,
						}
					},
				},
			},
			-- Shaman
			[262] = { -- Elemental
				talents = {
					{22356, 22357, 22358},
					{23108, 23460, 23190},
					{23162, 23163, 23164},
					{19271, 19272, 19273},
					{22144, 22172, 21966},
					{22145, 19266, 23111},
					{21198, 22153, 21675},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							727,  728,  730,
							731, 3062, 3488,
							3490, 3491, 3620,
							3621, 5415,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							727,  728,  730,
							731, 3062, 3488,
							3490, 3491, 3620,
							3621, 5415,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							727,  728,  730,
							731, 3062, 3488,
							3490, 3491, 3620,
							3621, 5415,
						}
					},
				},
			},
			[263] = { -- Enhancement
				talents = {
					{22354, 22355, 22353},
					{22636, 23462, 23109},
					{23165, 19260, 23166},
					{23089, 23090, 22171},
					{22144, 22149, 21966},
					{21973, 22352, 22351},
					{21970, 22977, 21972},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							721,  722,  725,
							1944, 3487, 3489,
							3492, 3519, 3622,
							3623, 5414, 5438,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							721,  722,  725,
							1944, 3487, 3489,
							3492, 3519, 3622,
							3623, 5414, 5438,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							721,  722,  725,
							1944, 3487, 3489,
							3492, 3519, 3622,
							3623, 5414, 5438,
						}
					},
				},
			},
			[264] = { -- Restoration
				talents = {
					{19262, 19263, 19264},
					{19259, 23461, 21963},
					{19275, 23110, 22127},
					{22152, 22322, 22323},
					{22144, 19269, 21966},
					{19265, 21971, 21968},
					{21969, 21199, 22359},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							707,  708,  712,
							713,  714,  715,
							1930, 3520, 3755,
							3756, 5388, 5437,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							707,  708,  712,
							713,  714,  715,
							1930, 3520, 3755,
							3756, 5388, 5437,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							707,  708,  712,
							713,  714,  715,
							1930, 3520, 3755,
							3756, 5388, 5437,
						}
					},
				},
			},
			-- Mage
			[62] = { -- Arcane
				talents = {
					{22458, 22461, 22464},
					{23072, 22443, 16025},
					{22444, 22445, 22447},
					{22453, 22467, 22470},
					{22907, 22448, 22471},
					{22455, 22449, 22474},
					{21630, 21144, 21145},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							61,   62,  635,
							637, 3442, 3517,
							3529, 3531, 5397,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							61,   62,  635,
							637, 3442, 3517,
							3529, 3531, 5397,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							61,   62,  635,
							637, 3442, 3517,
							3529, 3531, 5397,
						}
					},
				},
			},
			[63] = { -- Fire
				talents = {
					{22456, 22459, 22462},
					{23071, 22443, 23074},
					{22444, 22445, 22447},
					{22450, 22465, 22468},
					{22904, 22448, 22471},
					{22451, 23362, 22472},
					{21631, 22220, 21633},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							53,  643,  644,
							645,  646,  647,
							648,  828, 5389,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							53,  643,  644,
							645,  646,  647,
							648,  828, 5389,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							53,  643,  644,
							645,  646,  647,
							648,  828, 5389,
						}
					},
				},
			},
			[64] = { -- Frost
				talents = {
					{22457, 22460, 22463},
					{22442, 22443, 23073},
					{22444, 22445, 22447},
					{22452, 22466, 22469},
					{22446, 22448, 22471},
					{22454, 23176, 22473},
					{21632, 22309, 21634},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							66,   67,   68,
							632,  633,  634,
							3443, 3532, 5390,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							66,   67,   68,
							632,  633,  634,
							3443, 3532, 5390,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							66,   67,   68,
							632,  633,  634,
							3443, 3532, 5390,
						}
					},
				},
			},
			-- Warlock
			[265] = { -- Affliction
				talents = {
					{22039, 23140, 23141},
					{22044, 21180, 22089},
					{19280, 19285, 19286},
					{19279, 19292, 22046},
					{22047, 19291, 23465},
					{23139, 23159, 19295},
					{19284, 19281, 19293},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							11,   12,   15,
							16,   17,   18,
							19,   20, 3740,
							5370, 5379, 5386,
							5392,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							11,   12,   15,
							16,   17,   18,
							19,   20, 3740,
							5370, 5379, 5386,
							5392,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							11,   12,   15,
							16,   17,   18,
							19,   20, 3740,
							5370, 5379, 5386,
							5392,
						}
					},
				},
			},
			[266] = { -- Demonology
				talents = {
					{19290, 22048, 23138},
					{22045, 21694, 23158},
					{19280, 19285, 19286},
					{22477, 22042, 23160},
					{22047, 19291, 23465},
					{23147, 23146, 21717},
					{23161, 22479, 23091},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							156,  158,  162,
							165, 1213, 3505,
							3506, 3507, 3624,
							3625, 3626, 5394,
							5400,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							156,  158,  162,
							165, 1213, 3505,
							3506, 3507, 3624,
							3625, 3626, 5394,
							5400,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							156,  158,  162,
							165, 1213, 3505,
							3506, 3507, 3624,
							3625, 3626, 5394,
							5400,
						}
					},
				},
			},
			[267] = { -- Destruction
				talents = {
					{22038, 22090, 22040},
					{23148, 21695, 23157},
					{19280, 19285, 19286},
					{22480, 22043, 23143},
					{22047, 19291, 23465},
					{23155, 23156, 19295},
					{19284, 23144, 23092},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							157,  159,  164,
							3502, 3504, 3508,
							3509, 3510, 5382,
							5393, 5401,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							157,  159,  164,
							3502, 3504, 3508,
							3509, 3510, 5382,
							5393, 5401,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							157,  159,  164,
							3502, 3504, 3508,
							3509, 3510, 5382,
							5393, 5401,
						}
					},
				},
			},
			-- Monk
			[268] = { -- Brewmaster
				talents = {
					{23106, 19820, 20185},
					{19304, 19818, 19302},
					{22099, 22097, 19992},
					{19993, 19994, 19995},
					{20174, 23363, 20175},
					{19819, 20184, 22103},
					{22106, 22104, 22108},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							666,  667,  668,
							669,  670,  671,
							672,  673,  765,
							843, 1958, 5417,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							666,  667,  668,
							669,  670,  671,
							672,  673,  765,
							843, 1958, 5417,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							666,  667,  668,
							669,  670,  671,
							672,  673,  765,
							843, 1958, 5417,
						}
					},
				},
			},
			[270] = { -- Mistweaver
				talents = {
					{19823, 19820, 20185},
					{19304, 19818, 19302},
					{22168, 22167, 22166},
					{19993, 22219, 19995},
					{23371, 20173, 20175},
					{23107, 22101, 22214},
					{22218, 22169, 22170},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							70,  678,  679,
							680,  682,  683,
							1928, 3732, 5395,
							5398, 5402,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							70,  678,  679,
							680,  682,  683,
							1928, 3732, 5395,
							5398, 5402,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							70,  678,  679,
							680,  682,  683,
							1928, 3732, 5395,
							5398, 5402,
						}
					},
				},
			},
			[269] = { -- Windwalker
				talents = {
					{23106, 19820, 20185},
					{19304, 19818, 19302},
					{22098, 19771, 22096},
					{19993, 23364, 19995},
					{23258, 20173, 20175},
					{22093, 23122, 22102},
					{22107, 22105, 21191},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							77,  675,  852,
							3050, 3052, 3734,
							3737, 3744, 3745,
							5448,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							77,  675,  852,
							3050, 3052, 3734,
							3737, 3744, 3745,
							5448,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							77,  675,  852,
							3050, 3052, 3734,
							3737, 3744, 3745,
							5448,
						}
					},
				},
			},
			-- Druid
			[102] = { -- Balance
				talents = {
					{22385, 22386, 22387},
					{19283, 18570, 18571},
					{22155, 22157, 22159},
					{21778, 18576, 18577},
					{18580, 21706, 21702},
					{22389, 21712, 22165},
					{21648, 21193, 21655},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							180,  182,  184,
							185,  822,  834,
							836, 3058, 3728,
							3731, 5383, 5407,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							180,  182,  184,
							185,  822,  834,
							836, 3058, 3728,
							3731, 5383, 5407,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							180,  182,  184,
							185,  822,  834,
							836, 3058, 3728,
							3731, 5383, 5407,
						}
					},
				},
			},
			[103] = { -- Feral
				talents = {
					{22363, 22364, 22365},
					{19283, 18570, 18571},
					{22163, 22158, 22159},
					{21778, 18576, 18577},
					{21708, 18579, 21704},
					{21714, 21711, 22370},
					{21646, 21649, 21653},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							201,  203,  601,
							602,  611,  612,
							620,  820, 3053,
							3751, 5384,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							201,  203,  601,
							602,  611,  612,
							620,  820, 3053,
							3751, 5384,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							201,  203,  601,
							602,  611,  612,
							620,  820, 3053,
							3751, 5384,
						}
					},
				},
			},
			[104] = { -- Guardian
				talents = {
					{22419, 22418, 22420},
					{19283, 18570, 18571},
					{22163, 22156, 22159},
					{21778, 18576, 18577},
					{21709, 21707, 22388},
					{22423, 21713, 22390},
					{22426, 22427, 22425},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							49,   50,   51,
							52,  192,  193,
							194,  195,  196,
							197,  842, 1237,
							3750, 5410,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							49,   50,   51,
							52,  192,  193,
							194,  195,  196,
							197,  842, 1237,
							3750, 5410,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							49,   50,   51,
							52,  192,  193,
							194,  195,  196,
							197,  842, 1237,
							3750, 5410,
						}
					},
				},
			},
			[105] = { -- Restoration
				talents = {
					{18569, 18574, 18572},
					{19283, 18570, 18571},
					{22366, 22367, 22160},
					{21778, 18576, 18577},
					{21710, 21705, 22421},
					{21716, 18585, 22422},
					{22403, 21651, 22404},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							59,  691,  692,
							697,  700,  835,
							838, 1215, 3048,
							3752, 5387,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							59,  691,  692,
							697,  700,  835,
							838, 1215, 3048,
							3752, 5387,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							59,  691,  692,
							697,  700,  835,
							838, 1215, 3048,
							3752, 5387,
						}
					},
				},
			},
			-- Demon Hunter
			[577] = { -- Havoc
				talents = {
					{21854, 22493, 22416},
					{21857, 22765, 22799},
					{22909, 22494, 21862},
					{21863, 21864, 21865},
					{21866, 21867, 21868},
					{21869, 21870, 22767},
					{21900, 21901, 22547},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							805,  806,  809,
							810,  811,  812,
							813, 1204, 1206,
							1218, 5433, 5445,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							805,  806,  809,
							810,  811,  812,
							813, 1204, 1206,
							1218, 5433, 5445,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							805,  806,  809,
							810,  811,  812,
							813, 1204, 1206,
							1218, 5433, 5445,
						}
					},
				},
			},
			[581] = { -- Vengeance
				talents = {
					{22502, 22503, 22504},
					{22505, 22766, 22507},
					{22324, 22541, 22540},
					{22508, 22509, 22770},
					{22546, 22510, 22511},
					{22512, 22513, 22768},
					{22543, 23464, 21902},
				},
				pvptalentslots = {
					{
						level = 20,
						availableTalentIDs = {
							814,  815,  816,
							819, 1220, 1948,
							3423, 3429, 3430,
							3727, 5434, 5439,
						}
					},
					{
						level = 30,
						availableTalentIDs = {
							814,  815,  816,
							819, 1220, 1948,
							3423, 3429, 3430,
							3727, 5434, 5439,
						}
					},
					{
						level = 40,
						availableTalentIDs = {
							814,  815,  816,
							819, 1220, 1948,
							3423, 3429, 3430,
							3727, 5434, 5439,
						}
					},
				},
			},
		}
	end

	if type(specInfo.version) ~= "number" then
		error("MISSING SPEC INFO VERSION NUMBER")
	end
	
	function GetSpecInfoVersion()
		return specInfo.version
	end
	function VerifyTalentForSpec(specID, talentID)
		if specInfo[specID] then
			for tier,talents in ipairs(specInfo[specID].talents) do
				for column,talent in ipairs(talents) do
					if talent == talentID then
						return tier, column
					end
				end
			end
		end
	end
	function VerifyPvPTalentForSpec(specID, talentID)
		if specInfo[specID] then
			for _,slot in ipairs(specInfo[specID].pvptalentslots) do
				for _,talent in ipairs(slot.availableTalentIDs) do
					if talent == talentID then
						return true
					end
				end
			end
		end
	end
	function GetTalentInfoForSpecID(specID, tier, column)
		for specIndex=1,GetNumSpecializations() do
			local playerSpecID = GetSpecializationInfo(specIndex);
			if playerSpecID == specID then
				return GetTalentInfoBySpecialization(specIndex, tier, column);
			end
		end

		if BtWLoadoutsSpecInfo[specID] then
			return GetTalentInfoByID(BtWLoadoutsSpecInfo[specID].talents[tier][column]);
		end

		if specInfo[specID] then
			return GetTalentInfoByID(specInfo[specID].talents[tier][column]);
		end
	end
	function GetPvpTalentSlotInfoForSpecID(specID, index)
		local playerSpecID = GetSpecializationInfo(GetSpecialization());
		if playerSpecID == specID then
			local slotInfo = GetPvpTalentSlotInfo(index);
			return slotInfo
		end

		if BtWLoadoutsSpecInfo[specID] and BtWLoadoutsSpecInfo[specID].pvptalentslots and BtWLoadoutsSpecInfo[specID].pvptalentslots[index] then
			return BtWLoadoutsSpecInfo[specID].pvptalentslots[index];
		end

		if specInfo[specID] and specInfo[specID].pvptalentslots and specInfo[specID].pvptalentslots[index] then
			return specInfo[specID].pvptalentslots[index];
		end
	end
	Internal.GetSpecInfoVersion = GetSpecInfoVersion
	Internal.VerifyTalentForSpec = VerifyTalentForSpec
	Internal.VerifyPvPTalentForSpec = VerifyPvPTalentForSpec
	Internal.GetTalentInfoForSpecID = GetTalentInfoForSpecID
	Internal.GetPvpTalentSlotInfoForSpecID = GetPvpTalentSlotInfoForSpecID
end
local GetEssenceInfoByID, GetEssenceInfoForRole;
do
	local essenceInfo = {
		nil, -- [1]
		{
			["ID"] = 2,
			["name"] = "Azeroth's Undying Gift",
			["icon"] = 2967107,
		}, -- [2]
		{
			["ID"] = 3,
			["name"] = "Sphere of Suppression",
			["icon"] = 2065602,
		}, -- [3]
		{
			["ID"] = 4,
			["name"] = "Worldvein Resonance",
			["icon"] = 1830317,
		}, -- [4]
		{
			["ID"] = 5,
			["name"] = "Essence of the Focusing Iris",
			["icon"] = 2967111,
		}, -- [5]
		{
			["ID"] = 6,
			["name"] = "Purification Protocol",
			["icon"] = 2967103,
		}, -- [6]
		{
			["ID"] = 7,
			["name"] = "Anima of Life and Death",
			["icon"] = 2967105,
		}, -- [7]
		nil, -- [8]
		nil, -- [9]
		nil, -- [10]
		nil, -- [11]
		{
			["ID"] = 12,
			["name"] = "The Crucible of Flame",
			["icon"] = 3015740,
		}, -- [12]
		{
			["ID"] = 13,
			["name"] = "Nullification Dynamo",
			["icon"] = 3015741,
		}, -- [13]
		{
			["ID"] = 14,
			["name"] = "Condensed Life-Force",
			["icon"] = 2967113,
		}, -- [14]
		{
			["ID"] = 15,
			["name"] = "Ripple in Space",
			["icon"] = 2967109,
		}, -- [15]
		{
			["ID"] = 16,
			["name"] = "Unwavering Ward",
			["icon"] = 3193842,
		}, -- [16]
		{
			["ID"] = 17,
			["name"] = "The Ever-Rising Tide",
			["icon"] = 2967108,
		}, -- [17]
		{
			["ID"] = 18,
			["name"] = "Artifice of Time",
			["icon"] = 2967112,
		}, -- [18]
		{
			["ID"] = 19,
			["name"] = "The Well of Existence",
			["icon"] = 516796,
		}, -- [19]
		{
			["ID"] = 20,
			["name"] = "Life-Binder's Invocation",
			["icon"] = 2967106,
		}, -- [20]
		{
			["ID"] = 21,
			["name"] = "Vitality Conduit",
			["icon"] = 2967100,
		}, -- [21]
		{
			["ID"] = 22,
			["name"] = "Vision of Perfection",
			["icon"] = 3015743,
		}, -- [22]
		{
			["ID"] = 23,
			["name"] = "Blood of the Enemy",
			["icon"] = 2032580,
		}, -- [23]
		{
			["ID"] = 24,
			["name"] = "Spirit of Preservation",
			["icon"] = 2967101,
		}, -- [24]
		{
			["ID"] = 25,
			["name"] = "Aegis of the Deep",
			["icon"] = 2967110,
		}, -- [25]
		nil, -- [26]
		{
			["ID"] = 27,
			["name"] = "Memory of Lucid Dreams",
			["icon"] = 2967104,
		}, -- [27]
		{
			["ID"] = 28,
			["name"] = "The Unbound Force",
			["icon"] = 2967102,
		}, -- [28]
		nil, -- [29]
		nil, -- [30]
		nil, -- [31]
		{
			["ID"] = 32,
			["name"] = "Conflict and Strife",
			["icon"] = 3015742,
		}, -- [32]
		{
			["ID"] = 33,
			["name"] = "Touch of the Everlasting",
			["icon"] = 3193847,
		}, -- [33]
		{
			["ID"] = 34,
			["name"] = "Strength of the Warden",
			["icon"] = 3193846,
		}, -- [34]
		{
			["ID"] = 35,
			["name"] = "Breath of the Dying",
			["icon"] = 3193844,
		}, -- [35]
		{
			["ID"] = 36,
			["name"] = "Spark of Inspiration",
			["icon"] = 3193843,
		}, -- [36]
		{
			["ID"] = 37,
			["name"] = "The Formless Void",
			["icon"] = 3193845,
		}, -- [37]
	}
	local roleInfo = {
		["DAMAGER"] = {
			["essences"] = {
				23, -- [1]
				35, -- [2]
				14, -- [3]
				32, -- [4]
				5, -- [5]
				27, -- [6]
				6, -- [7]
				15, -- [8]
				36, -- [9]
				12, -- [10]
				37, -- [11]
				28, -- [12]
				22, -- [13]
				4, -- [14]
			},
		},
		["TANK"] = {
			["essences"] = {
				25, -- [1]
				7, -- [2]
				2, -- [3]
				32, -- [4]
				27, -- [5]
				13, -- [6]
				15, -- [7]
				3, -- [8]
				34, -- [9]
				12, -- [10]
				37, -- [11]
				33, -- [12]
				22, -- [13]
				4, -- [14]
			},
		},
		["HEALER"] = {
			["essences"] = {
				18, -- [1]
				32, -- [2]
				20, -- [3]
				27, -- [4]
				15, -- [5]
				24, -- [6]
				12, -- [7]
				17, -- [8]
				37, -- [9]
				19, -- [10]
				16, -- [11]
				22, -- [12]
				21, -- [13]
				4, -- [14]
			},
		},
	};
	function GetEssenceInfoByID(essenceID)
		local essence = GetEssenceInfo(essenceID);
		if not essence then
			essence = BtWLoadoutsEssenceInfo and BtWLoadoutsEssenceInfo[essenceID] or essenceInfo[essenceID];
		end
		return essence;
	end
	function GetEssenceInfoForRole(role, index)
		if BtWLoadoutsRoleInfo[role] and BtWLoadoutsRoleInfo[role].essences and BtWLoadoutsRoleInfo[role].essences[index] then
			return GetEssenceInfoByID(BtWLoadoutsRoleInfo[role].essences[index]);
		end

		if roleInfo[role] and roleInfo[role].essences and roleInfo[role].essences[index] then
			return GetEssenceInfoByID(roleInfo[role].essences[index]);
		end
	end
	Internal.GetEssenceInfoByID = GetEssenceInfoByID
	Internal.GetEssenceInfoForRole = GetEssenceInfoForRole
end
do
	local traitInfoVersion = 3

	local trees = {
		-- Warrior
		[71] = { -- Arms
			ID = 850,
			nodes = {
				90258, 90259, 90260, 90261, 90262, 90263, 90264, 90265,
				90266, 90267, 90268, 90269, 90270, 90271, 90272, 90273,
				90274, 90275, 90276, 90277, 90278, 90279, 90280, 90281,
				90282, 90283, 90284, 90285, 90286, 90287, 90288, 90289,
				90290, 90291, 90292, 90293, 90294, 90295, 90296, 90297,
				90298, 90299, 90300, 90301, 90302, 90303, 90304, 90305,
				90306, 90307, 90308, 90309, 90310, 90311, 90312, 90313,
				90314, 90315, 90316, 90317, 90318, 90319, 90320, 90321,
				90322, 90323, 90324, 90325, 90326, 90327, 90328, 90329,
				90330, 90331, 90332, 90333, 90334, 90335, 90336, 90337,
				90338, 90339, 90340, 90341, 90342, 90343, 90344, 90345,
				90346, 90347, 90348, 90349, 90350, 90351, 90352, 90353,
				90354, 90355, 90356, 90357, 90358, 90359, 90360, 90361,
				90362, 90363, 90364, 90365, 90366, 90367, 90368, 90369,
				90370, 90371, 90372, 90373, 90374, 90375, 90376, 90377,
				90378, 90379, 90380, 90381, 90382, 90383, 90384, 90385,
				90386, 90387, 90388, 90389, 90390, 90391, 90392, 90393,
				90394, 90395, 90396, 90397, 90398, 90399, 90400, 90401,
				90402, 90403, 90404, 90405, 90406, 90407, 90408, 90409,
				90410, 90411, 90412, 90413, 90414, 90415, 90416, 90417,
				90418, 90419, 90420, 90421, 90422, 90423, 90424, 90425,
				90426, 90427, 90428, 90429, 90430, 90431, 90432, 90433,
				90434, 90435, 90436, 90437, 90438, 90439, 90440, 90441,
				90442, 90443, 90444, 90445, 90446, 90447, 90448, 90449,
				90450, 90451, 90452,
			},
			visibleNodes = {
				[90263] = true, [90266] = true, [90267] = true, [90268] = true,
				[90269] = true, [90270] = true, [90271] = true, [90272] = true,
				[90273] = true, [90274] = true, [90275] = true, [90276] = true,
				[90277] = true, [90278] = true, [90279] = true, [90280] = true,
				[90281] = true, [90282] = true, [90283] = true, [90284] = true,
				[90285] = true, [90286] = true, [90287] = true, [90288] = true,
				[90289] = true, [90290] = true, [90291] = true, [90292] = true,
				[90293] = true, [90294] = true, [90321] = true, [90322] = true,
				[90323] = true, [90326] = true, [90327] = true, [90328] = true,
				[90329] = true, [90330] = true, [90331] = true, [90332] = true,
				[90333] = true, [90336] = true, [90337] = true, [90338] = true,
				[90340] = true, [90341] = true, [90342] = true, [90343] = true,
				[90344] = true, [90346] = true, [90347] = true, [90348] = true,
				[90351] = true, [90352] = true, [90353] = true, [90354] = true,
				[90355] = true, [90356] = true, [90357] = true, [90358] = true,
				[90359] = true, [90360] = true, [90363] = true, [90365] = true,
				[90366] = true, [90368] = true, [90371] = true, [90372] = true,
				[90374] = true, [90375] = true, [90377] = true, [90378] = true,
				[90379] = true, [90380] = true, [90381] = true, [90382] = true,
				[90383] = true, [90384] = true, [90385] = true, [90436] = true,
				[90437] = true, [90438] = true, [90439] = true, [90440] = true,
				[90441] = true, [90442] = true, [90443] = true, [90444] = true,
				[90445] = true, [90446] = true, [90447] = true,
			},
			grantedNodes = { 90327 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2896,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2895,
				},
			},
			gates = {
				{
					conditionID = 22745,
					topLeftNodeID = 90351,
					spentAmountRequired = 8,
					traitCurrencyID = 2896,
				},
				{
					conditionID = 22746,
					topLeftNodeID = 90282,
					spentAmountRequired = 8,
					traitCurrencyID = 2895,
				},
				{
					conditionID = 22743,
					topLeftNodeID = 90366,
					spentAmountRequired = 20,
					traitCurrencyID = 2896,
				},
				{
					conditionID = 22744,
					topLeftNodeID = 90437,
					spentAmountRequired = 20,
					traitCurrencyID = 2895,
				},
			},
		},
		[72] = { -- Fury
			ID = 850,
			nodes = {
				90258, 90259, 90260, 90261, 90262, 90263, 90264, 90265,
				90266, 90267, 90268, 90269, 90270, 90271, 90272, 90273,
				90274, 90275, 90276, 90277, 90278, 90279, 90280, 90281,
				90282, 90283, 90284, 90285, 90286, 90287, 90288, 90289,
				90290, 90291, 90292, 90293, 90294, 90295, 90296, 90297,
				90298, 90299, 90300, 90301, 90302, 90303, 90304, 90305,
				90306, 90307, 90308, 90309, 90310, 90311, 90312, 90313,
				90314, 90315, 90316, 90317, 90318, 90319, 90320, 90321,
				90322, 90323, 90324, 90325, 90326, 90327, 90328, 90329,
				90330, 90331, 90332, 90333, 90334, 90335, 90336, 90337,
				90338, 90339, 90340, 90341, 90342, 90343, 90344, 90345,
				90346, 90347, 90348, 90349, 90350, 90351, 90352, 90353,
				90354, 90355, 90356, 90357, 90358, 90359, 90360, 90361,
				90362, 90363, 90364, 90365, 90366, 90367, 90368, 90369,
				90370, 90371, 90372, 90373, 90374, 90375, 90376, 90377,
				90378, 90379, 90380, 90381, 90382, 90383, 90384, 90385,
				90386, 90387, 90388, 90389, 90390, 90391, 90392, 90393,
				90394, 90395, 90396, 90397, 90398, 90399, 90400, 90401,
				90402, 90403, 90404, 90405, 90406, 90407, 90408, 90409,
				90410, 90411, 90412, 90413, 90414, 90415, 90416, 90417,
				90418, 90419, 90420, 90421, 90422, 90423, 90424, 90425,
				90426, 90427, 90428, 90429, 90430, 90431, 90432, 90433,
				90434, 90435, 90436, 90437, 90438, 90439, 90440, 90441,
				90442, 90443, 90444, 90445, 90446, 90447, 90448, 90449,
				90450, 90451, 90452,
			},
			visibleNodes = {
				[90258] = true, [90321] = true, [90323] = true, [90325] = true,
				[90326] = true, [90329] = true, [90330] = true, [90331] = true,
				[90332] = true, [90335] = true, [90336] = true, [90337] = true,
				[90340] = true, [90341] = true, [90342] = true, [90343] = true,
				[90344] = true, [90346] = true, [90348] = true, [90349] = true,
				[90350] = true, [90351] = true, [90353] = true, [90355] = true,
				[90356] = true, [90357] = true, [90358] = true, [90359] = true,
				[90360] = true, [90362] = true, [90365] = true, [90367] = true,
				[90368] = true, [90371] = true, [90372] = true, [90373] = true,
				[90374] = true, [90375] = true, [90376] = true, [90377] = true,
				[90378] = true, [90379] = true, [90380] = true, [90381] = true,
				[90382] = true, [90383] = true, [90384] = true, [90385] = true,
				[90386] = true, [90387] = true, [90388] = true, [90389] = true,
				[90390] = true, [90391] = true, [90392] = true, [90393] = true,
				[90394] = true, [90395] = true, [90396] = true, [90397] = true,
				[90398] = true, [90399] = true, [90400] = true, [90401] = true,
				[90402] = true, [90403] = true, [90404] = true, [90405] = true,
				[90406] = true, [90407] = true, [90408] = true, [90409] = true,
				[90410] = true, [90411] = true, [90412] = true, [90413] = true,
				[90414] = true, [90415] = true, [90416] = true, [90417] = true,
				[90418] = true, [90419] = true, [90420] = true, [90421] = true,
				[90422] = true, [90423] = true, [90424] = true, [90425] = true,
				[90426] = true, [90427] = true, [90428] = true, [90429] = true,
				[90430] = true,
			},
			grantedNodes = { 90325 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2896,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2895,
				},
			},
			gates = {
				{
					conditionID = 22745,
					topLeftNodeID = 90351,
					spentAmountRequired = 8,
					traitCurrencyID = 2896,
				},
				{
					conditionID = 22746,
					topLeftNodeID = 90403,
					spentAmountRequired = 8,
					traitCurrencyID = 2895,
				},
				{
					conditionID = 22743,
					topLeftNodeID = 90258,
					spentAmountRequired = 20,
					traitCurrencyID = 2896,
				},
				{
					conditionID = 22744,
					topLeftNodeID = 90421,
					spentAmountRequired = 20,
					traitCurrencyID = 2895,
				},
			},
		},
		[73] = { -- Protection
			ID = 850,
			nodes = {
				90258, 90259, 90260, 90261, 90262, 90263, 90264, 90265,
				90266, 90267, 90268, 90269, 90270, 90271, 90272, 90273,
				90274, 90275, 90276, 90277, 90278, 90279, 90280, 90281,
				90282, 90283, 90284, 90285, 90286, 90287, 90288, 90289,
				90290, 90291, 90292, 90293, 90294, 90295, 90296, 90297,
				90298, 90299, 90300, 90301, 90302, 90303, 90304, 90305,
				90306, 90307, 90308, 90309, 90310, 90311, 90312, 90313,
				90314, 90315, 90316, 90317, 90318, 90319, 90320, 90321,
				90322, 90323, 90324, 90325, 90326, 90327, 90328, 90329,
				90330, 90331, 90332, 90333, 90334, 90335, 90336, 90337,
				90338, 90339, 90340, 90341, 90342, 90343, 90344, 90345,
				90346, 90347, 90348, 90349, 90350, 90351, 90352, 90353,
				90354, 90355, 90356, 90357, 90358, 90359, 90360, 90361,
				90362, 90363, 90364, 90365, 90366, 90367, 90368, 90369,
				90370, 90371, 90372, 90373, 90374, 90375, 90376, 90377,
				90378, 90379, 90380, 90381, 90382, 90383, 90384, 90385,
				90386, 90387, 90388, 90389, 90390, 90391, 90392, 90393,
				90394, 90395, 90396, 90397, 90398, 90399, 90400, 90401,
				90402, 90403, 90404, 90405, 90406, 90407, 90408, 90409,
				90410, 90411, 90412, 90413, 90414, 90415, 90416, 90417,
				90418, 90419, 90420, 90421, 90422, 90423, 90424, 90425,
				90426, 90427, 90428, 90429, 90430, 90431, 90432, 90433,
				90434, 90435, 90436, 90437, 90438, 90439, 90440, 90441,
				90442, 90443, 90444, 90445, 90446, 90447, 90448, 90449,
				90450, 90451, 90452,
			},
			visibleNodes = {
				[90259] = true, [90260] = true, [90261] = true, [90262] = true,
				[90264] = true, [90265] = true, [90295] = true, [90296] = true,
				[90297] = true, [90298] = true, [90299] = true, [90300] = true,
				[90301] = true, [90302] = true, [90303] = true, [90304] = true,
				[90305] = true, [90306] = true, [90307] = true, [90308] = true,
				[90309] = true, [90310] = true, [90311] = true, [90312] = true,
				[90313] = true, [90314] = true, [90315] = true, [90316] = true,
				[90317] = true, [90318] = true, [90319] = true, [90320] = true,
				[90321] = true, [90323] = true, [90324] = true, [90326] = true,
				[90329] = true, [90330] = true, [90331] = true, [90332] = true,
				[90334] = true, [90336] = true, [90337] = true, [90339] = true,
				[90340] = true, [90341] = true, [90342] = true, [90343] = true,
				[90344] = true, [90345] = true, [90346] = true, [90348] = true,
				[90351] = true, [90353] = true, [90355] = true, [90356] = true,
				[90357] = true, [90358] = true, [90359] = true, [90360] = true,
				[90361] = true, [90364] = true, [90365] = true, [90368] = true,
				[90369] = true, [90370] = true, [90371] = true, [90372] = true,
				[90374] = true, [90375] = true, [90377] = true, [90378] = true,
				[90379] = true, [90380] = true, [90381] = true, [90382] = true,
				[90383] = true, [90384] = true, [90385] = true, [90431] = true,
				[90432] = true, [90433] = true, [90434] = true, [90435] = true,
				[90448] = true, [90449] = true, [90450] = true, [90451] = true,
				[90452] = true,
			},
			grantedNodes = { 90261, 90330 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2896,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2895,
				},
			},
			gates = {
				{
					conditionID = 22745,
					topLeftNodeID = 90351,
					spentAmountRequired = 8,
					traitCurrencyID = 2896,
				},
				{
					conditionID = 22746,
					topLeftNodeID = 90309,
					spentAmountRequired = 8,
					traitCurrencyID = 2895,
				},
				{
					conditionID = 22743,
					topLeftNodeID = 90259,
					spentAmountRequired = 20,
					traitCurrencyID = 2896,
				},
				{
					conditionID = 22744,
					topLeftNodeID = 90318,
					spentAmountRequired = 20,
					traitCurrencyID = 2895,
				},
			},
		},
		-- Paladin
		[65] = { -- Holy
			ID = 790,
			nodes = {
				81469, 81470, 81471, 81472, 81473, 81474, 81475, 81476,
				81477, 81479, 81480, 81481, 81482, 81483, 81484, 81485,
				81486, 81487, 81488, 81489, 81490, 81491, 81492, 81493,
				81494, 81495, 81496, 81497, 81498, 81499, 81500, 81501,
				81502, 81503, 81504, 81505, 81506, 81507, 81508, 81509,
				81510, 81511, 81512, 81513, 81514, 81515, 81516, 81517,
				81518, 81519, 81520, 81521, 81522, 81523, 81524, 81525,
				81526, 81527, 81528, 81529, 81530, 81531, 81532, 81533,
				81534, 81535, 81536, 81537, 81538, 81539, 81540, 81541,
				81542, 81543, 81544, 81545, 81546, 81547, 81548, 81549,
				81550, 81551, 81552, 81553, 81554, 81555, 81556, 81557,
				81558, 81559, 81560, 81561, 81562, 81563, 81564, 81565,
				81566, 81567, 81568, 81569, 81570, 81571, 81572, 81573,
				81574, 81575, 81576, 81577, 81578, 81579, 81580, 81581,
				81582, 81583, 81584, 81585, 81586, 81587, 81588, 81589,
				81590, 81591, 81592, 81593, 81594, 81595, 81596, 81597,
				81598, 81599, 81600, 81601, 81602, 81603, 81604, 81605,
				81606, 81607, 81608, 81609, 81610, 81611, 81612, 81613,
				81614, 81615, 81616, 81617, 81618, 81619, 81620, 81621,
				81622, 81623, 81624, 81625, 81626, 81627, 81628, 81629,
				81630, 81631, 81632, 90062, 92220,
			},
			visibleNodes = {
				[81508] = true, [81509] = true, [81510] = true, [81554] = true,
				[81555] = true, [81556] = true, [81557] = true, [81558] = true,
				[81559] = true, [81560] = true, [81561] = true, [81562] = true,
				[81563] = true, [81564] = true, [81565] = true, [81566] = true,
				[81567] = true, [81568] = true, [81569] = true, [81570] = true,
				[81571] = true, [81572] = true, [81573] = true, [81574] = true,
				[81575] = true, [81576] = true, [81577] = true, [81578] = true,
				[81579] = true, [81580] = true, [81581] = true, [81582] = true,
				[81583] = true, [81584] = true, [81585] = true, [81586] = true,
				[81587] = true, [81588] = true, [81589] = true, [81590] = true,
				[81591] = true, [81592] = true, [81593] = true, [81594] = true,
				[81595] = true, [81596] = true, [81597] = true, [81598] = true,
				[81599] = true, [81600] = true, [81601] = true, [81602] = true,
				[81604] = true, [81605] = true, [81606] = true, [81607] = true,
				[81608] = true, [81609] = true, [81610] = true, [81611] = true,
				[81612] = true, [81613] = true, [81614] = true, [81615] = true,
				[81616] = true, [81617] = true, [81618] = true, [81619] = true,
				[81620] = true, [81621] = true, [81622] = true, [81623] = true,
				[81624] = true, [81625] = true, [81626] = true, [81627] = true,
				[81628] = true, [81629] = true, [81630] = true, [81631] = true,
				[81632] = true, [92220] = true,
			},
			grantedNodes = { 81597, 81599 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2795,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2794,
				},
			},
			gates = {
				{
					conditionID = 20155,
					topLeftNodeID = 81609,
					spentAmountRequired = 8,
					traitCurrencyID = 2795,
				},
				{
					conditionID = 20152,
					topLeftNodeID = 81570,
					spentAmountRequired = 8,
					traitCurrencyID = 2794,
				},
				{
					conditionID = 20153,
					topLeftNodeID = 81612,
					spentAmountRequired = 20,
					traitCurrencyID = 2795,
				},
				{
					conditionID = 20150,
					topLeftNodeID = 81579,
					spentAmountRequired = 20,
					traitCurrencyID = 2794,
				},
			},
		},
		[66] = { -- Protection
			ID = 790,
			nodes = {
				81469, 81470, 81471, 81472, 81473, 81474, 81475, 81476,
				81477, 81479, 81480, 81481, 81482, 81483, 81484, 81485,
				81486, 81487, 81488, 81489, 81490, 81491, 81492, 81493,
				81494, 81495, 81496, 81497, 81498, 81499, 81500, 81501,
				81502, 81503, 81504, 81505, 81506, 81507, 81508, 81509,
				81510, 81511, 81512, 81513, 81514, 81515, 81516, 81517,
				81518, 81519, 81520, 81521, 81522, 81523, 81524, 81525,
				81526, 81527, 81528, 81529, 81530, 81531, 81532, 81533,
				81534, 81535, 81536, 81537, 81538, 81539, 81540, 81541,
				81542, 81543, 81544, 81545, 81546, 81547, 81548, 81549,
				81550, 81551, 81552, 81553, 81554, 81555, 81556, 81557,
				81558, 81559, 81560, 81561, 81562, 81563, 81564, 81565,
				81566, 81567, 81568, 81569, 81570, 81571, 81572, 81573,
				81574, 81575, 81576, 81577, 81578, 81579, 81580, 81581,
				81582, 81583, 81584, 81585, 81586, 81587, 81588, 81589,
				81590, 81591, 81592, 81593, 81594, 81595, 81596, 81597,
				81598, 81599, 81600, 81601, 81602, 81603, 81604, 81605,
				81606, 81607, 81608, 81609, 81610, 81611, 81612, 81613,
				81614, 81615, 81616, 81617, 81618, 81619, 81620, 81621,
				81622, 81623, 81624, 81625, 81626, 81627, 81628, 81629,
				81630, 81631, 81632, 90062, 92220,
			},
			visibleNodes = {
				[81469] = true, [81470] = true, [81471] = true, [81472] = true,
				[81473] = true, [81474] = true, [81475] = true, [81476] = true,
				[81477] = true, [81479] = true, [81480] = true, [81481] = true,
				[81482] = true, [81483] = true, [81484] = true, [81485] = true,
				[81486] = true, [81487] = true, [81488] = true, [81489] = true,
				[81490] = true, [81491] = true, [81492] = true, [81493] = true,
				[81494] = true, [81495] = true, [81496] = true, [81497] = true,
				[81498] = true, [81499] = true, [81500] = true, [81501] = true,
				[81502] = true, [81503] = true, [81504] = true, [81505] = true,
				[81506] = true, [81507] = true, [81509] = true, [81510] = true,
				[81597] = true, [81598] = true, [81599] = true, [81600] = true,
				[81601] = true, [81602] = true, [81603] = true, [81604] = true,
				[81605] = true, [81606] = true, [81607] = true, [81608] = true,
				[81609] = true, [81610] = true, [81611] = true, [81612] = true,
				[81613] = true, [81614] = true, [81615] = true, [81616] = true,
				[81617] = true, [81618] = true, [81619] = true, [81620] = true,
				[81621] = true, [81622] = true, [81623] = true, [81624] = true,
				[81625] = true, [81626] = true, [81627] = true, [81628] = true,
				[81629] = true, [81630] = true, [81631] = true, [81632] = true,
				[90062] = true,
			},
			grantedNodes = { 81597, 81599 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2795,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2794,
				},
			},
			gates = {
				{
					conditionID = 20155,
					topLeftNodeID = 81609,
					spentAmountRequired = 8,
					traitCurrencyID = 2795,
				},
				{
					conditionID = 20152,
					topLeftNodeID = 81486,
					spentAmountRequired = 8,
					traitCurrencyID = 2794,
				},
				{
					conditionID = 20153,
					topLeftNodeID = 81612,
					spentAmountRequired = 20,
					traitCurrencyID = 2795,
				},
				{
					conditionID = 20150,
					topLeftNodeID = 81472,
					spentAmountRequired = 20,
					traitCurrencyID = 2794,
				},
			},
		},
		[70] = { -- Retribution
			ID = 790,
			nodes = {
				81469, 81470, 81471, 81472, 81473, 81474, 81475, 81476,
				81477, 81479, 81480, 81481, 81482, 81483, 81484, 81485,
				81486, 81487, 81488, 81489, 81490, 81491, 81492, 81493,
				81494, 81495, 81496, 81497, 81498, 81499, 81500, 81501,
				81502, 81503, 81504, 81505, 81506, 81507, 81508, 81509,
				81510, 81511, 81512, 81513, 81514, 81515, 81516, 81517,
				81518, 81519, 81520, 81521, 81522, 81523, 81524, 81525,
				81526, 81527, 81528, 81529, 81530, 81531, 81532, 81533,
				81534, 81535, 81536, 81537, 81538, 81539, 81540, 81541,
				81542, 81543, 81544, 81545, 81546, 81547, 81548, 81549,
				81550, 81551, 81552, 81553, 81554, 81555, 81556, 81557,
				81558, 81559, 81560, 81561, 81562, 81563, 81564, 81565,
				81566, 81567, 81568, 81569, 81570, 81571, 81572, 81573,
				81574, 81575, 81576, 81577, 81578, 81579, 81580, 81581,
				81582, 81583, 81584, 81585, 81586, 81587, 81588, 81589,
				81590, 81591, 81592, 81593, 81594, 81595, 81596, 81597,
				81598, 81599, 81600, 81601, 81602, 81603, 81604, 81605,
				81606, 81607, 81608, 81609, 81610, 81611, 81612, 81613,
				81614, 81615, 81616, 81617, 81618, 81619, 81620, 81621,
				81622, 81623, 81624, 81625, 81626, 81627, 81628, 81629,
				81630, 81631, 81632, 90062, 92220,
			},
			visibleNodes = {
				[81507] = true, [81509] = true, [81510] = true, [81511] = true,
				[81512] = true, [81513] = true, [81514] = true, [81515] = true,
				[81516] = true, [81517] = true, [81518] = true, [81519] = true,
				[81520] = true, [81521] = true, [81522] = true, [81523] = true,
				[81524] = true, [81525] = true, [81526] = true, [81527] = true,
				[81528] = true, [81529] = true, [81530] = true, [81531] = true,
				[81532] = true, [81533] = true, [81534] = true, [81535] = true,
				[81536] = true, [81537] = true, [81538] = true, [81539] = true,
				[81540] = true, [81541] = true, [81542] = true, [81543] = true,
				[81544] = true, [81545] = true, [81546] = true, [81547] = true,
				[81548] = true, [81549] = true, [81550] = true, [81551] = true,
				[81552] = true, [81553] = true, [81597] = true, [81598] = true,
				[81599] = true, [81600] = true, [81601] = true, [81602] = true,
				[81603] = true, [81604] = true, [81605] = true, [81606] = true,
				[81607] = true, [81608] = true, [81609] = true, [81610] = true,
				[81611] = true, [81612] = true, [81613] = true, [81614] = true,
				[81615] = true, [81616] = true, [81617] = true, [81618] = true,
				[81619] = true, [81620] = true, [81621] = true, [81622] = true,
				[81623] = true, [81624] = true, [81625] = true, [81626] = true,
				[81627] = true, [81628] = true, [81629] = true, [81630] = true,
				[81631] = true, [81632] = true,
			},
			grantedNodes = { 81510, 81601 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2795,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2794,
				},
			},
			gates = {
				{
					conditionID = 20155,
					topLeftNodeID = 81609,
					spentAmountRequired = 8,
					traitCurrencyID = 2795,
				},
				{
					conditionID = 20152,
					topLeftNodeID = 81533,
					spentAmountRequired = 8,
					traitCurrencyID = 2794,
				},
				{
					conditionID = 20153,
					topLeftNodeID = 81612,
					spentAmountRequired = 20,
					traitCurrencyID = 2795,
				},
				{
					conditionID = 20150,
					topLeftNodeID = 81540,
					spentAmountRequired = 20,
					traitCurrencyID = 2794,
				},
			},
		},
		-- Hunter
		[253] = { -- Beast Mastery
			ID = 774,
			nodes = {
				79813, 79814, 79815, 79816, 79817, 79818, 79819, 79820,
				79821, 79822, 79823, 79824, 79825, 79826, 79827, 79828,
				79829, 79830, 79831, 79832, 79833, 79834, 79835, 79836,
				79837, 79838, 79839, 79840, 79841, 79842, 79843, 79844,
				79845, 79846, 79847, 79848, 79849, 79850, 79851, 79852,
				79853, 79854, 79855, 79856, 79857, 79858, 79859, 79860,
				79861, 79862, 79863, 79864, 79865, 79866, 79867, 79868,
				79869, 79870, 79871, 79872, 79873, 79874, 79875, 79876,
				79877, 79878, 79879, 79880, 79881, 79882, 79883, 79884,
				79885, 79886, 79887, 79888, 79889, 79890, 79891, 79892,
				79893, 79894, 79895, 79896, 79897, 79898, 79899, 79900,
				79901, 79902, 79903, 79904, 79905, 79906, 79907, 79908,
				79909, 79910, 79911, 79912, 79913, 79914, 79915, 79916,
				79917, 79918, 79919, 79920, 79921, 79922, 79923, 79924,
				79925, 79926, 79927, 79928, 79930, 79931, 79932, 79933,
				79934, 79935, 79936, 79937, 79938, 79939, 79940, 79941,
				79942, 79943, 79944, 79945, 79946, 79947, 79948, 79949,
				79950, 79951, 79952, 79953, 79954, 79955, 79956, 79957,
				79958, 79959, 79960, 79961, 79962, 79963, 79964, 79965,
				79966, 79967, 79968, 79977,
			},
			visibleNodes = {
				[79814] = true, [79815] = true, [79816] = true, [79818] = true,
				[79819] = true, [79820] = true, [79821] = true, [79822] = true,
				[79823] = true, [79832] = true, [79835] = true, [79904] = true,
				[79905] = true, [79906] = true, [79907] = true, [79908] = true,
				[79909] = true, [79910] = true, [79911] = true, [79912] = true,
				[79913] = true, [79914] = true, [79916] = true, [79917] = true,
				[79918] = true, [79919] = true, [79920] = true, [79921] = true,
				[79922] = true, [79923] = true, [79924] = true, [79925] = true,
				[79926] = true, [79927] = true, [79928] = true, [79930] = true,
				[79931] = true, [79932] = true, [79933] = true, [79934] = true,
				[79935] = true, [79936] = true, [79937] = true, [79938] = true,
				[79939] = true, [79940] = true, [79941] = true, [79942] = true,
				[79943] = true, [79944] = true, [79945] = true, [79946] = true,
				[79947] = true, [79948] = true, [79949] = true, [79950] = true,
				[79951] = true, [79952] = true, [79953] = true, [79954] = true,
				[79955] = true, [79956] = true, [79957] = true, [79958] = true,
				[79959] = true, [79960] = true, [79961] = true, [79962] = true,
				[79963] = true, [79964] = true, [79965] = true, [79966] = true,
				[79967] = true, [79968] = true, [79977] = true,
			},
			grantedNodes = { 79935 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2770,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2769,
				},
			},
			gates = {
				{
					conditionID = 19946,
					topLeftNodeID = 79907,
					spentAmountRequired = 8,
					traitCurrencyID = 2770,
				},
				{
					conditionID = 19963,
					topLeftNodeID = 79941,
					spentAmountRequired = 8,
					traitCurrencyID = 2769,
				},
				{
					conditionID = 19945,
					topLeftNodeID = 79926,
					spentAmountRequired = 20,
					traitCurrencyID = 2770,
				},
				{
					conditionID = 19961,
					topLeftNodeID = 79953,
					spentAmountRequired = 20,
					traitCurrencyID = 2769,
				},
			},
		},
		[254] = { -- Marksmanship
			ID = 774,
			nodes = {
				79813, 79814, 79815, 79816, 79817, 79818, 79819, 79820,
				79821, 79822, 79823, 79824, 79825, 79826, 79827, 79828,
				79829, 79830, 79831, 79832, 79833, 79834, 79835, 79836,
				79837, 79838, 79839, 79840, 79841, 79842, 79843, 79844,
				79845, 79846, 79847, 79848, 79849, 79850, 79851, 79852,
				79853, 79854, 79855, 79856, 79857, 79858, 79859, 79860,
				79861, 79862, 79863, 79864, 79865, 79866, 79867, 79868,
				79869, 79870, 79871, 79872, 79873, 79874, 79875, 79876,
				79877, 79878, 79879, 79880, 79881, 79882, 79883, 79884,
				79885, 79886, 79887, 79888, 79889, 79890, 79891, 79892,
				79893, 79894, 79895, 79896, 79897, 79898, 79899, 79900,
				79901, 79902, 79903, 79904, 79905, 79906, 79907, 79908,
				79909, 79910, 79911, 79912, 79913, 79914, 79915, 79916,
				79917, 79918, 79919, 79920, 79921, 79922, 79923, 79924,
				79925, 79926, 79927, 79928, 79930, 79931, 79932, 79933,
				79934, 79935, 79936, 79937, 79938, 79939, 79940, 79941,
				79942, 79943, 79944, 79945, 79946, 79947, 79948, 79949,
				79950, 79951, 79952, 79953, 79954, 79955, 79956, 79957,
				79958, 79959, 79960, 79961, 79962, 79963, 79964, 79965,
				79966, 79967, 79968, 79977,
			},
			visibleNodes = {
				[79813] = true, [79814] = true, [79815] = true, [79817] = true,
				[79818] = true, [79819] = true, [79820] = true, [79821] = true,
				[79830] = true, [79831] = true, [79832] = true, [79834] = true,
				[79836] = true, [79838] = true, [79840] = true, [79871] = true,
				[79872] = true, [79873] = true, [79874] = true, [79875] = true,
				[79876] = true, [79877] = true, [79878] = true, [79879] = true,
				[79880] = true, [79881] = true, [79882] = true, [79883] = true,
				[79884] = true, [79885] = true, [79886] = true, [79887] = true,
				[79888] = true, [79889] = true, [79890] = true, [79891] = true,
				[79892] = true, [79893] = true, [79894] = true, [79895] = true,
				[79896] = true, [79897] = true, [79898] = true, [79899] = true,
				[79900] = true, [79901] = true, [79902] = true, [79903] = true,
				[79904] = true, [79905] = true, [79906] = true, [79907] = true,
				[79908] = true, [79909] = true, [79910] = true, [79911] = true,
				[79913] = true, [79914] = true, [79915] = true, [79916] = true,
				[79918] = true, [79919] = true, [79920] = true, [79921] = true,
				[79922] = true, [79923] = true, [79924] = true, [79925] = true,
				[79926] = true, [79927] = true, [79928] = true, [79930] = true,
				[79931] = true, [79932] = true, [79933] = true, [79934] = true,
				[79936] = true, [79937] = true, [79977] = true,
			},
			grantedNodes = { 79834 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2770,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2769,
				},
			},
			gates = {
				{
					conditionID = 19946,
					topLeftNodeID = 79907,
					spentAmountRequired = 8,
					traitCurrencyID = 2770,
				},
				{
					conditionID = 19963,
					topLeftNodeID = 79897,
					spentAmountRequired = 8,
					traitCurrencyID = 2769,
				},
				{
					conditionID = 19945,
					topLeftNodeID = 79926,
					spentAmountRequired = 20,
					traitCurrencyID = 2770,
				},
				{
					conditionID = 19961,
					topLeftNodeID = 79903,
					spentAmountRequired = 20,
					traitCurrencyID = 2769,
				},
			},
		},
		[255] = { -- Survival
			ID = 774,
			nodes = {
				79813, 79814, 79815, 79816, 79817, 79818, 79819, 79820,
				79821, 79822, 79823, 79824, 79825, 79826, 79827, 79828,
				79829, 79830, 79831, 79832, 79833, 79834, 79835, 79836,
				79837, 79838, 79839, 79840, 79841, 79842, 79843, 79844,
				79845, 79846, 79847, 79848, 79849, 79850, 79851, 79852,
				79853, 79854, 79855, 79856, 79857, 79858, 79859, 79860,
				79861, 79862, 79863, 79864, 79865, 79866, 79867, 79868,
				79869, 79870, 79871, 79872, 79873, 79874, 79875, 79876,
				79877, 79878, 79879, 79880, 79881, 79882, 79883, 79884,
				79885, 79886, 79887, 79888, 79889, 79890, 79891, 79892,
				79893, 79894, 79895, 79896, 79897, 79898, 79899, 79900,
				79901, 79902, 79903, 79904, 79905, 79906, 79907, 79908,
				79909, 79910, 79911, 79912, 79913, 79914, 79915, 79916,
				79917, 79918, 79919, 79920, 79921, 79922, 79923, 79924,
				79925, 79926, 79927, 79928, 79930, 79931, 79932, 79933,
				79934, 79935, 79936, 79937, 79938, 79939, 79940, 79941,
				79942, 79943, 79944, 79945, 79946, 79947, 79948, 79949,
				79950, 79951, 79952, 79953, 79954, 79955, 79956, 79957,
				79958, 79959, 79960, 79961, 79962, 79963, 79964, 79965,
				79966, 79967, 79968, 79977,
			},
			visibleNodes = {
				[79814] = true, [79815] = true, [79818] = true, [79819] = true,
				[79820] = true, [79821] = true, [79824] = true, [79825] = true,
				[79826] = true, [79827] = true, [79828] = true, [79829] = true,
				[79832] = true, [79833] = true, [79837] = true, [79839] = true,
				[79841] = true, [79842] = true, [79843] = true, [79844] = true,
				[79845] = true, [79846] = true, [79847] = true, [79848] = true,
				[79849] = true, [79850] = true, [79851] = true, [79852] = true,
				[79853] = true, [79854] = true, [79855] = true, [79856] = true,
				[79857] = true, [79858] = true, [79859] = true, [79860] = true,
				[79861] = true, [79862] = true, [79863] = true, [79864] = true,
				[79865] = true, [79866] = true, [79867] = true, [79868] = true,
				[79869] = true, [79870] = true, [79904] = true, [79905] = true,
				[79906] = true, [79907] = true, [79908] = true, [79909] = true,
				[79910] = true, [79911] = true, [79913] = true, [79914] = true,
				[79916] = true, [79918] = true, [79919] = true, [79920] = true,
				[79921] = true, [79922] = true, [79923] = true, [79924] = true,
				[79925] = true, [79926] = true, [79927] = true, [79928] = true,
				[79930] = true, [79931] = true, [79932] = true, [79933] = true,
				[79934] = true, [79936] = true, [79937] = true, [79977] = true,
			},
			grantedNodes = { 79839 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2770,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2769,
				},
			},
			gates = {
				{
					conditionID = 19946,
					topLeftNodeID = 79907,
					spentAmountRequired = 8,
					traitCurrencyID = 2770,
				},
				{
					conditionID = 19963,
					topLeftNodeID = 79867,
					spentAmountRequired = 8,
					traitCurrencyID = 2769,
				},
				{
					conditionID = 19945,
					topLeftNodeID = 79926,
					spentAmountRequired = 20,
					traitCurrencyID = 2770,
				},
				{
					conditionID = 19961,
					topLeftNodeID = 79870,
					spentAmountRequired = 20,
					traitCurrencyID = 2769,
				},
			},
		},
		-- Rogue
		[259] = { -- Assassination
			ID = 852,
			nodes = {
				90620, 90621, 90622, 90623, 90624, 90625, 90626, 90627,
				90628, 90629, 90630, 90631, 90632, 90633, 90634, 90635,
				90636, 90637, 90638, 90639, 90640, 90641, 90642, 90643,
				90644, 90645, 90646, 90647, 90648, 90649, 90650, 90651,
				90652, 90653, 90654, 90655, 90656, 90657, 90658, 90659,
				90660, 90661, 90662, 90663, 90664, 90665, 90666, 90667,
				90668, 90669, 90670, 90671, 90672, 90673, 90674, 90675,
				90676, 90677, 90678, 90679, 90680, 90681, 90682, 90683,
				90684, 90685, 90686, 90687, 90688, 90689, 90690, 90691,
				90692, 90693, 90694, 90695, 90696, 90697, 90698, 90699,
				90700, 90701, 90702, 90703, 90704, 90705, 90706, 90707,
				90708, 90709, 90710, 90711, 90712, 90713, 90714, 90715,
				90716, 90717, 90718, 90719, 90720, 90721, 90722, 90723,
				90724, 90725, 90726, 90727, 90728, 90729, 90730, 90731,
				90732, 90733, 90734, 90735, 90736, 90737, 90738, 90739,
				90740, 90741, 90742, 90743, 90744, 90745, 90746, 90747,
				90748, 90749, 90750, 90751, 90752, 90753, 90754, 90755,
				90756, 90757, 90758, 90759, 90760, 90761, 90762, 90763,
				90764, 90765, 90766, 90767, 90768, 90769, 90770, 90771,
				90772, 90773, 90774, 90775, 90776, 90777, 90778, 90779,
				90780, 90781, 90782, 90783, 90784, 90785, 90786,
			},
			visibleNodes = {
				[90620] = true, [90621] = true, [90622] = true, [90623] = true,
				[90624] = true, [90625] = true, [90626] = true, [90627] = true,
				[90628] = true, [90629] = true, [90630] = true, [90631] = true,
				[90632] = true, [90633] = true, [90634] = true, [90635] = true,
				[90636] = true, [90637] = true, [90638] = true, [90639] = true,
				[90640] = true, [90684] = true, [90685] = true, [90686] = true,
				[90687] = true, [90688] = true, [90689] = true, [90690] = true,
				[90691] = true, [90692] = true, [90693] = true, [90694] = true,
				[90695] = true, [90696] = true, [90697] = true, [90740] = true,
				[90741] = true, [90742] = true, [90743] = true, [90744] = true,
				[90745] = true, [90746] = true, [90747] = true, [90748] = true,
				[90749] = true, [90750] = true, [90751] = true, [90752] = true,
				[90753] = true, [90754] = true, [90755] = true, [90756] = true,
				[90757] = true, [90758] = true, [90759] = true, [90760] = true,
				[90761] = true, [90762] = true, [90763] = true, [90764] = true,
				[90765] = true, [90766] = true, [90767] = true, [90768] = true,
				[90769] = true, [90770] = true, [90771] = true, [90772] = true,
				[90773] = true, [90774] = true, [90775] = true, [90776] = true,
				[90777] = true, [90778] = true, [90779] = true, [90780] = true,
				[90781] = true, [90782] = true, [90783] = true, [90784] = true,
				[90785] = true, [90786] = true,
			},
			grantedNodes = { 90740 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2900,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2899,
				},
			},
			gates = {
				{
					conditionID = 22769,
					topLeftNodeID = 90637,
					spentAmountRequired = 8,
					traitCurrencyID = 2900,
				},
				{
					conditionID = 22763,
					topLeftNodeID = 90630,
					spentAmountRequired = 8,
					traitCurrencyID = 2899,
				},
				{
					conditionID = 22767,
					topLeftNodeID = 90758,
					spentAmountRequired = 20,
					traitCurrencyID = 2900,
				},
				{
					conditionID = 22764,
					topLeftNodeID = 90786,
					spentAmountRequired = 20,
					traitCurrencyID = 2899,
				},
			},
		},
		[260] = { -- Outlaw
			ID = 852,
			nodes = {
				90620, 90621, 90622, 90623, 90624, 90625, 90626, 90627,
				90628, 90629, 90630, 90631, 90632, 90633, 90634, 90635,
				90636, 90637, 90638, 90639, 90640, 90641, 90642, 90643,
				90644, 90645, 90646, 90647, 90648, 90649, 90650, 90651,
				90652, 90653, 90654, 90655, 90656, 90657, 90658, 90659,
				90660, 90661, 90662, 90663, 90664, 90665, 90666, 90667,
				90668, 90669, 90670, 90671, 90672, 90673, 90674, 90675,
				90676, 90677, 90678, 90679, 90680, 90681, 90682, 90683,
				90684, 90685, 90686, 90687, 90688, 90689, 90690, 90691,
				90692, 90693, 90694, 90695, 90696, 90697, 90698, 90699,
				90700, 90701, 90702, 90703, 90704, 90705, 90706, 90707,
				90708, 90709, 90710, 90711, 90712, 90713, 90714, 90715,
				90716, 90717, 90718, 90719, 90720, 90721, 90722, 90723,
				90724, 90725, 90726, 90727, 90728, 90729, 90730, 90731,
				90732, 90733, 90734, 90735, 90736, 90737, 90738, 90739,
				90740, 90741, 90742, 90743, 90744, 90745, 90746, 90747,
				90748, 90749, 90750, 90751, 90752, 90753, 90754, 90755,
				90756, 90757, 90758, 90759, 90760, 90761, 90762, 90763,
				90764, 90765, 90766, 90767, 90768, 90769, 90770, 90771,
				90772, 90773, 90774, 90775, 90776, 90777, 90778, 90779,
				90780, 90781, 90782, 90783, 90784, 90785, 90786,
			},
			visibleNodes = {
				[90636] = true, [90637] = true, [90638] = true, [90639] = true,
				[90640] = true, [90641] = true, [90642] = true, [90643] = true,
				[90644] = true, [90645] = true, [90646] = true, [90647] = true,
				[90648] = true, [90649] = true, [90650] = true, [90651] = true,
				[90652] = true, [90653] = true, [90654] = true, [90655] = true,
				[90656] = true, [90657] = true, [90658] = true, [90659] = true,
				[90660] = true, [90661] = true, [90662] = true, [90663] = true,
				[90664] = true, [90665] = true, [90666] = true, [90667] = true,
				[90668] = true, [90669] = true, [90670] = true, [90671] = true,
				[90672] = true, [90673] = true, [90674] = true, [90675] = true,
				[90676] = true, [90677] = true, [90678] = true, [90679] = true,
				[90680] = true, [90681] = true, [90682] = true, [90683] = true,
				[90684] = true, [90685] = true, [90686] = true, [90687] = true,
				[90688] = true, [90689] = true, [90690] = true, [90691] = true,
				[90692] = true, [90693] = true, [90694] = true, [90695] = true,
				[90696] = true, [90697] = true, [90740] = true, [90741] = true,
				[90742] = true, [90743] = true, [90744] = true, [90745] = true,
				[90746] = true, [90747] = true, [90748] = true, [90749] = true,
				[90750] = true, [90751] = true, [90752] = true, [90753] = true,
				[90754] = true, [90755] = true, [90756] = true, [90757] = true,
				[90758] = true, [90759] = true, [90760] = true, [90761] = true,
				[90762] = true, [90763] = true, [90764] = true,
			},
			grantedNodes = { 90684 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2900,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2899,
				},
			},
			gates = {
				{
					conditionID = 22769,
					topLeftNodeID = 90637,
					spentAmountRequired = 8,
					traitCurrencyID = 2900,
				},
				{
					conditionID = 22763,
					topLeftNodeID = 90643,
					spentAmountRequired = 8,
					traitCurrencyID = 2899,
				},
				{
					conditionID = 22767,
					topLeftNodeID = 90758,
					spentAmountRequired = 20,
					traitCurrencyID = 2900,
				},
				{
					conditionID = 22764,
					topLeftNodeID = 90677,
					spentAmountRequired = 20,
					traitCurrencyID = 2899,
				},
			},
		},
		[261] = { -- Subtlety
			ID = 852,
			nodes = {
				90620, 90621, 90622, 90623, 90624, 90625, 90626, 90627,
				90628, 90629, 90630, 90631, 90632, 90633, 90634, 90635,
				90636, 90637, 90638, 90639, 90640, 90641, 90642, 90643,
				90644, 90645, 90646, 90647, 90648, 90649, 90650, 90651,
				90652, 90653, 90654, 90655, 90656, 90657, 90658, 90659,
				90660, 90661, 90662, 90663, 90664, 90665, 90666, 90667,
				90668, 90669, 90670, 90671, 90672, 90673, 90674, 90675,
				90676, 90677, 90678, 90679, 90680, 90681, 90682, 90683,
				90684, 90685, 90686, 90687, 90688, 90689, 90690, 90691,
				90692, 90693, 90694, 90695, 90696, 90697, 90698, 90699,
				90700, 90701, 90702, 90703, 90704, 90705, 90706, 90707,
				90708, 90709, 90710, 90711, 90712, 90713, 90714, 90715,
				90716, 90717, 90718, 90719, 90720, 90721, 90722, 90723,
				90724, 90725, 90726, 90727, 90728, 90729, 90730, 90731,
				90732, 90733, 90734, 90735, 90736, 90737, 90738, 90739,
				90740, 90741, 90742, 90743, 90744, 90745, 90746, 90747,
				90748, 90749, 90750, 90751, 90752, 90753, 90754, 90755,
				90756, 90757, 90758, 90759, 90760, 90761, 90762, 90763,
				90764, 90765, 90766, 90767, 90768, 90769, 90770, 90771,
				90772, 90773, 90774, 90775, 90776, 90777, 90778, 90779,
				90780, 90781, 90782, 90783, 90784, 90785, 90786,
			},
			visibleNodes = {
				[90636] = true, [90637] = true, [90638] = true, [90639] = true,
				[90640] = true, [90684] = true, [90685] = true, [90686] = true,
				[90687] = true, [90688] = true, [90689] = true, [90690] = true,
				[90691] = true, [90692] = true, [90693] = true, [90694] = true,
				[90695] = true, [90696] = true, [90697] = true, [90698] = true,
				[90699] = true, [90700] = true, [90701] = true, [90702] = true,
				[90703] = true, [90704] = true, [90705] = true, [90706] = true,
				[90707] = true, [90708] = true, [90709] = true, [90710] = true,
				[90711] = true, [90712] = true, [90713] = true, [90714] = true,
				[90715] = true, [90716] = true, [90717] = true, [90718] = true,
				[90719] = true, [90720] = true, [90721] = true, [90722] = true,
				[90723] = true, [90724] = true, [90725] = true, [90726] = true,
				[90727] = true, [90728] = true, [90729] = true, [90730] = true,
				[90731] = true, [90732] = true, [90733] = true, [90734] = true,
				[90735] = true, [90736] = true, [90737] = true, [90738] = true,
				[90739] = true, [90740] = true, [90741] = true, [90742] = true,
				[90743] = true, [90744] = true, [90745] = true, [90746] = true,
				[90747] = true, [90748] = true, [90749] = true, [90750] = true,
				[90751] = true, [90752] = true, [90753] = true, [90754] = true,
				[90755] = true, [90756] = true, [90757] = true, [90758] = true,
				[90759] = true, [90760] = true, [90761] = true, [90762] = true,
				[90763] = true, [90764] = true,
			},
			grantedNodes = { 90685 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2900,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2899,
				},
			},
			gates = {
				{
					conditionID = 22769,
					topLeftNodeID = 90637,
					spentAmountRequired = 8,
					traitCurrencyID = 2900,
				},
				{
					conditionID = 22763,
					topLeftNodeID = 90699,
					spentAmountRequired = 8,
					traitCurrencyID = 2899,
				},
				{
					conditionID = 22767,
					topLeftNodeID = 90758,
					spentAmountRequired = 20,
					traitCurrencyID = 2900,
				},
				{
					conditionID = 22764,
					topLeftNodeID = 90704,
					spentAmountRequired = 20,
					traitCurrencyID = 2899,
				},
			},
		},
		-- Priest
		[256] = { -- Discipline
			ID = 795,
			nodes = {
				82552, 82553, 82554, 82555, 82556, 82557, 82558, 82559,
				82560, 82561, 82562, 82563, 82564, 82566, 82567, 82568,
				82569, 82570, 82571, 82572, 82573, 82574, 82575, 82576,
				82577, 82578, 82579, 82580, 82581, 82582, 82583, 82584,
				82585, 82586, 82587, 82588, 82589, 82590, 82591, 82592,
				82593, 82594, 82595, 82596, 82597, 82598, 82599, 82600,
				82601, 82602, 82603, 82604, 82605, 82606, 82607, 82608,
				82609, 82610, 82611, 82612, 82613, 82614, 82615, 82616,
				82617, 82618, 82619, 82620, 82621, 82622, 82623, 82624,
				82625, 82626, 82627, 82628, 82629, 82630, 82631, 82632,
				82633, 82634, 82635, 82636, 82637, 82638, 82639, 82640,
				82641, 82642, 82643, 82644, 82645, 82646, 82647, 82648,
				82649, 82650, 82651, 82652, 82653, 82654, 82655, 82656,
				82657, 82658, 82659, 82660, 82661, 82662, 82663, 82664,
				82665, 82666, 82667, 82668, 82669, 82670, 82671, 82672,
				82673, 82674, 82675, 82676, 82677, 82678, 82679, 82680,
				82681, 82682, 82683, 82684, 82685, 82686, 82687, 82688,
				82689, 82690, 82691, 82692, 82693, 82694, 82695, 82696,
				82697, 82698, 82699, 82700, 82701, 82702, 82703, 82704,
				82705, 82706, 82707, 82708, 82709, 82710, 82711, 82712,
				82713, 82714, 82715, 82716, 82717, 82718, 82719, 82720,
				82721, 86730, 92225,
			},
			visibleNodes = {
				[82556] = true, [82564] = true, [82566] = true, [82567] = true,
				[82568] = true, [82569] = true, [82570] = true, [82571] = true,
				[82572] = true, [82573] = true, [82574] = true, [82575] = true,
				[82576] = true, [82577] = true, [82578] = true, [82579] = true,
				[82580] = true, [82581] = true, [82582] = true, [82583] = true,
				[82584] = true, [82585] = true, [82586] = true, [82587] = true,
				[82588] = true, [82589] = true, [82590] = true, [82591] = true,
				[82592] = true, [82593] = true, [82594] = true, [82595] = true,
				[82596] = true, [82597] = true, [82598] = true, [82599] = true,
				[82600] = true, [82601] = true, [82602] = true, [82672] = true,
				[82673] = true, [82674] = true, [82675] = true, [82676] = true,
				[82677] = true, [82678] = true, [82679] = true, [82681] = true,
				[82682] = true, [82683] = true, [82684] = true, [82685] = true,
				[82686] = true, [82687] = true, [82688] = true, [82689] = true,
				[82690] = true, [82691] = true, [82692] = true, [82693] = true,
				[82694] = true, [82695] = true, [82696] = true, [82697] = true,
				[82698] = true, [82699] = true, [82700] = true, [82701] = true,
				[82702] = true, [82703] = true, [82705] = true, [82706] = true,
				[82707] = true, [82708] = true, [82709] = true, [82710] = true,
				[82711] = true, [82712] = true, [82713] = true, [82714] = true,
				[82715] = true, [82716] = true, [82717] = true, [82718] = true,
				[82719] = true, [82720] = true, [82721] = true, [86730] = true,
				[92225] = true,
			},
			grantedNodes = { 82713, 82717 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2805,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2804,
				},
			},
			gates = {
				{
					conditionID = 20304,
					topLeftNodeID = 82721,
					spentAmountRequired = 8,
					traitCurrencyID = 2805,
				},
				{
					conditionID = 20299,
					topLeftNodeID = 82590,
					spentAmountRequired = 8,
					traitCurrencyID = 2804,
				},
				{
					conditionID = 20302,
					topLeftNodeID = 82678,
					spentAmountRequired = 20,
					traitCurrencyID = 2805,
				},
				{
					conditionID = 20295,
					topLeftNodeID = 82601,
					spentAmountRequired = 20,
					traitCurrencyID = 2804,
				},
			},
		},
		[257] = { -- Holy
			ID = 795,
			nodes = {
				82552, 82553, 82554, 82555, 82556, 82557, 82558, 82559,
				82560, 82561, 82562, 82563, 82564, 82566, 82567, 82568,
				82569, 82570, 82571, 82572, 82573, 82574, 82575, 82576,
				82577, 82578, 82579, 82580, 82581, 82582, 82583, 82584,
				82585, 82586, 82587, 82588, 82589, 82590, 82591, 82592,
				82593, 82594, 82595, 82596, 82597, 82598, 82599, 82600,
				82601, 82602, 82603, 82604, 82605, 82606, 82607, 82608,
				82609, 82610, 82611, 82612, 82613, 82614, 82615, 82616,
				82617, 82618, 82619, 82620, 82621, 82622, 82623, 82624,
				82625, 82626, 82627, 82628, 82629, 82630, 82631, 82632,
				82633, 82634, 82635, 82636, 82637, 82638, 82639, 82640,
				82641, 82642, 82643, 82644, 82645, 82646, 82647, 82648,
				82649, 82650, 82651, 82652, 82653, 82654, 82655, 82656,
				82657, 82658, 82659, 82660, 82661, 82662, 82663, 82664,
				82665, 82666, 82667, 82668, 82669, 82670, 82671, 82672,
				82673, 82674, 82675, 82676, 82677, 82678, 82679, 82680,
				82681, 82682, 82683, 82684, 82685, 82686, 82687, 82688,
				82689, 82690, 82691, 82692, 82693, 82694, 82695, 82696,
				82697, 82698, 82699, 82700, 82701, 82702, 82703, 82704,
				82705, 82706, 82707, 82708, 82709, 82710, 82711, 82712,
				82713, 82714, 82715, 82716, 82717, 82718, 82719, 82720,
				82721, 86730, 92225,
			},
			visibleNodes = {
				[82554] = true, [82556] = true, [82603] = true, [82604] = true,
				[82605] = true, [82606] = true, [82607] = true, [82608] = true,
				[82609] = true, [82610] = true, [82611] = true, [82612] = true,
				[82613] = true, [82614] = true, [82615] = true, [82616] = true,
				[82617] = true, [82618] = true, [82619] = true, [82620] = true,
				[82621] = true, [82622] = true, [82623] = true, [82624] = true,
				[82625] = true, [82626] = true, [82627] = true, [82628] = true,
				[82629] = true, [82630] = true, [82631] = true, [82632] = true,
				[82633] = true, [82634] = true, [82635] = true, [82636] = true,
				[82637] = true, [82638] = true, [82639] = true, [82640] = true,
				[82641] = true, [82642] = true, [82672] = true, [82673] = true,
				[82674] = true, [82675] = true, [82676] = true, [82677] = true,
				[82678] = true, [82679] = true, [82681] = true, [82682] = true,
				[82683] = true, [82684] = true, [82685] = true, [82686] = true,
				[82687] = true, [82688] = true, [82689] = true, [82690] = true,
				[82691] = true, [82692] = true, [82693] = true, [82694] = true,
				[82695] = true, [82696] = true, [82697] = true, [82698] = true,
				[82699] = true, [82700] = true, [82701] = true, [82702] = true,
				[82703] = true, [82705] = true, [82706] = true, [82707] = true,
				[82708] = true, [82709] = true, [82710] = true, [82711] = true,
				[82712] = true, [82713] = true, [82714] = true, [82715] = true,
				[82716] = true, [82717] = true, [82718] = true, [82719] = true,
				[82720] = true, [82721] = true,
			},
			grantedNodes = { 82717, 82718 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2805,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2804,
				},
			},
			gates = {
				{
					conditionID = 20304,
					topLeftNodeID = 82721,
					spentAmountRequired = 8,
					traitCurrencyID = 2805,
				},
				{
					conditionID = 20299,
					topLeftNodeID = 82625,
					spentAmountRequired = 8,
					traitCurrencyID = 2804,
				},
				{
					conditionID = 20302,
					topLeftNodeID = 82678,
					spentAmountRequired = 20,
					traitCurrencyID = 2805,
				},
				{
					conditionID = 20295,
					topLeftNodeID = 82628,
					spentAmountRequired = 20,
					traitCurrencyID = 2804,
				},
			},
		},
		[258] = { -- Shadow
			ID = 795,
			nodes = {
				82552, 82553, 82554, 82555, 82556, 82557, 82558, 82559,
				82560, 82561, 82562, 82563, 82564, 82566, 82567, 82568,
				82569, 82570, 82571, 82572, 82573, 82574, 82575, 82576,
				82577, 82578, 82579, 82580, 82581, 82582, 82583, 82584,
				82585, 82586, 82587, 82588, 82589, 82590, 82591, 82592,
				82593, 82594, 82595, 82596, 82597, 82598, 82599, 82600,
				82601, 82602, 82603, 82604, 82605, 82606, 82607, 82608,
				82609, 82610, 82611, 82612, 82613, 82614, 82615, 82616,
				82617, 82618, 82619, 82620, 82621, 82622, 82623, 82624,
				82625, 82626, 82627, 82628, 82629, 82630, 82631, 82632,
				82633, 82634, 82635, 82636, 82637, 82638, 82639, 82640,
				82641, 82642, 82643, 82644, 82645, 82646, 82647, 82648,
				82649, 82650, 82651, 82652, 82653, 82654, 82655, 82656,
				82657, 82658, 82659, 82660, 82661, 82662, 82663, 82664,
				82665, 82666, 82667, 82668, 82669, 82670, 82671, 82672,
				82673, 82674, 82675, 82676, 82677, 82678, 82679, 82680,
				82681, 82682, 82683, 82684, 82685, 82686, 82687, 82688,
				82689, 82690, 82691, 82692, 82693, 82694, 82695, 82696,
				82697, 82698, 82699, 82700, 82701, 82702, 82703, 82704,
				82705, 82706, 82707, 82708, 82709, 82710, 82711, 82712,
				82713, 82714, 82715, 82716, 82717, 82718, 82719, 82720,
				82721, 86730, 92225,
			},
			visibleNodes = {
				[82552] = true, [82553] = true, [82555] = true, [82556] = true,
				[82557] = true, [82558] = true, [82559] = true, [82560] = true,
				[82561] = true, [82562] = true, [82563] = true, [82643] = true,
				[82644] = true, [82645] = true, [82646] = true, [82647] = true,
				[82648] = true, [82649] = true, [82650] = true, [82651] = true,
				[82652] = true, [82653] = true, [82654] = true, [82655] = true,
				[82656] = true, [82657] = true, [82658] = true, [82659] = true,
				[82660] = true, [82661] = true, [82662] = true, [82663] = true,
				[82664] = true, [82665] = true, [82666] = true, [82667] = true,
				[82668] = true, [82669] = true, [82670] = true, [82671] = true,
				[82672] = true, [82673] = true, [82674] = true, [82675] = true,
				[82676] = true, [82677] = true, [82678] = true, [82679] = true,
				[82680] = true, [82681] = true, [82683] = true, [82684] = true,
				[82685] = true, [82686] = true, [82687] = true, [82688] = true,
				[82689] = true, [82690] = true, [82691] = true, [82692] = true,
				[82693] = true, [82694] = true, [82695] = true, [82696] = true,
				[82697] = true, [82698] = true, [82699] = true, [82700] = true,
				[82701] = true, [82702] = true, [82703] = true, [82704] = true,
				[82706] = true, [82707] = true, [82708] = true, [82709] = true,
				[82710] = true, [82711] = true, [82712] = true, [82713] = true,
				[82714] = true, [82715] = true, [82716] = true, [82717] = true,
				[82718] = true, [82719] = true, [82720] = true, [82721] = true,
			},
			grantedNodes = { 82713, 82712 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2805,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2804,
				},
			},
			gates = {
				{
					conditionID = 20304,
					topLeftNodeID = 82721,
					spentAmountRequired = 8,
					traitCurrencyID = 2805,
				},
				{
					conditionID = 20299,
					topLeftNodeID = 82646,
					spentAmountRequired = 8,
					traitCurrencyID = 2804,
				},
				{
					conditionID = 20302,
					topLeftNodeID = 82678,
					spentAmountRequired = 20,
					traitCurrencyID = 2805,
				},
				{
					conditionID = 20295,
					topLeftNodeID = 82648,
					spentAmountRequired = 20,
					traitCurrencyID = 2804,
				},
			},
		},
		-- Death Knight
		[250] = { -- Blood
			ID = 750,
			nodes = {
				76033, 76034, 76035, 76036, 76037, 76038, 76039, 76040,
				76041, 76042, 76043, 76044, 76045, 76046, 76047, 76048,
				76049, 76050, 76051, 76052, 76053, 76054, 76055, 76056,
				76057, 76058, 76059, 76060, 76061, 76062, 76063, 76064,
				76065, 76066, 76067, 76068, 76069, 76070, 76071, 76072,
				76073, 76074, 76075, 76076, 76077, 76078, 76079, 76080,
				76081, 76082, 76083, 76084, 76085, 76086, 76087, 76088,
				76089, 76090, 76091, 76092, 76093, 76094, 76095, 76096,
				76097, 76098, 76099, 76100, 76101, 76102, 76103, 76104,
				76105, 76106, 76107, 76108, 76109, 76110, 76111, 76112,
				76113, 76114, 76115, 76116, 76117, 76118, 76119, 76120,
				76121, 76122, 76123, 76124, 76125, 76126, 76127, 76128,
				76129, 76130, 76131, 76132, 76133, 76134, 76135, 76136,
				76137, 76138, 76139, 76140, 76141, 76142, 76143, 76144,
				76145, 76146, 76147, 76148, 76149, 76150, 76151, 76152,
				76153, 76154, 76155, 76156, 76157, 76158, 76159, 76160,
				76161, 76162, 76163, 76164, 76165, 76166, 76167, 76168,
				76169, 76170, 76171, 76172, 76173, 76174, 76175, 76176,
				76177, 76178, 76179, 76180, 76181, 76182, 76183, 76184,
				76185, 76186, 76187, 76188, 76189, 76190, 76191, 76192,
				76193, 76194, 76195, 76196, 76197,
			},
			visibleNodes = {
				[76038] = true, [76039] = true, [76040] = true, [76041] = true,
				[76042] = true, [76043] = true, [76044] = true, [76045] = true,
				[76046] = true, [76047] = true, [76048] = true, [76049] = true,
				[76050] = true, [76051] = true, [76052] = true, [76053] = true,
				[76054] = true, [76055] = true, [76056] = true, [76057] = true,
				[76058] = true, [76059] = true, [76060] = true, [76061] = true,
				[76062] = true, [76063] = true, [76064] = true, [76065] = true,
				[76066] = true, [76067] = true, [76068] = true, [76069] = true,
				[76070] = true, [76071] = true, [76072] = true, [76073] = true,
				[76074] = true, [76075] = true, [76076] = true, [76077] = true,
				[76078] = true, [76079] = true, [76080] = true, [76081] = true,
				[76082] = true, [76083] = true, [76084] = true, [76085] = true,
				[76086] = true, [76087] = true, [76088] = true, [76124] = true,
				[76125] = true, [76126] = true, [76127] = true, [76128] = true,
				[76129] = true, [76130] = true, [76131] = true, [76132] = true,
				[76133] = true, [76134] = true, [76135] = true, [76136] = true,
				[76137] = true, [76138] = true, [76139] = true, [76140] = true,
				[76141] = true, [76142] = true, [76143] = true, [76144] = true,
				[76145] = true, [76146] = true, [76147] = true, [76165] = true,
				[76166] = true, [76167] = true, [76168] = true, [76169] = true,
				[76170] = true, [76171] = true, [76172] = true, [76173] = true,
				[76174] = true,
			},
			grantedNodes = { 76071 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2724,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2723,
				},
			},
			gates = {
				{
					conditionID = 19531,
					topLeftNodeID = 76047,
					spentAmountRequired = 8,
					traitCurrencyID = 2724,
				},
				{
					conditionID = 19529,
					topLeftNodeID = 76145,
					spentAmountRequired = 8,
					traitCurrencyID = 2723,
				},
				{
					conditionID = 19528,
					topLeftNodeID = 76088,
					spentAmountRequired = 20,
					traitCurrencyID = 2724,
				},
				{
					conditionID = 19535,
					topLeftNodeID = 76139,
					spentAmountRequired = 20,
					traitCurrencyID = 2723,
				},
			},
		},
		[251] = { -- Frost
			ID = 750,
			nodes = {
				76033, 76034, 76035, 76036, 76037, 76038, 76039, 76040,
				76041, 76042, 76043, 76044, 76045, 76046, 76047, 76048,
				76049, 76050, 76051, 76052, 76053, 76054, 76055, 76056,
				76057, 76058, 76059, 76060, 76061, 76062, 76063, 76064,
				76065, 76066, 76067, 76068, 76069, 76070, 76071, 76072,
				76073, 76074, 76075, 76076, 76077, 76078, 76079, 76080,
				76081, 76082, 76083, 76084, 76085, 76086, 76087, 76088,
				76089, 76090, 76091, 76092, 76093, 76094, 76095, 76096,
				76097, 76098, 76099, 76100, 76101, 76102, 76103, 76104,
				76105, 76106, 76107, 76108, 76109, 76110, 76111, 76112,
				76113, 76114, 76115, 76116, 76117, 76118, 76119, 76120,
				76121, 76122, 76123, 76124, 76125, 76126, 76127, 76128,
				76129, 76130, 76131, 76132, 76133, 76134, 76135, 76136,
				76137, 76138, 76139, 76140, 76141, 76142, 76143, 76144,
				76145, 76146, 76147, 76148, 76149, 76150, 76151, 76152,
				76153, 76154, 76155, 76156, 76157, 76158, 76159, 76160,
				76161, 76162, 76163, 76164, 76165, 76166, 76167, 76168,
				76169, 76170, 76171, 76172, 76173, 76174, 76175, 76176,
				76177, 76178, 76179, 76180, 76181, 76182, 76183, 76184,
				76185, 76186, 76187, 76188, 76189, 76190, 76191, 76192,
				76193, 76194, 76195, 76196, 76197,
			},
			visibleNodes = {
				[76033] = true, [76034] = true, [76035] = true, [76036] = true,
				[76037] = true, [76044] = true, [76045] = true, [76046] = true,
				[76047] = true, [76048] = true, [76049] = true, [76050] = true,
				[76051] = true, [76052] = true, [76053] = true, [76054] = true,
				[76055] = true, [76056] = true, [76057] = true, [76058] = true,
				[76059] = true, [76060] = true, [76061] = true, [76062] = true,
				[76063] = true, [76064] = true, [76065] = true, [76066] = true,
				[76067] = true, [76068] = true, [76069] = true, [76070] = true,
				[76071] = true, [76072] = true, [76073] = true, [76074] = true,
				[76075] = true, [76076] = true, [76077] = true, [76078] = true,
				[76079] = true, [76080] = true, [76081] = true, [76082] = true,
				[76083] = true, [76084] = true, [76085] = true, [76086] = true,
				[76087] = true, [76088] = true, [76089] = true, [76090] = true,
				[76091] = true, [76092] = true, [76093] = true, [76094] = true,
				[76095] = true, [76096] = true, [76097] = true, [76098] = true,
				[76099] = true, [76100] = true, [76101] = true, [76102] = true,
				[76103] = true, [76104] = true, [76105] = true, [76106] = true,
				[76107] = true, [76108] = true, [76109] = true, [76110] = true,
				[76111] = true, [76112] = true, [76113] = true, [76114] = true,
				[76115] = true, [76116] = true, [76117] = true, [76118] = true,
				[76119] = true, [76120] = true, [76121] = true, [76122] = true,
				[76123] = true,
			},
			grantedNodes = { 76081 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2724,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2723,
				},
			},
			gates = {
				{
					conditionID = 19531,
					topLeftNodeID = 76047,
					spentAmountRequired = 8,
					traitCurrencyID = 2724,
				},
				{
					conditionID = 19529,
					topLeftNodeID = 76119,
					spentAmountRequired = 8,
					traitCurrencyID = 2723,
				},
				{
					conditionID = 19528,
					topLeftNodeID = 76088,
					spentAmountRequired = 20,
					traitCurrencyID = 2724,
				},
				{
					conditionID = 19535,
					topLeftNodeID = 76090,
					spentAmountRequired = 20,
					traitCurrencyID = 2723,
				},
			},
		},
		[252] = { -- Unholy
			ID = 750,
			nodes = {
				76033, 76034, 76035, 76036, 76037, 76038, 76039, 76040,
				76041, 76042, 76043, 76044, 76045, 76046, 76047, 76048,
				76049, 76050, 76051, 76052, 76053, 76054, 76055, 76056,
				76057, 76058, 76059, 76060, 76061, 76062, 76063, 76064,
				76065, 76066, 76067, 76068, 76069, 76070, 76071, 76072,
				76073, 76074, 76075, 76076, 76077, 76078, 76079, 76080,
				76081, 76082, 76083, 76084, 76085, 76086, 76087, 76088,
				76089, 76090, 76091, 76092, 76093, 76094, 76095, 76096,
				76097, 76098, 76099, 76100, 76101, 76102, 76103, 76104,
				76105, 76106, 76107, 76108, 76109, 76110, 76111, 76112,
				76113, 76114, 76115, 76116, 76117, 76118, 76119, 76120,
				76121, 76122, 76123, 76124, 76125, 76126, 76127, 76128,
				76129, 76130, 76131, 76132, 76133, 76134, 76135, 76136,
				76137, 76138, 76139, 76140, 76141, 76142, 76143, 76144,
				76145, 76146, 76147, 76148, 76149, 76150, 76151, 76152,
				76153, 76154, 76155, 76156, 76157, 76158, 76159, 76160,
				76161, 76162, 76163, 76164, 76165, 76166, 76167, 76168,
				76169, 76170, 76171, 76172, 76173, 76174, 76175, 76176,
				76177, 76178, 76179, 76180, 76181, 76182, 76183, 76184,
				76185, 76186, 76187, 76188, 76189, 76190, 76191, 76192,
				76193, 76194, 76195, 76196, 76197,
			},
			visibleNodes = {
				[76044] = true, [76045] = true, [76046] = true, [76047] = true,
				[76048] = true, [76049] = true, [76050] = true, [76051] = true,
				[76052] = true, [76053] = true, [76054] = true, [76055] = true,
				[76056] = true, [76057] = true, [76058] = true, [76059] = true,
				[76060] = true, [76061] = true, [76062] = true, [76063] = true,
				[76064] = true, [76065] = true, [76066] = true, [76067] = true,
				[76068] = true, [76069] = true, [76070] = true, [76071] = true,
				[76072] = true, [76073] = true, [76074] = true, [76075] = true,
				[76076] = true, [76077] = true, [76078] = true, [76079] = true,
				[76080] = true, [76081] = true, [76082] = true, [76083] = true,
				[76084] = true, [76085] = true, [76086] = true, [76087] = true,
				[76088] = true, [76148] = true, [76149] = true, [76150] = true,
				[76151] = true, [76152] = true, [76153] = true, [76154] = true,
				[76155] = true, [76156] = true, [76157] = true, [76158] = true,
				[76159] = true, [76160] = true, [76161] = true, [76162] = true,
				[76163] = true, [76164] = true, [76175] = true, [76176] = true,
				[76177] = true, [76178] = true, [76179] = true, [76180] = true,
				[76181] = true, [76182] = true, [76183] = true, [76184] = true,
				[76185] = true, [76186] = true, [76187] = true, [76188] = true,
				[76189] = true, [76190] = true, [76191] = true, [76192] = true,
				[76193] = true, [76194] = true, [76195] = true, [76196] = true,
				[76197] = true,
			},
			grantedNodes = { 76072 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2724,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2723,
				},
			},
			gates = {
				{
					conditionID = 19531,
					topLeftNodeID = 76047,
					spentAmountRequired = 8,
					traitCurrencyID = 2724,
				},
				{
					conditionID = 19529,
					topLeftNodeID = 76161,
					spentAmountRequired = 8,
					traitCurrencyID = 2723,
				},
				{
					conditionID = 19528,
					topLeftNodeID = 76088,
					spentAmountRequired = 20,
					traitCurrencyID = 2724,
				},
				{
					conditionID = 19535,
					topLeftNodeID = 76158,
					spentAmountRequired = 20,
					traitCurrencyID = 2723,
				},
			},
		},
		-- Shaman
		[262] = { -- Elemental
			ID = 786,
			nodes = {
				80937, 80938, 80939, 80940, 80941, 80942, 80943, 80944,
				80945, 80946, 80947, 80948, 80949, 80950, 80951, 80953,
				80954, 80955, 80956, 80957, 80958, 80959, 80960, 80961,
				80962, 80963, 80964, 80965, 80966, 80967, 80968, 80969,
				80970, 80971, 80972, 80973, 80974, 80975, 80976, 80977,
				80978, 80979, 80980, 80981, 80982, 80983, 80984, 80985,
				80986, 80987, 80988, 80989, 80990, 80991, 80992, 80993,
				80994, 80995, 80996, 80997, 80998, 80999, 81000, 81001,
				81002, 81003, 81004, 81005, 81006, 81007, 81008, 81009,
				81010, 81011, 81012, 81013, 81014, 81015, 81016, 81017,
				81018, 81019, 81020, 81021, 81022, 81023, 81024, 81025,
				81026, 81027, 81028, 81029, 81030, 81031, 81032, 81033,
				81034, 81035, 81036, 81037, 81038, 81039, 81040, 81041,
				81042, 81043, 81044, 81045, 81046, 81047, 81048, 81049,
				81050, 81051, 81052, 81053, 81054, 81055, 81056, 81057,
				81058, 81059, 81060, 81061, 81062, 81063, 81064, 81065,
				81066, 81067, 81068, 81069, 81070, 81071, 81072, 81073,
				81074, 81075, 81076, 81077, 81078, 81079, 81080, 81081,
				81082, 81083, 81084, 81085, 81086, 81087, 81088, 81089,
				81090, 81091, 81092, 81093, 81094, 81095, 81096, 81097,
				81098, 81099, 81100, 81101, 81102, 81103, 81104, 81105,
				81106, 92219,
			},
			visibleNodes = {
				[80977] = true, [80978] = true, [80979] = true, [80980] = true,
				[80981] = true, [80982] = true, [80983] = true, [80984] = true,
				[80985] = true, [80986] = true, [80987] = true, [80988] = true,
				[80989] = true, [80990] = true, [80991] = true, [80992] = true,
				[80993] = true, [80994] = true, [80995] = true, [80996] = true,
				[80997] = true, [80998] = true, [80999] = true, [81000] = true,
				[81001] = true, [81002] = true, [81003] = true, [81004] = true,
				[81005] = true, [81006] = true, [81007] = true, [81008] = true,
				[81009] = true, [81010] = true, [81011] = true, [81012] = true,
				[81013] = true, [81014] = true, [81015] = true, [81016] = true,
				[81056] = true, [81057] = true, [81058] = true, [81059] = true,
				[81060] = true, [81061] = true, [81062] = true, [81063] = true,
				[81064] = true, [81065] = true, [81066] = true, [81067] = true,
				[81068] = true, [81069] = true, [81070] = true, [81071] = true,
				[81072] = true, [81074] = true, [81075] = true, [81076] = true,
				[81078] = true, [81079] = true, [81080] = true, [81081] = true,
				[81082] = true, [81083] = true, [81084] = true, [81085] = true,
				[81086] = true, [81087] = true, [81088] = true, [81089] = true,
				[81090] = true, [81091] = true, [81092] = true, [81093] = true,
				[81094] = true, [81095] = true, [81096] = true, [81097] = true,
				[81098] = true, [81099] = true, [81100] = true, [81101] = true,
				[81102] = true, [81103] = true, [81104] = true, [81105] = true,
				[81106] = true,
			},
			grantedNodes = { 81061, 81062 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2786,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2785,
				},
			},
			gates = {
				{
					conditionID = 20088,
					topLeftNodeID = 81065,
					spentAmountRequired = 8,
					traitCurrencyID = 2786,
				},
				{
					conditionID = 20092,
					topLeftNodeID = 80988,
					spentAmountRequired = 8,
					traitCurrencyID = 2785,
				},
				{
					conditionID = 20082,
					topLeftNodeID = 81101,
					spentAmountRequired = 20,
					traitCurrencyID = 2786,
				},
				{
					conditionID = 20094,
					topLeftNodeID = 80994,
					spentAmountRequired = 20,
					traitCurrencyID = 2785,
				},
			},
		},
		[263] = { -- Enhancement
			ID = 786,
			nodes = {
				80937, 80938, 80939, 80940, 80941, 80942, 80943, 80944,
				80945, 80946, 80947, 80948, 80949, 80950, 80951, 80953,
				80954, 80955, 80956, 80957, 80958, 80959, 80960, 80961,
				80962, 80963, 80964, 80965, 80966, 80967, 80968, 80969,
				80970, 80971, 80972, 80973, 80974, 80975, 80976, 80977,
				80978, 80979, 80980, 80981, 80982, 80983, 80984, 80985,
				80986, 80987, 80988, 80989, 80990, 80991, 80992, 80993,
				80994, 80995, 80996, 80997, 80998, 80999, 81000, 81001,
				81002, 81003, 81004, 81005, 81006, 81007, 81008, 81009,
				81010, 81011, 81012, 81013, 81014, 81015, 81016, 81017,
				81018, 81019, 81020, 81021, 81022, 81023, 81024, 81025,
				81026, 81027, 81028, 81029, 81030, 81031, 81032, 81033,
				81034, 81035, 81036, 81037, 81038, 81039, 81040, 81041,
				81042, 81043, 81044, 81045, 81046, 81047, 81048, 81049,
				81050, 81051, 81052, 81053, 81054, 81055, 81056, 81057,
				81058, 81059, 81060, 81061, 81062, 81063, 81064, 81065,
				81066, 81067, 81068, 81069, 81070, 81071, 81072, 81073,
				81074, 81075, 81076, 81077, 81078, 81079, 81080, 81081,
				81082, 81083, 81084, 81085, 81086, 81087, 81088, 81089,
				81090, 81091, 81092, 81093, 81094, 81095, 81096, 81097,
				81098, 81099, 81100, 81101, 81102, 81103, 81104, 81105,
				81106, 92219,
			},
			visibleNodes = {
				[80937] = true, [80938] = true, [80939] = true, [80940] = true,
				[80941] = true, [80942] = true, [80943] = true, [80944] = true,
				[80945] = true, [80946] = true, [80947] = true, [80948] = true,
				[80949] = true, [80950] = true, [80951] = true, [80953] = true,
				[80954] = true, [80955] = true, [80956] = true, [80957] = true,
				[80958] = true, [80959] = true, [80960] = true, [80961] = true,
				[80962] = true, [80963] = true, [80964] = true, [80965] = true,
				[80966] = true, [80967] = true, [80968] = true, [80969] = true,
				[80970] = true, [80971] = true, [80972] = true, [80973] = true,
				[80974] = true, [80975] = true, [81056] = true, [81057] = true,
				[81058] = true, [81059] = true, [81060] = true, [81061] = true,
				[81062] = true, [81063] = true, [81064] = true, [81065] = true,
				[81066] = true, [81067] = true, [81068] = true, [81069] = true,
				[81070] = true, [81071] = true, [81072] = true, [81074] = true,
				[81076] = true, [81077] = true, [81078] = true, [81079] = true,
				[81080] = true, [81081] = true, [81082] = true, [81083] = true,
				[81084] = true, [81085] = true, [81086] = true, [81087] = true,
				[81088] = true, [81089] = true, [81090] = true, [81091] = true,
				[81092] = true, [81093] = true, [81094] = true, [81095] = true,
				[81096] = true, [81097] = true, [81098] = true, [81099] = true,
				[81100] = true, [81101] = true, [81102] = true, [81103] = true,
				[81104] = true, [81105] = true, [81106] = true, [92219] = true,
			},
			grantedNodes = { 81061, 81060 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2786,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2785,
				},
			},
			gates = {
				{
					conditionID = 20088,
					topLeftNodeID = 81065,
					spentAmountRequired = 8,
					traitCurrencyID = 2786,
				},
				{
					conditionID = 20092,
					topLeftNodeID = 80959,
					spentAmountRequired = 8,
					traitCurrencyID = 2785,
				},
				{
					conditionID = 20082,
					topLeftNodeID = 81101,
					spentAmountRequired = 20,
					traitCurrencyID = 2786,
				},
				{
					conditionID = 20094,
					topLeftNodeID = 80965,
					spentAmountRequired = 20,
					traitCurrencyID = 2785,
				},
			},
		},
		[264] = { -- Restoration
			ID = 786,
			nodes = {
				80937, 80938, 80939, 80940, 80941, 80942, 80943, 80944,
				80945, 80946, 80947, 80948, 80949, 80950, 80951, 80953,
				80954, 80955, 80956, 80957, 80958, 80959, 80960, 80961,
				80962, 80963, 80964, 80965, 80966, 80967, 80968, 80969,
				80970, 80971, 80972, 80973, 80974, 80975, 80976, 80977,
				80978, 80979, 80980, 80981, 80982, 80983, 80984, 80985,
				80986, 80987, 80988, 80989, 80990, 80991, 80992, 80993,
				80994, 80995, 80996, 80997, 80998, 80999, 81000, 81001,
				81002, 81003, 81004, 81005, 81006, 81007, 81008, 81009,
				81010, 81011, 81012, 81013, 81014, 81015, 81016, 81017,
				81018, 81019, 81020, 81021, 81022, 81023, 81024, 81025,
				81026, 81027, 81028, 81029, 81030, 81031, 81032, 81033,
				81034, 81035, 81036, 81037, 81038, 81039, 81040, 81041,
				81042, 81043, 81044, 81045, 81046, 81047, 81048, 81049,
				81050, 81051, 81052, 81053, 81054, 81055, 81056, 81057,
				81058, 81059, 81060, 81061, 81062, 81063, 81064, 81065,
				81066, 81067, 81068, 81069, 81070, 81071, 81072, 81073,
				81074, 81075, 81076, 81077, 81078, 81079, 81080, 81081,
				81082, 81083, 81084, 81085, 81086, 81087, 81088, 81089,
				81090, 81091, 81092, 81093, 81094, 81095, 81096, 81097,
				81098, 81099, 81100, 81101, 81102, 81103, 81104, 81105,
				81106, 92219,
			},
			visibleNodes = {
				[80976] = true, [81017] = true, [81018] = true, [81019] = true,
				[81020] = true, [81021] = true, [81022] = true, [81023] = true,
				[81024] = true, [81025] = true, [81026] = true, [81027] = true,
				[81028] = true, [81029] = true, [81030] = true, [81031] = true,
				[81032] = true, [81033] = true, [81034] = true, [81035] = true,
				[81036] = true, [81037] = true, [81038] = true, [81039] = true,
				[81040] = true, [81041] = true, [81042] = true, [81043] = true,
				[81044] = true, [81045] = true, [81046] = true, [81047] = true,
				[81048] = true, [81049] = true, [81050] = true, [81051] = true,
				[81052] = true, [81053] = true, [81054] = true, [81055] = true,
				[81056] = true, [81057] = true, [81058] = true, [81059] = true,
				[81060] = true, [81061] = true, [81062] = true, [81063] = true,
				[81064] = true, [81065] = true, [81066] = true, [81067] = true,
				[81068] = true, [81069] = true, [81070] = true, [81071] = true,
				[81072] = true, [81073] = true, [81074] = true, [81076] = true,
				[81078] = true, [81079] = true, [81080] = true, [81081] = true,
				[81082] = true, [81083] = true, [81084] = true, [81085] = true,
				[81086] = true, [81087] = true, [81088] = true, [81089] = true,
				[81090] = true, [81091] = true, [81092] = true, [81093] = true,
				[81094] = true, [81095] = true, [81096] = true, [81097] = true,
				[81098] = true, [81099] = true, [81100] = true, [81101] = true,
				[81102] = true, [81103] = true, [81104] = true, [81105] = true,
				[81106] = true,
			},
			grantedNodes = { 81063, 81062 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2786,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2785,
				},
			},
			gates = {
				{
					conditionID = 20088,
					topLeftNodeID = 81065,
					spentAmountRequired = 8,
					traitCurrencyID = 2786,
				},
				{
					conditionID = 20092,
					topLeftNodeID = 81031,
					spentAmountRequired = 8,
					traitCurrencyID = 2785,
				},
				{
					conditionID = 20082,
					topLeftNodeID = 81101,
					spentAmountRequired = 20,
					traitCurrencyID = 2786,
				},
				{
					conditionID = 20094,
					topLeftNodeID = 81036,
					spentAmountRequired = 20,
					traitCurrencyID = 2785,
				},
			},
		},
		-- Mage
		[62] = { -- Arcane
			ID = 658,
			nodes = {
				62083, 62084, 62085, 62086, 62087, 62088, 62089, 62090,
				62091, 62092, 62093, 62094, 62095, 62096, 62097, 62098,
				62099, 62100, 62101, 62102, 62103, 62104, 62105, 62106,
				62107, 62108, 62109, 62110, 62111, 62112, 62113, 62114,
				62115, 62116, 62117, 62118, 62119, 62120, 62121, 62122,
				62123, 62124, 62125, 62126, 62127, 62128, 62129, 62130,
				62131, 62132, 62133, 62134, 62135, 62136, 62137, 62138,
				62139, 62140, 62141, 62142, 62143, 62144, 62145, 62146,
				62147, 62148, 62150, 62151, 62152, 62153, 62154, 62155,
				62156, 62157, 62158, 62159, 62160, 62161, 62162, 62163,
				62164, 62165, 62166, 62167, 62168, 62169, 62170, 62171,
				62172, 62173, 62174, 62175, 62176, 62177, 62178, 62179,
				62180, 62181, 62182, 62183, 62184, 62185, 62186, 62187,
				62188, 62189, 62190, 62191, 62192, 62193, 62194, 62195,
				62196, 62197, 62198, 62199, 62200, 62201, 62202, 62203,
				62204, 62205, 62206, 62207, 62208, 62209, 62210, 62211,
				62212, 62213, 62214, 62215, 62216, 62217, 62218, 62219,
				62220, 62221, 62222, 62223, 62224, 62225, 62226, 62227,
				62228, 62229, 62230, 62231, 62232, 62233, 62234, 62235,
				62236, 62237, 62238, 62239, 62240, 62241, 81467, 81468,
			},
			visibleNodes = {
				[62084] = true, [62085] = true, [62086] = true, [62087] = true,
				[62088] = true, [62089] = true, [62090] = true, [62091] = true,
				[62092] = true, [62093] = true, [62094] = true, [62095] = true,
				[62096] = true, [62097] = true, [62098] = true, [62099] = true,
				[62100] = true, [62101] = true, [62102] = true, [62103] = true,
				[62104] = true, [62105] = true, [62106] = true, [62107] = true,
				[62108] = true, [62109] = true, [62110] = true, [62111] = true,
				[62112] = true, [62113] = true, [62114] = true, [62115] = true,
				[62116] = true, [62118] = true, [62120] = true, [62121] = true,
				[62122] = true, [62123] = true, [62124] = true, [62125] = true,
				[62126] = true, [62127] = true, [62128] = true, [62129] = true,
				[62130] = true, [62131] = true, [62132] = true, [62133] = true,
				[62134] = true, [62135] = true, [62136] = true, [62137] = true,
				[62138] = true, [62139] = true, [62140] = true, [62141] = true,
				[62142] = true, [62143] = true, [62144] = true, [62145] = true,
				[62146] = true, [62147] = true, [62148] = true, [62221] = true,
				[62222] = true, [62223] = true, [62224] = true, [62225] = true,
				[62226] = true, [62227] = true, [62228] = true, [62229] = true,
				[62230] = true, [62231] = true, [62232] = true, [62233] = true,
				[62234] = true, [62235] = true, [62236] = true, [62237] = true,
				[62238] = true, [62239] = true, [62240] = true, [62241] = true,
			},
			grantedNodes = { 62121 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2517,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2516,
				},
			},
			gates = {
				{
					conditionID = 18031,
					topLeftNodeID = 62107,
					spentAmountRequired = 8,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18033,
					topLeftNodeID = 62145,
					spentAmountRequired = 8,
					traitCurrencyID = 2516,
				},
				{
					conditionID = 18031,
					topLeftNodeID = 62128,
					spentAmountRequired = 8,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18034,
					topLeftNodeID = 62128,
					spentAmountRequired = 20,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18042,
					topLeftNodeID = 62147,
					spentAmountRequired = 20,
					traitCurrencyID = 2516,
				},
			},
		},
		[63] = { -- Fire
			ID = 658,
			nodes = {
				62083, 62084, 62085, 62086, 62087, 62088, 62089, 62090,
				62091, 62092, 62093, 62094, 62095, 62096, 62097, 62098,
				62099, 62100, 62101, 62102, 62103, 62104, 62105, 62106,
				62107, 62108, 62109, 62110, 62111, 62112, 62113, 62114,
				62115, 62116, 62117, 62118, 62119, 62120, 62121, 62122,
				62123, 62124, 62125, 62126, 62127, 62128, 62129, 62130,
				62131, 62132, 62133, 62134, 62135, 62136, 62137, 62138,
				62139, 62140, 62141, 62142, 62143, 62144, 62145, 62146,
				62147, 62148, 62150, 62151, 62152, 62153, 62154, 62155,
				62156, 62157, 62158, 62159, 62160, 62161, 62162, 62163,
				62164, 62165, 62166, 62167, 62168, 62169, 62170, 62171,
				62172, 62173, 62174, 62175, 62176, 62177, 62178, 62179,
				62180, 62181, 62182, 62183, 62184, 62185, 62186, 62187,
				62188, 62189, 62190, 62191, 62192, 62193, 62194, 62195,
				62196, 62197, 62198, 62199, 62200, 62201, 62202, 62203,
				62204, 62205, 62206, 62207, 62208, 62209, 62210, 62211,
				62212, 62213, 62214, 62215, 62216, 62217, 62218, 62219,
				62220, 62221, 62222, 62223, 62224, 62225, 62226, 62227,
				62228, 62229, 62230, 62231, 62232, 62233, 62234, 62235,
				62236, 62237, 62238, 62239, 62240, 62241, 81467, 81468,
			},
			visibleNodes = {
				[62083] = true, [62084] = true, [62085] = true, [62086] = true,
				[62087] = true, [62088] = true, [62089] = true, [62090] = true,
				[62091] = true, [62092] = true, [62093] = true, [62094] = true,
				[62095] = true, [62096] = true, [62097] = true, [62098] = true,
				[62099] = true, [62100] = true, [62101] = true, [62102] = true,
				[62103] = true, [62104] = true, [62105] = true, [62106] = true,
				[62107] = true, [62108] = true, [62109] = true, [62110] = true,
				[62111] = true, [62112] = true, [62113] = true, [62114] = true,
				[62115] = true, [62116] = true, [62118] = true, [62119] = true,
				[62120] = true, [62122] = true, [62123] = true, [62124] = true,
				[62125] = true, [62126] = true, [62127] = true, [62128] = true,
				[62129] = true, [62186] = true, [62187] = true, [62188] = true,
				[62189] = true, [62190] = true, [62191] = true, [62192] = true,
				[62193] = true, [62194] = true, [62195] = true, [62196] = true,
				[62197] = true, [62198] = true, [62199] = true, [62200] = true,
				[62201] = true, [62202] = true, [62203] = true, [62204] = true,
				[62205] = true, [62206] = true, [62207] = true, [62208] = true,
				[62209] = true, [62210] = true, [62211] = true, [62212] = true,
				[62213] = true, [62214] = true, [62215] = true, [62216] = true,
				[62217] = true, [62218] = true, [62219] = true, [62220] = true,
			},
			grantedNodes = { 62119 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2517,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2516,
				},
			},
			gates = {
				{
					conditionID = 18031,
					topLeftNodeID = 62107,
					spentAmountRequired = 8,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18033,
					topLeftNodeID = 62211,
					spentAmountRequired = 8,
					traitCurrencyID = 2516,
				},
				{
					conditionID = 18031,
					topLeftNodeID = 62128,
					spentAmountRequired = 8,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18034,
					topLeftNodeID = 62128,
					spentAmountRequired = 20,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18042,
					topLeftNodeID = 62199,
					spentAmountRequired = 20,
					traitCurrencyID = 2516,
				},
			},
		},
		[64] = { -- Frost
			ID = 658,
			nodes = {
				62083, 62084, 62085, 62086, 62087, 62088, 62089, 62090,
				62091, 62092, 62093, 62094, 62095, 62096, 62097, 62098,
				62099, 62100, 62101, 62102, 62103, 62104, 62105, 62106,
				62107, 62108, 62109, 62110, 62111, 62112, 62113, 62114,
				62115, 62116, 62117, 62118, 62119, 62120, 62121, 62122,
				62123, 62124, 62125, 62126, 62127, 62128, 62129, 62130,
				62131, 62132, 62133, 62134, 62135, 62136, 62137, 62138,
				62139, 62140, 62141, 62142, 62143, 62144, 62145, 62146,
				62147, 62148, 62150, 62151, 62152, 62153, 62154, 62155,
				62156, 62157, 62158, 62159, 62160, 62161, 62162, 62163,
				62164, 62165, 62166, 62167, 62168, 62169, 62170, 62171,
				62172, 62173, 62174, 62175, 62176, 62177, 62178, 62179,
				62180, 62181, 62182, 62183, 62184, 62185, 62186, 62187,
				62188, 62189, 62190, 62191, 62192, 62193, 62194, 62195,
				62196, 62197, 62198, 62199, 62200, 62201, 62202, 62203,
				62204, 62205, 62206, 62207, 62208, 62209, 62210, 62211,
				62212, 62213, 62214, 62215, 62216, 62217, 62218, 62219,
				62220, 62221, 62222, 62223, 62224, 62225, 62226, 62227,
				62228, 62229, 62230, 62231, 62232, 62233, 62234, 62235,
				62236, 62237, 62238, 62239, 62240, 62241, 81467, 81468,
			},
			visibleNodes = {
				[62084] = true, [62085] = true, [62086] = true, [62087] = true,
				[62088] = true, [62089] = true, [62090] = true, [62091] = true,
				[62092] = true, [62093] = true, [62094] = true, [62095] = true,
				[62096] = true, [62097] = true, [62098] = true, [62099] = true,
				[62100] = true, [62101] = true, [62102] = true, [62103] = true,
				[62104] = true, [62105] = true, [62106] = true, [62107] = true,
				[62108] = true, [62109] = true, [62110] = true, [62111] = true,
				[62112] = true, [62113] = true, [62114] = true, [62115] = true,
				[62116] = true, [62117] = true, [62118] = true, [62120] = true,
				[62122] = true, [62123] = true, [62124] = true, [62125] = true,
				[62126] = true, [62127] = true, [62128] = true, [62129] = true,
				[62150] = true, [62151] = true, [62152] = true, [62153] = true,
				[62154] = true, [62155] = true, [62156] = true, [62157] = true,
				[62158] = true, [62159] = true, [62160] = true, [62161] = true,
				[62162] = true, [62163] = true, [62164] = true, [62165] = true,
				[62166] = true, [62167] = true, [62168] = true, [62169] = true,
				[62170] = true, [62171] = true, [62172] = true, [62173] = true,
				[62174] = true, [62175] = true, [62176] = true, [62177] = true,
				[62178] = true, [62179] = true, [62180] = true, [62181] = true,
				[62182] = true, [62183] = true, [62184] = true, [62185] = true,
				[81467] = true, [81468] = true,
			},
			grantedNodes = { 62117 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2517,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2516,
				},
			},
			gates = {
				{
					conditionID = 18031,
					topLeftNodeID = 62107,
					spentAmountRequired = 8,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18033,
					topLeftNodeID = 62181,
					spentAmountRequired = 8,
					traitCurrencyID = 2516,
				},
				{
					conditionID = 18031,
					topLeftNodeID = 62128,
					spentAmountRequired = 8,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18034,
					topLeftNodeID = 62128,
					spentAmountRequired = 20,
					traitCurrencyID = 2517,
				},
				{
					conditionID = 18042,
					topLeftNodeID = 62183,
					spentAmountRequired = 20,
					traitCurrencyID = 2516,
				},
			},
		},
		-- Warlock
		[265] = { -- Affliction
			ID = 720,
			nodes = {
				71915, 71916, 71917, 71918, 71919, 71920, 71921, 71922,
				71923, 71924, 71925, 71926, 71927, 71928, 71929, 71930,
				71931, 71932, 71933, 71934, 71935, 71936, 71937, 71938,
				71939, 71940, 71941, 71942, 71943, 71944, 71945, 71946,
				71947, 71948, 71949, 71950, 71951, 71952, 71953, 71954,
				71955, 71956, 71957, 71958, 71959, 71960, 71961, 71962,
				71963, 71964, 71965, 71966, 71967, 71968, 71969, 71970,
				71971, 71972, 71973, 71974, 71975, 71976, 71977, 71978,
				71979, 71980, 71981, 71982, 71983, 71984, 71985, 71986,
				71987, 71988, 71989, 71990, 71991, 71992, 71993, 71994,
				71995, 71996, 71997, 71998, 71999, 72000, 72001, 72002,
				72003, 72004, 72005, 72006, 72007, 72008, 72009, 72010,
				72011, 72012, 72013, 72014, 72015, 72016, 72017, 72018,
				72019, 72020, 72021, 72022, 72023, 72024, 72025, 72026,
				72027, 72028, 72029, 72030, 72031, 72032, 72033, 72034,
				72035, 72036, 72037, 72038, 72039, 72040, 72041, 72042,
				72043, 72044, 72045, 72046, 72047, 72048, 72049, 72050,
				72051, 72052, 72053, 72054, 72055, 72056, 72057, 72058,
				72059, 72060, 72061, 72062, 72063, 72064, 72065, 72066,
				72067, 72068, 72069,
			},
			visibleNodes = {
				[71915] = true, [71916] = true, [71917] = true, [71918] = true,
				[71919] = true, [71920] = true, [71921] = true, [71922] = true,
				[71923] = true, [71924] = true, [71925] = true, [71926] = true,
				[71927] = true, [71928] = true, [71929] = true, [71930] = true,
				[71931] = true, [71932] = true, [71933] = true, [71934] = true,
				[71935] = true, [71936] = true, [71937] = true, [71938] = true,
				[71939] = true, [71940] = true, [71941] = true, [71942] = true,
				[71943] = true, [71944] = true, [71945] = true, [71946] = true,
				[71947] = true, [71948] = true, [71949] = true, [71950] = true,
				[71951] = true, [71952] = true, [71953] = true, [71954] = true,
				[71955] = true, [71956] = true, [71957] = true, [71986] = true,
				[71987] = true, [71988] = true, [71989] = true, [71990] = true,
				[72031] = true, [72032] = true, [72033] = true, [72034] = true,
				[72035] = true, [72036] = true, [72037] = true, [72038] = true,
				[72039] = true, [72040] = true, [72041] = true, [72042] = true,
				[72043] = true, [72044] = true, [72045] = true, [72046] = true,
				[72047] = true, [72048] = true, [72049] = true, [72050] = true,
				[72051] = true, [72052] = true, [72053] = true, [72054] = true,
				[72055] = true, [72056] = true, [72057] = true, [72058] = true,
			},
			grantedNodes = { 71933 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2665,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2664,
				},
			},
			gates = {
				{
					conditionID = 19167,
					topLeftNodeID = 71935,
					spentAmountRequired = 8,
					traitCurrencyID = 2665,
				},
				{
					conditionID = 19163,
					topLeftNodeID = 72045,
					spentAmountRequired = 8,
					traitCurrencyID = 2664,
				},
				{
					conditionID = 19168,
					topLeftNodeID = 71918,
					spentAmountRequired = 20,
					traitCurrencyID = 2665,
				},
				{
					conditionID = 19162,
					topLeftNodeID = 72058,
					spentAmountRequired = 20,
					traitCurrencyID = 2664,
				},
			},
		},
		[266] = { -- Demonology
			ID = 720,
			nodes = {
				71915, 71916, 71917, 71918, 71919, 71920, 71921, 71922,
				71923, 71924, 71925, 71926, 71927, 71928, 71929, 71930,
				71931, 71932, 71933, 71934, 71935, 71936, 71937, 71938,
				71939, 71940, 71941, 71942, 71943, 71944, 71945, 71946,
				71947, 71948, 71949, 71950, 71951, 71952, 71953, 71954,
				71955, 71956, 71957, 71958, 71959, 71960, 71961, 71962,
				71963, 71964, 71965, 71966, 71967, 71968, 71969, 71970,
				71971, 71972, 71973, 71974, 71975, 71976, 71977, 71978,
				71979, 71980, 71981, 71982, 71983, 71984, 71985, 71986,
				71987, 71988, 71989, 71990, 71991, 71992, 71993, 71994,
				71995, 71996, 71997, 71998, 71999, 72000, 72001, 72002,
				72003, 72004, 72005, 72006, 72007, 72008, 72009, 72010,
				72011, 72012, 72013, 72014, 72015, 72016, 72017, 72018,
				72019, 72020, 72021, 72022, 72023, 72024, 72025, 72026,
				72027, 72028, 72029, 72030, 72031, 72032, 72033, 72034,
				72035, 72036, 72037, 72038, 72039, 72040, 72041, 72042,
				72043, 72044, 72045, 72046, 72047, 72048, 72049, 72050,
				72051, 72052, 72053, 72054, 72055, 72056, 72057, 72058,
				72059, 72060, 72061, 72062, 72063, 72064, 72065, 72066,
				72067, 72068, 72069,
			},
			visibleNodes = {
				[71915] = true, [71916] = true, [71917] = true, [71918] = true,
				[71919] = true, [71922] = true, [71923] = true, [71924] = true,
				[71925] = true, [71926] = true, [71927] = true, [71928] = true,
				[71929] = true, [71930] = true, [71931] = true, [71932] = true,
				[71933] = true, [71934] = true, [71935] = true, [71936] = true,
				[71937] = true, [71938] = true, [71939] = true, [71940] = true,
				[71941] = true, [71942] = true, [71943] = true, [71944] = true,
				[71945] = true, [71946] = true, [71947] = true, [71948] = true,
				[71949] = true, [71950] = true, [71951] = true, [71952] = true,
				[71953] = true, [71954] = true, [71955] = true, [71956] = true,
				[71957] = true, [71991] = true, [71992] = true, [71993] = true,
				[71994] = true, [71995] = true, [71996] = true, [71997] = true,
				[71998] = true, [71999] = true, [72000] = true, [72001] = true,
				[72002] = true, [72003] = true, [72004] = true, [72005] = true,
				[72006] = true, [72007] = true, [72008] = true, [72009] = true,
				[72010] = true, [72011] = true, [72012] = true, [72013] = true,
				[72014] = true, [72015] = true, [72016] = true, [72017] = true,
				[72018] = true, [72019] = true, [72020] = true, [72021] = true,
				[72022] = true, [72023] = true, [72024] = true, [72025] = true,
				[72026] = true, [72027] = true, [72028] = true, [72029] = true,
				[72030] = true,
			},
			grantedNodes = { 71933 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2665,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2664,
				},
			},
			gates = {
				{
					conditionID = 19167,
					topLeftNodeID = 71935,
					spentAmountRequired = 8,
					traitCurrencyID = 2665,
				},
				{
					conditionID = 19163,
					topLeftNodeID = 72003,
					spentAmountRequired = 8,
					traitCurrencyID = 2664,
				},
				{
					conditionID = 19168,
					topLeftNodeID = 71918,
					spentAmountRequired = 20,
					traitCurrencyID = 2665,
				},
				{
					conditionID = 19162,
					topLeftNodeID = 71997,
					spentAmountRequired = 20,
					traitCurrencyID = 2664,
				},
			},
		},
		[267] = { -- Destruction
			ID = 720,
			nodes = {
				71915, 71916, 71917, 71918, 71919, 71920, 71921, 71922,
				71923, 71924, 71925, 71926, 71927, 71928, 71929, 71930,
				71931, 71932, 71933, 71934, 71935, 71936, 71937, 71938,
				71939, 71940, 71941, 71942, 71943, 71944, 71945, 71946,
				71947, 71948, 71949, 71950, 71951, 71952, 71953, 71954,
				71955, 71956, 71957, 71958, 71959, 71960, 71961, 71962,
				71963, 71964, 71965, 71966, 71967, 71968, 71969, 71970,
				71971, 71972, 71973, 71974, 71975, 71976, 71977, 71978,
				71979, 71980, 71981, 71982, 71983, 71984, 71985, 71986,
				71987, 71988, 71989, 71990, 71991, 71992, 71993, 71994,
				71995, 71996, 71997, 71998, 71999, 72000, 72001, 72002,
				72003, 72004, 72005, 72006, 72007, 72008, 72009, 72010,
				72011, 72012, 72013, 72014, 72015, 72016, 72017, 72018,
				72019, 72020, 72021, 72022, 72023, 72024, 72025, 72026,
				72027, 72028, 72029, 72030, 72031, 72032, 72033, 72034,
				72035, 72036, 72037, 72038, 72039, 72040, 72041, 72042,
				72043, 72044, 72045, 72046, 72047, 72048, 72049, 72050,
				72051, 72052, 72053, 72054, 72055, 72056, 72057, 72058,
				72059, 72060, 72061, 72062, 72063, 72064, 72065, 72066,
				72067, 72068, 72069,
			},
			visibleNodes = {
				[71915] = true, [71916] = true, [71917] = true, [71918] = true,
				[71919] = true, [71922] = true, [71923] = true, [71924] = true,
				[71925] = true, [71926] = true, [71927] = true, [71928] = true,
				[71929] = true, [71930] = true, [71931] = true, [71932] = true,
				[71933] = true, [71934] = true, [71935] = true, [71936] = true,
				[71937] = true, [71938] = true, [71939] = true, [71940] = true,
				[71941] = true, [71942] = true, [71943] = true, [71944] = true,
				[71945] = true, [71946] = true, [71947] = true, [71948] = true,
				[71949] = true, [71950] = true, [71951] = true, [71952] = true,
				[71953] = true, [71954] = true, [71955] = true, [71956] = true,
				[71957] = true, [71958] = true, [71959] = true, [71960] = true,
				[71961] = true, [71962] = true, [71963] = true, [71964] = true,
				[71965] = true, [71966] = true, [71967] = true, [71968] = true,
				[71969] = true, [71970] = true, [71971] = true, [71972] = true,
				[71973] = true, [71974] = true, [71975] = true, [71976] = true,
				[71977] = true, [71978] = true, [71979] = true, [71980] = true,
				[71981] = true, [71982] = true, [71983] = true, [71984] = true,
				[71985] = true, [72059] = true, [72060] = true, [72061] = true,
				[72062] = true, [72063] = true, [72064] = true, [72065] = true,
				[72066] = true, [72067] = true, [72068] = true, [72069] = true,
			},
			grantedNodes = { 71933 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2665,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2664,
				},
			},
			gates = {
				{
					conditionID = 19167,
					topLeftNodeID = 71935,
					spentAmountRequired = 8,
					traitCurrencyID = 2665,
				},
				{
					conditionID = 19163,
					topLeftNodeID = 71978,
					spentAmountRequired = 8,
					traitCurrencyID = 2664,
				},
				{
					conditionID = 19168,
					topLeftNodeID = 71918,
					spentAmountRequired = 20,
					traitCurrencyID = 2665,
				},
				{
					conditionID = 19162,
					topLeftNodeID = 71985,
					spentAmountRequired = 20,
					traitCurrencyID = 2664,
				},
			},
		},
		-- Monk
		[268] = { -- Brewmaster
			ID = 781,
			nodes = {
				80558, 80559, 80560, 80561, 80562, 80563, 80564, 80565,
				80566, 80567, 80568, 80569, 80570, 80571, 80572, 80573,
				80574, 80575, 80576, 80577, 80578, 80579, 80580, 80581,
				80582, 80583, 80584, 80585, 80586, 80587, 80588, 80589,
				80590, 80591, 80592, 80593, 80594, 80595, 80596, 80597,
				80598, 80599, 80600, 80601, 80602, 80603, 80604, 80605,
				80606, 80607, 80608, 80609, 80610, 80611, 80612, 80613,
				80614, 80615, 80616, 80617, 80618, 80619, 80620, 80621,
				80622, 80623, 80624, 80625, 80626, 80627, 80628, 80629,
				80630, 80631, 80632, 80633, 80634, 80635, 80636, 80637,
				80638, 80639, 80640, 80641, 80642, 80643, 80644, 80645,
				80646, 80647, 80648, 80649, 80650, 80651, 80652, 80653,
				80654, 80655, 80656, 80657, 80658, 80659, 80660, 80661,
				80662, 80663, 80664, 80665, 80666, 80667, 80668, 80669,
				80670, 80671, 80672, 80673, 80674, 80675, 80676, 80677,
				80678, 80679, 80680, 80681, 80682, 80683, 80684, 80685,
				80686, 80687, 80688, 80689, 80690, 80691, 80692, 80693,
				80694, 80695, 80696, 80697, 80698, 80699, 80700, 80701,
				80702, 80703, 80704, 80705, 80706, 80707, 80708, 80709,
				80710, 80711, 80712, 80713, 80714, 80715, 80716, 80717,
				80718, 80719, 80720, 80721, 80722, 80723, 80724, 80725,
				80726, 80727, 80728, 80729, 81633, 81634,
			},
			visibleNodes = {
				[80601] = true, [80602] = true, [80603] = true, [80604] = true,
				[80628] = true, [80629] = true, [80630] = true, [80631] = true,
				[80632] = true, [80633] = true, [80634] = true, [80635] = true,
				[80636] = true, [80637] = true, [80638] = true, [80639] = true,
				[80640] = true, [80641] = true, [80642] = true, [80643] = true,
				[80644] = true, [80645] = true, [80646] = true, [80647] = true,
				[80648] = true, [80649] = true, [80650] = true, [80651] = true,
				[80652] = true, [80653] = true, [80654] = true, [80655] = true,
				[80679] = true, [80680] = true, [80681] = true, [80682] = true,
				[80683] = true, [80684] = true, [80685] = true, [80686] = true,
				[80687] = true, [80688] = true, [80689] = true, [80690] = true,
				[80691] = true, [80692] = true, [80693] = true, [80694] = true,
				[80695] = true, [80696] = true, [80697] = true, [80698] = true,
				[80699] = true, [80700] = true, [80701] = true, [80702] = true,
				[80703] = true, [80704] = true, [80705] = true, [80706] = true,
				[80707] = true, [80708] = true, [80709] = true, [80710] = true,
				[80711] = true, [80712] = true, [80713] = true, [80714] = true,
				[80715] = true, [80716] = true, [80717] = true, [80718] = true,
				[80719] = true, [80720] = true, [80721] = true, [80722] = true,
				[80723] = true, [80724] = true, [80725] = true, [80726] = true,
				[80727] = true, [80728] = true, [80729] = true, [81633] = true,
			},
			grantedNodes = { 80689 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2778,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2777,
				},
			},
			gates = {
				{
					conditionID = 20031,
					topLeftNodeID = 80603,
					spentAmountRequired = 8,
					traitCurrencyID = 2778,
				},
				{
					conditionID = 20042,
					topLeftNodeID = 80646,
					spentAmountRequired = 8,
					traitCurrencyID = 2777,
				},
				{
					conditionID = 20037,
					topLeftNodeID = 80707,
					spentAmountRequired = 20,
					traitCurrencyID = 2778,
				},
				{
					conditionID = 20043,
					topLeftNodeID = 80651,
					spentAmountRequired = 20,
					traitCurrencyID = 2777,
				},
			},
		},
		[270] = { -- Mistweaver
			ID = 781,
			nodes = {
				80558, 80559, 80560, 80561, 80562, 80563, 80564, 80565,
				80566, 80567, 80568, 80569, 80570, 80571, 80572, 80573,
				80574, 80575, 80576, 80577, 80578, 80579, 80580, 80581,
				80582, 80583, 80584, 80585, 80586, 80587, 80588, 80589,
				80590, 80591, 80592, 80593, 80594, 80595, 80596, 80597,
				80598, 80599, 80600, 80601, 80602, 80603, 80604, 80605,
				80606, 80607, 80608, 80609, 80610, 80611, 80612, 80613,
				80614, 80615, 80616, 80617, 80618, 80619, 80620, 80621,
				80622, 80623, 80624, 80625, 80626, 80627, 80628, 80629,
				80630, 80631, 80632, 80633, 80634, 80635, 80636, 80637,
				80638, 80639, 80640, 80641, 80642, 80643, 80644, 80645,
				80646, 80647, 80648, 80649, 80650, 80651, 80652, 80653,
				80654, 80655, 80656, 80657, 80658, 80659, 80660, 80661,
				80662, 80663, 80664, 80665, 80666, 80667, 80668, 80669,
				80670, 80671, 80672, 80673, 80674, 80675, 80676, 80677,
				80678, 80679, 80680, 80681, 80682, 80683, 80684, 80685,
				80686, 80687, 80688, 80689, 80690, 80691, 80692, 80693,
				80694, 80695, 80696, 80697, 80698, 80699, 80700, 80701,
				80702, 80703, 80704, 80705, 80706, 80707, 80708, 80709,
				80710, 80711, 80712, 80713, 80714, 80715, 80716, 80717,
				80718, 80719, 80720, 80721, 80722, 80723, 80724, 80725,
				80726, 80727, 80728, 80729, 81633, 81634,
			},
			visibleNodes = {
				[80558] = true, [80559] = true, [80560] = true, [80561] = true,
				[80562] = true, [80563] = true, [80564] = true, [80565] = true,
				[80566] = true, [80567] = true, [80568] = true, [80569] = true,
				[80570] = true, [80571] = true, [80572] = true, [80573] = true,
				[80574] = true, [80575] = true, [80576] = true, [80577] = true,
				[80578] = true, [80579] = true, [80580] = true, [80581] = true,
				[80582] = true, [80583] = true, [80584] = true, [80585] = true,
				[80586] = true, [80587] = true, [80588] = true, [80589] = true,
				[80590] = true, [80591] = true, [80592] = true, [80593] = true,
				[80594] = true, [80595] = true, [80596] = true, [80597] = true,
				[80598] = true, [80599] = true, [80600] = true, [80603] = true,
				[80604] = true, [80679] = true, [80680] = true, [80681] = true,
				[80682] = true, [80683] = true, [80684] = true, [80685] = true,
				[80686] = true, [80687] = true, [80688] = true, [80689] = true,
				[80690] = true, [80691] = true, [80692] = true, [80693] = true,
				[80694] = true, [80695] = true, [80696] = true, [80697] = true,
				[80698] = true, [80699] = true, [80700] = true, [80701] = true,
				[80702] = true, [80703] = true, [80704] = true, [80705] = true,
				[80706] = true, [80707] = true, [80708] = true, [80709] = true,
				[80710] = true, [80711] = true, [80712] = true, [80713] = true,
				[80714] = true, [80715] = true, [80716] = true, [80717] = true,
				[81634] = true,
			},
			grantedNodes = { 80691 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2778,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2777,
				},
			},
			gates = {
				{
					conditionID = 20031,
					topLeftNodeID = 80603,
					spentAmountRequired = 8,
					traitCurrencyID = 2778,
				},
				{
					conditionID = 20042,
					topLeftNodeID = 80562,
					spentAmountRequired = 8,
					traitCurrencyID = 2777,
				},
				{
					conditionID = 20043,
					topLeftNodeID = 80576,
					spentAmountRequired = 20,
					traitCurrencyID = 2777,
				},
				{
					conditionID = 20037,
					topLeftNodeID = 80707,
					spentAmountRequired = 20,
					traitCurrencyID = 2778,
				},
			},
		},
		[269] = { -- Windwalker
			ID = 781,
			nodes = {
				80558, 80559, 80560, 80561, 80562, 80563, 80564, 80565,
				80566, 80567, 80568, 80569, 80570, 80571, 80572, 80573,
				80574, 80575, 80576, 80577, 80578, 80579, 80580, 80581,
				80582, 80583, 80584, 80585, 80586, 80587, 80588, 80589,
				80590, 80591, 80592, 80593, 80594, 80595, 80596, 80597,
				80598, 80599, 80600, 80601, 80602, 80603, 80604, 80605,
				80606, 80607, 80608, 80609, 80610, 80611, 80612, 80613,
				80614, 80615, 80616, 80617, 80618, 80619, 80620, 80621,
				80622, 80623, 80624, 80625, 80626, 80627, 80628, 80629,
				80630, 80631, 80632, 80633, 80634, 80635, 80636, 80637,
				80638, 80639, 80640, 80641, 80642, 80643, 80644, 80645,
				80646, 80647, 80648, 80649, 80650, 80651, 80652, 80653,
				80654, 80655, 80656, 80657, 80658, 80659, 80660, 80661,
				80662, 80663, 80664, 80665, 80666, 80667, 80668, 80669,
				80670, 80671, 80672, 80673, 80674, 80675, 80676, 80677,
				80678, 80679, 80680, 80681, 80682, 80683, 80684, 80685,
				80686, 80687, 80688, 80689, 80690, 80691, 80692, 80693,
				80694, 80695, 80696, 80697, 80698, 80699, 80700, 80701,
				80702, 80703, 80704, 80705, 80706, 80707, 80708, 80709,
				80710, 80711, 80712, 80713, 80714, 80715, 80716, 80717,
				80718, 80719, 80720, 80721, 80722, 80723, 80724, 80725,
				80726, 80727, 80728, 80729, 81633, 81634,
			},
			visibleNodes = {
				[80603] = true, [80604] = true, [80605] = true, [80606] = true,
				[80607] = true, [80608] = true, [80609] = true, [80610] = true,
				[80611] = true, [80612] = true, [80613] = true, [80614] = true,
				[80615] = true, [80616] = true, [80617] = true, [80618] = true,
				[80619] = true, [80620] = true, [80621] = true, [80622] = true,
				[80623] = true, [80624] = true, [80625] = true, [80626] = true,
				[80627] = true, [80656] = true, [80657] = true, [80658] = true,
				[80659] = true, [80660] = true, [80661] = true, [80662] = true,
				[80663] = true, [80664] = true, [80665] = true, [80666] = true,
				[80667] = true, [80668] = true, [80669] = true, [80670] = true,
				[80671] = true, [80672] = true, [80673] = true, [80674] = true,
				[80675] = true, [80676] = true, [80677] = true, [80678] = true,
				[80679] = true, [80680] = true, [80681] = true, [80682] = true,
				[80683] = true, [80684] = true, [80685] = true, [80686] = true,
				[80687] = true, [80688] = true, [80689] = true, [80690] = true,
				[80691] = true, [80692] = true, [80693] = true, [80694] = true,
				[80695] = true, [80696] = true, [80697] = true, [80698] = true,
				[80699] = true, [80700] = true, [80701] = true, [80702] = true,
				[80703] = true, [80704] = true, [80705] = true, [80706] = true,
				[80707] = true, [80708] = true, [80709] = true, [80710] = true,
				[80711] = true, [80712] = true, [80713] = true, [80714] = true,
				[80715] = true, [80716] = true, [80717] = true,
			},
			grantedNodes = { 80690 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2778,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2777,
				},
			},
			gates = {
				{
					conditionID = 20031,
					topLeftNodeID = 80603,
					spentAmountRequired = 8,
					traitCurrencyID = 2778,
				},
				{
					conditionID = 20042,
					topLeftNodeID = 80624,
					spentAmountRequired = 8,
					traitCurrencyID = 2777,
				},
				{
					conditionID = 20037,
					topLeftNodeID = 80707,
					spentAmountRequired = 20,
					traitCurrencyID = 2778,
				},
				{
					conditionID = 20043,
					topLeftNodeID = 80667,
					spentAmountRequired = 20,
					traitCurrencyID = 2777,
				},
			},
		},
		-- Druid
		[102] = { -- Balance
			ID = 793,
			nodes = {
				82043, 82044, 82045, 82046, 82047, 82048, 82049, 82050,
				82051, 82052, 82053, 82054, 82055, 82056, 82057, 82058,
				82059, 82060, 82061, 82062, 82063, 82064, 82065, 82066,
				82067, 82068, 82069, 82070, 82071, 82072, 82073, 82074,
				82075, 82076, 82077, 82078, 82079, 82080, 82081, 82082,
				82083, 82084, 82085, 82086, 82087, 82088, 82089, 82090,
				82091, 82092, 82093, 82094, 82095, 82096, 82097, 82098,
				82099, 82100, 82101, 82102, 82103, 82104, 82105, 82106,
				82107, 82108, 82109, 82110, 82111, 82112, 82113, 82114,
				82115, 82116, 82117, 82118, 82119, 82120, 82121, 82122,
				82123, 82124, 82125, 82126, 82127, 82128, 82129, 82130,
				82131, 82132, 82133, 82134, 82135, 82136, 82137, 82138,
				82139, 82140, 82141, 82142, 82143, 82144, 82145, 82146,
				82147, 82148, 82149, 82150, 82151, 82152, 82153, 82154,
				82155, 82156, 82157, 82158, 82159, 82160, 82161, 82162,
				82197, 82198, 82199, 82200, 82201, 82202, 82203, 82204,
				82205, 82206, 82207, 82208, 82209, 82210, 82211, 82212,
				82213, 82214, 82215, 82216, 82217, 82218, 82219, 82220,
				82221, 82222, 82223, 82224, 82225, 82226, 82227, 82228,
				82229, 82230, 82231, 82232, 82233, 82234, 82235, 82236,
				82237, 82238, 82239, 82240, 82241, 82242, 82243, 82244,
				82245, 82246, 88199, 88200, 88201, 88202, 88203, 88204,
				88205, 88206, 88207, 88208, 88209, 88210, 88211, 88212,
				88213, 88214, 88215, 88216, 88217, 88218, 88219, 88220,
				88221, 88222, 88223, 88224, 88225, 88226, 88227, 88228,
				88229, 88231, 88232, 88233, 88234, 88235, 88236, 91040,
				91041, 91042, 91043, 91044, 91045, 91046, 91047, 91048,
			},
			visibleNodes = {
				[82197] = true, [82198] = true, [82199] = true, [82201] = true,
				[82202] = true, [82205] = true, [82206] = true, [82207] = true,
				[82208] = true, [82209] = true, [82210] = true, [82211] = true,
				[82212] = true, [82213] = true, [82214] = true, [82216] = true,
				[82217] = true, [82218] = true, [82219] = true, [82220] = true,
				[82221] = true, [82222] = true, [82223] = true, [82224] = true,
				[82225] = true, [82226] = true, [82227] = true, [82228] = true,
				[82229] = true, [82230] = true, [82231] = true, [82232] = true,
				[82233] = true, [82234] = true, [82235] = true, [82236] = true,
				[82237] = true, [82238] = true, [82239] = true, [82240] = true,
				[82241] = true, [82242] = true, [82243] = true, [82244] = true,
				[82245] = true, [82246] = true, [88199] = true, [88200] = true,
				[88201] = true, [88202] = true, [88203] = true, [88204] = true,
				[88205] = true, [88206] = true, [88207] = true, [88208] = true,
				[88209] = true, [88210] = true, [88211] = true, [88212] = true,
				[88213] = true, [88214] = true, [88215] = true, [88216] = true,
				[88217] = true, [88218] = true, [88219] = true, [88220] = true,
				[88221] = true, [88222] = true, [88223] = true, [88224] = true,
				[88225] = true, [88226] = true, [88227] = true, [88228] = true,
				[88229] = true, [88231] = true, [88232] = true, [88233] = true,
				[88234] = true, [88235] = true, [88236] = true, [91048] = true,
			},
			grantedNodes = { 82201, 82202 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2801,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2800,
				},
			},
			gates = {
				{
					conditionID = 20238,
					topLeftNodeID = 82239,
					spentAmountRequired = 8,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20233,
					topLeftNodeID = 88199,
					spentAmountRequired = 8,
					traitCurrencyID = 2800,
				},
				{
					conditionID = 20242,
					topLeftNodeID = 82237,
					spentAmountRequired = 20,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20248,
					topLeftNodeID = 88227,
					spentAmountRequired = 20,
					traitCurrencyID = 2800,
				},
			},
		},
		[103] = { -- Feral
			ID = 793,
			nodes = {
				82043, 82044, 82045, 82046, 82047, 82048, 82049, 82050,
				82051, 82052, 82053, 82054, 82055, 82056, 82057, 82058,
				82059, 82060, 82061, 82062, 82063, 82064, 82065, 82066,
				82067, 82068, 82069, 82070, 82071, 82072, 82073, 82074,
				82075, 82076, 82077, 82078, 82079, 82080, 82081, 82082,
				82083, 82084, 82085, 82086, 82087, 82088, 82089, 82090,
				82091, 82092, 82093, 82094, 82095, 82096, 82097, 82098,
				82099, 82100, 82101, 82102, 82103, 82104, 82105, 82106,
				82107, 82108, 82109, 82110, 82111, 82112, 82113, 82114,
				82115, 82116, 82117, 82118, 82119, 82120, 82121, 82122,
				82123, 82124, 82125, 82126, 82127, 82128, 82129, 82130,
				82131, 82132, 82133, 82134, 82135, 82136, 82137, 82138,
				82139, 82140, 82141, 82142, 82143, 82144, 82145, 82146,
				82147, 82148, 82149, 82150, 82151, 82152, 82153, 82154,
				82155, 82156, 82157, 82158, 82159, 82160, 82161, 82162,
				82197, 82198, 82199, 82200, 82201, 82202, 82203, 82204,
				82205, 82206, 82207, 82208, 82209, 82210, 82211, 82212,
				82213, 82214, 82215, 82216, 82217, 82218, 82219, 82220,
				82221, 82222, 82223, 82224, 82225, 82226, 82227, 82228,
				82229, 82230, 82231, 82232, 82233, 82234, 82235, 82236,
				82237, 82238, 82239, 82240, 82241, 82242, 82243, 82244,
				82245, 82246, 88199, 88200, 88201, 88202, 88203, 88204,
				88205, 88206, 88207, 88208, 88209, 88210, 88211, 88212,
				88213, 88214, 88215, 88216, 88217, 88218, 88219, 88220,
				88221, 88222, 88223, 88224, 88225, 88226, 88227, 88228,
				88229, 88231, 88232, 88233, 88234, 88235, 88236, 91040,
				91041, 91042, 91043, 91044, 91045, 91046, 91047, 91048,
			},
			visibleNodes = {
				[82085] = true, [82086] = true, [82087] = true, [82088] = true,
				[82089] = true, [82090] = true, [82091] = true, [82092] = true,
				[82093] = true, [82094] = true, [82095] = true, [82096] = true,
				[82097] = true, [82098] = true, [82099] = true, [82100] = true,
				[82101] = true, [82102] = true, [82103] = true, [82104] = true,
				[82105] = true, [82106] = true, [82107] = true, [82108] = true,
				[82109] = true, [82110] = true, [82111] = true, [82112] = true,
				[82113] = true, [82114] = true, [82115] = true, [82116] = true,
				[82117] = true, [82118] = true, [82119] = true, [82120] = true,
				[82121] = true, [82122] = true, [82123] = true, [82124] = true,
				[82197] = true, [82198] = true, [82199] = true, [82200] = true,
				[82204] = true, [82206] = true, [82207] = true, [82208] = true,
				[82209] = true, [82210] = true, [82211] = true, [82213] = true,
				[82214] = true, [82216] = true, [82217] = true, [82218] = true,
				[82219] = true, [82220] = true, [82221] = true, [82222] = true,
				[82223] = true, [82224] = true, [82225] = true, [82226] = true,
				[82227] = true, [82228] = true, [82229] = true, [82230] = true,
				[82231] = true, [82232] = true, [82233] = true, [82234] = true,
				[82235] = true, [82236] = true, [82237] = true, [82238] = true,
				[82239] = true, [82240] = true, [82241] = true, [82242] = true,
				[82243] = true, [82244] = true, [82245] = true, [82246] = true,
				[91044] = true, [91045] = true, [91046] = true, [91047] = true,
			},
			grantedNodes = { 82199, 82223 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2801,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2800,
				},
			},
			gates = {
				{
					conditionID = 20238,
					topLeftNodeID = 82239,
					spentAmountRequired = 8,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20233,
					topLeftNodeID = 82104,
					spentAmountRequired = 8,
					traitCurrencyID = 2800,
				},
				{
					conditionID = 20242,
					topLeftNodeID = 82237,
					spentAmountRequired = 20,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20248,
					topLeftNodeID = 82110,
					spentAmountRequired = 20,
					traitCurrencyID = 2800,
				},
			},
		},
		[104] = { -- Guardian
			ID = 793,
			nodes = {
				82043, 82044, 82045, 82046, 82047, 82048, 82049, 82050,
				82051, 82052, 82053, 82054, 82055, 82056, 82057, 82058,
				82059, 82060, 82061, 82062, 82063, 82064, 82065, 82066,
				82067, 82068, 82069, 82070, 82071, 82072, 82073, 82074,
				82075, 82076, 82077, 82078, 82079, 82080, 82081, 82082,
				82083, 82084, 82085, 82086, 82087, 82088, 82089, 82090,
				82091, 82092, 82093, 82094, 82095, 82096, 82097, 82098,
				82099, 82100, 82101, 82102, 82103, 82104, 82105, 82106,
				82107, 82108, 82109, 82110, 82111, 82112, 82113, 82114,
				82115, 82116, 82117, 82118, 82119, 82120, 82121, 82122,
				82123, 82124, 82125, 82126, 82127, 82128, 82129, 82130,
				82131, 82132, 82133, 82134, 82135, 82136, 82137, 82138,
				82139, 82140, 82141, 82142, 82143, 82144, 82145, 82146,
				82147, 82148, 82149, 82150, 82151, 82152, 82153, 82154,
				82155, 82156, 82157, 82158, 82159, 82160, 82161, 82162,
				82197, 82198, 82199, 82200, 82201, 82202, 82203, 82204,
				82205, 82206, 82207, 82208, 82209, 82210, 82211, 82212,
				82213, 82214, 82215, 82216, 82217, 82218, 82219, 82220,
				82221, 82222, 82223, 82224, 82225, 82226, 82227, 82228,
				82229, 82230, 82231, 82232, 82233, 82234, 82235, 82236,
				82237, 82238, 82239, 82240, 82241, 82242, 82243, 82244,
				82245, 82246, 88199, 88200, 88201, 88202, 88203, 88204,
				88205, 88206, 88207, 88208, 88209, 88210, 88211, 88212,
				88213, 88214, 88215, 88216, 88217, 88218, 88219, 88220,
				88221, 88222, 88223, 88224, 88225, 88226, 88227, 88228,
				88229, 88231, 88232, 88233, 88234, 88235, 88236, 91040,
				91041, 91042, 91043, 91044, 91045, 91046, 91047, 91048,
			},
			visibleNodes = {
				[82125] = true, [82126] = true, [82127] = true, [82128] = true,
				[82129] = true, [82130] = true, [82131] = true, [82132] = true,
				[82133] = true, [82134] = true, [82135] = true, [82136] = true,
				[82137] = true, [82138] = true, [82139] = true, [82140] = true,
				[82141] = true, [82142] = true, [82143] = true, [82144] = true,
				[82145] = true, [82146] = true, [82147] = true, [82148] = true,
				[82149] = true, [82150] = true, [82151] = true, [82152] = true,
				[82153] = true, [82154] = true, [82155] = true, [82156] = true,
				[82157] = true, [82158] = true, [82159] = true, [82160] = true,
				[82161] = true, [82162] = true, [82197] = true, [82198] = true,
				[82199] = true, [82200] = true, [82206] = true, [82207] = true,
				[82208] = true, [82209] = true, [82210] = true, [82211] = true,
				[82213] = true, [82214] = true, [82215] = true, [82216] = true,
				[82217] = true, [82218] = true, [82219] = true, [82220] = true,
				[82221] = true, [82222] = true, [82223] = true, [82224] = true,
				[82225] = true, [82226] = true, [82227] = true, [82228] = true,
				[82229] = true, [82230] = true, [82231] = true, [82232] = true,
				[82233] = true, [82234] = true, [82235] = true, [82236] = true,
				[82237] = true, [82238] = true, [82239] = true, [82240] = true,
				[82241] = true, [82242] = true, [82243] = true, [82244] = true,
				[82245] = true, [82246] = true, [91041] = true, [91043] = true,
				[91046] = true, [91047] = true,
			},
			grantedNodes = { 82223, 82220 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2801,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2800,
				},
			},
			gates = {
				{
					conditionID = 20238,
					topLeftNodeID = 82239,
					spentAmountRequired = 8,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20233,
					topLeftNodeID = 82157,
					spentAmountRequired = 8,
					traitCurrencyID = 2800,
				},
				{
					conditionID = 20242,
					topLeftNodeID = 82237,
					spentAmountRequired = 20,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20248,
					topLeftNodeID = 82154,
					spentAmountRequired = 20,
					traitCurrencyID = 2800,
				},
			},
		},
		[105] = { -- Restoration
			ID = 793,
			nodes = {
				82043, 82044, 82045, 82046, 82047, 82048, 82049, 82050,
				82051, 82052, 82053, 82054, 82055, 82056, 82057, 82058,
				82059, 82060, 82061, 82062, 82063, 82064, 82065, 82066,
				82067, 82068, 82069, 82070, 82071, 82072, 82073, 82074,
				82075, 82076, 82077, 82078, 82079, 82080, 82081, 82082,
				82083, 82084, 82085, 82086, 82087, 82088, 82089, 82090,
				82091, 82092, 82093, 82094, 82095, 82096, 82097, 82098,
				82099, 82100, 82101, 82102, 82103, 82104, 82105, 82106,
				82107, 82108, 82109, 82110, 82111, 82112, 82113, 82114,
				82115, 82116, 82117, 82118, 82119, 82120, 82121, 82122,
				82123, 82124, 82125, 82126, 82127, 82128, 82129, 82130,
				82131, 82132, 82133, 82134, 82135, 82136, 82137, 82138,
				82139, 82140, 82141, 82142, 82143, 82144, 82145, 82146,
				82147, 82148, 82149, 82150, 82151, 82152, 82153, 82154,
				82155, 82156, 82157, 82158, 82159, 82160, 82161, 82162,
				82197, 82198, 82199, 82200, 82201, 82202, 82203, 82204,
				82205, 82206, 82207, 82208, 82209, 82210, 82211, 82212,
				82213, 82214, 82215, 82216, 82217, 82218, 82219, 82220,
				82221, 82222, 82223, 82224, 82225, 82226, 82227, 82228,
				82229, 82230, 82231, 82232, 82233, 82234, 82235, 82236,
				82237, 82238, 82239, 82240, 82241, 82242, 82243, 82244,
				82245, 82246, 88199, 88200, 88201, 88202, 88203, 88204,
				88205, 88206, 88207, 88208, 88209, 88210, 88211, 88212,
				88213, 88214, 88215, 88216, 88217, 88218, 88219, 88220,
				88221, 88222, 88223, 88224, 88225, 88226, 88227, 88228,
				88229, 88231, 88232, 88233, 88234, 88235, 88236, 91040,
				91041, 91042, 91043, 91044, 91045, 91046, 91047, 91048,
			},
			visibleNodes = {
				[82043] = true, [82044] = true, [82045] = true, [82046] = true,
				[82047] = true, [82048] = true, [82049] = true, [82050] = true,
				[82051] = true, [82052] = true, [82053] = true, [82054] = true,
				[82055] = true, [82056] = true, [82057] = true, [82058] = true,
				[82059] = true, [82060] = true, [82061] = true, [82062] = true,
				[82063] = true, [82064] = true, [82065] = true, [82066] = true,
				[82067] = true, [82068] = true, [82069] = true, [82070] = true,
				[82071] = true, [82072] = true, [82073] = true, [82074] = true,
				[82075] = true, [82076] = true, [82077] = true, [82078] = true,
				[82079] = true, [82080] = true, [82081] = true, [82082] = true,
				[82083] = true, [82084] = true, [82197] = true, [82198] = true,
				[82199] = true, [82200] = true, [82203] = true, [82206] = true,
				[82207] = true, [82208] = true, [82209] = true, [82210] = true,
				[82211] = true, [82213] = true, [82214] = true, [82216] = true,
				[82217] = true, [82218] = true, [82219] = true, [82220] = true,
				[82221] = true, [82222] = true, [82223] = true, [82224] = true,
				[82225] = true, [82226] = true, [82227] = true, [82228] = true,
				[82229] = true, [82230] = true, [82231] = true, [82232] = true,
				[82233] = true, [82234] = true, [82235] = true, [82236] = true,
				[82237] = true, [82238] = true, [82239] = true, [82240] = true,
				[82241] = true, [82242] = true, [82243] = true, [82244] = true,
				[82245] = true, [82246] = true, [91040] = true, [91042] = true,
			},
			grantedNodes = { 82216, 82217 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2801,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2800,
				},
			},
			gates = {
				{
					conditionID = 20238,
					topLeftNodeID = 82239,
					spentAmountRequired = 8,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20233,
					topLeftNodeID = 82057,
					spentAmountRequired = 8,
					traitCurrencyID = 2800,
				},
				{
					conditionID = 20242,
					topLeftNodeID = 82237,
					spentAmountRequired = 20,
					traitCurrencyID = 2801,
				},
				{
					conditionID = 20248,
					topLeftNodeID = 82061,
					spentAmountRequired = 20,
					traitCurrencyID = 2800,
				},
			},
		},
		-- Demon Hunter
		[577] = { -- Havoc
			ID = 854,
			nodes = {
				90912, 90913, 90914, 90915, 90916, 90917, 90918, 90919,
				90920, 90921, 90922, 90923, 90924, 90925, 90926, 90927,
				90928, 90929, 90930, 90931, 90932, 90933, 90934, 90935,
				90936, 90937, 90938, 90939, 90940, 90941, 90942, 90943,
				90944, 90945, 90946, 90947, 90948, 90949, 90950, 90951,
				90952, 90953, 90954, 90955, 90956, 90957, 90958, 90959,
				90960, 90961, 90962, 90963, 90964, 90965, 90966, 90967,
				90968, 90969, 90970, 90971, 90972, 90973, 90974, 90975,
				90976, 90977, 90978, 90979, 90980, 90981, 90982, 90983,
				90984, 90985, 90986, 90987, 90988, 90989, 90990, 90991,
				90992, 90993, 90994, 90995, 90996, 90997, 90998, 90999,
				91000, 91001, 91002, 91003, 91004, 91005, 91006, 91007,
				91008, 91009, 91010, 91011, 91012, 91013, 91014, 91015,
				91016, 91017, 91018, 91019, 91020, 91021, 91022, 91023,
				91024, 91025, 91026, 91027, 91028, 91029, 91030, 91031,
				91032, 91033, 91034, 91035, 91036,
			},
			visibleNodes = {
				[90912] = true, [90913] = true, [90914] = true, [90915] = true,
				[90916] = true, [90917] = true, [90918] = true, [90919] = true,
				[90920] = true, [90921] = true, [90922] = true, [90923] = true,
				[90924] = true, [90925] = true, [90926] = true, [90927] = true,
				[90928] = true, [90929] = true, [90930] = true, [90931] = true,
				[90932] = true, [90933] = true, [90934] = true, [90935] = true,
				[90936] = true, [90937] = true, [90938] = true, [90939] = true,
				[90940] = true, [90941] = true, [90942] = true, [90943] = true,
				[90944] = true, [90945] = true, [90946] = true, [90947] = true,
				[90948] = true, [90949] = true, [90950] = true, [90992] = true,
				[90993] = true, [90994] = true, [90995] = true, [90996] = true,
				[90997] = true, [90998] = true, [90999] = true, [91000] = true,
				[91001] = true, [91002] = true, [91003] = true, [91004] = true,
				[91005] = true, [91006] = true, [91007] = true, [91008] = true,
				[91009] = true, [91010] = true, [91011] = true, [91012] = true,
				[91013] = true, [91014] = true, [91015] = true, [91016] = true,
				[91017] = true, [91018] = true, [91019] = true, [91020] = true,
				[91021] = true, [91022] = true, [91023] = true, [91024] = true,
				[91025] = true, [91026] = true, [91027] = true, [91028] = true,
				[91029] = true, [91030] = true, [91031] = true, [91032] = true,
				[91033] = true, [91034] = true, [91035] = true, [91036] = true,
			},
			grantedNodes = { 90942 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2904,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2903,
				},
			},
			gates = {
				{
					conditionID = 22783,
					topLeftNodeID = 90939,
					spentAmountRequired = 8,
					traitCurrencyID = 2904,
				},
				{
					conditionID = 22779,
					topLeftNodeID = 91027,
					spentAmountRequired = 8,
					traitCurrencyID = 2903,
				},
				{
					conditionID = 22781,
					topLeftNodeID = 90934,
					spentAmountRequired = 20,
					traitCurrencyID = 2904,
				},
				{
					conditionID = 22782,
					topLeftNodeID = 91021,
					spentAmountRequired = 20,
					traitCurrencyID = 2903,
				},
			},
		},
		[581] = { -- Vengeance
			ID = 854,
			nodes = {
				90912, 90913, 90914, 90915, 90916, 90917, 90918, 90919,
				90920, 90921, 90922, 90923, 90924, 90925, 90926, 90927,
				90928, 90929, 90930, 90931, 90932, 90933, 90934, 90935,
				90936, 90937, 90938, 90939, 90940, 90941, 90942, 90943,
				90944, 90945, 90946, 90947, 90948, 90949, 90950, 90951,
				90952, 90953, 90954, 90955, 90956, 90957, 90958, 90959,
				90960, 90961, 90962, 90963, 90964, 90965, 90966, 90967,
				90968, 90969, 90970, 90971, 90972, 90973, 90974, 90975,
				90976, 90977, 90978, 90979, 90980, 90981, 90982, 90983,
				90984, 90985, 90986, 90987, 90988, 90989, 90990, 90991,
				90992, 90993, 90994, 90995, 90996, 90997, 90998, 90999,
				91000, 91001, 91002, 91003, 91004, 91005, 91006, 91007,
				91008, 91009, 91010, 91011, 91012, 91013, 91014, 91015,
				91016, 91017, 91018, 91019, 91020, 91021, 91022, 91023,
				91024, 91025, 91026, 91027, 91028, 91029, 91030, 91031,
				91032, 91033, 91034, 91035, 91036,
			},
			visibleNodes = {
				[90912] = true, [90926] = true, [90927] = true, [90928] = true,
				[90929] = true, [90930] = true, [90931] = true, [90932] = true,
				[90933] = true, [90934] = true, [90935] = true, [90936] = true,
				[90937] = true, [90938] = true, [90939] = true, [90940] = true,
				[90941] = true, [90942] = true, [90943] = true, [90944] = true,
				[90945] = true, [90946] = true, [90947] = true, [90948] = true,
				[90949] = true, [90950] = true, [90951] = true, [90952] = true,
				[90953] = true, [90954] = true, [90955] = true, [90956] = true,
				[90957] = true, [90958] = true, [90959] = true, [90960] = true,
				[90961] = true, [90962] = true, [90963] = true, [90964] = true,
				[90965] = true, [90966] = true, [90967] = true, [90968] = true,
				[90969] = true, [90970] = true, [90971] = true, [90972] = true,
				[90973] = true, [90974] = true, [90975] = true, [90976] = true,
				[90977] = true, [90978] = true, [90979] = true, [90980] = true,
				[90981] = true, [90982] = true, [90983] = true, [90984] = true,
				[90985] = true, [90986] = true, [90987] = true, [90988] = true,
				[90989] = true, [90990] = true, [90991] = true, [90992] = true,
				[90993] = true, [90994] = true, [90995] = true, [90996] = true,
				[90997] = true, [90998] = true, [90999] = true, [91000] = true,
				[91001] = true, [91002] = true, [91003] = true, [91004] = true,
				[91005] = true, [91006] = true, [91007] = true, [91008] = true,
			},
			grantedNodes = { 90943 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2904,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2903,
				},
			},
			gates = {
				{
					conditionID = 22783,
					topLeftNodeID = 90939,
					spentAmountRequired = 8,
					traitCurrencyID = 2904,
				},
				{
					conditionID = 22779,
					topLeftNodeID = 90978,
					spentAmountRequired = 8,
					traitCurrencyID = 2903,
				},
				{
					conditionID = 22781,
					topLeftNodeID = 90934,
					spentAmountRequired = 20,
					traitCurrencyID = 2904,
				},
				{
					conditionID = 22782,
					topLeftNodeID = 90975,
					spentAmountRequired = 20,
					traitCurrencyID = 2903,
				},
			},
		},
		-- Evoker
		[1467] = { -- Devastation
			ID = 701,
			nodes = {
				68568, 68569, 68570, 68571, 68572, 68573, 68574, 68575,
				68576, 68577, 68578, 68579, 68580, 68581, 68582, 68583,
				68584, 68585, 68586, 68587, 68588, 68589, 68590, 68591,
				68592, 68593, 68594, 68595, 68596, 68597, 68598, 68599,
				68600, 68601, 68602, 68603, 68604, 68605, 68606, 68607,
				68608, 68609, 68610, 68611, 68612, 68613, 68614, 68615,
				68616, 68617, 68618, 68619, 68620, 68621, 68622, 68623,
				68624, 68625, 68626, 68627, 68628, 68629, 68630, 68631,
				68632, 68633, 68634, 68635, 68636, 68637, 68638, 68639,
				68640, 68641, 68642, 68643, 68644, 68645, 68646, 68647,
				68648, 68649, 68650, 68651, 68652, 68653, 68654, 68655,
				68656, 68657, 68658, 68659, 68660, 68661, 68662, 68663,
				68664, 68665, 68666, 68667, 68668, 68669, 68670, 68671,
				68672, 68673, 68674, 68675, 68676, 68677, 68678, 68679,
				68680, 68681, 68682, 68683, 68684, 68685, 68686, 68687,
				68688, 68689,
			},
			visibleNodes = {
				[68568] = true, [68569] = true, [68570] = true, [68571] = true,
				[68572] = true, [68573] = true, [68574] = true, [68575] = true,
				[68615] = true, [68616] = true, [68617] = true, [68618] = true,
				[68619] = true, [68620] = true, [68621] = true, [68622] = true,
				[68623] = true, [68624] = true, [68625] = true, [68626] = true,
				[68627] = true, [68628] = true, [68629] = true, [68630] = true,
				[68631] = true, [68632] = true, [68633] = true, [68634] = true,
				[68635] = true, [68636] = true, [68637] = true, [68638] = true,
				[68639] = true, [68640] = true, [68641] = true, [68642] = true,
				[68643] = true, [68644] = true, [68645] = true, [68646] = true,
				[68647] = true, [68648] = true, [68649] = true, [68650] = true,
				[68651] = true, [68652] = true, [68653] = true, [68654] = true,
				[68655] = true, [68656] = true, [68657] = true, [68658] = true,
				[68659] = true, [68660] = true, [68661] = true, [68662] = true,
				[68663] = true, [68664] = true, [68665] = true, [68666] = true,
				[68667] = true, [68668] = true, [68669] = true, [68670] = true,
				[68671] = true, [68672] = true, [68673] = true, [68674] = true,
				[68675] = true, [68676] = true, [68677] = true, [68678] = true,
				[68679] = true, [68680] = true, [68681] = true, [68682] = true,
				[68683] = true, [68684] = true, [68685] = true, [68686] = true,
				[68687] = true, [68688] = true, [68689] = true,
			},
			grantedNodes = { 68681 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2629,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2628,
				},
			},
			gates = {
				{
					conditionID = 18819,
					topLeftNodeID = 68664,
					spentAmountRequired = 8,
					traitCurrencyID = 2629,
				},
				{
					conditionID = 18823,
					topLeftNodeID = 68648,
					spentAmountRequired = 8,
					traitCurrencyID = 2628,
				},
				{
					conditionID = 18824,
					topLeftNodeID = 68663,
					spentAmountRequired = 20,
					traitCurrencyID = 2629,
				},
				{
					conditionID = 18821,
					topLeftNodeID = 68634,
					spentAmountRequired = 20,
					traitCurrencyID = 2628,
				},
			},
		},
		[1468] = { -- Preservation
			ID = 701,
			nodes = {
				68568, 68569, 68570, 68571, 68572, 68573, 68574, 68575,
				68576, 68577, 68578, 68579, 68580, 68581, 68582, 68583,
				68584, 68585, 68586, 68587, 68588, 68589, 68590, 68591,
				68592, 68593, 68594, 68595, 68596, 68597, 68598, 68599,
				68600, 68601, 68602, 68603, 68604, 68605, 68606, 68607,
				68608, 68609, 68610, 68611, 68612, 68613, 68614, 68615,
				68616, 68617, 68618, 68619, 68620, 68621, 68622, 68623,
				68624, 68625, 68626, 68627, 68628, 68629, 68630, 68631,
				68632, 68633, 68634, 68635, 68636, 68637, 68638, 68639,
				68640, 68641, 68642, 68643, 68644, 68645, 68646, 68647,
				68648, 68649, 68650, 68651, 68652, 68653, 68654, 68655,
				68656, 68657, 68658, 68659, 68660, 68661, 68662, 68663,
				68664, 68665, 68666, 68667, 68668, 68669, 68670, 68671,
				68672, 68673, 68674, 68675, 68676, 68677, 68678, 68679,
				68680, 68681, 68682, 68683, 68684, 68685, 68686, 68687,
				68688, 68689,
			},
			visibleNodes = {
				[68568] = true, [68569] = true, [68570] = true, [68571] = true,
				[68572] = true, [68573] = true, [68576] = true, [68577] = true,
				[68578] = true, [68579] = true, [68580] = true, [68581] = true,
				[68582] = true, [68583] = true, [68584] = true, [68585] = true,
				[68586] = true, [68587] = true, [68588] = true, [68589] = true,
				[68590] = true, [68591] = true, [68592] = true, [68593] = true,
				[68594] = true, [68595] = true, [68596] = true, [68597] = true,
				[68598] = true, [68599] = true, [68600] = true, [68601] = true,
				[68602] = true, [68603] = true, [68604] = true, [68605] = true,
				[68606] = true, [68607] = true, [68608] = true, [68609] = true,
				[68610] = true, [68611] = true, [68612] = true, [68613] = true,
				[68614] = true, [68649] = true, [68650] = true, [68651] = true,
				[68652] = true, [68653] = true, [68654] = true, [68655] = true,
				[68656] = true, [68657] = true, [68658] = true, [68659] = true,
				[68660] = true, [68661] = true, [68662] = true, [68663] = true,
				[68664] = true, [68665] = true, [68666] = true, [68667] = true,
				[68668] = true, [68669] = true, [68670] = true, [68671] = true,
				[68672] = true, [68673] = true, [68674] = true, [68675] = true,
				[68676] = true, [68677] = true, [68678] = true, [68679] = true,
				[68680] = true, [68681] = true, [68682] = true, [68683] = true,
				[68684] = true, [68685] = true, [68686] = true, [68687] = true,
				[68688] = true, [68689] = true,
			},
			grantedNodes = { 68689 },
			currencies = {
				{
					maxQuantity = 31,
					traitCurrencyID = 2629,
				},
				{
					maxQuantity = 30,
					traitCurrencyID = 2628,
				},
			},
			gates = {
				{
					conditionID = 18819,
					topLeftNodeID = 68664,
					spentAmountRequired = 8,
					traitCurrencyID = 2629,
				},
				{
					conditionID = 18823,
					topLeftNodeID = 68577,
					spentAmountRequired = 8,
					traitCurrencyID = 2628,
				},
				{
					conditionID = 18824,
					topLeftNodeID = 68663,
					spentAmountRequired = 20,
					traitCurrencyID = 2629,
				},
				{
					conditionID = 18821,
					topLeftNodeID = 68614,
					spentAmountRequired = 20,
					traitCurrencyID = 2628,
				},
			},
		},
	}
	local nodes = {
		[62083] = {
			ID = 62083,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80139 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62206, type = 2, visualStyle = 1 },
				{ targetNode = 62219, type = 2, visualStyle = 1 }
			}
		},
		[62084] = {
			ID = 62084,
			flags = 0,
			type = 0,
			posX = 2694,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80140 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62124, type = 2, visualStyle = 1 }
			}
		},
		[62085] = {
			ID = 62085,
			flags = 0,
			type = 0,
			posX = 2095,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80141 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {}
		},
		[62086] = {
			ID = 62086,
			flags = 0,
			type = 0,
			posX = 2095,
			posY = 6298,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80142 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62085, type = 2, visualStyle = 1 },
				{ targetNode = 62087, type = 2, visualStyle = 1 }
			}
		},
		[62087] = {
			ID = 62087,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80143 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {}
		},
		[62088] = {
			ID = 62088,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80144 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62108, type = 2, visualStyle = 1 },
				{ targetNode = 62110, type = 2, visualStyle = 1 }
			}
		},
		[62089] = {
			ID = 62089,
			flags = 0,
			type = 0,
			posX = 5090,
			posY = 5094,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80145 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62099, type = 2, visualStyle = 1 }
			}
		},
		[62090] = {
			ID = 62090,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80146 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {}
		},
		[62091] = {
			ID = 62091,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80147 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62092, type = 2, visualStyle = 1 },
				{ targetNode = 62090, type = 2, visualStyle = 1 }
			}
		},
		[62092] = {
			ID = 62092,
			flags = 0,
			type = 0,
			posX = 5092,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80148 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {}
		},
		[62093] = {
			ID = 62093,
			flags = 0,
			type = 0,
			posX = 4490,
			posY = 6297,
			maxRanks = 2,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80149 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62092, type = 2, visualStyle = 1 }
			}
		},
		[62094] = {
			ID = 62094,
			flags = 1,
			type = 2,
			posX = 3895,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80150, 80151 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {}
		},
		[62095] = {
			ID = 62095,
			flags = 0,
			type = 0,
			posX = 3895,
			posY = 6298,
			maxRanks = 1,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80152 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62094, type = 2, visualStyle = 1 }
			}
		},
		[62096] = {
			ID = 62096,
			flags = 0,
			type = 0,
			posX = 3895,
			posY = 5699,
			maxRanks = 2,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80153 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62095, type = 2, visualStyle = 1 },
				{ targetNode = 62093, type = 2, visualStyle = 1 },
				{ targetNode = 62129, type = 2, visualStyle = 1 }
			}
		},
		[62097] = {
			ID = 62097,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80154 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62103, type = 2, visualStyle = 1 },
				{ targetNode = 62105, type = 2, visualStyle = 1 },
				{ targetNode = 62109, type = 2, visualStyle = 1 }
			}
		},
		[62098] = {
			ID = 62098,
			flags = 0,
			type = 0,
			posX = 4499,
			posY = 5098,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80155 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62099, type = 2, visualStyle = 1 },
				{ targetNode = 62096, type = 2, visualStyle = 1 }
			}
		},
		[62099] = {
			ID = 62099,
			flags = 0,
			type = 0,
			posX = 5092,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80156 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62093, type = 2, visualStyle = 1 },
				{ targetNode = 62091, type = 2, visualStyle = 1 }
			}
		},
		[62100] = {
			ID = 62100,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80157 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62099, type = 2, visualStyle = 1 }
			}
		},
		[62101] = {
			ID = 62101,
			flags = 0,
			type = 0,
			posX = 5699,
			posY = 3902,
			maxRanks = 2,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80158 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62100, type = 2, visualStyle = 1 },
				{ targetNode = 62103, type = 2, visualStyle = 1 }
			}
		},
		[62102] = {
			ID = 62102,
			flags = 0,
			type = 0,
			posX = 5089,
			posY = 3902,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80159 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62103, type = 2, visualStyle = 1 }
			}
		},
		[62103] = {
			ID = 62103,
			flags = 0,
			type = 0,
			posX = 5099,
			posY = 4501,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80160 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62100, type = 2, visualStyle = 1 },
				{ targetNode = 62098, type = 2, visualStyle = 1 },
				{ targetNode = 62089, type = 2, visualStyle = 1 }
			}
		},
		[62104] = {
			ID = 62104,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80161 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62105, type = 2, visualStyle = 1 },
				{ targetNode = 62126, type = 2, visualStyle = 1 },
				{ targetNode = 62088, type = 2, visualStyle = 1 }
			}
		},
		[62105] = {
			ID = 62105,
			flags = 1,
			type = 2,
			posX = 3895,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80162, 80163 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62098, type = 2, visualStyle = 1 },
				{ targetNode = 62127, type = 2, visualStyle = 1 }
			}
		},
		[62106] = {
			ID = 62106,
			flags = 0,
			type = 0,
			posX = 3898,
			posY = 3902,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80164 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62105, type = 2, visualStyle = 1 }
			}
		},
		[62107] = {
			ID = 62107,
			flags = 0,
			type = 0,
			posX = 2094,
			posY = 3902,
			maxRanks = 2,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80165 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62088, type = 2, visualStyle = 1 },
				{ targetNode = 62108, type = 2, visualStyle = 1 }
			}
		},
		[62108] = {
			ID = 62108,
			flags = 0,
			type = 0,
			posX = 2091,
			posY = 5095,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80166 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62128, type = 2, visualStyle = 1 }
			}
		},
		[62109] = {
			ID = 62109,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80167 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62098, type = 2, visualStyle = 1 }
			}
		},
		[62110] = {
			ID = 62110,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80168 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62128, type = 2, visualStyle = 1 }
			}
		},
		[62111] = {
			ID = 62111,
			flags = 0,
			type = 0,
			posX = 3292,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 80169 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62124, type = 2, visualStyle = 1 },
				{ targetNode = 62113, type = 2, visualStyle = 1 }
			}
		},
		[62112] = {
			ID = 62112,
			flags = 0,
			type = 0,
			posX = 4496,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 80170 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62115, type = 2, visualStyle = 1 },
				{ targetNode = 62113, type = 2, visualStyle = 1 }
			}
		},
		[62113] = {
			ID = 62113,
			flags = 1,
			type = 2,
			posX = 3899,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80171, 80172 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62106, type = 2, visualStyle = 1 },
				{ targetNode = 62104, type = 2, visualStyle = 1 },
				{ targetNode = 62097, type = 2, visualStyle = 1 }
			}
		},
		[62114] = {
			ID = 62114,
			flags = 0,
			type = 0,
			posX = 5699,
			posY = 2701,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 80173 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62115, type = 2, visualStyle = 1 }
			}
		},
		[62115] = {
			ID = 62115,
			flags = 0,
			type = 0,
			posX = 5094,
			posY = 3298,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80174 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62097, type = 2, visualStyle = 1 },
				{ targetNode = 62101, type = 2, visualStyle = 1 },
				{ targetNode = 62102, type = 2, visualStyle = 1 }
			}
		},
		[62116] = {
			ID = 62116,
			flags = 0,
			type = 0,
			posX = 5094,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80175 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62115, type = 2, visualStyle = 1 }
			}
		},
		[62117] = {
			ID = 62117,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18039, 18040, 18039, 18040, 18039, 18040, 18039, 18040 },
			entryIDs = { 80176 },
			groupIDs = {  },
			costs = {},
			edges = {
				{ targetNode = 62120, type = 2, visualStyle = 1 },
				{ targetNode = 62122, type = 2, visualStyle = 1 },
				{ targetNode = 62118, type = 2, visualStyle = 1 }
			}
		},
		[62118] = {
			ID = 62118,
			flags = 0,
			type = 0,
			posX = 5094,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80177 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62112, type = 2, visualStyle = 1 },
				{ targetNode = 62114, type = 2, visualStyle = 1 },
				{ targetNode = 62116, type = 2, visualStyle = 1 }
			}
		},
		[62119] = {
			ID = 62119,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18036, 18045, 18036, 18045, 18036, 18045, 18036, 18045 },
			entryIDs = { 80178 },
			groupIDs = {  },
			costs = {},
			edges = {
				{ targetNode = 62120, type = 2, visualStyle = 1 },
				{ targetNode = 62122, type = 2, visualStyle = 1 },
				{ targetNode = 62118, type = 2, visualStyle = 1 }
			}
		},
		[62120] = {
			ID = 62120,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80179 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62113, type = 2, visualStyle = 1 }
			}
		},
		[62121] = {
			ID = 62121,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18032, 18041, 18032, 18041, 18032, 18041, 18032, 18041 },
			entryIDs = { 80180 },
			groupIDs = {  },
			costs = {},
			edges = {
				{ targetNode = 62120, type = 2, visualStyle = 1 },
				{ targetNode = 62122, type = 2, visualStyle = 1 },
				{ targetNode = 62118, type = 2, visualStyle = 1 }
			}
		},
		[62122] = {
			ID = 62122,
			flags = 0,
			type = 0,
			posX = 2703,
			posY = 2101,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80181 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62084, type = 2, visualStyle = 1 },
				{ targetNode = 62123, type = 2, visualStyle = 1 },
				{ targetNode = 62111, type = 2, visualStyle = 1 }
			}
		},
		[62123] = {
			ID = 62123,
			flags = 0,
			type = 0,
			posX = 2092,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 80182 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62124, type = 2, visualStyle = 1 }
			}
		},
		[62124] = {
			ID = 62124,
			flags = 0,
			type = 0,
			posX = 2699,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 80183 },
			groupIDs = { 7139 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62104, type = 2, visualStyle = 1 },
				{ targetNode = 62125, type = 2, visualStyle = 1 },
				{ targetNode = 62107, type = 2, visualStyle = 1 }
			}
		},
		[62125] = {
			ID = 62125,
			flags = 1,
			type = 2,
			posX = 2703,
			posY = 3902,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80184, 80185 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62088, type = 2, visualStyle = 1 }
			}
		},
		[62126] = {
			ID = 62126,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80186 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62127, type = 2, visualStyle = 1 },
				{ targetNode = 62110, type = 2, visualStyle = 1 }
			}
		},
		[62127] = {
			ID = 62127,
			flags = 0,
			type = 0,
			posX = 3295,
			posY = 5097,
			maxRanks = 1,
			conditionIDs = { 18031, 18031, 18031 },
			entryIDs = { 80187 },
			groupIDs = { 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62128, type = 2, visualStyle = 1 },
				{ targetNode = 62096, type = 2, visualStyle = 1 }
			}
		},
		[62128] = {
			ID = 62128,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80188 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62129, type = 2, visualStyle = 1 },
				{ targetNode = 62086, type = 2, visualStyle = 1 }
			}
		},
		[62129] = {
			ID = 62129,
			flags = 0,
			type = 0,
			posX = 3290,
			posY = 6298,
			maxRanks = 2,
			conditionIDs = { 18031, 18034, 18031, 18031, 18034, 18031, 18031, 18034, 18031 },
			entryIDs = { 80189 },
			groupIDs = { 7138, 7139, 7144 },
			costs = {
				{ ID = 2517, amount = 1 }
			},
			edges = {
				{ targetNode = 62087, type = 2, visualStyle = 1 }
			}
		},
		[62130] = {
			ID = 62130,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80190 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62131] = {
			ID = 62131,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80191 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62235, type = 2, visualStyle = 1 }
			}
		},
		[62132] = {
			ID = 62132,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80192 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62133, type = 2, visualStyle = 1 }
			}
		},
		[62133] = {
			ID = 62133,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80193 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62134] = {
			ID = 62134,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80194 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62135, type = 2, visualStyle = 1 }
			}
		},
		[62135] = {
			ID = 62135,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80195 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62136] = {
			ID = 62136,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80196 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62137] = {
			ID = 62137,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80197 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62136, type = 2, visualStyle = 1 }
			}
		},
		[62138] = {
			ID = 62138,
			flags = 1,
			type = 2,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80198, 80199 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62233, type = 2, visualStyle = 1 }
			}
		},
		[62139] = {
			ID = 62139,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80200 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62138, type = 2, visualStyle = 1 },
				{ targetNode = 62140, type = 2, visualStyle = 1 }
			}
		},
		[62140] = {
			ID = 62140,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80201 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62141, type = 2, visualStyle = 1 },
				{ targetNode = 62233, type = 2, visualStyle = 1 }
			}
		},
		[62141] = {
			ID = 62141,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80202 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62143, type = 2, visualStyle = 1 }
			}
		},
		[62142] = {
			ID = 62142,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80203 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62143, type = 2, visualStyle = 1 },
				{ targetNode = 62141, type = 2, visualStyle = 1 }
			}
		},
		[62143] = {
			ID = 62143,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80204 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62137, type = 2, visualStyle = 1 }
			}
		},
		[62144] = {
			ID = 62144,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80205 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62241, type = 2, visualStyle = 1 },
				{ targetNode = 62145, type = 2, visualStyle = 1 }
			}
		},
		[62145] = {
			ID = 62145,
			flags = 1,
			type = 2,
			posX = 9899,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80206, 80207 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62146, type = 2, visualStyle = 1 }
			}
		},
		[62146] = {
			ID = 62146,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80208 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62143, type = 2, visualStyle = 1 },
				{ targetNode = 62147, type = 2, visualStyle = 1 }
			}
		},
		[62147] = {
			ID = 62147,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80209 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62148, type = 2, visualStyle = 1 }
			}
		},
		[62148] = {
			ID = 62148,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80210 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62150] = {
			ID = 62150,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80212 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62184, type = 2, visualStyle = 1 }
			}
		},
		[62151] = {
			ID = 62151,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80214 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62152] = {
			ID = 62152,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80215 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62151, type = 2, visualStyle = 1 }
			}
		},
		[62153] = {
			ID = 62153,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80216 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62154] = {
			ID = 62154,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5699,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80217 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62155, type = 2, visualStyle = 1 },
				{ targetNode = 62153, type = 2, visualStyle = 1 },
				{ targetNode = 62152, type = 2, visualStyle = 1 }
			}
		},
		[62155] = {
			ID = 62155,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80218 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62156, type = 2, visualStyle = 1 }
			}
		},
		[62156] = {
			ID = 62156,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80219 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62157] = {
			ID = 62157,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80220 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62158] = {
			ID = 62158,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80221 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62157, type = 2, visualStyle = 1 }
			}
		},
		[62159] = {
			ID = 62159,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80222 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62150, type = 2, visualStyle = 1 },
				{ targetNode = 62183, type = 2, visualStyle = 1 }
			}
		},
		[62160] = {
			ID = 62160,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80223 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62161, type = 2, visualStyle = 1 }
			}
		},
		[62161] = {
			ID = 62161,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80224 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62158, type = 2, visualStyle = 1 }
			}
		},
		[62162] = {
			ID = 62162,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 5097,
			maxRanks = 2,
			conditionIDs = { 18043, 18044, 18033, 18043, 18044, 18033, 18043, 18044, 18033, 18043 },
			entryIDs = { 80225 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62161, type = 2, visualStyle = 1 },
				{ targetNode = 62163, type = 2, visualStyle = 1 }
			}
		},
		[62163] = {
			ID = 62163,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80226 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62158, type = 2, visualStyle = 1 }
			}
		},
		[62164] = {
			ID = 62164,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80227 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62165, type = 2, visualStyle = 1 }
			}
		},
		[62165] = {
			ID = 62165,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80228 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62166, type = 2, visualStyle = 1 },
				{ targetNode = 81467, type = 2, visualStyle = 1 }
			}
		},
		[62166] = {
			ID = 62166,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80229 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62167, type = 2, visualStyle = 1 }
			}
		},
		[62167] = {
			ID = 62167,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80230 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62160, type = 2, visualStyle = 1 },
				{ targetNode = 62168, type = 2, visualStyle = 1 }
			}
		},
		[62168] = {
			ID = 62168,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80231 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62162, type = 2, visualStyle = 1 }
			}
		},
		[62169] = {
			ID = 62169,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80233 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62170, type = 2, visualStyle = 1 },
				{ targetNode = 62168, type = 2, visualStyle = 1 }
			}
		},
		[62170] = {
			ID = 62170,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80234 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62171, type = 2, visualStyle = 1 }
			}
		},
		[62171] = {
			ID = 62171,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5097,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80235 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62150, type = 2, visualStyle = 1 },
				{ targetNode = 62163, type = 2, visualStyle = 1 },
				{ targetNode = 62154, type = 2, visualStyle = 1 }
			}
		},
		[62172] = {
			ID = 62172,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80236 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62171, type = 2, visualStyle = 1 }
			}
		},
		[62173] = {
			ID = 62173,
			flags = 1,
			type = 2,
			posX = 11099,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80237, 80238 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62172, type = 2, visualStyle = 1 },
				{ targetNode = 62180, type = 2, visualStyle = 1 }
			}
		},
		[62174] = {
			ID = 62174,
			flags = 0,
			type = 0,
			posX = 11699,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80239 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62169, type = 2, visualStyle = 1 },
				{ targetNode = 62173, type = 2, visualStyle = 1 }
			}
		},
		[62175] = {
			ID = 62175,
			flags = 0,
			type = 0,
			posX = 11699,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80240 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62174, type = 2, visualStyle = 1 }
			}
		},
		[62176] = {
			ID = 62176,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80241 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62177, type = 2, visualStyle = 1 },
				{ targetNode = 62175, type = 2, visualStyle = 1 },
				{ targetNode = 62164, type = 2, visualStyle = 1 }
			}
		},
		[62177] = {
			ID = 62177,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80242 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62178, type = 2, visualStyle = 1 }
			}
		},
		[62178] = {
			ID = 62178,
			flags = 0,
			type = 0,
			posX = 11097,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80243 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62179, type = 2, visualStyle = 1 },
				{ targetNode = 81468, type = 2, visualStyle = 1 }
			}
		},
		[62179] = {
			ID = 62179,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 80244 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62181, type = 2, visualStyle = 1 }
			}
		},
		[62180] = {
			ID = 62180,
			flags = 1,
			type = 2,
			posX = 10500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80245, 80246 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62159, type = 2, visualStyle = 1 }
			}
		},
		[62181] = {
			ID = 62181,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80247 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62180, type = 2, visualStyle = 1 },
				{ targetNode = 62182, type = 2, visualStyle = 1 }
			}
		},
		[62182] = {
			ID = 62182,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18044, 18033, 18044, 18033 },
			entryIDs = { 80248 },
			groupIDs = { 7136, 7140, 7141 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62183, type = 2, visualStyle = 1 }
			}
		},
		[62183] = {
			ID = 62183,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80249 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62184, type = 2, visualStyle = 1 }
			}
		},
		[62184] = {
			ID = 62184,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 6299,
			maxRanks = 2,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80250 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62185, type = 2, visualStyle = 1 }
			}
		},
		[62185] = {
			ID = 62185,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 18044, 18033, 18042, 18044, 18033, 18042, 18044, 18033, 18042 },
			entryIDs = { 80251 },
			groupIDs = { 7136, 7140, 7141, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62186] = {
			ID = 62186,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80252 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62187] = {
			ID = 62187,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80253 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62186, type = 2, visualStyle = 1 }
			}
		},
		[62188] = {
			ID = 62188,
			flags = 0,
			type = 0,
			posX = 13498,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80254 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62197, type = 2, visualStyle = 1 },
				{ targetNode = 62196, type = 2, visualStyle = 1 }
			}
		},
		[62189] = {
			ID = 62189,
			flags = 0,
			type = 0,
			posX = 13498,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80255 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62188, type = 2, visualStyle = 1 }
			}
		},
		[62190] = {
			ID = 62190,
			flags = 0,
			type = 0,
			posX = 12297,
			posY = 3897,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80256 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62207, type = 2, visualStyle = 1 },
				{ targetNode = 62194, type = 2, visualStyle = 1 }
			}
		},
		[62191] = {
			ID = 62191,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80257 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62193, type = 2, visualStyle = 1 },
				{ targetNode = 62190, type = 2, visualStyle = 1 }
			}
		},
		[62192] = {
			ID = 62192,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80258 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62191, type = 2, visualStyle = 1 }
			}
		},
		[62193] = {
			ID = 62193,
			flags = 0,
			type = 0,
			posX = 13498,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80259 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62194, type = 2, visualStyle = 1 },
				{ targetNode = 62189, type = 2, visualStyle = 1 }
			}
		},
		[62194] = {
			ID = 62194,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80260 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62188, type = 2, visualStyle = 1 },
				{ targetNode = 62195, type = 2, visualStyle = 1 }
			}
		},
		[62195] = {
			ID = 62195,
			flags = 0,
			type = 0,
			posX = 12297,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80261 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62196, type = 2, visualStyle = 1 }
			}
		},
		[62196] = {
			ID = 62196,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80262 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62187, type = 2, visualStyle = 1 }
			}
		},
		[62197] = {
			ID = 62197,
			flags = 1,
			type = 2,
			posX = 14100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80263, 80264 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62187, type = 2, visualStyle = 1 }
			}
		},
		[62198] = {
			ID = 62198,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80265 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62199] = {
			ID = 62199,
			flags = 0,
			type = 0,
			posX = 9300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80266 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62204, type = 2, visualStyle = 1 }
			}
		},
		[62200] = {
			ID = 62200,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80267 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62203, type = 2, visualStyle = 1 }
			}
		},
		[62201] = {
			ID = 62201,
			flags = 1,
			type = 2,
			posX = 11696,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80268, 80269 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62202, type = 2, visualStyle = 1 },
				{ targetNode = 62200, type = 2, visualStyle = 1 },
				{ targetNode = 62198, type = 2, visualStyle = 1 }
			}
		},
		[62202] = {
			ID = 62202,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80270 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62203, type = 2, visualStyle = 1 }
			}
		},
		[62203] = {
			ID = 62203,
			flags = 0,
			type = 0,
			posX = 11696,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80271 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62204] = {
			ID = 62204,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80272 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62205, type = 2, visualStyle = 1 }
			}
		},
		[62205] = {
			ID = 62205,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80273 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62206] = {
			ID = 62206,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80274 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62207, type = 2, visualStyle = 1 }
			}
		},
		[62207] = {
			ID = 62207,
			flags = 0,
			type = 0,
			posX = 11696,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80275 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62208, type = 2, visualStyle = 1 },
				{ targetNode = 62195, type = 2, visualStyle = 1 },
				{ targetNode = 62201, type = 2, visualStyle = 1 }
			}
		},
		[62208] = {
			ID = 62208,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80276 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62209, type = 2, visualStyle = 1 }
			}
		},
		[62209] = {
			ID = 62209,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18042, 18033, 18035, 18042, 18033, 18035, 18042 },
			entryIDs = { 80277 },
			groupIDs = { 7136, 7141, 7142, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62204, type = 2, visualStyle = 1 }
			}
		},
		[62210] = {
			ID = 62210,
			flags = 0,
			type = 0,
			posX = 9897,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80278 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62209, type = 2, visualStyle = 1 },
				{ targetNode = 62199, type = 2, visualStyle = 1 }
			}
		},
		[62211] = {
			ID = 62211,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80279 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62210, type = 2, visualStyle = 1 },
				{ targetNode = 62220, type = 2, visualStyle = 1 }
			}
		},
		[62212] = {
			ID = 62212,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80280 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62211, type = 2, visualStyle = 1 },
				{ targetNode = 62219, type = 2, visualStyle = 1 }
			}
		},
		[62213] = {
			ID = 62213,
			flags = 0,
			type = 0,
			posX = 10497,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80281 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62212, type = 2, visualStyle = 1 }
			}
		},
		[62214] = {
			ID = 62214,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80282 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62213, type = 2, visualStyle = 1 },
				{ targetNode = 62217, type = 2, visualStyle = 1 }
			}
		},
		[62215] = {
			ID = 62215,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80283 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62214, type = 2, visualStyle = 1 },
				{ targetNode = 62216, type = 2, visualStyle = 1 }
			}
		},
		[62216] = {
			ID = 62216,
			flags = 0,
			type = 0,
			posX = 12297,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80284 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62192, type = 2, visualStyle = 1 },
				{ targetNode = 62217, type = 2, visualStyle = 1 }
			}
		},
		[62217] = {
			ID = 62217,
			flags = 0,
			type = 0,
			posX = 11696,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80285 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62206, type = 2, visualStyle = 1 },
				{ targetNode = 62083, type = 2, visualStyle = 1 },
				{ targetNode = 62218, type = 2, visualStyle = 1 }
			}
		},
		[62218] = {
			ID = 62218,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18035, 18035, 18035 },
			entryIDs = { 80286 },
			groupIDs = { 7136, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62190, type = 2, visualStyle = 1 },
				{ targetNode = 62206, type = 2, visualStyle = 1 }
			}
		},
		[62219] = {
			ID = 62219,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80287 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62207, type = 2, visualStyle = 1 },
				{ targetNode = 62220, type = 2, visualStyle = 1 }
			}
		},
		[62220] = {
			ID = 62220,
			flags = 1,
			type = 2,
			posX = 10499,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18035, 18033, 18035, 18033, 18035 },
			entryIDs = { 80288, 80289 },
			groupIDs = { 7136, 7141, 7142 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62208, type = 2, visualStyle = 1 },
				{ targetNode = 62210, type = 2, visualStyle = 1 }
			}
		},
		[62221] = {
			ID = 62221,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80290 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62223, type = 2, visualStyle = 1 }
			}
		},
		[62222] = {
			ID = 62222,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80291 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62221, type = 2, visualStyle = 1 },
				{ targetNode = 62223, type = 2, visualStyle = 1 }
			}
		},
		[62223] = {
			ID = 62223,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80292 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62134, type = 2, visualStyle = 1 }
			}
		},
		[62224] = {
			ID = 62224,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80293 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62132, type = 2, visualStyle = 1 },
				{ targetNode = 62223, type = 2, visualStyle = 1 }
			}
		},
		[62225] = {
			ID = 62225,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80294 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62224, type = 2, visualStyle = 1 }
			}
		},
		[62226] = {
			ID = 62226,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80295 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62227, type = 2, visualStyle = 1 },
				{ targetNode = 62225, type = 2, visualStyle = 1 }
			}
		},
		[62227] = {
			ID = 62227,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80296 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62222, type = 2, visualStyle = 1 },
				{ targetNode = 62224, type = 2, visualStyle = 1 }
			}
		},
		[62228] = {
			ID = 62228,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80297 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62227, type = 2, visualStyle = 1 },
				{ targetNode = 62231, type = 2, visualStyle = 1 }
			}
		},
		[62229] = {
			ID = 62229,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80298 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62230, type = 2, visualStyle = 1 },
				{ targetNode = 62228, type = 2, visualStyle = 1 },
				{ targetNode = 62226, type = 2, visualStyle = 1 }
			}
		},
		[62230] = {
			ID = 62230,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80299 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62139, type = 2, visualStyle = 1 },
				{ targetNode = 62130, type = 2, visualStyle = 1 },
				{ targetNode = 62231, type = 2, visualStyle = 1 }
			}
		},
		[62231] = {
			ID = 62231,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80300 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62232, type = 2, visualStyle = 1 },
				{ targetNode = 62138, type = 2, visualStyle = 1 }
			}
		},
		[62232] = {
			ID = 62232,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80301 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62221, type = 2, visualStyle = 1 },
				{ targetNode = 62233, type = 2, visualStyle = 1 }
			}
		},
		[62233] = {
			ID = 62233,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80302 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62234, type = 2, visualStyle = 1 },
				{ targetNode = 62131, type = 2, visualStyle = 1 }
			}
		},
		[62234] = {
			ID = 62234,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80303 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62235, type = 2, visualStyle = 1 }
			}
		},
		[62235] = {
			ID = 62235,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80304 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62236, type = 2, visualStyle = 1 }
			}
		},
		[62236] = {
			ID = 62236,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18042, 18033, 18037, 18042, 18033, 18037, 18042 },
			entryIDs = { 80305 },
			groupIDs = { 7136, 7141, 7143, 7145 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {}
		},
		[62237] = {
			ID = 62237,
			flags = 0,
			type = 0,
			posX = 11699,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80306 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62238, type = 2, visualStyle = 1 }
			}
		},
		[62238] = {
			ID = 62238,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80307 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62239, type = 2, visualStyle = 1 },
				{ targetNode = 62229, type = 2, visualStyle = 1 }
			}
		},
		[62239] = {
			ID = 62239,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80308 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62230, type = 2, visualStyle = 1 },
				{ targetNode = 62240, type = 2, visualStyle = 1 },
				{ targetNode = 62144, type = 2, visualStyle = 1 }
			}
		},
		[62240] = {
			ID = 62240,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 18037, 18037, 18037 },
			entryIDs = { 80309 },
			groupIDs = { 7136, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62139, type = 2, visualStyle = 1 },
				{ targetNode = 62241, type = 2, visualStyle = 1 }
			}
		},
		[62241] = {
			ID = 62241,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18033, 18037, 18033, 18037, 18033, 18037 },
			entryIDs = { 80310 },
			groupIDs = { 7136, 7141, 7143 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62142, type = 2, visualStyle = 1 },
				{ targetNode = 62146, type = 2, visualStyle = 1 }
			}
		},
		[68568] = {
			ID = 68568,
			flags = 0,
			type = 0,
			posX = 16640,
			posY = -320,
			maxRanks = 0,
			conditionIDs = {  },
			entryIDs = { 87583 },
			groupIDs = {  },
			costs = {},
			edges = {}
		},
		[68569] = {
			ID = 68569,
			flags = 0,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87584 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68570] = {
			ID = 68570,
			flags = 1,
			type = 2,
			posX = 3900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87586, 87585 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68571] = {
			ID = 68571,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87587 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68572] = {
			ID = 68572,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87588 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68680, type = 2, visualStyle = 1 }
			}
		},
		[68573] = {
			ID = 68573,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87589 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68668, type = 2, visualStyle = 1 }
			}
		},
		[68574] = {
			ID = 68574,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87590 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68648, type = 2, visualStyle = 1 }
			}
		},
		[68575] = {
			ID = 68575,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87591 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68576] = {
			ID = 68576,
			flags = 1,
			type = 2,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87593, 87592 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68599, type = 2, visualStyle = 1 },
				{ targetNode = 68599, type = 2, visualStyle = 1 }
			}
		},
		[68577] = {
			ID = 68577,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87594 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68576, type = 2, visualStyle = 1 },
				{ targetNode = 68578, type = 2, visualStyle = 1 },
				{ targetNode = 68576, type = 2, visualStyle = 1 },
				{ targetNode = 68576, type = 2, visualStyle = 1 }
			}
		},
		[68578] = {
			ID = 68578,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87595 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68579] = {
			ID = 68579,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87596 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68601, type = 2, visualStyle = 1 }
			}
		},
		[68580] = {
			ID = 68580,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87597 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68581] = {
			ID = 68581,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87598 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68582, type = 2, visualStyle = 1 }
			}
		},
		[68582] = {
			ID = 68582,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87599 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68580, type = 2, visualStyle = 1 }
			}
		},
		[68583] = {
			ID = 68583,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87600 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68601, type = 2, visualStyle = 1 },
				{ targetNode = 68582, type = 2, visualStyle = 1 }
			}
		},
		[68584] = {
			ID = 68584,
			flags = 1,
			type = 2,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87602, 87601 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68585] = {
			ID = 68585,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87603 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68586] = {
			ID = 68586,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87604 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68587, type = 2, visualStyle = 1 }
			}
		},
		[68587] = {
			ID = 68587,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87605 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68585, type = 2, visualStyle = 1 }
			}
		},
		[68588] = {
			ID = 68588,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87606 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68587, type = 2, visualStyle = 1 }
			}
		},
		[68589] = {
			ID = 68589,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87607 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68588, type = 2, visualStyle = 1 },
				{ targetNode = 68586, type = 2, visualStyle = 1 },
				{ targetNode = 68600, type = 2, visualStyle = 1 }
			}
		},
		[68590] = {
			ID = 68590,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87609, 87608 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68589, type = 2, visualStyle = 1 }
			}
		},
		[68591] = {
			ID = 68591,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87610 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68592] = {
			ID = 68592,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87611 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68590, type = 2, visualStyle = 1 },
				{ targetNode = 68591, type = 2, visualStyle = 1 }
			}
		},
		[68593] = {
			ID = 68593,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87612 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68594, type = 2, visualStyle = 1 }
			}
		},
		[68594] = {
			ID = 68594,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87613 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68592, type = 2, visualStyle = 1 },
				{ targetNode = 68584, type = 2, visualStyle = 1 },
				{ targetNode = 68595, type = 2, visualStyle = 1 }
			}
		},
		[68595] = {
			ID = 68595,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87614 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68596, type = 2, visualStyle = 1 },
				{ targetNode = 68591, type = 2, visualStyle = 1 }
			}
		},
		[68596] = {
			ID = 68596,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87615 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68589, type = 2, visualStyle = 1 },
				{ targetNode = 68613, type = 2, visualStyle = 1 }
			}
		},
		[68597] = {
			ID = 68597,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87616 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68598, type = 2, visualStyle = 1 }
			}
		},
		[68598] = {
			ID = 68598,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87617 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68613, type = 2, visualStyle = 1 }
			}
		},
		[68599] = {
			ID = 68599,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87618 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68583, type = 2, visualStyle = 1 },
				{ targetNode = 68581, type = 2, visualStyle = 1 },
				{ targetNode = 68614, type = 2, visualStyle = 1 }
			}
		},
		[68600] = {
			ID = 68600,
			flags = 1,
			type = 2,
			posX = 12300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87620, 87619 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68587, type = 2, visualStyle = 1 },
				{ targetNode = 68601, type = 2, visualStyle = 1 }
			}
		},
		[68601] = {
			ID = 68601,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87621 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68602, type = 2, visualStyle = 1 }
			}
		},
		[68602] = {
			ID = 68602,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87622 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68603] = {
			ID = 68603,
			flags = 1,
			type = 2,
			posX = 10500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87624, 87623 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68604] = {
			ID = 68604,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87625 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68577, type = 2, visualStyle = 1 },
				{ targetNode = 68611, type = 2, visualStyle = 1 },
				{ targetNode = 68603, type = 2, visualStyle = 1 }
			}
		},
		[68605] = {
			ID = 68605,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87626 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68604, type = 2, visualStyle = 1 }
			}
		},
		[68606] = {
			ID = 68606,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87627 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68605, type = 2, visualStyle = 1 },
				{ targetNode = 68609, type = 2, visualStyle = 1 }
			}
		},
		[68607] = {
			ID = 68607,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87628 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68606, type = 2, visualStyle = 1 },
				{ targetNode = 68608, type = 2, visualStyle = 1 }
			}
		},
		[68608] = {
			ID = 68608,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87629 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68593, type = 2, visualStyle = 1 },
				{ targetNode = 68609, type = 2, visualStyle = 1 }
			}
		},
		[68609] = {
			ID = 68609,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87630 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68610, type = 2, visualStyle = 1 }
			}
		},
		[68610] = {
			ID = 68610,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18817, 18817 },
			entryIDs = { 87631 },
			groupIDs = { 7589, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68595, type = 2, visualStyle = 1 },
				{ targetNode = 68597, type = 2, visualStyle = 1 },
				{ targetNode = 68611, type = 2, visualStyle = 1 }
			}
		},
		[68611] = {
			ID = 68611,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87632 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68612, type = 2, visualStyle = 1 },
				{ targetNode = 68578, type = 2, visualStyle = 1 },
				{ targetNode = 68612, type = 2, visualStyle = 1 }
			}
		},
		[68612] = {
			ID = 68612,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87633 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68613, type = 2, visualStyle = 1 },
				{ targetNode = 68599, type = 2, visualStyle = 1 }
			}
		},
		[68613] = {
			ID = 68613,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18817, 18823, 18817, 18823 },
			entryIDs = { 87634 },
			groupIDs = { 7589, 7591, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68579, type = 2, visualStyle = 1 },
				{ targetNode = 68600, type = 2, visualStyle = 1 },
				{ targetNode = 68583, type = 2, visualStyle = 1 }
			}
		},
		[68614] = {
			ID = 68614,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18817, 18821, 18817, 18821 },
			entryIDs = { 87635 },
			groupIDs = { 7589, 7590, 7594 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68582, type = 2, visualStyle = 1 }
			}
		},
		[68615] = {
			ID = 68615,
			flags = 1,
			type = 2,
			posX = 9900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87637, 87636 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68616] = {
			ID = 68616,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87638 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68617] = {
			ID = 68617,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87640, 87639 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68618, type = 2, visualStyle = 1 },
				{ targetNode = 68627, type = 2, visualStyle = 1 }
			}
		},
		[68618] = {
			ID = 68618,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87641 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68619, type = 2, visualStyle = 1 }
			}
		},
		[68619] = {
			ID = 68619,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87643, 87642 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68620, type = 2, visualStyle = 1 }
			}
		},
		[68620] = {
			ID = 68620,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87644 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68616, type = 2, visualStyle = 1 }
			}
		},
		[68621] = {
			ID = 68621,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87645 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {}
		},
		[68622] = {
			ID = 68622,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87646 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68625, type = 2, visualStyle = 1 }
			}
		},
		[68623] = {
			ID = 68623,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87647 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68622, type = 2, visualStyle = 1 },
				{ targetNode = 68624, type = 2, visualStyle = 1 }
			}
		},
		[68624] = {
			ID = 68624,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87648 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68625, type = 2, visualStyle = 1 }
			}
		},
		[68625] = {
			ID = 68625,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87649 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68617, type = 2, visualStyle = 1 },
				{ targetNode = 68626, type = 2, visualStyle = 1 },
				{ targetNode = 68621, type = 2, visualStyle = 1 }
			}
		},
		[68626] = {
			ID = 68626,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87650 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68627, type = 2, visualStyle = 1 },
				{ targetNode = 68638, type = 2, visualStyle = 1 }
			}
		},
		[68627] = {
			ID = 68627,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87651 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68628, type = 2, visualStyle = 1 }
			}
		},
		[68628] = {
			ID = 68628,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87652 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68620, type = 2, visualStyle = 1 },
				{ targetNode = 68629, type = 2, visualStyle = 1 }
			}
		},
		[68629] = {
			ID = 68629,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87653 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68575, type = 2, visualStyle = 1 }
			}
		},
		[68630] = {
			ID = 68630,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87654 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68629, type = 2, visualStyle = 1 },
				{ targetNode = 68631, type = 2, visualStyle = 1 }
			}
		},
		[68631] = {
			ID = 68631,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87655 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68575, type = 2, visualStyle = 1 }
			}
		},
		[68632] = {
			ID = 68632,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87656 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68631, type = 2, visualStyle = 1 },
				{ targetNode = 68633, type = 2, visualStyle = 1 }
			}
		},
		[68633] = {
			ID = 68633,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87657 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68615, type = 2, visualStyle = 1 }
			}
		},
		[68634] = {
			ID = 68634,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18821, 18823, 18820, 18821, 18823, 18820 },
			entryIDs = { 87658 },
			groupIDs = { 7590, 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68633, type = 2, visualStyle = 1 }
			}
		},
		[68635] = {
			ID = 68635,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87659 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68634, type = 2, visualStyle = 1 },
				{ targetNode = 68636, type = 2, visualStyle = 1 }
			}
		},
		[68636] = {
			ID = 68636,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87660 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68632, type = 2, visualStyle = 1 }
			}
		},
		[68637] = {
			ID = 68637,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87661 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68636, type = 2, visualStyle = 1 },
				{ targetNode = 68638, type = 2, visualStyle = 1 }
			}
		},
		[68638] = {
			ID = 68638,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87662 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68628, type = 2, visualStyle = 1 },
				{ targetNode = 68630, type = 2, visualStyle = 1 },
				{ targetNode = 68632, type = 2, visualStyle = 1 }
			}
		},
		[68639] = {
			ID = 68639,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87663 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68638, type = 2, visualStyle = 1 }
			}
		},
		[68640] = {
			ID = 68640,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87664 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68626, type = 2, visualStyle = 1 },
				{ targetNode = 68637, type = 2, visualStyle = 1 },
				{ targetNode = 68639, type = 2, visualStyle = 1 }
			}
		},
		[68641] = {
			ID = 68641,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87665 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68640, type = 2, visualStyle = 1 }
			}
		},
		[68642] = {
			ID = 68642,
			flags = 1,
			type = 2,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87667, 87666 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68641, type = 2, visualStyle = 1 }
			}
		},
		[68643] = {
			ID = 68643,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87668 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68642, type = 2, visualStyle = 1 },
				{ targetNode = 68623, type = 2, visualStyle = 1 }
			}
		},
		[68644] = {
			ID = 68644,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87669 },
			groupIDs = { 7594, 7597, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68645, type = 2, visualStyle = 1 },
				{ targetNode = 68643, type = 2, visualStyle = 1 }
			}
		},
		[68645] = {
			ID = 68645,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87670 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68642, type = 2, visualStyle = 1 },
				{ targetNode = 68646, type = 2, visualStyle = 1 }
			}
		},
		[68646] = {
			ID = 68646,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87671 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68574, type = 2, visualStyle = 1 },
				{ targetNode = 68647, type = 2, visualStyle = 1 }
			}
		},
		[68647] = {
			ID = 68647,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 18820, 18820 },
			entryIDs = { 87672 },
			groupIDs = { 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68648, type = 2, visualStyle = 1 }
			}
		},
		[68648] = {
			ID = 68648,
			flags = 1,
			type = 2,
			posX = 10500,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 18823, 18820, 18823, 18820 },
			entryIDs = { 87674, 87673 },
			groupIDs = { 7591, 7594, 7598 },
			costs = {
				{ ID = 2628, amount = 1 }
			},
			edges = {
				{ targetNode = 68635, type = 2, visualStyle = 1 },
				{ targetNode = 68637, type = 2, visualStyle = 1 }
			}
		},
		[68649] = {
			ID = 68649,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87675 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68650] = {
			ID = 68650,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87676 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68651] = {
			ID = 68651,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87677 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68659, type = 2, visualStyle = 1 }
			}
		},
		[68652] = {
			ID = 68652,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87678 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68655, type = 2, visualStyle = 1 }
			}
		},
		[68653] = {
			ID = 68653,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87679 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68654, type = 2, visualStyle = 1 }
			}
		},
		[68654] = {
			ID = 68654,
			flags = 1,
			type = 2,
			posX = 5700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87681, 87680 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68655, type = 2, visualStyle = 1 }
			}
		},
		[68655] = {
			ID = 68655,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87682 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68656] = {
			ID = 68656,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87683 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68655, type = 2, visualStyle = 1 }
			}
		},
		[68657] = {
			ID = 68657,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87684 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68658, type = 2, visualStyle = 1 }
			}
		},
		[68658] = {
			ID = 68658,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87685 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68656, type = 2, visualStyle = 1 },
				{ targetNode = 68659, type = 2, visualStyle = 1 }
			}
		},
		[68659] = {
			ID = 68659,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87686 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68650, type = 2, visualStyle = 1 }
			}
		},
		[68660] = {
			ID = 68660,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87687 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68661] = {
			ID = 68661,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87688 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68662, type = 2, visualStyle = 1 }
			}
		},
		[68662] = {
			ID = 68662,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87689 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68649, type = 2, visualStyle = 1 }
			}
		},
		[68663] = {
			ID = 68663,
			flags = 0,
			type = 0,
			posX = 2100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87690 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68662, type = 2, visualStyle = 1 }
			}
		},
		[68664] = {
			ID = 68664,
			flags = 0,
			type = 0,
			posX = 2100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87691 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68665] = {
			ID = 68665,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87692 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68664, type = 2, visualStyle = 1 },
				{ targetNode = 68666, type = 2, visualStyle = 1 }
			}
		},
		[68666] = {
			ID = 68666,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87693 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68667, type = 2, visualStyle = 1 }
			}
		},
		[68667] = {
			ID = 68667,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87694 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68661, type = 2, visualStyle = 1 },
				{ targetNode = 68668, type = 2, visualStyle = 1 },
				{ targetNode = 68663, type = 2, visualStyle = 1 }
			}
		},
		[68668] = {
			ID = 68668,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 18824, 18819, 18824, 18819 },
			entryIDs = { 87695 },
			groupIDs = { 7592, 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68660, type = 2, visualStyle = 1 },
				{ targetNode = 68659, type = 2, visualStyle = 1 },
				{ targetNode = 68662, type = 2, visualStyle = 1 }
			}
		},
		[68669] = {
			ID = 68669,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87696 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68651, type = 2, visualStyle = 1 },
				{ targetNode = 68658, type = 2, visualStyle = 1 },
				{ targetNode = 68668, type = 2, visualStyle = 1 }
			}
		},
		[68670] = {
			ID = 68670,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87697 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68669, type = 2, visualStyle = 1 }
			}
		},
		[68671] = {
			ID = 68671,
			flags = 0,
			type = 0,
			posX = 5699,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87698 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68672] = {
			ID = 68672,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87699 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68671, type = 2, visualStyle = 1 },
				{ targetNode = 68572, type = 2, visualStyle = 1 }
			}
		},
		[68673] = {
			ID = 68673,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87700 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68571, type = 2, visualStyle = 1 },
				{ targetNode = 68672, type = 2, visualStyle = 1 }
			}
		},
		[68674] = {
			ID = 68674,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87701 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68675] = {
			ID = 68675,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87702 },
			groupIDs = { 7596, 7597 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68676, type = 2, visualStyle = 1 }
			}
		},
		[68676] = {
			ID = 68676,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87703 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68674, type = 2, visualStyle = 1 },
				{ targetNode = 68677, type = 2, visualStyle = 1 },
				{ targetNode = 68683, type = 2, visualStyle = 1 }
			}
		},
		[68677] = {
			ID = 68677,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 87704 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68570, type = 2, visualStyle = 1 },
				{ targetNode = 68678, type = 2, visualStyle = 1 },
				{ targetNode = 68673, type = 2, visualStyle = 1 }
			}
		},
		[68678] = {
			ID = 68678,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87705 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68679, type = 2, visualStyle = 1 }
			}
		},
		[68679] = {
			ID = 68679,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87706 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68657, type = 2, visualStyle = 1 },
				{ targetNode = 68680, type = 2, visualStyle = 1 }
			}
		},
		[68680] = {
			ID = 68680,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87707 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68652, type = 2, visualStyle = 1 },
				{ targetNode = 68653, type = 2, visualStyle = 1 },
				{ targetNode = 68658, type = 2, visualStyle = 1 }
			}
		},
		[68681] = {
			ID = 68681,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18822, 18822 },
			entryIDs = { 87708 },
			groupIDs = { 7593, 7596, 7597 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68682, type = 2, visualStyle = 1 }
			}
		},
		[68682] = {
			ID = 68682,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87709 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68569, type = 2, visualStyle = 1 },
				{ targetNode = 68665, type = 2, visualStyle = 1 },
				{ targetNode = 68683, type = 2, visualStyle = 1 }
			}
		},
		[68683] = {
			ID = 68683,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 87710 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68665, type = 2, visualStyle = 1 },
				{ targetNode = 68684, type = 2, visualStyle = 1 },
				{ targetNode = 68570, type = 2, visualStyle = 1 }
			}
		},
		[68684] = {
			ID = 68684,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87711 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68685, type = 2, visualStyle = 1 }
			}
		},
		[68685] = {
			ID = 68685,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87712 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68573, type = 2, visualStyle = 1 },
				{ targetNode = 68667, type = 2, visualStyle = 1 }
			}
		},
		[68686] = {
			ID = 68686,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 18819, 18819 },
			entryIDs = { 87713 },
			groupIDs = { 7595, 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68679, type = 2, visualStyle = 1 },
				{ targetNode = 68670, type = 2, visualStyle = 1 },
				{ targetNode = 68685, type = 2, visualStyle = 1 }
			}
		},
		[68687] = {
			ID = 68687,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87714 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {}
		},
		[68688] = {
			ID = 68688,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 87715 },
			groupIDs = { 7596 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68687, type = 2, visualStyle = 1 },
				{ targetNode = 68677, type = 2, visualStyle = 1 },
				{ targetNode = 68673, type = 2, visualStyle = 1 }
			}
		},
		[68689] = {
			ID = 68689,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 18818, 18818 },
			entryIDs = { 87716 },
			groupIDs = { 7596, 7597, 7599 },
			costs = {
				{ ID = 2629, amount = 1 }
			},
			edges = {
				{ targetNode = 68688, type = 2, visualStyle = 1 }
			}
		},
		[71915] = {
			ID = 71915,
			flags = 1,
			type = 0,
			posX = 2400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91421 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71926, type = 2, visualStyle = 1 }
			}
		},
		[71916] = {
			ID = 71916,
			flags = 0,
			type = 0,
			posX = 4200,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91422 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71956, type = 2, visualStyle = 1 }
			}
		},
		[71917] = {
			ID = 71917,
			flags = 0,
			type = 0,
			posX = 6000,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91424 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71957, type = 2, visualStyle = 1 }
			}
		},
		[71918] = {
			ID = 71918,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91425 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71915, type = 2, visualStyle = 1 },
				{ targetNode = 71924, type = 2, visualStyle = 1 }
			}
		},
		[71919] = {
			ID = 71919,
			flags = 0,
			type = 0,
			posX = 4200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91426 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71939, type = 2, visualStyle = 1 }
			}
		},
		[71920] = {
			ID = 71920,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91428 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72057, type = 2, visualStyle = 1 }
			}
		},
		[71921] = {
			ID = 71921,
			flags = 1,
			type = 0,
			posX = 10200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91429 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71986, type = 2, visualStyle = 1 }
			}
		},
		[71922] = {
			ID = 71922,
			flags = 0,
			type = 0,
			posX = 5400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91430 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71945, type = 2, visualStyle = 1 }
			}
		},
		[71923] = {
			ID = 71923,
			flags = 0,
			type = 0,
			posX = 4800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91431 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71939, type = 2, visualStyle = 1 },
				{ targetNode = 71957, type = 2, visualStyle = 1 }
			}
		},
		[71924] = {
			ID = 71924,
			flags = 1,
			type = 0,
			posX = 3600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91432 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71926, type = 2, visualStyle = 1 },
				{ targetNode = 71939, type = 2, visualStyle = 1 }
			}
		},
		[71925] = {
			ID = 71925,
			flags = 0,
			type = 0,
			posX = 4200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91433 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71924, type = 2, visualStyle = 1 },
				{ targetNode = 71919, type = 2, visualStyle = 1 },
				{ targetNode = 71923, type = 2, visualStyle = 1 }
			}
		},
		[71926] = {
			ID = 71926,
			flags = 1,
			type = 0,
			posX = 3000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91434 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {}
		},
		[71927] = {
			ID = 71927,
			flags = 0,
			type = 0,
			posX = 3600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91435 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71956, type = 2, visualStyle = 1 },
				{ targetNode = 71936, type = 2, visualStyle = 1 }
			}
		},
		[71928] = {
			ID = 71928,
			flags = 0,
			type = 0,
			posX = 3600,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91436 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71916, type = 2, visualStyle = 1 },
				{ targetNode = 71929, type = 2, visualStyle = 1 },
				{ targetNode = 71927, type = 2, visualStyle = 1 }
			}
		},
		[71929] = {
			ID = 71929,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91437 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71936, type = 2, visualStyle = 1 }
			}
		},
		[71930] = {
			ID = 71930,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91438 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71929, type = 2, visualStyle = 1 }
			}
		},
		[71931] = {
			ID = 71931,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91439 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71932, type = 2, visualStyle = 1 },
				{ targetNode = 71952, type = 2, visualStyle = 1 }
			}
		},
		[71932] = {
			ID = 71932,
			flags = 0,
			type = 0,
			posX = 2400,
			posY = 1800,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 91440 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71951, type = 2, visualStyle = 1 }
			}
		},
		[71933] = {
			ID = 71933,
			flags = 0,
			type = 0,
			posX = 4200,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19161, 22787, 22788, 22789, 19161, 22787, 22788, 22789, 19161, 22787, 22788, 22789, 19161 },
			entryIDs = { 91441 },
			groupIDs = { 7823, 9085, 9086, 9087 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71950, type = 2, visualStyle = 1 },
				{ targetNode = 71952, type = 2, visualStyle = 1 }
			}
		},
		[71934] = {
			ID = 71934,
			flags = 0,
			type = 0,
			posX = 2400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91442 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71935, type = 2, visualStyle = 1 },
				{ targetNode = 71929, type = 2, visualStyle = 1 }
			}
		},
		[71935] = {
			ID = 71935,
			flags = 0,
			type = 0,
			posX = 2400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91443 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71936, type = 2, visualStyle = 1 }
			}
		},
		[71936] = {
			ID = 71936,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91444 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71953, type = 2, visualStyle = 1 },
				{ targetNode = 71937, type = 2, visualStyle = 1 }
			}
		},
		[71937] = {
			ID = 71937,
			flags = 1,
			type = 2,
			posX = 2400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91446, 91445 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71918, type = 2, visualStyle = 1 }
			}
		},
		[71938] = {
			ID = 71938,
			flags = 0,
			type = 0,
			posX = 5400,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91447 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71917, type = 2, visualStyle = 1 },
				{ targetNode = 71923, type = 2, visualStyle = 1 }
			}
		},
		[71939] = {
			ID = 71939,
			flags = 1,
			type = 2,
			posX = 4200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91448, 91427 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {}
		},
		[71940] = {
			ID = 71940,
			flags = 0,
			type = 0,
			posX = 4800,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91449 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71938, type = 2, visualStyle = 1 },
				{ targetNode = 71925, type = 2, visualStyle = 1 }
			}
		},
		[71941] = {
			ID = 71941,
			flags = 1,
			type = 2,
			posX = 6000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91451, 91450 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71938, type = 2, visualStyle = 1 }
			}
		},
		[71942] = {
			ID = 71942,
			flags = 0,
			type = 0,
			posX = 5400,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91452 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71940, type = 2, visualStyle = 1 },
				{ targetNode = 71941, type = 2, visualStyle = 1 }
			}
		},
		[71943] = {
			ID = 71943,
			flags = 0,
			type = 0,
			posX = 6000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91453 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71942, type = 2, visualStyle = 1 }
			}
		},
		[71944] = {
			ID = 71944,
			flags = 0,
			type = 0,
			posX = 6000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91454 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71945, type = 2, visualStyle = 1 },
				{ targetNode = 71943, type = 2, visualStyle = 1 }
			}
		},
		[71945] = {
			ID = 71945,
			flags = 0,
			type = 0,
			posX = 5400,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91455 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71942, type = 2, visualStyle = 1 }
			}
		},
		[71946] = {
			ID = 71946,
			flags = 0,
			type = 0,
			posX = 4800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91456 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71916, type = 2, visualStyle = 1 },
				{ targetNode = 71945, type = 2, visualStyle = 1 },
				{ targetNode = 71955, type = 2, visualStyle = 1 }
			}
		},
		[71947] = {
			ID = 71947,
			flags = 1,
			type = 2,
			posX = 5400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91458, 91457 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71946, type = 2, visualStyle = 1 },
				{ targetNode = 71944, type = 2, visualStyle = 1 },
				{ targetNode = 71922, type = 2, visualStyle = 1 }
			}
		},
		[71948] = {
			ID = 71948,
			flags = 0,
			type = 0,
			posX = 6000,
			posY = 1800,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 91459 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71947, type = 2, visualStyle = 1 }
			}
		},
		[71949] = {
			ID = 71949,
			flags = 0,
			type = 0,
			posX = 5400,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91460 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71950, type = 2, visualStyle = 1 },
				{ targetNode = 71948, type = 2, visualStyle = 1 }
			}
		},
		[71950] = {
			ID = 71950,
			flags = 1,
			type = 0,
			posX = 4800,
			posY = 1800,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 91461 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71954, type = 2, visualStyle = 1 },
				{ targetNode = 71947, type = 2, visualStyle = 1 }
			}
		},
		[71951] = {
			ID = 71951,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91462 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71930, type = 2, visualStyle = 1 },
				{ targetNode = 71928, type = 2, visualStyle = 1 },
				{ targetNode = 71934, type = 2, visualStyle = 1 }
			}
		},
		[71952] = {
			ID = 71952,
			flags = 1,
			type = 0,
			posX = 3600,
			posY = 1800,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 91463 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71951, type = 2, visualStyle = 1 },
				{ targetNode = 71954, type = 2, visualStyle = 1 }
			}
		},
		[71953] = {
			ID = 71953,
			flags = 0,
			type = 0,
			posX = 3599,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91464 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71918, type = 2, visualStyle = 1 },
				{ targetNode = 71925, type = 2, visualStyle = 1 }
			}
		},
		[71954] = {
			ID = 71954,
			flags = 0,
			type = 0,
			posX = 4200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 91465 },
			groupIDs = { 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71946, type = 2, visualStyle = 1 },
				{ targetNode = 71928, type = 2, visualStyle = 1 }
			}
		},
		[71955] = {
			ID = 71955,
			flags = 0,
			type = 0,
			posX = 4800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91466 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71956, type = 2, visualStyle = 1 },
				{ targetNode = 71942, type = 2, visualStyle = 1 }
			}
		},
		[71956] = {
			ID = 71956,
			flags = 1,
			type = 2,
			posX = 4200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19167, 19167, 19167 },
			entryIDs = { 91468, 91467 },
			groupIDs = { 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {
				{ targetNode = 71940, type = 2, visualStyle = 1 },
				{ targetNode = 71953, type = 2, visualStyle = 1 }
			}
		},
		[71957] = {
			ID = 71957,
			flags = 0,
			type = 0,
			posX = 5400,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19168, 19167, 19168, 19167, 19168, 19167 },
			entryIDs = { 91469 },
			groupIDs = { 7821, 7822, 7823 },
			costs = {
				{ ID = 2665, amount = 1 }
			},
			edges = {}
		},
		[71958] = {
			ID = 71958,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91470 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71959, type = 2, visualStyle = 1 }
			}
		},
		[71959] = {
			ID = 71959,
			flags = 1,
			type = 2,
			posX = 10800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91472, 91471 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71960] = {
			ID = 71960,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91473 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71959, type = 2, visualStyle = 1 }
			}
		},
		[71961] = {
			ID = 71961,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91474 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71972, type = 2, visualStyle = 1 }
			}
		},
		[71962] = {
			ID = 71962,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91475 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71963, type = 2, visualStyle = 1 }
			}
		},
		[71963] = {
			ID = 71963,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91476 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71964] = {
			ID = 71964,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91477 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71963, type = 2, visualStyle = 1 }
			}
		},
		[71965] = {
			ID = 71965,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91478 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71966, type = 2, visualStyle = 1 }
			}
		},
		[71966] = {
			ID = 71966,
			flags = 1,
			type = 2,
			posX = 12000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91479, 91423 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71967] = {
			ID = 71967,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91480 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71966, type = 2, visualStyle = 1 }
			}
		},
		[71968] = {
			ID = 71968,
			flags = 1,
			type = 0,
			posX = 12000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91481 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71965, type = 2, visualStyle = 1 },
				{ targetNode = 71967, type = 2, visualStyle = 1 }
			}
		},
		[71969] = {
			ID = 71969,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91482 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71970, type = 2, visualStyle = 1 },
				{ targetNode = 71968, type = 2, visualStyle = 1 }
			}
		},
		[71970] = {
			ID = 71970,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91483 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71962, type = 2, visualStyle = 1 },
				{ targetNode = 71967, type = 2, visualStyle = 1 },
				{ targetNode = 71964, type = 2, visualStyle = 1 }
			}
		},
		[71971] = {
			ID = 71971,
			flags = 1,
			type = 0,
			posX = 13800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91484 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71970, type = 2, visualStyle = 1 }
			}
		},
		[71972] = {
			ID = 71972,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91485 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71969, type = 2, visualStyle = 1 },
				{ targetNode = 71984, type = 2, visualStyle = 1 }
			}
		},
		[71973] = {
			ID = 71973,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91486 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71969, type = 2, visualStyle = 1 },
				{ targetNode = 71971, type = 2, visualStyle = 1 }
			}
		},
		[71974] = {
			ID = 71974,
			flags = 1,
			type = 2,
			posX = 13800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91488, 91487 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71982, type = 2, visualStyle = 1 }
			}
		},
		[71975] = {
			ID = 71975,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91489 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71976, type = 2, visualStyle = 1 },
				{ targetNode = 71974, type = 2, visualStyle = 1 }
			}
		},
		[71976] = {
			ID = 71976,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91490 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71982, type = 2, visualStyle = 1 },
				{ targetNode = 71983, type = 2, visualStyle = 1 }
			}
		},
		[71977] = {
			ID = 71977,
			flags = 0,
			type = 0,
			posX = 10199,
			posY = 4198,
			maxRanks = 1,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91491 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72062, type = 2, visualStyle = 1 }
			}
		},
		[71978] = {
			ID = 71978,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91492 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71977, type = 2, visualStyle = 1 }
			}
		},
		[71979] = {
			ID = 71979,
			flags = 1,
			type = 2,
			posX = 12000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91494, 91493 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72064, type = 2, visualStyle = 1 },
				{ targetNode = 71976, type = 2, visualStyle = 1 },
				{ targetNode = 71981, type = 2, visualStyle = 1 }
			}
		},
		[71980] = {
			ID = 71980,
			flags = 1,
			type = 2,
			posX = 12000,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91496, 91495 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71979, type = 2, visualStyle = 1 }
			}
		},
		[71981] = {
			ID = 71981,
			flags = 1,
			type = 2,
			posX = 12000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91498, 91497 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71983, type = 2, visualStyle = 1 },
				{ targetNode = 71961, type = 2, visualStyle = 1 }
			}
		},
		[71982] = {
			ID = 71982,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91499 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71973, type = 2, visualStyle = 1 }
			}
		},
		[71983] = {
			ID = 71983,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91500 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71973, type = 2, visualStyle = 1 },
				{ targetNode = 71972, type = 2, visualStyle = 1 }
			}
		},
		[71984] = {
			ID = 71984,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91501 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71985, type = 2, visualStyle = 1 },
				{ targetNode = 71968, type = 2, visualStyle = 1 }
			}
		},
		[71985] = {
			ID = 71985,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19166, 19162, 19163, 19166, 19162, 19163, 19166 },
			entryIDs = { 91502 },
			groupIDs = { 7815, 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71965, type = 2, visualStyle = 1 },
				{ targetNode = 71960, type = 2, visualStyle = 1 },
				{ targetNode = 71958, type = 2, visualStyle = 1 }
			}
		},
		[71986] = {
			ID = 71986,
			flags = 1,
			type = 2,
			posX = 10200,
			posY = 6599,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91503, 91420 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71987] = {
			ID = 71987,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91504 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71988, type = 2, visualStyle = 1 }
			}
		},
		[71988] = {
			ID = 71988,
			flags = 1,
			type = 2,
			posX = 12602,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91505, 91419 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71989] = {
			ID = 71989,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 6599,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91506 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71990] = {
			ID = 71990,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91507 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71989, type = 2, visualStyle = 1 }
			}
		},
		[71991] = {
			ID = 71991,
			flags = 1,
			type = 2,
			posX = 12000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91509, 91508 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71992] = {
			ID = 71992,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91510 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71991, type = 2, visualStyle = 1 }
			}
		},
		[71993] = {
			ID = 71993,
			flags = 0,
			type = 0,
			posX = 11399,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91511 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71994] = {
			ID = 71994,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91512 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71995] = {
			ID = 71995,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91513 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[71996] = {
			ID = 71996,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91514 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71995, type = 2, visualStyle = 1 }
			}
		},
		[71997] = {
			ID = 71997,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91515 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72007, type = 2, visualStyle = 1 },
				{ targetNode = 71996, type = 2, visualStyle = 1 },
				{ targetNode = 71993, type = 2, visualStyle = 1 }
			}
		},
		[71998] = {
			ID = 71998,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91516 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72030, type = 2, visualStyle = 1 },
				{ targetNode = 71997, type = 2, visualStyle = 1 }
			}
		},
		[71999] = {
			ID = 71999,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91517 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71998, type = 2, visualStyle = 1 },
				{ targetNode = 72000, type = 2, visualStyle = 1 }
			}
		},
		[72000] = {
			ID = 72000,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91518 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71997, type = 2, visualStyle = 1 }
			}
		},
		[72001] = {
			ID = 72001,
			flags = 0,
			type = 0,
			posX = 9600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91519 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72000, type = 2, visualStyle = 1 }
			}
		},
		[72002] = {
			ID = 72002,
			flags = 0,
			type = 0,
			posX = 9600,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91520 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72001, type = 2, visualStyle = 1 },
				{ targetNode = 72003, type = 2, visualStyle = 1 }
			}
		},
		[72003] = {
			ID = 72003,
			flags = 1,
			type = 0,
			posX = 10199,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91521 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71999, type = 2, visualStyle = 1 },
				{ targetNode = 72000, type = 2, visualStyle = 1 },
				{ targetNode = 72001, type = 2, visualStyle = 1 }
			}
		},
		[72004] = {
			ID = 72004,
			flags = 0,
			type = 0,
			posX = 12599,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91522 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[72005] = {
			ID = 72005,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91523 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[72006] = {
			ID = 72006,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91524 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72005, type = 2, visualStyle = 1 }
			}
		},
		[72007] = {
			ID = 72007,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91525 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[72008] = {
			ID = 72008,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91526 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71994, type = 2, visualStyle = 1 },
				{ targetNode = 72004, type = 2, visualStyle = 1 },
				{ targetNode = 72006, type = 2, visualStyle = 1 }
			}
		},
		[72009] = {
			ID = 72009,
			flags = 0,
			type = 0,
			posX = 12599,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91527 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72008, type = 2, visualStyle = 1 },
				{ targetNode = 72030, type = 2, visualStyle = 1 }
			}
		},
		[72010] = {
			ID = 72010,
			flags = 0,
			type = 0,
			posX = 14400,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91528 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72011, type = 2, visualStyle = 1 }
			}
		},
		[72011] = {
			ID = 72011,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91529 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72008, type = 2, visualStyle = 1 }
			}
		},
		[72012] = {
			ID = 72012,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91530 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72009, type = 2, visualStyle = 1 },
				{ targetNode = 72011, type = 2, visualStyle = 1 }
			}
		},
		[72013] = {
			ID = 72013,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91531 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72010, type = 2, visualStyle = 1 },
				{ targetNode = 72011, type = 2, visualStyle = 1 },
				{ targetNode = 72012, type = 2, visualStyle = 1 }
			}
		},
		[72014] = {
			ID = 72014,
			flags = 0,
			type = 0,
			posX = 14399,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91532 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72010, type = 2, visualStyle = 1 },
				{ targetNode = 72013, type = 2, visualStyle = 1 }
			}
		},
		[72015] = {
			ID = 72015,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91533 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72016, type = 2, visualStyle = 1 },
				{ targetNode = 72014, type = 2, visualStyle = 1 }
			}
		},
		[72016] = {
			ID = 72016,
			flags = 0,
			type = 0,
			posX = 13199,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91534 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72012, type = 2, visualStyle = 1 },
				{ targetNode = 72013, type = 2, visualStyle = 1 },
				{ targetNode = 72017, type = 2, visualStyle = 1 }
			}
		},
		[72017] = {
			ID = 72017,
			flags = 0,
			type = 0,
			posX = 12599,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91535 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72028, type = 2, visualStyle = 1 },
				{ targetNode = 72012, type = 2, visualStyle = 1 }
			}
		},
		[72018] = {
			ID = 72018,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91536 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72027, type = 2, visualStyle = 1 },
				{ targetNode = 72017, type = 2, visualStyle = 1 }
			}
		},
		[72019] = {
			ID = 72019,
			flags = 1,
			type = 2,
			posX = 11399,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91538, 91537 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72018, type = 2, visualStyle = 1 }
			}
		},
		[72020] = {
			ID = 72020,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91539 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72019, type = 2, visualStyle = 1 },
				{ targetNode = 72021, type = 2, visualStyle = 1 }
			}
		},
		[72021] = {
			ID = 72021,
			flags = 1,
			type = 2,
			posX = 12599,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91541, 91540 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72018, type = 2, visualStyle = 1 }
			}
		},
		[72022] = {
			ID = 72022,
			flags = 0,
			type = 0,
			posX = 13199,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91542 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72016, type = 2, visualStyle = 1 },
				{ targetNode = 72015, type = 2, visualStyle = 1 },
				{ targetNode = 72021, type = 2, visualStyle = 1 }
			}
		},
		[72023] = {
			ID = 72023,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91543 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72024, type = 2, visualStyle = 1 },
				{ targetNode = 72022, type = 2, visualStyle = 1 },
				{ targetNode = 72020, type = 2, visualStyle = 1 }
			}
		},
		[72024] = {
			ID = 72024,
			flags = 0,
			type = 0,
			posX = 10799,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91544 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72025, type = 2, visualStyle = 1 },
				{ targetNode = 72026, type = 2, visualStyle = 1 },
				{ targetNode = 72019, type = 2, visualStyle = 1 }
			}
		},
		[72025] = {
			ID = 72025,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91545 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72027, type = 2, visualStyle = 1 },
				{ targetNode = 71999, type = 2, visualStyle = 1 },
				{ targetNode = 72003, type = 2, visualStyle = 1 }
			}
		},
		[72026] = {
			ID = 72026,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19165, 19165, 19165 },
			entryIDs = { 91546 },
			groupIDs = { 7816, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72025, type = 2, visualStyle = 1 },
				{ targetNode = 72002, type = 2, visualStyle = 1 }
			}
		},
		[72027] = {
			ID = 72027,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91547 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72028, type = 2, visualStyle = 1 },
				{ targetNode = 71999, type = 2, visualStyle = 1 }
			}
		},
		[72028] = {
			ID = 72028,
			flags = 1,
			type = 0,
			posX = 12000,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91548 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72009, type = 2, visualStyle = 1 },
				{ targetNode = 72029, type = 2, visualStyle = 1 },
				{ targetNode = 71998, type = 2, visualStyle = 1 }
			}
		},
		[72029] = {
			ID = 72029,
			flags = 1,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19165, 19163, 19165, 19163, 19165 },
			entryIDs = { 91549 },
			groupIDs = { 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72030, type = 2, visualStyle = 1 }
			}
		},
		[72030] = {
			ID = 72030,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19165, 19162, 19163, 19165, 19162, 19163, 19165 },
			entryIDs = { 91550 },
			groupIDs = { 7815, 7816, 7817, 7819 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71992, type = 2, visualStyle = 1 },
				{ targetNode = 72004, type = 2, visualStyle = 1 },
				{ targetNode = 71993, type = 2, visualStyle = 1 }
			}
		},
		[72031] = {
			ID = 72031,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 5999,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91551 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[72032] = {
			ID = 72032,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91552 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72031, type = 2, visualStyle = 1 },
				{ targetNode = 71990, type = 2, visualStyle = 1 }
			}
		},
		[72033] = {
			ID = 72033,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91553 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[72034] = {
			ID = 72034,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91554 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71987, type = 2, visualStyle = 1 },
				{ targetNode = 72033, type = 2, visualStyle = 1 }
			}
		},
		[72035] = {
			ID = 72035,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91555 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72056, type = 2, visualStyle = 1 },
				{ targetNode = 72034, type = 2, visualStyle = 1 }
			}
		},
		[72036] = {
			ID = 72036,
			flags = 1,
			type = 2,
			posX = 13200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91557, 91556 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72054, type = 2, visualStyle = 1 },
				{ targetNode = 72041, type = 2, visualStyle = 1 },
				{ targetNode = 72035, type = 2, visualStyle = 1 }
			}
		},
		[72037] = {
			ID = 72037,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91558 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72055, type = 2, visualStyle = 1 }
			}
		},
		[72038] = {
			ID = 72038,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91559 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72054, type = 2, visualStyle = 1 },
				{ targetNode = 72036, type = 2, visualStyle = 1 }
			}
		},
		[72039] = {
			ID = 72039,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91560 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72038, type = 2, visualStyle = 1 },
				{ targetNode = 72040, type = 2, visualStyle = 1 }
			}
		},
		[72040] = {
			ID = 72040,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91561 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72041, type = 2, visualStyle = 1 },
				{ targetNode = 72053, type = 2, visualStyle = 1 },
				{ targetNode = 72036, type = 2, visualStyle = 1 }
			}
		},
		[72041] = {
			ID = 72041,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91562 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72055, type = 2, visualStyle = 1 },
				{ targetNode = 72035, type = 2, visualStyle = 1 }
			}
		},
		[72042] = {
			ID = 72042,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 4199,
			maxRanks = 1,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91563 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72058, type = 2, visualStyle = 1 },
				{ targetNode = 72052, type = 2, visualStyle = 1 }
			}
		},
		[72043] = {
			ID = 72043,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91564 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72046, type = 2, visualStyle = 1 },
				{ targetNode = 72053, type = 2, visualStyle = 1 },
				{ targetNode = 72045, type = 2, visualStyle = 1 }
			}
		},
		[72044] = {
			ID = 72044,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91565 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72045, type = 2, visualStyle = 1 },
				{ targetNode = 72042, type = 2, visualStyle = 1 }
			}
		},
		[72045] = {
			ID = 72045,
			flags = 1,
			type = 0,
			posX = 10799,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91566 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72052, type = 2, visualStyle = 1 },
				{ targetNode = 72046, type = 2, visualStyle = 1 },
				{ targetNode = 72042, type = 2, visualStyle = 1 }
			}
		},
		[72046] = {
			ID = 72046,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91567 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72052, type = 2, visualStyle = 1 },
				{ targetNode = 72055, type = 2, visualStyle = 1 }
			}
		},
		[72047] = {
			ID = 72047,
			flags = 1,
			type = 0,
			posX = 10800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91568 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72043, type = 2, visualStyle = 1 },
				{ targetNode = 72044, type = 2, visualStyle = 1 }
			}
		},
		[72048] = {
			ID = 72048,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91569 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72047, type = 2, visualStyle = 1 },
				{ targetNode = 72051, type = 2, visualStyle = 1 }
			}
		},
		[72049] = {
			ID = 72049,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91570 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72048, type = 2, visualStyle = 1 },
				{ targetNode = 72050, type = 2, visualStyle = 1 }
			}
		},
		[72050] = {
			ID = 72050,
			flags = 0,
			type = 0,
			posX = 12599,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91571 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72039, type = 2, visualStyle = 1 },
				{ targetNode = 72051, type = 2, visualStyle = 1 }
			}
		},
		[72051] = {
			ID = 72051,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19164, 19164, 19164 },
			entryIDs = { 91572 },
			groupIDs = { 7816, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72043, type = 2, visualStyle = 1 },
				{ targetNode = 72040, type = 2, visualStyle = 1 }
			}
		},
		[72052] = {
			ID = 72052,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91573 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72058, type = 2, visualStyle = 1 },
				{ targetNode = 72032, type = 2, visualStyle = 1 }
			}
		},
		[72053] = {
			ID = 72053,
			flags = 1,
			type = 2,
			posX = 11999,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91575, 91574 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72046, type = 2, visualStyle = 1 },
				{ targetNode = 72037, type = 2, visualStyle = 1 },
				{ targetNode = 72041, type = 2, visualStyle = 1 }
			}
		},
		[72054] = {
			ID = 72054,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91576 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72056, type = 2, visualStyle = 1 },
				{ targetNode = 72035, type = 2, visualStyle = 1 }
			}
		},
		[72055] = {
			ID = 72055,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19164, 19163, 19164, 19163, 19164 },
			entryIDs = { 91577 },
			groupIDs = { 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72034, type = 2, visualStyle = 1 },
				{ targetNode = 72032, type = 2, visualStyle = 1 }
			}
		},
		[72056] = {
			ID = 72056,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91578 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71920, type = 2, visualStyle = 1 },
				{ targetNode = 72033, type = 2, visualStyle = 1 }
			}
		},
		[72057] = {
			ID = 72057,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91579 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {}
		},
		[72058] = {
			ID = 72058,
			flags = 1,
			type = 0,
			posX = 10200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19162, 19163, 19164, 19162, 19163, 19164, 19162, 19163, 19164 },
			entryIDs = { 91580 },
			groupIDs = { 7815, 7816, 7817, 7818 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72031, type = 2, visualStyle = 1 },
				{ targetNode = 71921, type = 2, visualStyle = 1 }
			}
		},
		[72059] = {
			ID = 72059,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91581 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72060, type = 2, visualStyle = 1 }
			}
		},
		[72060] = {
			ID = 72060,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91582 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72061, type = 2, visualStyle = 1 }
			}
		},
		[72061] = {
			ID = 72061,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91583 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71984, type = 2, visualStyle = 1 },
				{ targetNode = 72062, type = 2, visualStyle = 1 }
			}
		},
		[72062] = {
			ID = 72062,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91584 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71985, type = 2, visualStyle = 1 }
			}
		},
		[72063] = {
			ID = 72063,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 3596,
			maxRanks = 2,
			conditionIDs = { 19163, 19166, 19163, 19166, 19163, 19166 },
			entryIDs = { 91585 },
			groupIDs = { 7816, 7817, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71972, type = 2, visualStyle = 1 }
			}
		},
		[72064] = {
			ID = 72064,
			flags = 1,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91586 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72063, type = 2, visualStyle = 1 }
			}
		},
		[72065] = {
			ID = 72065,
			flags = 1,
			type = 2,
			posX = 10200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91588, 91587 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71978, type = 2, visualStyle = 1 },
				{ targetNode = 72060, type = 2, visualStyle = 1 }
			}
		},
		[72066] = {
			ID = 72066,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91589 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 72064, type = 2, visualStyle = 1 },
				{ targetNode = 72065, type = 2, visualStyle = 1 },
				{ targetNode = 72059, type = 2, visualStyle = 1 }
			}
		},
		[72067] = {
			ID = 72067,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91590 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71979, type = 2, visualStyle = 1 },
				{ targetNode = 72066, type = 2, visualStyle = 1 }
			}
		},
		[72068] = {
			ID = 72068,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91591 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71980, type = 2, visualStyle = 1 },
				{ targetNode = 72067, type = 2, visualStyle = 1 },
				{ targetNode = 72069, type = 2, visualStyle = 1 }
			}
		},
		[72069] = {
			ID = 72069,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19166, 19166, 19166 },
			entryIDs = { 91592 },
			groupIDs = { 7816, 7820 },
			costs = {
				{ ID = 2664, amount = 1 }
			},
			edges = {
				{ targetNode = 71979, type = 2, visualStyle = 1 },
				{ targetNode = 71975, type = 2, visualStyle = 1 }
			}
		},
		[76033] = {
			ID = 76033,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96161 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76108, type = 2, visualStyle = 1 }
			}
		},
		[76034] = {
			ID = 76034,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96162 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76105, type = 2, visualStyle = 1 },
				{ targetNode = 76101, type = 2, visualStyle = 1 }
			}
		},
		[76035] = {
			ID = 76035,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96163 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76121, type = 2, visualStyle = 1 }
			}
		},
		[76036] = {
			ID = 76036,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96164 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76109, type = 2, visualStyle = 1 }
			}
		},
		[76037] = {
			ID = 76037,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96165 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76101, type = 2, visualStyle = 1 },
				{ targetNode = 76122, type = 2, visualStyle = 1 }
			}
		},
		[76038] = {
			ID = 76038,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96166 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76041, type = 2, visualStyle = 1 }
			}
		},
		[76039] = {
			ID = 76039,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96167 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76139, type = 2, visualStyle = 1 }
			}
		},
		[76040] = {
			ID = 76040,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96168 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76041] = {
			ID = 76041,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96169 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76172, type = 2, visualStyle = 1 },
				{ targetNode = 76132, type = 2, visualStyle = 1 }
			}
		},
		[76042] = {
			ID = 76042,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96170 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76165, type = 2, visualStyle = 1 }
			}
		},
		[76043] = {
			ID = 76043,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96171 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76136, type = 2, visualStyle = 1 },
				{ targetNode = 76041, type = 2, visualStyle = 1 }
			}
		},
		[76044] = {
			ID = 76044,
			flags = 8,
			type = 0,
			posX = 1800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96172 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76084, type = 2, visualStyle = 1 }
			}
		},
		[76045] = {
			ID = 76045,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96173 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76084, type = 2, visualStyle = 1 }
			}
		},
		[76046] = {
			ID = 76046,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96174 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76068, type = 2, visualStyle = 1 }
			}
		},
		[76047] = {
			ID = 76047,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96175 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76086, type = 2, visualStyle = 1 }
			}
		},
		[76048] = {
			ID = 76048,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96176 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76078, type = 2, visualStyle = 1 }
			}
		},
		[76049] = {
			ID = 76049,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96177 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {}
		},
		[76050] = {
			ID = 76050,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96178 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {}
		},
		[76051] = {
			ID = 76051,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96179 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76050, type = 2, visualStyle = 1 }
			}
		},
		[76052] = {
			ID = 76052,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96180 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76087, type = 2, visualStyle = 1 }
			}
		},
		[76053] = {
			ID = 76053,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96181 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {}
		},
		[76054] = {
			ID = 76054,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96182 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76055, type = 2, visualStyle = 1 },
				{ targetNode = 76080, type = 2, visualStyle = 1 }
			}
		},
		[76055] = {
			ID = 76055,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96183 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76053, type = 2, visualStyle = 1 }
			}
		},
		[76056] = {
			ID = 76056,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96184 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76055, type = 2, visualStyle = 1 }
			}
		},
		[76057] = {
			ID = 76057,
			flags = 9,
			type = 2,
			posX = 5400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96186, 96185 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76058, type = 2, visualStyle = 1 }
			}
		},
		[76058] = {
			ID = 76058,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96187 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76054, type = 2, visualStyle = 1 },
				{ targetNode = 76056, type = 2, visualStyle = 1 }
			}
		},
		[76059] = {
			ID = 76059,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96188 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76061, type = 2, visualStyle = 1 }
			}
		},
		[76060] = {
			ID = 76060,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96189 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76061, type = 2, visualStyle = 1 }
			}
		},
		[76061] = {
			ID = 76061,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96190 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76076, type = 2, visualStyle = 1 },
				{ targetNode = 76062, type = 2, visualStyle = 1 }
			}
		},
		[76062] = {
			ID = 76062,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96191 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76063, type = 2, visualStyle = 1 }
			}
		},
		[76063] = {
			ID = 76063,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96192 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76058, type = 2, visualStyle = 1 }
			}
		},
		[76064] = {
			ID = 76064,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96193 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76078, type = 2, visualStyle = 1 }
			}
		},
		[76065] = {
			ID = 76065,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96194 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76064, type = 2, visualStyle = 1 },
				{ targetNode = 76048, type = 2, visualStyle = 1 },
				{ targetNode = 76077, type = 2, visualStyle = 1 }
			}
		},
		[76066] = {
			ID = 76066,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96195 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76065, type = 2, visualStyle = 1 },
				{ targetNode = 76085, type = 2, visualStyle = 1 }
			}
		},
		[76067] = {
			ID = 76067,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96196 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76068, type = 2, visualStyle = 1 },
				{ targetNode = 76066, type = 2, visualStyle = 1 }
			}
		},
		[76068] = {
			ID = 76068,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 96197 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76065, type = 2, visualStyle = 1 }
			}
		},
		[76069] = {
			ID = 76069,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96198 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76075, type = 2, visualStyle = 1 },
				{ targetNode = 76068, type = 2, visualStyle = 1 }
			}
		},
		[76070] = {
			ID = 76070,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96199 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76069, type = 2, visualStyle = 1 },
				{ targetNode = 76046, type = 2, visualStyle = 1 },
				{ targetNode = 76067, type = 2, visualStyle = 1 }
			}
		},
		[76071] = {
			ID = 76071,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19536, 19536, 19536 },
			entryIDs = { 96200 },
			groupIDs = { 8089, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76070, type = 2, visualStyle = 1 }
			}
		},
		[76072] = {
			ID = 76072,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19532, 19532, 19532, 19532 },
			entryIDs = { 96201 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76073, type = 2, visualStyle = 1 }
			}
		},
		[76073] = {
			ID = 76073,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96202 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76059, type = 2, visualStyle = 1 },
				{ targetNode = 76060, type = 2, visualStyle = 1 },
				{ targetNode = 76074, type = 2, visualStyle = 1 }
			}
		},
		[76074] = {
			ID = 76074,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96203 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76075, type = 2, visualStyle = 1 },
				{ targetNode = 76061, type = 2, visualStyle = 1 }
			}
		},
		[76075] = {
			ID = 76075,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96204 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76076, type = 2, visualStyle = 1 },
				{ targetNode = 76065, type = 2, visualStyle = 1 }
			}
		},
		[76076] = {
			ID = 76076,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96205 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76057, type = 2, visualStyle = 1 },
				{ targetNode = 76077, type = 2, visualStyle = 1 },
				{ targetNode = 76063, type = 2, visualStyle = 1 }
			}
		},
		[76077] = {
			ID = 76077,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96206 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76078, type = 2, visualStyle = 1 }
			}
		},
		[76078] = {
			ID = 76078,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96207 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76054, type = 2, visualStyle = 1 },
				{ targetNode = 76079, type = 2, visualStyle = 1 }
			}
		},
		[76079] = {
			ID = 76079,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96208 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76080, type = 2, visualStyle = 1 },
				{ targetNode = 76051, type = 2, visualStyle = 1 }
			}
		},
		[76080] = {
			ID = 76080,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96209 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76049, type = 2, visualStyle = 1 }
			}
		},
		[76081] = {
			ID = 76081,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19530, 19530, 19530, 19530 },
			entryIDs = { 96210 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76082, type = 2, visualStyle = 1 }
			}
		},
		[76082] = {
			ID = 76082,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96211 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76045, type = 2, visualStyle = 1 },
				{ targetNode = 76044, type = 2, visualStyle = 1 },
				{ targetNode = 76083, type = 2, visualStyle = 1 }
			}
		},
		[76083] = {
			ID = 76083,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96212 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76066, type = 2, visualStyle = 1 },
				{ targetNode = 76084, type = 2, visualStyle = 1 }
			}
		},
		[76084] = {
			ID = 76084,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 96213 },
			groupIDs = { 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76047, type = 2, visualStyle = 1 },
				{ targetNode = 76085, type = 2, visualStyle = 1 }
			}
		},
		[76085] = {
			ID = 76085,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96214 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76064, type = 2, visualStyle = 1 },
				{ targetNode = 76086, type = 2, visualStyle = 1 },
				{ targetNode = 76052, type = 2, visualStyle = 1 }
			}
		},
		[76086] = {
			ID = 76086,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96215 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76087, type = 2, visualStyle = 1 }
			}
		},
		[76087] = {
			ID = 76087,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19531, 19531, 19531 },
			entryIDs = { 96216 },
			groupIDs = { 8091, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76079, type = 2, visualStyle = 1 },
				{ targetNode = 76088, type = 2, visualStyle = 1 }
			}
		},
		[76088] = {
			ID = 76088,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19531, 19528, 19531, 19528, 19531, 19528 },
			entryIDs = { 96217 },
			groupIDs = { 8091, 8093, 8097 },
			costs = {
				{ ID = 2724, amount = 1 }
			},
			edges = {
				{ targetNode = 76051, type = 2, visualStyle = 1 }
			}
		},
		[76089] = {
			ID = 76089,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96218 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76121, type = 2, visualStyle = 1 },
				{ targetNode = 76037, type = 2, visualStyle = 1 }
			}
		},
		[76090] = {
			ID = 76090,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96219 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76091] = {
			ID = 76091,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96220 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76092] = {
			ID = 76092,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96221 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76093] = {
			ID = 76093,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96222 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76094] = {
			ID = 76094,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96223 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76095] = {
			ID = 76095,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96224 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76094, type = 2, visualStyle = 1 }
			}
		},
		[76096] = {
			ID = 76096,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96225 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76097] = {
			ID = 76097,
			flags = 9,
			type = 2,
			posX = 14400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96227, 96226 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76098] = {
			ID = 76098,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96228 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76109, type = 2, visualStyle = 1 },
				{ targetNode = 76097, type = 2, visualStyle = 1 }
			}
		},
		[76099] = {
			ID = 76099,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96229 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76105, type = 2, visualStyle = 1 },
				{ targetNode = 76033, type = 2, visualStyle = 1 }
			}
		},
		[76100] = {
			ID = 76100,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96230 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76034, type = 2, visualStyle = 1 },
				{ targetNode = 76037, type = 2, visualStyle = 1 }
			}
		},
		[76101] = {
			ID = 76101,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96231 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76095, type = 2, visualStyle = 1 }
			}
		},
		[76102] = {
			ID = 76102,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96232 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76096, type = 2, visualStyle = 1 },
				{ targetNode = 76104, type = 2, visualStyle = 1 }
			}
		},
		[76103] = {
			ID = 76103,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96233 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76092, type = 2, visualStyle = 1 },
				{ targetNode = 76104, type = 2, visualStyle = 1 }
			}
		},
		[76104] = {
			ID = 76104,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96234 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76106, type = 2, visualStyle = 1 },
				{ targetNode = 76100, type = 2, visualStyle = 1 }
			}
		},
		[76105] = {
			ID = 76105,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96235 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76095, type = 2, visualStyle = 1 }
			}
		},
		[76106] = {
			ID = 76106,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96236 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76034, type = 2, visualStyle = 1 },
				{ targetNode = 76099, type = 2, visualStyle = 1 }
			}
		},
		[76107] = {
			ID = 76107,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96237 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76108] = {
			ID = 76108,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96238 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76093, type = 2, visualStyle = 1 }
			}
		},
		[76109] = {
			ID = 76109,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96239 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76033, type = 2, visualStyle = 1 },
				{ targetNode = 76107, type = 2, visualStyle = 1 }
			}
		},
		[76110] = {
			ID = 76110,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96240 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76099, type = 2, visualStyle = 1 },
				{ targetNode = 76109, type = 2, visualStyle = 1 }
			}
		},
		[76111] = {
			ID = 76111,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96241 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76036, type = 2, visualStyle = 1 },
				{ targetNode = 76110, type = 2, visualStyle = 1 },
				{ targetNode = 76098, type = 2, visualStyle = 1 }
			}
		},
		[76112] = {
			ID = 76112,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96242 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76096, type = 2, visualStyle = 1 },
				{ targetNode = 76111, type = 2, visualStyle = 1 }
			}
		},
		[76113] = {
			ID = 76113,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96243 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76102, type = 2, visualStyle = 1 },
				{ targetNode = 76112, type = 2, visualStyle = 1 }
			}
		},
		[76114] = {
			ID = 76114,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96244 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76113, type = 2, visualStyle = 1 }
			}
		},
		[76115] = {
			ID = 76115,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96245 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76116, type = 2, visualStyle = 1 },
				{ targetNode = 76114, type = 2, visualStyle = 1 }
			}
		},
		[76116] = {
			ID = 76116,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96246 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76117, type = 2, visualStyle = 1 }
			}
		},
		[76117] = {
			ID = 76117,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96247 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76103, type = 2, visualStyle = 1 },
				{ targetNode = 76118, type = 2, visualStyle = 1 }
			}
		},
		[76118] = {
			ID = 76118,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19527, 19526, 19527, 19526 },
			entryIDs = { 96248 },
			groupIDs = { 8094, 8095 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76092, type = 2, visualStyle = 1 },
				{ targetNode = 76119, type = 2, visualStyle = 1 }
			}
		},
		[76119] = {
			ID = 76119,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96249 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76035, type = 2, visualStyle = 1 },
				{ targetNode = 76089, type = 2, visualStyle = 1 },
				{ targetNode = 76120, type = 2, visualStyle = 1 }
			}
		},
		[76120] = {
			ID = 76120,
			flags = 9,
			type = 2,
			posX = 9600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96251, 96250 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76121, type = 2, visualStyle = 1 }
			}
		},
		[76121] = {
			ID = 76121,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19527, 19526, 19529, 19527, 19526, 19529, 19527, 19526, 19529 },
			entryIDs = { 96252 },
			groupIDs = { 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76090, type = 2, visualStyle = 1 },
				{ targetNode = 76122, type = 2, visualStyle = 1 }
			}
		},
		[76122] = {
			ID = 76122,
			flags = 8,
			type = 0,
			posX = 10799,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96253 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76123, type = 2, visualStyle = 1 }
			}
		},
		[76123] = {
			ID = 76123,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529, 19535, 19527, 19526, 19529 },
			entryIDs = { 96254 },
			groupIDs = { 8092, 8094, 8095, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76091, type = 2, visualStyle = 1 }
			}
		},
		[76124] = {
			ID = 76124,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96255 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76143, type = 2, visualStyle = 1 },
				{ targetNode = 76141, type = 2, visualStyle = 1 }
			}
		},
		[76125] = {
			ID = 76125,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96256 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76126] = {
			ID = 76126,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96257 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76137, type = 2, visualStyle = 1 },
				{ targetNode = 76138, type = 2, visualStyle = 1 }
			}
		},
		[76127] = {
			ID = 76127,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96258 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76128] = {
			ID = 76128,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96259 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76127, type = 2, visualStyle = 1 }
			}
		},
		[76129] = {
			ID = 76129,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96260 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76130, type = 2, visualStyle = 1 }
			}
		},
		[76130] = {
			ID = 76130,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96261 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76136, type = 2, visualStyle = 1 }
			}
		},
		[76131] = {
			ID = 76131,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96262 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76133, type = 2, visualStyle = 1 }
			}
		},
		[76132] = {
			ID = 76132,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96263 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76040, type = 2, visualStyle = 1 }
			}
		},
		[76133] = {
			ID = 76133,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96264 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76134] = {
			ID = 76134,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96265 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76133, type = 2, visualStyle = 1 },
				{ targetNode = 76125, type = 2, visualStyle = 1 }
			}
		},
		[76135] = {
			ID = 76135,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96266 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76042, type = 2, visualStyle = 1 },
				{ targetNode = 76166, type = 2, visualStyle = 1 }
			}
		},
		[76136] = {
			ID = 76136,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96267 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76172, type = 2, visualStyle = 1 },
				{ targetNode = 76131, type = 2, visualStyle = 1 },
				{ targetNode = 76134, type = 2, visualStyle = 1 }
			}
		},
		[76137] = {
			ID = 76137,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96268 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76143, type = 2, visualStyle = 1 }
			}
		},
		[76138] = {
			ID = 76138,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96269 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76129, type = 2, visualStyle = 1 }
			}
		},
		[76139] = {
			ID = 76139,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96271, 96270 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76131, type = 2, visualStyle = 1 },
				{ targetNode = 76128, type = 2, visualStyle = 1 }
			}
		},
		[76140] = {
			ID = 76140,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96272 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76138, type = 2, visualStyle = 1 },
				{ targetNode = 76167, type = 2, visualStyle = 1 }
			}
		},
		[76141] = {
			ID = 76141,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96273 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76038, type = 2, visualStyle = 1 },
				{ targetNode = 76043, type = 2, visualStyle = 1 },
				{ targetNode = 76174, type = 2, visualStyle = 1 }
			}
		},
		[76142] = {
			ID = 76142,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96274 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76139, type = 2, visualStyle = 1 }
			}
		},
		[76143] = {
			ID = 76143,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96276, 96275 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76043, type = 2, visualStyle = 1 }
			}
		},
		[76144] = {
			ID = 76144,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96277 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76167, type = 2, visualStyle = 1 },
				{ targetNode = 76135, type = 2, visualStyle = 1 },
				{ targetNode = 76145, type = 2, visualStyle = 1 }
			}
		},
		[76145] = {
			ID = 76145,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96278 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76166, type = 2, visualStyle = 1 }
			}
		},
		[76146] = {
			ID = 76146,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96279 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76124, type = 2, visualStyle = 1 },
				{ targetNode = 76137, type = 2, visualStyle = 1 },
				{ targetNode = 76147, type = 2, visualStyle = 1 }
			}
		},
		[76147] = {
			ID = 76147,
			flags = 9,
			type = 0,
			posX = 13800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96280 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76141, type = 2, visualStyle = 1 }
			}
		},
		[76148] = {
			ID = 76148,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96282, 96281 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76196, type = 2, visualStyle = 1 }
			}
		},
		[76149] = {
			ID = 76149,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96283 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76150] = {
			ID = 76150,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96284 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76149, type = 2, visualStyle = 1 }
			}
		},
		[76151] = {
			ID = 76151,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96285 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76152] = {
			ID = 76152,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96286 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76151, type = 2, visualStyle = 1 }
			}
		},
		[76153] = {
			ID = 76153,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96287 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76155, type = 2, visualStyle = 1 }
			}
		},
		[76154] = {
			ID = 76154,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96288 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76155, type = 2, visualStyle = 1 }
			}
		},
		[76155] = {
			ID = 76155,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96289 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {}
		},
		[76156] = {
			ID = 76156,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96290 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76176, type = 2, visualStyle = 1 },
				{ targetNode = 76196, type = 2, visualStyle = 1 }
			}
		},
		[76157] = {
			ID = 76157,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96291 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76158, type = 2, visualStyle = 1 }
			}
		},
		[76158] = {
			ID = 76158,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96292 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76152, type = 2, visualStyle = 1 },
				{ targetNode = 76154, type = 2, visualStyle = 1 }
			}
		},
		[76159] = {
			ID = 76159,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96293 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76158, type = 2, visualStyle = 1 }
			}
		},
		[76160] = {
			ID = 76160,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96294 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76159, type = 2, visualStyle = 1 }
			}
		},
		[76161] = {
			ID = 76161,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96295 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76160, type = 2, visualStyle = 1 }
			}
		},
		[76162] = {
			ID = 76162,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96296 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76163, type = 2, visualStyle = 1 },
				{ targetNode = 76193, type = 2, visualStyle = 1 },
				{ targetNode = 76161, type = 2, visualStyle = 1 }
			}
		},
		[76163] = {
			ID = 76163,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96297 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76164, type = 2, visualStyle = 1 },
				{ targetNode = 76194, type = 2, visualStyle = 1 },
				{ targetNode = 76160, type = 2, visualStyle = 1 }
			}
		},
		[76164] = {
			ID = 76164,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96299, 96298 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76157, type = 2, visualStyle = 1 },
				{ targetNode = 76159, type = 2, visualStyle = 1 }
			}
		},
		[76165] = {
			ID = 76165,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96300 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76136, type = 2, visualStyle = 1 },
				{ targetNode = 76139, type = 2, visualStyle = 1 }
			}
		},
		[76166] = {
			ID = 76166,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96301 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76039, type = 2, visualStyle = 1 },
				{ targetNode = 76165, type = 2, visualStyle = 1 },
				{ targetNode = 76142, type = 2, visualStyle = 1 }
			}
		},
		[76167] = {
			ID = 76167,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96302 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76042, type = 2, visualStyle = 1 }
			}
		},
		[76168] = {
			ID = 76168,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96303 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76173, type = 2, visualStyle = 1 }
			}
		},
		[76169] = {
			ID = 76169,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96304 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76170, type = 2, visualStyle = 1 },
				{ targetNode = 76168, type = 2, visualStyle = 1 }
			}
		},
		[76170] = {
			ID = 76170,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96305 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76171, type = 2, visualStyle = 1 }
			}
		},
		[76171] = {
			ID = 76171,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96306 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76126, type = 2, visualStyle = 1 },
				{ targetNode = 76146, type = 2, visualStyle = 1 }
			}
		},
		[76172] = {
			ID = 76172,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529, 19533, 19535, 19527, 19529 },
			entryIDs = { 96307 },
			groupIDs = { 8088, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76125, type = 2, visualStyle = 1 }
			}
		},
		[76173] = {
			ID = 76173,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19533, 19527, 19533, 19527 },
			entryIDs = { 96308 },
			groupIDs = { 8088, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76140, type = 2, visualStyle = 1 },
				{ targetNode = 76144, type = 2, visualStyle = 1 }
			}
		},
		[76174] = {
			ID = 76174,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19533, 19527, 19529, 19533, 19527, 19529, 19533, 19527, 19529 },
			entryIDs = { 96309 },
			groupIDs = { 8088, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76041, type = 2, visualStyle = 1 }
			}
		},
		[76175] = {
			ID = 76175,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96310 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76176, type = 2, visualStyle = 1 }
			}
		},
		[76176] = {
			ID = 76176,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96311 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76197, type = 2, visualStyle = 1 },
				{ targetNode = 76150, type = 2, visualStyle = 1 }
			}
		},
		[76177] = {
			ID = 76177,
			flags = 9,
			type = 0,
			posX = 13800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96312 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76176, type = 2, visualStyle = 1 }
			}
		},
		[76178] = {
			ID = 76178,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96313 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76177, type = 2, visualStyle = 1 },
				{ targetNode = 76175, type = 2, visualStyle = 1 }
			}
		},
		[76179] = {
			ID = 76179,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96314 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76184, type = 2, visualStyle = 1 },
				{ targetNode = 76180, type = 2, visualStyle = 1 },
				{ targetNode = 76178, type = 2, visualStyle = 1 }
			}
		},
		[76180] = {
			ID = 76180,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96316, 96315 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76177, type = 2, visualStyle = 1 }
			}
		},
		[76181] = {
			ID = 76181,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96317 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76180, type = 2, visualStyle = 1 }
			}
		},
		[76182] = {
			ID = 76182,
			flags = 9,
			type = 0,
			posX = 13200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96318 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76181, type = 2, visualStyle = 1 },
				{ targetNode = 76183, type = 2, visualStyle = 1 },
				{ targetNode = 76179, type = 2, visualStyle = 1 }
			}
		},
		[76183] = {
			ID = 76183,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96320, 96319 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76184, type = 2, visualStyle = 1 }
			}
		},
		[76184] = {
			ID = 76184,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96321 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76156, type = 2, visualStyle = 1 }
			}
		},
		[76185] = {
			ID = 76185,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96322 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76184, type = 2, visualStyle = 1 },
				{ targetNode = 76194, type = 2, visualStyle = 1 },
				{ targetNode = 76148, type = 2, visualStyle = 1 }
			}
		},
		[76186] = {
			ID = 76186,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96323 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76185, type = 2, visualStyle = 1 }
			}
		},
		[76187] = {
			ID = 76187,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96324 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76182, type = 2, visualStyle = 1 },
				{ targetNode = 76186, type = 2, visualStyle = 1 }
			}
		},
		[76188] = {
			ID = 76188,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96325 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76187, type = 2, visualStyle = 1 }
			}
		},
		[76189] = {
			ID = 76189,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96326 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76190, type = 2, visualStyle = 1 },
				{ targetNode = 76188, type = 2, visualStyle = 1 }
			}
		},
		[76190] = {
			ID = 76190,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96327 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76191, type = 2, visualStyle = 1 }
			}
		},
		[76191] = {
			ID = 76191,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96328 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76192, type = 2, visualStyle = 1 },
				{ targetNode = 76162, type = 2, visualStyle = 1 }
			}
		},
		[76192] = {
			ID = 76192,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 19534, 19527, 19534, 19527, 19534, 19527 },
			entryIDs = { 96329 },
			groupIDs = { 8090, 8094 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76193, type = 2, visualStyle = 1 },
				{ targetNode = 76185, type = 2, visualStyle = 1 }
			}
		},
		[76193] = {
			ID = 76193,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96330 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76194, type = 2, visualStyle = 1 }
			}
		},
		[76194] = {
			ID = 76194,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96331 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76195, type = 2, visualStyle = 1 }
			}
		},
		[76195] = {
			ID = 76195,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 19534, 19527, 19529, 19534, 19527, 19529, 19534, 19527, 19529 },
			entryIDs = { 96332 },
			groupIDs = { 8090, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76196, type = 2, visualStyle = 1 },
				{ targetNode = 76158, type = 2, visualStyle = 1 }
			}
		},
		[76196] = {
			ID = 76196,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96333 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76153, type = 2, visualStyle = 1 },
				{ targetNode = 76197, type = 2, visualStyle = 1 },
				{ targetNode = 76154, type = 2, visualStyle = 1 }
			}
		},
		[76197] = {
			ID = 76197,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529, 19534, 19535, 19527, 19529 },
			entryIDs = { 96334 },
			groupIDs = { 8090, 8092, 8094, 8096 },
			costs = {
				{ ID = 2723, amount = 1 }
			},
			edges = {
				{ targetNode = 76155, type = 2, visualStyle = 1 }
			}
		},
		[79813] = {
			ID = 79813,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100512, 100511 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79814] = {
			ID = 79814,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100513 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79908, type = 2, visualStyle = 1 }
			}
		},
		[79815] = {
			ID = 79815,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100514 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79914, type = 2, visualStyle = 1 }
			}
		},
		[79816] = {
			ID = 79816,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100515 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79817] = {
			ID = 79817,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100517 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79830, type = 2, visualStyle = 1 }
			}
		},
		[79818] = {
			ID = 79818,
			flags = 9,
			type = 2,
			posX = 6000,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100519, 100518 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79913, type = 2, visualStyle = 1 }
			}
		},
		[79819] = {
			ID = 79819,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100520 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79818, type = 2, visualStyle = 1 }
			}
		},
		[79820] = {
			ID = 79820,
			flags = 9,
			type = 2,
			posX = 4800,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100522, 100521 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79909, type = 2, visualStyle = 1 },
				{ targetNode = 79937, type = 2, visualStyle = 1 },
				{ targetNode = 79934, type = 2, visualStyle = 1 }
			}
		},
		[79821] = {
			ID = 79821,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 100523 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79820, type = 2, visualStyle = 1 },
				{ targetNode = 79933, type = 2, visualStyle = 1 },
				{ targetNode = 79923, type = 2, visualStyle = 1 }
			}
		},
		[79822] = {
			ID = 79822,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100524 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79965, type = 2, visualStyle = 1 }
			}
		},
		[79823] = {
			ID = 79823,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100527 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79940, type = 2, visualStyle = 1 }
			}
		},
		[79824] = {
			ID = 79824,
			flags = 8,
			type = 0,
			posX = 11999,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100528 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79864, type = 2, visualStyle = 1 }
			}
		},
		[79825] = {
			ID = 79825,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100529 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79826] = {
			ID = 79826,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100530 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79868, type = 2, visualStyle = 1 },
				{ targetNode = 79870, type = 2, visualStyle = 1 }
			}
		},
		[79827] = {
			ID = 79827,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100531 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79826, type = 2, visualStyle = 1 }
			}
		},
		[79828] = {
			ID = 79828,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100532 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79854, type = 2, visualStyle = 1 }
			}
		},
		[79829] = {
			ID = 79829,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6900,
			maxRanks = 3,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100533 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79830] = {
			ID = 79830,
			flags = 9,
			type = 0,
			posX = 10800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100534 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79831] = {
			ID = 79831,
			flags = 9,
			type = 0,
			posX = 11400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100535 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79891, type = 2, visualStyle = 1 },
				{ targetNode = 79890, type = 2, visualStyle = 1 }
			}
		},
		[79832] = {
			ID = 79832,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100536 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79922, type = 2, visualStyle = 1 }
			}
		},
		[79833] = {
			ID = 79833,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 1499,
			maxRanks = 1,
			conditionIDs = { 19948, 19948, 19948, 19948 },
			entryIDs = { 100537 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79930, type = 2, visualStyle = 1 },
				{ targetNode = 79921, type = 2, visualStyle = 1 }
			}
		},
		[79834] = {
			ID = 79834,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 1499,
			maxRanks = 1,
			conditionIDs = { 19950, 19949, 19950, 19949, 19950, 19949 },
			entryIDs = { 100538 },
			groupIDs = { 8353, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79930, type = 2, visualStyle = 1 },
				{ targetNode = 79921, type = 2, visualStyle = 1 }
			}
		},
		[79835] = {
			ID = 79835,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 1499,
			maxRanks = 1,
			conditionIDs = { 19951, 19951, 19951, 19951 },
			entryIDs = { 100539 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79930, type = 2, visualStyle = 1 },
				{ targetNode = 79921, type = 2, visualStyle = 1 }
			}
		},
		[79836] = {
			ID = 79836,
			flags = 9,
			type = 0,
			posX = 4200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19953, 19953, 19953, 19953 },
			entryIDs = { 100540 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79821, type = 2, visualStyle = 1 },
				{ targetNode = 79924, type = 2, visualStyle = 1 },
				{ targetNode = 79928, type = 2, visualStyle = 1 }
			}
		},
		[79837] = {
			ID = 79837,
			flags = 9,
			type = 0,
			posX = 4200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19954, 19954, 19954, 19954 },
			entryIDs = { 100543 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79821, type = 2, visualStyle = 1 },
				{ targetNode = 79924, type = 2, visualStyle = 1 },
				{ targetNode = 79928, type = 2, visualStyle = 1 }
			}
		},
		[79838] = {
			ID = 79838,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 19955, 19955, 19955, 19955 },
			entryIDs = { 100541 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79936, type = 2, visualStyle = 1 },
				{ targetNode = 79931, type = 2, visualStyle = 1 }
			}
		},
		[79839] = {
			ID = 79839,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 19958, 19957, 19958, 19957, 19958, 19957 },
			entryIDs = { 100542 },
			groupIDs = { 8354, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79936, type = 2, visualStyle = 1 },
				{ targetNode = 79931, type = 2, visualStyle = 1 }
			}
		},
		[79840] = {
			ID = 79840,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100544 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79889, type = 2, visualStyle = 1 },
				{ targetNode = 79890, type = 2, visualStyle = 1 },
				{ targetNode = 79875, type = 2, visualStyle = 1 }
			}
		},
		[79841] = {
			ID = 79841,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100545 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79851, type = 2, visualStyle = 1 },
				{ targetNode = 79856, type = 2, visualStyle = 1 }
			}
		},
		[79842] = {
			ID = 79842,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100546 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79861, type = 2, visualStyle = 1 },
				{ targetNode = 79857, type = 2, visualStyle = 1 },
				{ targetNode = 79862, type = 2, visualStyle = 1 }
			}
		},
		[79843] = {
			ID = 79843,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5090,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100547 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79868, type = 2, visualStyle = 1 },
				{ targetNode = 79865, type = 2, visualStyle = 1 }
			}
		},
		[79844] = {
			ID = 79844,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100548 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79856, type = 2, visualStyle = 1 },
				{ targetNode = 79843, type = 2, visualStyle = 1 }
			}
		},
		[79845] = {
			ID = 79845,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100549 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79855, type = 2, visualStyle = 1 },
				{ targetNode = 79859, type = 2, visualStyle = 1 },
				{ targetNode = 79867, type = 2, visualStyle = 1 }
			}
		},
		[79846] = {
			ID = 79846,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100550 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79850, type = 2, visualStyle = 1 }
			}
		},
		[79847] = {
			ID = 79847,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100551 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79849, type = 2, visualStyle = 1 },
				{ targetNode = 79863, type = 2, visualStyle = 1 },
				{ targetNode = 79860, type = 2, visualStyle = 1 }
			}
		},
		[79848] = {
			ID = 79848,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100553, 100552 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79844, type = 2, visualStyle = 1 },
				{ targetNode = 79841, type = 2, visualStyle = 1 }
			}
		},
		[79849] = {
			ID = 79849,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 2099,
			maxRanks = 2,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100554 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79842, type = 2, visualStyle = 1 },
				{ targetNode = 79860, type = 2, visualStyle = 1 }
			}
		},
		[79850] = {
			ID = 79850,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100555 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79826, type = 2, visualStyle = 1 },
				{ targetNode = 79843, type = 2, visualStyle = 1 }
			}
		},
		[79851] = {
			ID = 79851,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100556 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79854, type = 2, visualStyle = 1 }
			}
		},
		[79852] = {
			ID = 79852,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100557 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79829, type = 2, visualStyle = 1 }
			}
		},
		[79853] = {
			ID = 79853,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100558 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79828, type = 2, visualStyle = 1 }
			}
		},
		[79854] = {
			ID = 79854,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100559 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79858, type = 2, visualStyle = 1 },
				{ targetNode = 79866, type = 2, visualStyle = 1 }
			}
		},
		[79855] = {
			ID = 79855,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100560 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79827, type = 2, visualStyle = 1 },
				{ targetNode = 79867, type = 2, visualStyle = 1 }
			}
		},
		[79856] = {
			ID = 79856,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5090,
			maxRanks = 2,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100561 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79854, type = 2, visualStyle = 1 },
				{ targetNode = 79865, type = 2, visualStyle = 1 }
			}
		},
		[79857] = {
			ID = 79857,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100562 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79861, type = 2, visualStyle = 1 },
				{ targetNode = 79848, type = 2, visualStyle = 1 }
			}
		},
		[79858] = {
			ID = 79858,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100563 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79859] = {
			ID = 79859,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100564 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79846, type = 2, visualStyle = 1 },
				{ targetNode = 79867, type = 2, visualStyle = 1 },
				{ targetNode = 79848, type = 2, visualStyle = 1 }
			}
		},
		[79860] = {
			ID = 79860,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100565 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79857, type = 2, visualStyle = 1 },
				{ targetNode = 79848, type = 2, visualStyle = 1 }
			}
		},
		[79861] = {
			ID = 79861,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100566 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79853, type = 2, visualStyle = 1 },
				{ targetNode = 79841, type = 2, visualStyle = 1 }
			}
		},
		[79862] = {
			ID = 79862,
			flags = 0,
			type = 0,
			posX = 13799,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100567 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79863] = {
			ID = 79863,
			flags = 0,
			type = 0,
			posX = 11399,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 19959, 19959, 19959 },
			entryIDs = { 100568 },
			groupIDs = { 8355, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79859, type = 2, visualStyle = 1 },
				{ targetNode = 79860, type = 2, visualStyle = 1 },
				{ targetNode = 79845, type = 2, visualStyle = 1 }
			}
		},
		[79864] = {
			ID = 79864,
			flags = 1,
			type = 2,
			posX = 12000,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100569, 100510 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79865] = {
			ID = 79865,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100570 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79858, type = 2, visualStyle = 1 },
				{ targetNode = 79825, type = 2, visualStyle = 1 },
				{ targetNode = 79824, type = 2, visualStyle = 1 }
			}
		},
		[79866] = {
			ID = 79866,
			flags = 8,
			type = 0,
			posX = 13199,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100571 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79869, type = 2, visualStyle = 1 }
			}
		},
		[79867] = {
			ID = 79867,
			flags = 0,
			type = 0,
			posX = 10790,
			posY = 3890,
			maxRanks = 1,
			conditionIDs = { 19959, 19963, 19959, 19963, 19959, 19963 },
			entryIDs = { 100572 },
			groupIDs = { 8355, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79850, type = 2, visualStyle = 1 },
				{ targetNode = 79827, type = 2, visualStyle = 1 }
			}
		},
		[79868] = {
			ID = 79868,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100573 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79825, type = 2, visualStyle = 1 },
				{ targetNode = 79852, type = 2, visualStyle = 1 }
			}
		},
		[79869] = {
			ID = 79869,
			flags = 8,
			type = 0,
			posX = 13199,
			posY = 6900,
			maxRanks = 2,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100574 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79870] = {
			ID = 79870,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19959, 19961, 19963, 19959, 19961, 19963, 19959, 19961, 19963 },
			entryIDs = { 100575 },
			groupIDs = { 8355, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79852, type = 2, visualStyle = 1 }
			}
		},
		[79871] = {
			ID = 79871,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100576 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79879, type = 2, visualStyle = 1 },
				{ targetNode = 79888, type = 2, visualStyle = 1 },
				{ targetNode = 79900, type = 2, visualStyle = 1 }
			}
		},
		[79872] = {
			ID = 79872,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100577 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79878, type = 2, visualStyle = 1 }
			}
		},
		[79873] = {
			ID = 79873,
			flags = 0,
			type = 0,
			posX = 11990,
			posY = 1490,
			maxRanks = 1,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100578 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79898, type = 2, visualStyle = 1 },
				{ targetNode = 79877, type = 2, visualStyle = 1 },
				{ targetNode = 79895, type = 2, visualStyle = 1 }
			}
		},
		[79874] = {
			ID = 79874,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100579 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79884, type = 2, visualStyle = 1 },
				{ targetNode = 79881, type = 2, visualStyle = 1 },
				{ targetNode = 79891, type = 2, visualStyle = 1 }
			}
		},
		[79875] = {
			ID = 79875,
			flags = 0,
			type = 0,
			posX = 10200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100580 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79817, type = 2, visualStyle = 1 },
				{ targetNode = 79903, type = 2, visualStyle = 1 }
			}
		},
		[79876] = {
			ID = 79876,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100581 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79899, type = 2, visualStyle = 1 },
				{ targetNode = 79885, type = 2, visualStyle = 1 }
			}
		},
		[79877] = {
			ID = 79877,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 2100,
			maxRanks = 2,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100582 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79879, type = 2, visualStyle = 1 },
				{ targetNode = 79915, type = 2, visualStyle = 1 },
				{ targetNode = 79871, type = 2, visualStyle = 1 }
			}
		},
		[79878] = {
			ID = 79878,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5101,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100583 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79879] = {
			ID = 79879,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100584 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79896, type = 2, visualStyle = 1 },
				{ targetNode = 79886, type = 2, visualStyle = 1 }
			}
		},
		[79880] = {
			ID = 79880,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100585 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79900, type = 2, visualStyle = 1 },
				{ targetNode = 79893, type = 2, visualStyle = 1 }
			}
		},
		[79881] = {
			ID = 79881,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100586 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79884, type = 2, visualStyle = 1 },
				{ targetNode = 79876, type = 2, visualStyle = 1 }
			}
		},
		[79882] = {
			ID = 79882,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100587 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79885, type = 2, visualStyle = 1 },
				{ targetNode = 79901, type = 2, visualStyle = 1 }
			}
		},
		[79883] = {
			ID = 79883,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100588 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79831, type = 2, visualStyle = 1 },
				{ targetNode = 79840, type = 2, visualStyle = 1 }
			}
		},
		[79884] = {
			ID = 79884,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100589 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79885, type = 2, visualStyle = 1 }
			}
		},
		[79885] = {
			ID = 79885,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100590 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79813, type = 2, visualStyle = 1 }
			}
		},
		[79886] = {
			ID = 79886,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100591 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79874, type = 2, visualStyle = 1 },
				{ targetNode = 79891, type = 2, visualStyle = 1 }
			}
		},
		[79887] = {
			ID = 79887,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100592 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79830, type = 2, visualStyle = 1 }
			}
		},
		[79888] = {
			ID = 79888,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100593 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79886, type = 2, visualStyle = 1 }
			}
		},
		[79889] = {
			ID = 79889,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100594 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79903, type = 2, visualStyle = 1 }
			}
		},
		[79890] = {
			ID = 79890,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100595 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79887, type = 2, visualStyle = 1 },
				{ targetNode = 79903, type = 2, visualStyle = 1 },
				{ targetNode = 79882, type = 2, visualStyle = 1 }
			}
		},
		[79891] = {
			ID = 79891,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100596 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79884, type = 2, visualStyle = 1 },
				{ targetNode = 79882, type = 2, visualStyle = 1 }
			}
		},
		[79892] = {
			ID = 79892,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100597 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79881, type = 2, visualStyle = 1 }
			}
		},
		[79893] = {
			ID = 79893,
			flags = 0,
			type = 0,
			posX = 10800,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100598 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79883, type = 2, visualStyle = 1 },
				{ targetNode = 79897, type = 2, visualStyle = 1 }
			}
		},
		[79894] = {
			ID = 79894,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100599 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79895] = {
			ID = 79895,
			flags = 8,
			type = 0,
			posX = 11390,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100600 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79900, type = 2, visualStyle = 1 },
				{ targetNode = 79880, type = 2, visualStyle = 1 },
				{ targetNode = 79871, type = 2, visualStyle = 1 }
			}
		},
		[79896] = {
			ID = 79896,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3899,
			maxRanks = 2,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100601 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79892, type = 2, visualStyle = 1 },
				{ targetNode = 79872, type = 2, visualStyle = 1 },
				{ targetNode = 79874, type = 2, visualStyle = 1 }
			}
		},
		[79897] = {
			ID = 79897,
			flags = 1,
			type = 2,
			posX = 10200,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19947, 19963, 19947, 19963, 19947, 19963 },
			entryIDs = { 100603, 100602 },
			groupIDs = { 8352, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79840, type = 2, visualStyle = 1 }
			}
		},
		[79898] = {
			ID = 79898,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100604 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79871, type = 2, visualStyle = 1 }
			}
		},
		[79899] = {
			ID = 79899,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100605 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79894, type = 2, visualStyle = 1 }
			}
		},
		[79900] = {
			ID = 79900,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100606 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79886, type = 2, visualStyle = 1 },
				{ targetNode = 79883, type = 2, visualStyle = 1 }
			}
		},
		[79901] = {
			ID = 79901,
			flags = 0,
			type = 0,
			posX = 12000,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100607 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79902, type = 2, visualStyle = 1 }
			}
		},
		[79902] = {
			ID = 79902,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 6890,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100609, 100608 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79903] = {
			ID = 79903,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19947, 19961, 19963, 19947, 19961, 19963, 19947, 19961, 19963 },
			entryIDs = { 100611, 100610 },
			groupIDs = { 8352, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79817, type = 2, visualStyle = 1 },
				{ targetNode = 79830, type = 2, visualStyle = 1 },
				{ targetNode = 79887, type = 2, visualStyle = 1 }
			}
		},
		[79904] = {
			ID = 79904,
			flags = 9,
			type = 2,
			posX = 2400,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100614, 100613 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {}
		},
		[79905] = {
			ID = 79905,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100615 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79911, type = 2, visualStyle = 1 }
			}
		},
		[79906] = {
			ID = 79906,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 100616 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79921, type = 2, visualStyle = 1 },
				{ targetNode = 79931, type = 2, visualStyle = 1 }
			}
		},
		[79907] = {
			ID = 79907,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100617 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79910, type = 2, visualStyle = 1 },
				{ targetNode = 79919, type = 2, visualStyle = 1 },
				{ targetNode = 79927, type = 2, visualStyle = 1 }
			}
		},
		[79908] = {
			ID = 79908,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100618 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {}
		},
		[79909] = {
			ID = 79909,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100619 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79918, type = 2, visualStyle = 1 }
			}
		},
		[79910] = {
			ID = 79910,
			flags = 9,
			type = 2,
			posX = 3600,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100621, 100620 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79920, type = 2, visualStyle = 1 }
			}
		},
		[79911] = {
			ID = 79911,
			flags = 9,
			type = 2,
			posX = 6000,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100623, 100622 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {}
		},
		[79912] = {
			ID = 79912,
			flags = 9,
			type = 0,
			posX = 4200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19952, 19952, 19952, 19952 },
			entryIDs = { 100624 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79821, type = 2, visualStyle = 1 },
				{ targetNode = 79924, type = 2, visualStyle = 1 },
				{ targetNode = 79928, type = 2, visualStyle = 1 }
			}
		},
		[79913] = {
			ID = 79913,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100625 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79815, type = 2, visualStyle = 1 },
				{ targetNode = 79905, type = 2, visualStyle = 1 }
			}
		},
		[79914] = {
			ID = 79914,
			flags = 9,
			type = 2,
			posX = 4800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100626, 100526 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {}
		},
		[79915] = {
			ID = 79915,
			flags = 9,
			type = 0,
			posX = 13200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19947, 19947, 19947 },
			entryIDs = { 100627 },
			groupIDs = { 8352, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79879, type = 2, visualStyle = 1 },
				{ targetNode = 79896, type = 2, visualStyle = 1 }
			}
		},
		[79916] = {
			ID = 79916,
			flags = 9,
			type = 2,
			posX = 4200,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100629, 100628 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {}
		},
		[79917] = {
			ID = 79917,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100630 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79956, type = 2, visualStyle = 1 }
			}
		},
		[79918] = {
			ID = 79918,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100631 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79922, type = 2, visualStyle = 1 },
				{ targetNode = 79913, type = 2, visualStyle = 1 }
			}
		},
		[79919] = {
			ID = 79919,
			flags = 8,
			type = 0,
			posX = 2998,
			posY = 4498,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100632 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79926, type = 2, visualStyle = 1 }
			}
		},
		[79920] = {
			ID = 79920,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100633 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79922, type = 2, visualStyle = 1 },
				{ targetNode = 79926, type = 2, visualStyle = 1 }
			}
		},
		[79921] = {
			ID = 79921,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 2100,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 100634 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79836, type = 2, visualStyle = 1 },
				{ targetNode = 79837, type = 2, visualStyle = 1 },
				{ targetNode = 79925, type = 2, visualStyle = 1 },
				{ targetNode = 79912, type = 2, visualStyle = 1 }
			}
		},
		[79922] = {
			ID = 79922,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100635 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79815, type = 2, visualStyle = 1 },
				{ targetNode = 79916, type = 2, visualStyle = 1 },
				{ targetNode = 79814, type = 2, visualStyle = 1 }
			}
		},
		[79923] = {
			ID = 79923,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 3899,
			maxRanks = 2,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100636 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79937, type = 2, visualStyle = 1 }
			}
		},
		[79924] = {
			ID = 79924,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 100637 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79923, type = 2, visualStyle = 1 },
				{ targetNode = 79923, type = 2, visualStyle = 1 }
			}
		},
		[79925] = {
			ID = 79925,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 100638 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79821, type = 2, visualStyle = 1 },
				{ targetNode = 79933, type = 2, visualStyle = 1 }
			}
		},
		[79926] = {
			ID = 79926,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100639 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79932, type = 2, visualStyle = 1 },
				{ targetNode = 79814, type = 2, visualStyle = 1 }
			}
		},
		[79927] = {
			ID = 79927,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100640 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {}
		},
		[79928] = {
			ID = 79928,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 3298,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 100641 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79907, type = 2, visualStyle = 1 },
				{ targetNode = 79977, type = 2, visualStyle = 1 },
				{ targetNode = 79923, type = 2, visualStyle = 1 }
			}
		},
		[79930] = {
			ID = 79930,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 100643 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79925, type = 2, visualStyle = 1 }
			}
		},
		[79931] = {
			ID = 79931,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 2099,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 100644 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79936, type = 2, visualStyle = 1 },
				{ targetNode = 79836, type = 2, visualStyle = 1 },
				{ targetNode = 79837, type = 2, visualStyle = 1 },
				{ targetNode = 79912, type = 2, visualStyle = 1 }
			}
		},
		[79932] = {
			ID = 79932,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 19945, 19946, 19945, 19946, 19945, 19946 },
			entryIDs = { 100645 },
			groupIDs = { 8350, 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79904, type = 2, visualStyle = 1 }
			}
		},
		[79933] = {
			ID = 79933,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 3899,
			maxRanks = 2,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100646 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79819, type = 2, visualStyle = 1 },
				{ targetNode = 79934, type = 2, visualStyle = 1 }
			}
		},
		[79934] = {
			ID = 79934,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100647 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79918, type = 2, visualStyle = 1 },
				{ targetNode = 79913, type = 2, visualStyle = 1 }
			}
		},
		[79935] = {
			ID = 79935,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 1499,
			maxRanks = 1,
			conditionIDs = { 19956, 19962, 19956, 19962, 19956, 19962 },
			entryIDs = { 100648 },
			groupIDs = { 8357, 8358 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79936, type = 2, visualStyle = 1 },
				{ targetNode = 79931, type = 2, visualStyle = 1 }
			}
		},
		[79936] = {
			ID = 79936,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 100649 },
			groupIDs = { 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79928, type = 2, visualStyle = 1 },
				{ targetNode = 79907, type = 2, visualStyle = 1 }
			}
		},
		[79937] = {
			ID = 79937,
			flags = 9,
			type = 2,
			posX = 4200,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100651, 100650 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79918, type = 2, visualStyle = 1 },
				{ targetNode = 79920, type = 2, visualStyle = 1 },
				{ targetNode = 79832, type = 2, visualStyle = 1 }
			}
		},
		[79938] = {
			ID = 79938,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100652 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79939] = {
			ID = 79939,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3310,
			maxRanks = 2,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100653 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79943, type = 2, visualStyle = 1 }
			}
		},
		[79940] = {
			ID = 79940,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100654 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79941] = {
			ID = 79941,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3899,
			maxRanks = 2,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100655 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79951, type = 2, visualStyle = 1 },
				{ targetNode = 79959, type = 2, visualStyle = 1 }
			}
		},
		[79942] = {
			ID = 79942,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100656 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79938, type = 2, visualStyle = 1 },
				{ targetNode = 79953, type = 2, visualStyle = 1 }
			}
		},
		[79943] = {
			ID = 79943,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100657, 100525 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79952, type = 2, visualStyle = 1 }
			}
		},
		[79944] = {
			ID = 79944,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100658 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79964, type = 2, visualStyle = 1 },
				{ targetNode = 79947, type = 2, visualStyle = 1 }
			}
		},
		[79945] = {
			ID = 79945,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100659 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79963, type = 2, visualStyle = 1 },
				{ targetNode = 79943, type = 2, visualStyle = 1 }
			}
		},
		[79946] = {
			ID = 79946,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100660, 100612 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79947] = {
			ID = 79947,
			flags = 8,
			type = 0,
			posX = 10790,
			posY = 3310,
			maxRanks = 1,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100661 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79941, type = 2, visualStyle = 1 },
				{ targetNode = 79964, type = 2, visualStyle = 1 }
			}
		},
		[79948] = {
			ID = 79948,
			flags = 0,
			type = 0,
			posX = 13200,
			posY = 2710,
			maxRanks = 2,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100662 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79939, type = 2, visualStyle = 1 },
				{ targetNode = 79945, type = 2, visualStyle = 1 }
			}
		},
		[79949] = {
			ID = 79949,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100663 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79958, type = 2, visualStyle = 1 },
				{ targetNode = 79968, type = 2, visualStyle = 1 },
				{ targetNode = 79917, type = 2, visualStyle = 1 }
			}
		},
		[79950] = {
			ID = 79950,
			flags = 8,
			type = 0,
			posX = 13795,
			posY = 5096,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100664 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79962, type = 2, visualStyle = 1 }
			}
		},
		[79951] = {
			ID = 79951,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100665 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79953, type = 2, visualStyle = 1 }
			}
		},
		[79952] = {
			ID = 79952,
			flags = 8,
			type = 0,
			posX = 13199,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100666 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79950, type = 2, visualStyle = 1 },
				{ targetNode = 79966, type = 2, visualStyle = 1 }
			}
		},
		[79953] = {
			ID = 79953,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5700,
			maxRanks = 3,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100667 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79938, type = 2, visualStyle = 1 },
				{ targetNode = 79823, type = 2, visualStyle = 1 }
			}
		},
		[79954] = {
			ID = 79954,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3910,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100668 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79952, type = 2, visualStyle = 1 },
				{ targetNode = 79955, type = 2, visualStyle = 1 }
			}
		},
		[79955] = {
			ID = 79955,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100669 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79966, type = 2, visualStyle = 1 },
				{ targetNode = 79822, type = 2, visualStyle = 1 },
				{ targetNode = 79942, type = 2, visualStyle = 1 }
			}
		},
		[79956] = {
			ID = 79956,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3310,
			maxRanks = 2,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100670 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79954, type = 2, visualStyle = 1 },
				{ targetNode = 79955, type = 2, visualStyle = 1 },
				{ targetNode = 79964, type = 2, visualStyle = 1 }
			}
		},
		[79957] = {
			ID = 79957,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2710,
			maxRanks = 2,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100671 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79939, type = 2, visualStyle = 1 }
			}
		},
		[79958] = {
			ID = 79958,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100672 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79944, type = 2, visualStyle = 1 }
			}
		},
		[79959] = {
			ID = 79959,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100673 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79942, type = 2, visualStyle = 1 },
				{ targetNode = 79951, type = 2, visualStyle = 1 }
			}
		},
		[79960] = {
			ID = 79960,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100674 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79816, type = 2, visualStyle = 1 },
				{ targetNode = 79967, type = 2, visualStyle = 1 }
			}
		},
		[79961] = {
			ID = 79961,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100676, 100675 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {}
		},
		[79962] = {
			ID = 79962,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100677, 100516 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79967, type = 2, visualStyle = 1 }
			}
		},
		[79963] = {
			ID = 79963,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100678 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79952, type = 2, visualStyle = 1 }
			}
		},
		[79964] = {
			ID = 79964,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3910,
			maxRanks = 3,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100679 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79959, type = 2, visualStyle = 1 },
				{ targetNode = 79942, type = 2, visualStyle = 1 },
				{ targetNode = 79955, type = 2, visualStyle = 1 }
			}
		},
		[79965] = {
			ID = 79965,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100680 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79816, type = 2, visualStyle = 1 },
				{ targetNode = 79938, type = 2, visualStyle = 1 },
				{ targetNode = 79961, type = 2, visualStyle = 1 }
			}
		},
		[79966] = {
			ID = 79966,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 19960, 19963, 19960, 19963, 19960, 19963 },
			entryIDs = { 100681 },
			groupIDs = { 8356, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79960, type = 2, visualStyle = 1 }
			}
		},
		[79967] = {
			ID = 79967,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 19960, 19961, 19963, 19960, 19961, 19963, 19960, 19961, 19963 },
			entryIDs = { 100682 },
			groupIDs = { 8356, 8359, 8360, 8361 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79946, type = 2, visualStyle = 1 }
			}
		},
		[79968] = {
			ID = 79968,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 19960, 19960, 19960 },
			entryIDs = { 100683 },
			groupIDs = { 8356, 8360 },
			costs = {
				{ ID = 2769, amount = 1 }
			},
			edges = {
				{ targetNode = 79948, type = 2, visualStyle = 1 },
				{ targetNode = 79957, type = 2, visualStyle = 1 }
			}
		},
		[79977] = {
			ID = 79977,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 19946, 19946, 19946 },
			entryIDs = { 100692 },
			groupIDs = { 8351, 8357 },
			costs = {
				{ ID = 2770, amount = 1 }
			},
			edges = {
				{ targetNode = 79910, type = 2, visualStyle = 1 },
				{ targetNode = 79937, type = 2, visualStyle = 1 }
			}
		},
		[80558] = {
			ID = 80558,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101357, 101356 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80559] = {
			ID = 80559,
			flags = 8,
			type = 0,
			posX = 13199,
			posY = 2696,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101358 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80589, type = 2, visualStyle = 1 }
			}
		},
		[80560] = {
			ID = 80560,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101359 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80569, type = 2, visualStyle = 1 }
			}
		},
		[80561] = {
			ID = 80561,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101360 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80566, type = 2, visualStyle = 1 },
				{ targetNode = 80572, type = 2, visualStyle = 1 }
			}
		},
		[80562] = {
			ID = 80562,
			flags = 8,
			type = 0,
			posX = 9600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101361 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80599, type = 2, visualStyle = 1 },
				{ targetNode = 80583, type = 2, visualStyle = 1 }
			}
		},
		[80563] = {
			ID = 80563,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101363, 101362 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80598, type = 2, visualStyle = 1 }
			}
		},
		[80564] = {
			ID = 80564,
			flags = 1,
			type = 2,
			posX = 12600,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101365, 101364 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80575, type = 2, visualStyle = 1 },
				{ targetNode = 80587, type = 2, visualStyle = 1 }
			}
		},
		[80565] = {
			ID = 80565,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101367, 101366 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80566] = {
			ID = 80566,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101368 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80590, type = 2, visualStyle = 1 },
				{ targetNode = 80564, type = 2, visualStyle = 1 }
			}
		},
		[80567] = {
			ID = 80567,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101369 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80578, type = 2, visualStyle = 1 },
				{ targetNode = 80581, type = 2, visualStyle = 1 },
				{ targetNode = 80599, type = 2, visualStyle = 1 }
			}
		},
		[80568] = {
			ID = 80568,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101370 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80597, type = 2, visualStyle = 1 },
				{ targetNode = 80588, type = 2, visualStyle = 1 }
			}
		},
		[80569] = {
			ID = 80569,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101371 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80577, type = 2, visualStyle = 1 },
				{ targetNode = 80565, type = 2, visualStyle = 1 },
				{ targetNode = 80565, type = 2, visualStyle = 1 }
			}
		},
		[80570] = {
			ID = 80570,
			flags = 8,
			type = 0,
			posX = 11999,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101372 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80571, type = 2, visualStyle = 1 },
				{ targetNode = 80573, type = 2, visualStyle = 1 }
			}
		},
		[80571] = {
			ID = 80571,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101373 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80572] = {
			ID = 80572,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101374 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80579, type = 2, visualStyle = 1 },
				{ targetNode = 80575, type = 2, visualStyle = 1 }
			}
		},
		[80573] = {
			ID = 80573,
			flags = 1,
			type = 2,
			posX = 11999,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101376, 101375 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80574] = {
			ID = 80574,
			flags = 9,
			type = 2,
			posX = 11999,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101378, 101377 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80591, type = 2, visualStyle = 1 },
				{ targetNode = 80566, type = 2, visualStyle = 1 },
				{ targetNode = 80580, type = 2, visualStyle = 1 }
			}
		},
		[80575] = {
			ID = 80575,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101380, 101379 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80586, type = 2, visualStyle = 1 },
				{ targetNode = 80593, type = 2, visualStyle = 1 }
			}
		},
		[80576] = {
			ID = 80576,
			flags = 1,
			type = 2,
			posX = 12004,
			posY = 5687,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101382, 101381 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80594, type = 2, visualStyle = 1 },
				{ targetNode = 80585, type = 2, visualStyle = 1 },
				{ targetNode = 80570, type = 2, visualStyle = 1 }
			}
		},
		[80577] = {
			ID = 80577,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101383 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80578] = {
			ID = 80578,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101384 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80560, type = 2, visualStyle = 1 },
				{ targetNode = 80598, type = 2, visualStyle = 1 }
			}
		},
		[80579] = {
			ID = 80579,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101385 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80586, type = 2, visualStyle = 1 },
				{ targetNode = 80575, type = 2, visualStyle = 1 }
			}
		},
		[80580] = {
			ID = 80580,
			flags = 8,
			type = 0,
			posX = 11999,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101386 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80590, type = 2, visualStyle = 1 }
			}
		},
		[80581] = {
			ID = 80581,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101387 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80563, type = 2, visualStyle = 1 },
				{ targetNode = 80578, type = 2, visualStyle = 1 }
			}
		},
		[80582] = {
			ID = 80582,
			flags = 8,
			type = 0,
			posX = 11999,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101388 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80598, type = 2, visualStyle = 1 },
				{ targetNode = 80576, type = 2, visualStyle = 1 }
			}
		},
		[80583] = {
			ID = 80583,
			flags = 0,
			type = 0,
			posX = 9600,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101389 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80560, type = 2, visualStyle = 1 }
			}
		},
		[80584] = {
			ID = 80584,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101390 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80595, type = 2, visualStyle = 1 },
				{ targetNode = 80567, type = 2, visualStyle = 1 }
			}
		},
		[80585] = {
			ID = 80585,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101391 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80573, type = 2, visualStyle = 1 },
				{ targetNode = 80565, type = 2, visualStyle = 1 }
			}
		},
		[80586] = {
			ID = 80586,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101392 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80596, type = 2, visualStyle = 1 },
				{ targetNode = 80592, type = 2, visualStyle = 1 }
			}
		},
		[80587] = {
			ID = 80587,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101393 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80593, type = 2, visualStyle = 1 }
			}
		},
		[80588] = {
			ID = 80588,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101394 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80600, type = 2, visualStyle = 1 },
				{ targetNode = 80559, type = 2, visualStyle = 1 }
			}
		},
		[80589] = {
			ID = 80589,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101395 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80572, type = 2, visualStyle = 1 },
				{ targetNode = 80579, type = 2, visualStyle = 1 }
			}
		},
		[80590] = {
			ID = 80590,
			flags = 9,
			type = 2,
			posX = 12019,
			posY = 4492,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101397, 101396 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80582, type = 2, visualStyle = 1 },
				{ targetNode = 80563, type = 2, visualStyle = 1 },
				{ targetNode = 80587, type = 2, visualStyle = 1 }
			}
		},
		[80591] = {
			ID = 80591,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101398 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80590, type = 2, visualStyle = 1 },
				{ targetNode = 80581, type = 2, visualStyle = 1 }
			}
		},
		[80592] = {
			ID = 80592,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101399 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80558, type = 2, visualStyle = 1 }
			}
		},
		[80593] = {
			ID = 80593,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101401, 101400 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80592, type = 2, visualStyle = 1 },
				{ targetNode = 80594, type = 2, visualStyle = 1 }
			}
		},
		[80594] = {
			ID = 80594,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101402 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80558, type = 2, visualStyle = 1 }
			}
		},
		[80595] = {
			ID = 80595,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101403 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80599, type = 2, visualStyle = 1 },
				{ targetNode = 80562, type = 2, visualStyle = 1 }
			}
		},
		[80596] = {
			ID = 80596,
			flags = 9,
			type = 2,
			posX = 14400,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101405, 101404 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80597] = {
			ID = 80597,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101406 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80600, type = 2, visualStyle = 1 },
				{ targetNode = 80584, type = 2, visualStyle = 1 }
			}
		},
		[80598] = {
			ID = 80598,
			flags = 1,
			type = 2,
			posX = 11400,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20038, 20042, 20043, 20038, 20042, 20043, 20038 },
			entryIDs = { 101408, 101407 },
			groupIDs = { 8403, 8405, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80585, type = 2, visualStyle = 1 }
			}
		},
		[80599] = {
			ID = 80599,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20042, 20038, 20042, 20038, 20042, 20038 },
			entryIDs = { 101409 },
			groupIDs = { 8403, 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80578, type = 2, visualStyle = 1 },
				{ targetNode = 80583, type = 2, visualStyle = 1 }
			}
		},
		[80600] = {
			ID = 80600,
			flags = 8,
			type = 0,
			posX = 11999,
			posY = 2696,
			maxRanks = 1,
			conditionIDs = { 20038, 20038, 20038 },
			entryIDs = { 101410 },
			groupIDs = { 8413, 8414 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80561, type = 2, visualStyle = 1 },
				{ targetNode = 80574, type = 2, visualStyle = 1 }
			}
		},
		[80601] = {
			ID = 80601,
			flags = 8,
			type = 0,
			posX = 12610,
			posY = 6312,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101411 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80721, type = 2, visualStyle = 1 }
			}
		},
		[80602] = {
			ID = 80602,
			flags = 8,
			type = 0,
			posX = 12598,
			posY = 5699,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101412 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80601, type = 2, visualStyle = 1 },
				{ targetNode = 80722, type = 2, visualStyle = 1 },
				{ targetNode = 80719, type = 2, visualStyle = 1 }
			}
		},
		[80603] = {
			ID = 80603,
			flags = 0,
			type = 0,
			posX = 2400,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101413 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80709, type = 2, visualStyle = 1 },
				{ targetNode = 80708, type = 2, visualStyle = 1 }
			}
		},
		[80604] = {
			ID = 80604,
			flags = 8,
			type = 0,
			posX = 2398,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 101414 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80603, type = 2, visualStyle = 1 }
			}
		},
		[80605] = {
			ID = 80605,
			flags = 8,
			type = 0,
			posX = 13806,
			posY = 6901,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101415 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80606] = {
			ID = 80606,
			flags = 8,
			type = 0,
			posX = 4805,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = { 20160, 20160, 20160, 20160 },
			entryIDs = { 101416 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80706, type = 2, visualStyle = 1 }
			}
		},
		[80607] = {
			ID = 80607,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101417 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80657, type = 2, visualStyle = 1 },
				{ targetNode = 80608, type = 2, visualStyle = 1 },
				{ targetNode = 80608, type = 2, visualStyle = 1 },
				{ targetNode = 80608, type = 2, visualStyle = 1 }
			}
		},
		[80608] = {
			ID = 80608,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101418 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80667, type = 2, visualStyle = 1 },
				{ targetNode = 80665, type = 2, visualStyle = 1 }
			}
		},
		[80609] = {
			ID = 80609,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101419 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80623, type = 2, visualStyle = 1 },
				{ targetNode = 80623, type = 2, visualStyle = 1 }
			}
		},
		[80610] = {
			ID = 80610,
			flags = 0,
			type = 0,
			posX = 11400,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101420 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80609, type = 2, visualStyle = 1 },
				{ targetNode = 80622, type = 2, visualStyle = 1 }
			}
		},
		[80611] = {
			ID = 80611,
			flags = 8,
			type = 0,
			posX = 12007,
			posY = 2703,
			maxRanks = 2,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101421 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80621, type = 2, visualStyle = 1 }
			}
		},
		[80612] = {
			ID = 80612,
			flags = 0,
			type = 0,
			posX = 12002,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101422 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80611, type = 2, visualStyle = 1 },
				{ targetNode = 80615, type = 2, visualStyle = 1 },
				{ targetNode = 80622, type = 2, visualStyle = 1 }
			}
		},
		[80613] = {
			ID = 80613,
			flags = 0,
			type = 0,
			posX = 12005,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101423 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80610, type = 2, visualStyle = 1 },
				{ targetNode = 80612, type = 2, visualStyle = 1 },
				{ targetNode = 80614, type = 2, visualStyle = 1 },
				{ targetNode = 80614, type = 2, visualStyle = 1 }
			}
		},
		[80614] = {
			ID = 80614,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101424 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80678, type = 2, visualStyle = 1 },
				{ targetNode = 80615, type = 2, visualStyle = 1 },
				{ targetNode = 80678, type = 2, visualStyle = 1 }
			}
		},
		[80615] = {
			ID = 80615,
			flags = 8,
			type = 0,
			posX = 12606,
			posY = 2703,
			maxRanks = 2,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101425 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80677, type = 2, visualStyle = 1 },
				{ targetNode = 80621, type = 2, visualStyle = 1 }
			}
		},
		[80616] = {
			ID = 80616,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101426 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80673, type = 2, visualStyle = 1 },
				{ targetNode = 80659, type = 2, visualStyle = 1 }
			}
		},
		[80617] = {
			ID = 80617,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101427 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80657, type = 2, visualStyle = 1 },
				{ targetNode = 80616, type = 2, visualStyle = 1 },
				{ targetNode = 80616, type = 2, visualStyle = 1 }
			}
		},
		[80618] = {
			ID = 80618,
			flags = 9,
			type = 2,
			posX = 12007,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101429, 101428 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80619, type = 2, visualStyle = 1 }
			}
		},
		[80619] = {
			ID = 80619,
			flags = 8,
			type = 0,
			posX = 12002,
			posY = 4496,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101430 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80657, type = 2, visualStyle = 1 }
			}
		},
		[80620] = {
			ID = 80620,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101431 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80617, type = 2, visualStyle = 1 },
				{ targetNode = 80619, type = 2, visualStyle = 1 },
				{ targetNode = 80617, type = 2, visualStyle = 1 }
			}
		},
		[80621] = {
			ID = 80621,
			flags = 8,
			type = 0,
			posX = 12007,
			posY = 3302,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101432 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80618, type = 2, visualStyle = 1 },
				{ targetNode = 80620, type = 2, visualStyle = 1 },
				{ targetNode = 80627, type = 2, visualStyle = 1 }
			}
		},
		[80622] = {
			ID = 80622,
			flags = 8,
			type = 0,
			posX = 11406,
			posY = 2703,
			maxRanks = 2,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101433 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80621, type = 2, visualStyle = 1 },
				{ targetNode = 80623, type = 2, visualStyle = 1 }
			}
		},
		[80623] = {
			ID = 80623,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101434 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80627, type = 2, visualStyle = 1 },
				{ targetNode = 80624, type = 2, visualStyle = 1 }
			}
		},
		[80624] = {
			ID = 80624,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101435 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80626, type = 2, visualStyle = 1 },
				{ targetNode = 80625, type = 2, visualStyle = 1 }
			}
		},
		[80625] = {
			ID = 80625,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101436 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80667, type = 2, visualStyle = 1 }
			}
		},
		[80626] = {
			ID = 80626,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101437 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80608, type = 2, visualStyle = 1 },
				{ targetNode = 80625, type = 2, visualStyle = 1 },
				{ targetNode = 80608, type = 2, visualStyle = 1 }
			}
		},
		[80627] = {
			ID = 80627,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101438 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80607, type = 2, visualStyle = 1 },
				{ targetNode = 80619, type = 2, visualStyle = 1 },
				{ targetNode = 80626, type = 2, visualStyle = 1 },
				{ targetNode = 80626, type = 2, visualStyle = 1 }
			}
		},
		[80628] = {
			ID = 80628,
			flags = 8,
			type = 0,
			posX = 13203,
			posY = 4506,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101439 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80629] = {
			ID = 80629,
			flags = 9,
			type = 0,
			posX = 13800,
			posY = 3901,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101440 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80632, type = 2, visualStyle = 1 }
			}
		},
		[80630] = {
			ID = 80630,
			flags = 9,
			type = 0,
			posX = 13800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101441 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80719, type = 2, visualStyle = 1 }
			}
		},
		[80631] = {
			ID = 80631,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101442 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80634, type = 2, visualStyle = 1 },
				{ targetNode = 80630, type = 2, visualStyle = 1 }
			}
		},
		[80632] = {
			ID = 80632,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101444, 101443 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80631, type = 2, visualStyle = 1 },
				{ targetNode = 80633, type = 2, visualStyle = 1 }
			}
		},
		[80633] = {
			ID = 80633,
			flags = 8,
			type = 0,
			posX = 13203,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101445 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80634, type = 2, visualStyle = 1 }
			}
		},
		[80634] = {
			ID = 80634,
			flags = 8,
			type = 0,
			posX = 13203,
			posY = 5704,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101446 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80719, type = 2, visualStyle = 1 }
			}
		},
		[80635] = {
			ID = 80635,
			flags = 9,
			type = 2,
			posX = 12598,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101448, 101447 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80634, type = 2, visualStyle = 1 }
			}
		},
		[80636] = {
			ID = 80636,
			flags = 9,
			type = 2,
			posX = 11401,
			posY = 5105,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101450, 101449 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80653, type = 2, visualStyle = 1 }
			}
		},
		[80637] = {
			ID = 80637,
			flags = 8,
			type = 0,
			posX = 12004,
			posY = 1502,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101451 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80640, type = 2, visualStyle = 1 }
			}
		},
		[80638] = {
			ID = 80638,
			flags = 8,
			type = 0,
			posX = 11396,
			posY = 3302,
			maxRanks = 2,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101452 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80645, type = 2, visualStyle = 1 }
			}
		},
		[80639] = {
			ID = 80639,
			flags = 8,
			type = 0,
			posX = 11396,
			posY = 2702,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101453 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80638, type = 2, visualStyle = 1 },
				{ targetNode = 80647, type = 2, visualStyle = 1 },
				{ targetNode = 80644, type = 2, visualStyle = 1 }
			}
		},
		[80640] = {
			ID = 80640,
			flags = 8,
			type = 0,
			posX = 12004,
			posY = 2104,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101454 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80639, type = 2, visualStyle = 1 },
				{ targetNode = 80641, type = 2, visualStyle = 1 }
			}
		},
		[80641] = {
			ID = 80641,
			flags = 8,
			type = 0,
			posX = 12598,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101455 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80727, type = 2, visualStyle = 1 },
				{ targetNode = 80644, type = 2, visualStyle = 1 },
				{ targetNode = 80642, type = 2, visualStyle = 1 }
			}
		},
		[80642] = {
			ID = 80642,
			flags = 8,
			type = 0,
			posX = 12598,
			posY = 3301,
			maxRanks = 2,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101456 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80643, type = 2, visualStyle = 1 }
			}
		},
		[80643] = {
			ID = 80643,
			flags = 8,
			type = 0,
			posX = 12598,
			posY = 3901,
			maxRanks = 2,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101457 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80725, type = 2, visualStyle = 1 }
			}
		},
		[80644] = {
			ID = 80644,
			flags = 8,
			type = 0,
			posX = 12004,
			posY = 3302,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101458 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80643, type = 2, visualStyle = 1 },
				{ targetNode = 80645, type = 2, visualStyle = 1 }
			}
		},
		[80645] = {
			ID = 80645,
			flags = 8,
			type = 0,
			posX = 11401,
			posY = 3904,
			maxRanks = 2,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101459 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80655, type = 2, visualStyle = 1 }
			}
		},
		[80646] = {
			ID = 80646,
			flags = 8,
			type = 0,
			posX = 10199,
			posY = 3903,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101460 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80650, type = 2, visualStyle = 1 }
			}
		},
		[80647] = {
			ID = 80647,
			flags = 8,
			type = 0,
			posX = 10803,
			posY = 3306,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101461 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80645, type = 2, visualStyle = 1 },
				{ targetNode = 80646, type = 2, visualStyle = 1 },
				{ targetNode = 80649, type = 2, visualStyle = 1 }
			}
		},
		[80648] = {
			ID = 80648,
			flags = 8,
			type = 0,
			posX = 10803,
			posY = 4503,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101462 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80649] = {
			ID = 80649,
			flags = 8,
			type = 0,
			posX = 10803,
			posY = 3906,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101463 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80648, type = 2, visualStyle = 1 },
				{ targetNode = 80655, type = 2, visualStyle = 1 },
				{ targetNode = 80650, type = 2, visualStyle = 1 }
			}
		},
		[80650] = {
			ID = 80650,
			flags = 8,
			type = 0,
			posX = 10203,
			posY = 4505,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101464 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80654, type = 2, visualStyle = 1 },
				{ targetNode = 80652, type = 2, visualStyle = 1 }
			}
		},
		[80651] = {
			ID = 80651,
			flags = 9,
			type = 2,
			posX = 10199,
			posY = 5702,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101466, 101465 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80729, type = 2, visualStyle = 1 }
			}
		},
		[80652] = {
			ID = 80652,
			flags = 9,
			type = 2,
			posX = 10200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101468, 101467 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80651, type = 2, visualStyle = 1 },
				{ targetNode = 80653, type = 2, visualStyle = 1 }
			}
		},
		[80653] = {
			ID = 80653,
			flags = 8,
			type = 0,
			posX = 10803,
			posY = 5702,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101469 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80729, type = 2, visualStyle = 1 }
			}
		},
		[80654] = {
			ID = 80654,
			flags = 8,
			type = 0,
			posX = 10803,
			posY = 5104,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101470 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80653, type = 2, visualStyle = 1 }
			}
		},
		[80655] = {
			ID = 80655,
			flags = 8,
			type = 0,
			posX = 11401,
			posY = 4508,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101471 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80636, type = 2, visualStyle = 1 },
				{ targetNode = 80654, type = 2, visualStyle = 1 },
				{ targetNode = 80724, type = 2, visualStyle = 1 }
			}
		},
		[80656] = {
			ID = 80656,
			flags = 8,
			type = 0,
			posX = 12002,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101472 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80662, type = 2, visualStyle = 1 }
			}
		},
		[80657] = {
			ID = 80657,
			flags = 8,
			type = 0,
			posX = 12006,
			posY = 5102,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101473 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80665, type = 2, visualStyle = 1 },
				{ targetNode = 80656, type = 2, visualStyle = 1 },
				{ targetNode = 80659, type = 2, visualStyle = 1 }
			}
		},
		[80658] = {
			ID = 80658,
			flags = 8,
			type = 0,
			posX = 13206,
			posY = 6302,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101474 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80659] = {
			ID = 80659,
			flags = 8,
			type = 0,
			posX = 12603,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101475 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80662, type = 2, visualStyle = 1 },
				{ targetNode = 80658, type = 2, visualStyle = 1 },
				{ targetNode = 80660, type = 2, visualStyle = 1 }
			}
		},
		[80660] = {
			ID = 80660,
			flags = 8,
			type = 0,
			posX = 12605,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101476 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80661, type = 2, visualStyle = 1 }
			}
		},
		[80661] = {
			ID = 80661,
			flags = 8,
			type = 0,
			posX = 12605,
			posY = 6901,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101477 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80662] = {
			ID = 80662,
			flags = 8,
			type = 0,
			posX = 12002,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101478 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80661, type = 2, visualStyle = 1 },
				{ targetNode = 80663, type = 2, visualStyle = 1 }
			}
		},
		[80663] = {
			ID = 80663,
			flags = 8,
			type = 0,
			posX = 11408,
			posY = 6901,
			maxRanks = 1,
			conditionIDs = { 20032, 20043, 20029, 20032, 20043, 20029, 20032, 20043, 20029, 20032 },
			entryIDs = { 101479 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80664] = {
			ID = 80664,
			flags = 8,
			type = 0,
			posX = 11407,
			posY = 6302,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101480 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80663, type = 2, visualStyle = 1 }
			}
		},
		[80665] = {
			ID = 80665,
			flags = 8,
			type = 0,
			posX = 11403,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101481 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80662, type = 2, visualStyle = 1 },
				{ targetNode = 80664, type = 2, visualStyle = 1 },
				{ targetNode = 80666, type = 2, visualStyle = 1 }
			}
		},
		[80666] = {
			ID = 80666,
			flags = 8,
			type = 0,
			posX = 10803,
			posY = 6302,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101482 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80667] = {
			ID = 80667,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101483 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80666, type = 2, visualStyle = 1 },
				{ targetNode = 80669, type = 2, visualStyle = 1 }
			}
		},
		[80668] = {
			ID = 80668,
			flags = 8,
			type = 0,
			posX = 9608,
			posY = 6904,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101484 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80669] = {
			ID = 80669,
			flags = 8,
			type = 0,
			posX = 10205,
			posY = 6302,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101485 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80668, type = 2, visualStyle = 1 },
				{ targetNode = 80670, type = 2, visualStyle = 1 }
			}
		},
		[80670] = {
			ID = 80670,
			flags = 8,
			type = 0,
			posX = 10205,
			posY = 6901,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101486 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80671] = {
			ID = 80671,
			flags = 8,
			type = 0,
			posX = 14406,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101487 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80672] = {
			ID = 80672,
			flags = 8,
			type = 0,
			posX = 13806,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101488 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80605, type = 2, visualStyle = 1 },
				{ targetNode = 80671, type = 2, visualStyle = 1 }
			}
		},
		[80673] = {
			ID = 80673,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20043, 20029, 20043, 20029, 20043, 20029 },
			entryIDs = { 101489 },
			groupIDs = { 8405, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80658, type = 2, visualStyle = 1 },
				{ targetNode = 80672, type = 2, visualStyle = 1 }
			}
		},
		[80674] = {
			ID = 80674,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101490 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80673, type = 2, visualStyle = 1 }
			}
		},
		[80675] = {
			ID = 80675,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101491 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80674, type = 2, visualStyle = 1 },
				{ targetNode = 80676, type = 2, visualStyle = 1 }
			}
		},
		[80676] = {
			ID = 80676,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 20042, 20029, 20042, 20029, 20042, 20029 },
			entryIDs = { 101492 },
			groupIDs = { 8403, 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80616, type = 2, visualStyle = 1 }
			}
		},
		[80677] = {
			ID = 80677,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101493 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80620, type = 2, visualStyle = 1 },
				{ targetNode = 80620, type = 2, visualStyle = 1 },
				{ targetNode = 80675, type = 2, visualStyle = 1 },
				{ targetNode = 80676, type = 2, visualStyle = 1 }
			}
		},
		[80678] = {
			ID = 80678,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20029, 20029, 20029 },
			entryIDs = { 101494 },
			groupIDs = { 8409, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80677, type = 2, visualStyle = 1 },
				{ targetNode = 80677, type = 2, visualStyle = 1 }
			}
		},
		[80679] = {
			ID = 80679,
			flags = 8,
			type = 0,
			posX = 6022,
			posY = 2078,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101495 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80688, type = 2, visualStyle = 1 },
				{ targetNode = 80680, type = 2, visualStyle = 1 }
			}
		},
		[80680] = {
			ID = 80680,
			flags = 8,
			type = 0,
			posX = 6003,
			posY = 3906,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101496 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80685, type = 2, visualStyle = 1 },
				{ targetNode = 80681, type = 2, visualStyle = 1 }
			}
		},
		[80681] = {
			ID = 80681,
			flags = 1,
			type = 2,
			posX = 5995,
			posY = 4496,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101498, 101497 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80684, type = 2, visualStyle = 1 },
				{ targetNode = 80682, type = 2, visualStyle = 1 }
			}
		},
		[80682] = {
			ID = 80682,
			flags = 8,
			type = 0,
			posX = 5997,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101499 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80683, type = 2, visualStyle = 1 }
			}
		},
		[80683] = {
			ID = 80683,
			flags = 0,
			type = 0,
			posX = 6000,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101500 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80717, type = 2, visualStyle = 1 }
			}
		},
		[80684] = {
			ID = 80684,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 5097,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101501 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80683, type = 2, visualStyle = 1 },
				{ targetNode = 80703, type = 2, visualStyle = 1 }
			}
		},
		[80685] = {
			ID = 80685,
			flags = 9,
			type = 2,
			posX = 5402,
			posY = 4495,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101503, 101502 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80684, type = 2, visualStyle = 1 }
			}
		},
		[80686] = {
			ID = 80686,
			flags = 0,
			type = 0,
			posX = 5402,
			posY = 3907,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101504 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80705, type = 2, visualStyle = 1 },
				{ targetNode = 80685, type = 2, visualStyle = 1 }
			}
		},
		[80687] = {
			ID = 80687,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101505 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80680, type = 2, visualStyle = 1 },
				{ targetNode = 80686, type = 2, visualStyle = 1 }
			}
		},
		[80688] = {
			ID = 80688,
			flags = 0,
			type = 0,
			posX = 5404,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101506 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80706, type = 2, visualStyle = 1 },
				{ targetNode = 80687, type = 2, visualStyle = 1 }
			}
		},
		[80689] = {
			ID = 80689,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 1505,
			maxRanks = 1,
			conditionIDs = { 20040, 20040, 20040 },
			entryIDs = { 101507 },
			groupIDs = { 8404, 8411, 8415 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80693, type = 2, visualStyle = 1 },
				{ targetNode = 80606, type = 2, visualStyle = 1 },
				{ targetNode = 80679, type = 2, visualStyle = 1 },
				{ targetNode = 80688, type = 2, visualStyle = 1 },
				{ targetNode = 81633, type = 2, visualStyle = 1 },
				{ targetNode = 81634, type = 2, visualStyle = 1 }
			}
		},
		[80690] = {
			ID = 80690,
			flags = 0,
			type = 0,
			posX = 4203,
			posY = 1510,
			maxRanks = 1,
			conditionIDs = { 20030, 20030, 20030 },
			entryIDs = { 101508 },
			groupIDs = { 8406, 8411, 8415 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80693, type = 2, visualStyle = 1 }
			}
		},
		[80691] = {
			ID = 80691,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 1502,
			maxRanks = 1,
			conditionIDs = { 20033, 20033, 20033 },
			entryIDs = { 101509 },
			groupIDs = { 8407, 8411, 8415 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80712, type = 2, visualStyle = 1 },
				{ targetNode = 80693, type = 2, visualStyle = 1 },
				{ targetNode = 80711, type = 2, visualStyle = 1 },
				{ targetNode = 80692, type = 2, visualStyle = 1 }
			}
		},
		[80692] = {
			ID = 80692,
			flags = 8,
			type = 0,
			posX = 3599,
			posY = 2705,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 101510 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80695, type = 2, visualStyle = 1 }
			}
		},
		[80693] = {
			ID = 80693,
			flags = 0,
			type = 0,
			posX = 4205,
			posY = 2111,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101511 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80606, type = 2, visualStyle = 1 },
				{ targetNode = 80692, type = 2, visualStyle = 1 },
				{ targetNode = 80694, type = 2, visualStyle = 1 },
				{ targetNode = 81633, type = 2, visualStyle = 1 },
				{ targetNode = 81634, type = 2, visualStyle = 1 }
			}
		},
		[80694] = {
			ID = 80694,
			flags = 8,
			type = 0,
			posX = 4205,
			posY = 3910,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101512 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80698, type = 2, visualStyle = 1 },
				{ targetNode = 80696, type = 2, visualStyle = 1 },
				{ targetNode = 80705, type = 2, visualStyle = 1 }
			}
		},
		[80695] = {
			ID = 80695,
			flags = 8,
			type = 0,
			posX = 3597,
			posY = 3293,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101513 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80709, type = 2, visualStyle = 1 },
				{ targetNode = 80694, type = 2, visualStyle = 1 },
				{ targetNode = 80696, type = 2, visualStyle = 1 }
			}
		},
		[80696] = {
			ID = 80696,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 4506,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101514 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80697, type = 2, visualStyle = 1 },
				{ targetNode = 80697, type = 2, visualStyle = 1 }
			}
		},
		[80697] = {
			ID = 80697,
			flags = 8,
			type = 0,
			posX = 3597,
			posY = 5102,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101515 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80715, type = 2, visualStyle = 1 },
				{ targetNode = 80715, type = 2, visualStyle = 1 }
			}
		},
		[80698] = {
			ID = 80698,
			flags = 8,
			type = 0,
			posX = 4201,
			posY = 4503,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101516 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80697, type = 2, visualStyle = 1 },
				{ targetNode = 80704, type = 2, visualStyle = 1 },
				{ targetNode = 80700, type = 2, visualStyle = 1 },
				{ targetNode = 80697, type = 2, visualStyle = 1 }
			}
		},
		[80699] = {
			ID = 80699,
			flags = 0,
			type = 0,
			posX = 4203,
			posY = 5699,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101517 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {}
		},
		[80700] = {
			ID = 80700,
			flags = 0,
			type = 0,
			posX = 4200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101518 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80699, type = 2, visualStyle = 1 }
			}
		},
		[80701] = {
			ID = 80701,
			flags = 0,
			type = 0,
			posX = 4197,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101519 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {}
		},
		[80702] = {
			ID = 80702,
			flags = 0,
			type = 0,
			posX = 4203,
			posY = 6292,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101520 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80701, type = 2, visualStyle = 1 }
			}
		},
		[80703] = {
			ID = 80703,
			flags = 8,
			type = 0,
			posX = 4804,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101521 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80717, type = 2, visualStyle = 1 },
				{ targetNode = 80702, type = 2, visualStyle = 1 }
			}
		},
		[80704] = {
			ID = 80704,
			flags = 8,
			type = 0,
			posX = 4803,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101522 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80703, type = 2, visualStyle = 1 }
			}
		},
		[80705] = {
			ID = 80705,
			flags = 8,
			type = 0,
			posX = 4796,
			posY = 4506,
			maxRanks = 2,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101523 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80684, type = 2, visualStyle = 1 },
				{ targetNode = 80704, type = 2, visualStyle = 1 }
			}
		},
		[80706] = {
			ID = 80706,
			flags = 8,
			type = 0,
			posX = 4805,
			posY = 3302,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 101524 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80694, type = 2, visualStyle = 1 },
				{ targetNode = 80686, type = 2, visualStyle = 1 },
				{ targetNode = 80705, type = 2, visualStyle = 1 }
			}
		},
		[80707] = {
			ID = 80707,
			flags = 0,
			type = 0,
			posX = 2397,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101525 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80714, type = 2, visualStyle = 1 }
			}
		},
		[80708] = {
			ID = 80708,
			flags = 8,
			type = 0,
			posX = 2398,
			posY = 5102,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101526 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80707, type = 2, visualStyle = 1 }
			}
		},
		[80709] = {
			ID = 80709,
			flags = 1,
			type = 2,
			posX = 3004,
			posY = 4508,
			maxRanks = 1,
			conditionIDs = { 20031, 20031, 20031 },
			entryIDs = { 101528, 101527 },
			groupIDs = { 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80697, type = 2, visualStyle = 1 },
				{ targetNode = 80708, type = 2, visualStyle = 1 },
				{ targetNode = 80697, type = 2, visualStyle = 1 }
			}
		},
		[80710] = {
			ID = 80710,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 3301,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 101529 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80709, type = 2, visualStyle = 1 }
			}
		},
		[80711] = {
			ID = 80711,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101530 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80695, type = 2, visualStyle = 1 },
				{ targetNode = 80710, type = 2, visualStyle = 1 }
			}
		},
		[80712] = {
			ID = 80712,
			flags = 8,
			type = 0,
			posX = 2396,
			posY = 2104,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101531 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80604, type = 2, visualStyle = 1 },
				{ targetNode = 80711, type = 2, visualStyle = 1 }
			}
		},
		[80713] = {
			ID = 80713,
			flags = 0,
			type = 0,
			posX = 3000,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101532 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {}
		},
		[80714] = {
			ID = 80714,
			flags = 0,
			type = 0,
			posX = 3005,
			posY = 6307,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101533 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80713, type = 2, visualStyle = 1 }
			}
		},
		[80715] = {
			ID = 80715,
			flags = 8,
			type = 0,
			posX = 3598,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101534 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80702, type = 2, visualStyle = 1 },
				{ targetNode = 80714, type = 2, visualStyle = 1 }
			}
		},
		[80716] = {
			ID = 80716,
			flags = 0,
			type = 0,
			posX = 5397,
			posY = 6897,
			maxRanks = 1,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101535 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {}
		},
		[80717] = {
			ID = 80717,
			flags = 0,
			type = 0,
			posX = 5397,
			posY = 6292,
			maxRanks = 2,
			conditionIDs = { 20037, 20031, 20037, 20031, 20037, 20031 },
			entryIDs = { 101536 },
			groupIDs = { 8408, 8411, 8412 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80716, type = 2, visualStyle = 1 }
			}
		},
		[80718] = {
			ID = 80718,
			flags = 9,
			type = 2,
			posX = 13203,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101538, 101537 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80719] = {
			ID = 80719,
			flags = 8,
			type = 0,
			posX = 13203,
			posY = 6304,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101539 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80718, type = 2, visualStyle = 1 }
			}
		},
		[80720] = {
			ID = 80720,
			flags = 8,
			type = 0,
			posX = 11396,
			posY = 6298,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101540 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80721, type = 2, visualStyle = 1 }
			}
		},
		[80721] = {
			ID = 80721,
			flags = 8,
			type = 0,
			posX = 12004,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101541 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80722] = {
			ID = 80722,
			flags = 8,
			type = 0,
			posX = 12004,
			posY = 6304,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101542 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80721, type = 2, visualStyle = 1 }
			}
		},
		[80723] = {
			ID = 80723,
			flags = 8,
			type = 0,
			posX = 11396,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101543 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80729, type = 2, visualStyle = 1 },
				{ targetNode = 80720, type = 2, visualStyle = 1 },
				{ targetNode = 80722, type = 2, visualStyle = 1 }
			}
		},
		[80724] = {
			ID = 80724,
			flags = 8,
			type = 0,
			posX = 12004,
			posY = 5102,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101544 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80602, type = 2, visualStyle = 1 },
				{ targetNode = 80723, type = 2, visualStyle = 1 }
			}
		},
		[80725] = {
			ID = 80725,
			flags = 9,
			type = 2,
			posX = 12598,
			posY = 4501,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101546, 101545 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80635, type = 2, visualStyle = 1 },
				{ targetNode = 80633, type = 2, visualStyle = 1 },
				{ targetNode = 80724, type = 2, visualStyle = 1 }
			}
		},
		[80726] = {
			ID = 80726,
			flags = 8,
			type = 0,
			posX = 13203,
			posY = 3903,
			maxRanks = 1,
			conditionIDs = { 20042, 20039, 20042, 20039, 20042, 20039 },
			entryIDs = { 101547 },
			groupIDs = { 8403, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80628, type = 2, visualStyle = 1 },
				{ targetNode = 80632, type = 2, visualStyle = 1 },
				{ targetNode = 80725, type = 2, visualStyle = 1 }
			}
		},
		[80727] = {
			ID = 80727,
			flags = 9,
			type = 2,
			posX = 13199,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20039, 20039, 20039 },
			entryIDs = { 101549, 101548 },
			groupIDs = { 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80629, type = 2, visualStyle = 1 },
				{ targetNode = 80643, type = 2, visualStyle = 1 },
				{ targetNode = 80726, type = 2, visualStyle = 1 }
			}
		},
		[80728] = {
			ID = 80728,
			flags = 9,
			type = 2,
			posX = 10803,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101551, 101550 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {}
		},
		[80729] = {
			ID = 80729,
			flags = 9,
			type = 0,
			posX = 10803,
			posY = 6302,
			maxRanks = 1,
			conditionIDs = { 20042, 20043, 20039, 20042, 20043, 20039, 20042, 20043, 20039 },
			entryIDs = { 101552 },
			groupIDs = { 8403, 8405, 8410, 8413 },
			costs = {
				{ ID = 2777, amount = 1 }
			},
			edges = {
				{ targetNode = 80728, type = 2, visualStyle = 1 }
			}
		},
		[80937] = {
			ID = 80937,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101800, 101799 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80938] = {
			ID = 80938,
			flags = 9,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101801 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80974, type = 2, visualStyle = 1 }
			}
		},
		[80939] = {
			ID = 80939,
			flags = 9,
			type = 0,
			posX = 12000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101802 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80975, type = 2, visualStyle = 1 },
				{ targetNode = 80938, type = 2, visualStyle = 1 },
				{ targetNode = 80940, type = 2, visualStyle = 1 }
			}
		},
		[80940] = {
			ID = 80940,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101803 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80974, type = 2, visualStyle = 1 },
				{ targetNode = 80954, type = 2, visualStyle = 1 }
			}
		},
		[80941] = {
			ID = 80941,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101804 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80958, type = 2, visualStyle = 1 },
				{ targetNode = 80942, type = 2, visualStyle = 1 }
			}
		},
		[80942] = {
			ID = 80942,
			flags = 8,
			type = 0,
			posX = 12590,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101805 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80957, type = 2, visualStyle = 1 },
				{ targetNode = 80956, type = 2, visualStyle = 1 },
				{ targetNode = 80943, type = 2, visualStyle = 1 }
			}
		},
		[80943] = {
			ID = 80943,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 2400,
			maxRanks = 2,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101806 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80956, type = 2, visualStyle = 1 },
				{ targetNode = 80944, type = 2, visualStyle = 1 }
			}
		},
		[80944] = {
			ID = 80944,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101808, 101807 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80955, type = 2, visualStyle = 1 },
				{ targetNode = 80945, type = 2, visualStyle = 1 }
			}
		},
		[80945] = {
			ID = 80945,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101809 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80954, type = 2, visualStyle = 1 },
				{ targetNode = 80947, type = 2, visualStyle = 1 }
			}
		},
		[80946] = {
			ID = 80946,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101810 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80975, type = 2, visualStyle = 1 }
			}
		},
		[80947] = {
			ID = 80947,
			flags = 9,
			type = 0,
			posX = 13800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101811 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80948, type = 2, visualStyle = 1 }
			}
		},
		[80948] = {
			ID = 80948,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101812 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 92219, type = 2, visualStyle = 1 }
			}
		},
		[80949] = {
			ID = 80949,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101813 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80950] = {
			ID = 80950,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101814 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80949, type = 2, visualStyle = 1 }
			}
		},
		[80951] = {
			ID = 80951,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101815 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80953] = {
			ID = 80953,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101818 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80972, type = 2, visualStyle = 1 },
				{ targetNode = 92219, type = 2, visualStyle = 1 }
			}
		},
		[80954] = {
			ID = 80954,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101819 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80953, type = 2, visualStyle = 1 },
				{ targetNode = 92219, type = 2, visualStyle = 1 }
			}
		},
		[80955] = {
			ID = 80955,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101820 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80954, type = 2, visualStyle = 1 }
			}
		},
		[80956] = {
			ID = 80956,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101821 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80940, type = 2, visualStyle = 1 },
				{ targetNode = 80955, type = 2, visualStyle = 1 }
			}
		},
		[80957] = {
			ID = 80957,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2400,
			maxRanks = 2,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101822 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80946, type = 2, visualStyle = 1 },
				{ targetNode = 80939, type = 2, visualStyle = 1 },
				{ targetNode = 80956, type = 2, visualStyle = 1 }
			}
		},
		[80958] = {
			ID = 80958,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101823 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80946, type = 2, visualStyle = 1 },
				{ targetNode = 80957, type = 2, visualStyle = 1 },
				{ targetNode = 80969, type = 2, visualStyle = 1 }
			}
		},
		[80959] = {
			ID = 80959,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101824 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80967, type = 2, visualStyle = 1 },
				{ targetNode = 80966, type = 2, visualStyle = 1 }
			}
		},
		[80960] = {
			ID = 80960,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101825 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80965, type = 2, visualStyle = 1 }
			}
		},
		[80961] = {
			ID = 80961,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101826 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80972, type = 2, visualStyle = 1 },
				{ targetNode = 80965, type = 2, visualStyle = 1 }
			}
		},
		[80962] = {
			ID = 80962,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101827 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80963] = {
			ID = 80963,
			flags = 8,
			type = 0,
			posX = 10190,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101828 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80964] = {
			ID = 80964,
			flags = 8,
			type = 0,
			posX = 10190,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101829 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80963, type = 2, visualStyle = 1 }
			}
		},
		[80965] = {
			ID = 80965,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101830 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80962, type = 2, visualStyle = 1 },
				{ targetNode = 80964, type = 2, visualStyle = 1 }
			}
		},
		[80966] = {
			ID = 80966,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101831 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80965, type = 2, visualStyle = 1 }
			}
		},
		[80967] = {
			ID = 80967,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101832 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80960, type = 2, visualStyle = 1 },
				{ targetNode = 80961, type = 2, visualStyle = 1 },
				{ targetNode = 80966, type = 2, visualStyle = 1 }
			}
		},
		[80968] = {
			ID = 80968,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101833 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80959, type = 2, visualStyle = 1 },
				{ targetNode = 80967, type = 2, visualStyle = 1 },
				{ targetNode = 80975, type = 2, visualStyle = 1 }
			}
		},
		[80969] = {
			ID = 80969,
			flags = 8,
			type = 0,
			posX = 10790,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20084, 20084, 20084 },
			entryIDs = { 101834 },
			groupIDs = { 8441, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80946, type = 2, visualStyle = 1 },
				{ targetNode = 80968, type = 2, visualStyle = 1 }
			}
		},
		[80970] = {
			ID = 80970,
			flags = 9,
			type = 2,
			posX = 11990,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101836, 101835 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80971] = {
			ID = 80971,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101837 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80970, type = 2, visualStyle = 1 }
			}
		},
		[80972] = {
			ID = 80972,
			flags = 8,
			type = 0,
			posX = 11990,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101838 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80951, type = 2, visualStyle = 1 },
				{ targetNode = 80962, type = 2, visualStyle = 1 },
				{ targetNode = 80971, type = 2, visualStyle = 1 }
			}
		},
		[80973] = {
			ID = 80973,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101839 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80972, type = 2, visualStyle = 1 }
			}
		},
		[80974] = {
			ID = 80974,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101840 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80953, type = 2, visualStyle = 1 },
				{ targetNode = 80961, type = 2, visualStyle = 1 },
				{ targetNode = 80973, type = 2, visualStyle = 1 }
			}
		},
		[80975] = {
			ID = 80975,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20084, 20092, 20084, 20092 },
			entryIDs = { 101841 },
			groupIDs = { 8441, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80937, type = 2, visualStyle = 1 },
				{ targetNode = 80967, type = 2, visualStyle = 1 },
				{ targetNode = 80974, type = 2, visualStyle = 1 }
			}
		},
		[80976] = {
			ID = 80976,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101842 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80977] = {
			ID = 80977,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101843 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80978, type = 2, visualStyle = 1 }
			}
		},
		[80978] = {
			ID = 80978,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101845, 101844 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80979] = {
			ID = 80979,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101846 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80999, type = 2, visualStyle = 1 },
				{ targetNode = 81011, type = 2, visualStyle = 1 }
			}
		},
		[80980] = {
			ID = 80980,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101848, 101847 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80979, type = 2, visualStyle = 1 }
			}
		},
		[80981] = {
			ID = 80981,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101850, 101849 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80980, type = 2, visualStyle = 1 }
			}
		},
		[80982] = {
			ID = 80982,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101852, 101851 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80998, type = 2, visualStyle = 1 }
			}
		},
		[80983] = {
			ID = 80983,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101853 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80982, type = 2, visualStyle = 1 }
			}
		},
		[80984] = {
			ID = 80984,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101854 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80981, type = 2, visualStyle = 1 },
				{ targetNode = 80983, type = 2, visualStyle = 1 },
				{ targetNode = 80985, type = 2, visualStyle = 1 }
			}
		},
		[80985] = {
			ID = 80985,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101855 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80986, type = 2, visualStyle = 1 }
			}
		},
		[80986] = {
			ID = 80986,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101857, 101856 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80987, type = 2, visualStyle = 1 }
			}
		},
		[80987] = {
			ID = 80987,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101858 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80997, type = 2, visualStyle = 1 },
				{ targetNode = 80988, type = 2, visualStyle = 1 }
			}
		},
		[80988] = {
			ID = 80988,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101859 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80989, type = 2, visualStyle = 1 }
			}
		},
		[80989] = {
			ID = 80989,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101860 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80995, type = 2, visualStyle = 1 },
				{ targetNode = 80990, type = 2, visualStyle = 1 }
			}
		},
		[80990] = {
			ID = 80990,
			flags = 8,
			type = 0,
			posX = 9600,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101861 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80994, type = 2, visualStyle = 1 },
				{ targetNode = 80991, type = 2, visualStyle = 1 }
			}
		},
		[80991] = {
			ID = 80991,
			flags = 8,
			type = 0,
			posX = 9600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101862 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80992, type = 2, visualStyle = 1 }
			}
		},
		[80992] = {
			ID = 80992,
			flags = 9,
			type = 2,
			posX = 10200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101864, 101863 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[80993] = {
			ID = 80993,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101865 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80992, type = 2, visualStyle = 1 }
			}
		},
		[80994] = {
			ID = 80994,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101866 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80991, type = 2, visualStyle = 1 },
				{ targetNode = 80993, type = 2, visualStyle = 1 }
			}
		},
		[80995] = {
			ID = 80995,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101867 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81014, type = 2, visualStyle = 1 },
				{ targetNode = 80993, type = 2, visualStyle = 1 },
				{ targetNode = 80994, type = 2, visualStyle = 1 }
			}
		},
		[80996] = {
			ID = 80996,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101869, 101868 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80995, type = 2, visualStyle = 1 },
				{ targetNode = 81015, type = 2, visualStyle = 1 }
			}
		},
		[80997] = {
			ID = 80997,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101870 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80996, type = 2, visualStyle = 1 }
			}
		},
		[80998] = {
			ID = 80998,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20087, 20087, 20087 },
			entryIDs = { 101871 },
			groupIDs = { 8439, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81016, type = 2, visualStyle = 1 },
				{ targetNode = 80997, type = 2, visualStyle = 1 },
				{ targetNode = 80999, type = 2, visualStyle = 1 }
			}
		},
		[80999] = {
			ID = 80999,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101872 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81000, type = 2, visualStyle = 1 }
			}
		},
		[81000] = {
			ID = 81000,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101874, 101873 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81015, type = 2, visualStyle = 1 },
				{ targetNode = 81004, type = 2, visualStyle = 1 }
			}
		},
		[81001] = {
			ID = 81001,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101875 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81002] = {
			ID = 81002,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101876 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81001, type = 2, visualStyle = 1 }
			}
		},
		[81003] = {
			ID = 81003,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101878, 101877 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81013, type = 2, visualStyle = 1 },
				{ targetNode = 81007, type = 2, visualStyle = 1 },
				{ targetNode = 81002, type = 2, visualStyle = 1 }
			}
		},
		[81004] = {
			ID = 81004,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101879 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81003, type = 2, visualStyle = 1 },
				{ targetNode = 81008, type = 2, visualStyle = 1 },
				{ targetNode = 81007, type = 2, visualStyle = 1 }
			}
		},
		[81005] = {
			ID = 81005,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101880 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81006, type = 2, visualStyle = 1 }
			}
		},
		[81006] = {
			ID = 81006,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101882, 101881 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81007] = {
			ID = 81007,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101883 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81006, type = 2, visualStyle = 1 }
			}
		},
		[81008] = {
			ID = 81008,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101885, 101884 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81005, type = 2, visualStyle = 1 },
				{ targetNode = 81007, type = 2, visualStyle = 1 }
			}
		},
		[81009] = {
			ID = 81009,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101886 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81005, type = 2, visualStyle = 1 },
				{ targetNode = 81008, type = 2, visualStyle = 1 }
			}
		},
		[81010] = {
			ID = 81010,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101887 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81004, type = 2, visualStyle = 1 },
				{ targetNode = 81009, type = 2, visualStyle = 1 }
			}
		},
		[81011] = {
			ID = 81011,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101888 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81010, type = 2, visualStyle = 1 }
			}
		},
		[81012] = {
			ID = 81012,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101889 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81013] = {
			ID = 81013,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101890 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81012, type = 2, visualStyle = 1 }
			}
		},
		[81014] = {
			ID = 81014,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20094, 20087, 20092, 20094, 20087, 20092, 20094 },
			entryIDs = { 101891 },
			groupIDs = { 8439, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80977, type = 2, visualStyle = 1 },
				{ targetNode = 80993, type = 2, visualStyle = 1 },
				{ targetNode = 81013, type = 2, visualStyle = 1 }
			}
		},
		[81015] = {
			ID = 81015,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101892 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81013, type = 2, visualStyle = 1 },
				{ targetNode = 81003, type = 2, visualStyle = 1 },
				{ targetNode = 81014, type = 2, visualStyle = 1 }
			}
		},
		[81016] = {
			ID = 81016,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20087, 20092, 20087, 20092, 20087, 20092 },
			entryIDs = { 101893 },
			groupIDs = { 8439, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81000, type = 2, visualStyle = 1 },
				{ targetNode = 81015, type = 2, visualStyle = 1 }
			}
		},
		[81017] = {
			ID = 81017,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101894 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81044, type = 2, visualStyle = 1 }
			}
		},
		[81018] = {
			ID = 81018,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101895 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81048, type = 2, visualStyle = 1 },
				{ targetNode = 81019, type = 2, visualStyle = 1 }
			}
		},
		[81019] = {
			ID = 81019,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101897, 101896 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81047, type = 2, visualStyle = 1 },
				{ targetNode = 81045, type = 2, visualStyle = 1 }
			}
		},
		[81020] = {
			ID = 81020,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101898 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81033, type = 2, visualStyle = 1 },
				{ targetNode = 81019, type = 2, visualStyle = 1 }
			}
		},
		[81021] = {
			ID = 81021,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101899 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81018, type = 2, visualStyle = 1 },
				{ targetNode = 81020, type = 2, visualStyle = 1 }
			}
		},
		[81022] = {
			ID = 81022,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101900 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81021, type = 2, visualStyle = 1 },
				{ targetNode = 81023, type = 2, visualStyle = 1 }
			}
		},
		[81023] = {
			ID = 81023,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101901 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81024] = {
			ID = 81024,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101902 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81033, type = 2, visualStyle = 1 }
			}
		},
		[81025] = {
			ID = 81025,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101903 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81030, type = 2, visualStyle = 1 },
				{ targetNode = 81024, type = 2, visualStyle = 1 }
			}
		},
		[81026] = {
			ID = 81026,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101904 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81023, type = 2, visualStyle = 1 },
				{ targetNode = 81025, type = 2, visualStyle = 1 },
				{ targetNode = 81029, type = 2, visualStyle = 1 }
			}
		},
		[81027] = {
			ID = 81027,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101905 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81022, type = 2, visualStyle = 1 },
				{ targetNode = 81026, type = 2, visualStyle = 1 },
				{ targetNode = 81028, type = 2, visualStyle = 1 }
			}
		},
		[81028] = {
			ID = 81028,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 1800,
			maxRanks = 2,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101906 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81040, type = 2, visualStyle = 1 },
				{ targetNode = 81029, type = 2, visualStyle = 1 }
			}
		},
		[81029] = {
			ID = 81029,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101908, 101907 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81030, type = 2, visualStyle = 1 }
			}
		},
		[81030] = {
			ID = 81030,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3000,
			maxRanks = 2,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101909 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81033, type = 2, visualStyle = 1 },
				{ targetNode = 81031, type = 2, visualStyle = 1 }
			}
		},
		[81031] = {
			ID = 81031,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101911, 101910 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81038, type = 2, visualStyle = 1 },
				{ targetNode = 81032, type = 2, visualStyle = 1 }
			}
		},
		[81032] = {
			ID = 81032,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101912 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81044, type = 2, visualStyle = 1 },
				{ targetNode = 81037, type = 2, visualStyle = 1 }
			}
		},
		[81033] = {
			ID = 81033,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101913 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81017, type = 2, visualStyle = 1 },
				{ targetNode = 81032, type = 2, visualStyle = 1 },
				{ targetNode = 81045, type = 2, visualStyle = 1 }
			}
		},
		[81034] = {
			ID = 81034,
			flags = 9,
			type = 2,
			posX = 10200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101915, 101914 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81035] = {
			ID = 81035,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101916 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81034, type = 2, visualStyle = 1 }
			}
		},
		[81036] = {
			ID = 81036,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101917 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80976, type = 2, visualStyle = 1 },
				{ targetNode = 81035, type = 2, visualStyle = 1 }
			}
		},
		[81037] = {
			ID = 81037,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101919, 101918 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81043, type = 2, visualStyle = 1 },
				{ targetNode = 81036, type = 2, visualStyle = 1 }
			}
		},
		[81038] = {
			ID = 81038,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101920 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81036, type = 2, visualStyle = 1 },
				{ targetNode = 81037, type = 2, visualStyle = 1 }
			}
		},
		[81039] = {
			ID = 81039,
			flags = 9,
			type = 2,
			posX = 10200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101922, 101921 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81031, type = 2, visualStyle = 1 },
				{ targetNode = 81038, type = 2, visualStyle = 1 }
			}
		},
		[81040] = {
			ID = 81040,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20085, 20085, 20085 },
			entryIDs = { 101923 },
			groupIDs = { 8440, 8444 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81030, type = 2, visualStyle = 1 },
				{ targetNode = 81039, type = 2, visualStyle = 1 }
			}
		},
		[81041] = {
			ID = 81041,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101924 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81042] = {
			ID = 81042,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101926, 101925 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81043] = {
			ID = 81043,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101927 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80976, type = 2, visualStyle = 1 },
				{ targetNode = 81041, type = 2, visualStyle = 1 },
				{ targetNode = 81042, type = 2, visualStyle = 1 }
			}
		},
		[81044] = {
			ID = 81044,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101928 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81043, type = 2, visualStyle = 1 },
				{ targetNode = 81054, type = 2, visualStyle = 1 }
			}
		},
		[81045] = {
			ID = 81045,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101929 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81044, type = 2, visualStyle = 1 },
				{ targetNode = 81046, type = 2, visualStyle = 1 }
			}
		},
		[81046] = {
			ID = 81046,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101931, 101930 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81052, type = 2, visualStyle = 1 },
				{ targetNode = 81054, type = 2, visualStyle = 1 }
			}
		},
		[81047] = {
			ID = 81047,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101932 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81049, type = 2, visualStyle = 1 },
				{ targetNode = 81046, type = 2, visualStyle = 1 }
			}
		},
		[81048] = {
			ID = 81048,
			flags = 9,
			type = 2,
			posX = 14400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101934, 101933 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81047, type = 2, visualStyle = 1 },
				{ targetNode = 81049, type = 2, visualStyle = 1 }
			}
		},
		[81049] = {
			ID = 81049,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20085, 20092, 20085, 20092 },
			entryIDs = { 101935 },
			groupIDs = { 8440, 8444, 8445 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81052, type = 2, visualStyle = 1 },
				{ targetNode = 81050, type = 2, visualStyle = 1 }
			}
		},
		[81050] = {
			ID = 81050,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 6000,
			maxRanks = 2,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101936 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81051, type = 2, visualStyle = 1 }
			}
		},
		[81051] = {
			ID = 81051,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101938, 101937 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81052] = {
			ID = 81052,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101939 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81051, type = 2, visualStyle = 1 },
				{ targetNode = 81053, type = 2, visualStyle = 1 }
			}
		},
		[81053] = {
			ID = 81053,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101940 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81054] = {
			ID = 81054,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101941 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 81041, type = 2, visualStyle = 1 },
				{ targetNode = 81053, type = 2, visualStyle = 1 },
				{ targetNode = 81055, type = 2, visualStyle = 1 }
			}
		},
		[81055] = {
			ID = 81055,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20085, 20092, 20094, 20085, 20092, 20094, 20085, 20092, 20094 },
			entryIDs = { 101942 },
			groupIDs = { 8440, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {}
		},
		[81056] = {
			ID = 81056,
			flags = 9,
			type = 2,
			posX = 4200,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101944, 101943 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81071, type = 2, visualStyle = 1 }
			}
		},
		[81057] = {
			ID = 81057,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101945 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81056, type = 2, visualStyle = 1 },
				{ targetNode = 81072, type = 2, visualStyle = 1 },
				{ targetNode = 81068, type = 2, visualStyle = 1 }
			}
		},
		[81058] = {
			ID = 81058,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 2400,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 101946 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81086, type = 2, visualStyle = 1 },
				{ targetNode = 81076, type = 2, visualStyle = 1 },
				{ targetNode = 81059, type = 2, visualStyle = 1 }
			}
		},
		[81059] = {
			ID = 81059,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101947 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81086, type = 2, visualStyle = 1 }
			}
		},
		[81060] = {
			ID = 81060,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = { 20091, 20091, 20091 },
			entryIDs = { 101948 },
			groupIDs = { 8438, 8447 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81059, type = 2, visualStyle = 1 }
			}
		},
		[81061] = {
			ID = 81061,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 20091, 20086, 20091, 20086, 20091, 20086 },
			entryIDs = { 101949 },
			groupIDs = { 8438, 8447, 8449 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81074, type = 2, visualStyle = 1 },
				{ targetNode = 81058, type = 2, visualStyle = 1 },
				{ targetNode = 81060, type = 2, visualStyle = 1 }
			}
		},
		[81062] = {
			ID = 81062,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 20089, 20086, 20089, 20086, 20089, 20086 },
			entryIDs = { 101950 },
			groupIDs = { 8438, 8442, 8449 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81064, type = 2, visualStyle = 1 },
				{ targetNode = 81068, type = 2, visualStyle = 1 },
				{ targetNode = 81067, type = 2, visualStyle = 1 }
			}
		},
		[81063] = {
			ID = 81063,
			flags = 8,
			type = 0,
			posX = 1800,
			posY = 1200,
			maxRanks = 1,
			conditionIDs = { 20089, 20089, 20089 },
			entryIDs = { 101951 },
			groupIDs = { 8438, 8442 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81106, type = 2, visualStyle = 1 },
				{ targetNode = 81064, type = 2, visualStyle = 1 }
			}
		},
		[81064] = {
			ID = 81064,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101952 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81106, type = 2, visualStyle = 1 },
				{ targetNode = 81067, type = 2, visualStyle = 1 },
				{ targetNode = 81066, type = 2, visualStyle = 1 }
			}
		},
		[81065] = {
			ID = 81065,
			flags = 9,
			type = 2,
			posX = 2400,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101954, 101953 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81104, type = 2, visualStyle = 1 },
				{ targetNode = 81084, type = 2, visualStyle = 1 }
			}
		},
		[81066] = {
			ID = 81066,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101955 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81065, type = 2, visualStyle = 1 }
			}
		},
		[81067] = {
			ID = 81067,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101956 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81069, type = 2, visualStyle = 1 },
				{ targetNode = 81083, type = 2, visualStyle = 1 },
				{ targetNode = 81066, type = 2, visualStyle = 1 }
			}
		},
		[81068] = {
			ID = 81068,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101957 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81071, type = 2, visualStyle = 1 },
				{ targetNode = 81067, type = 2, visualStyle = 1 },
				{ targetNode = 81069, type = 2, visualStyle = 1 }
			}
		},
		[81069] = {
			ID = 81069,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101958 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81082, type = 2, visualStyle = 1 }
			}
		},
		[81070] = {
			ID = 81070,
			flags = 9,
			type = 2,
			posX = 4200,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101960, 101959 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81079, type = 2, visualStyle = 1 },
				{ targetNode = 81082, type = 2, visualStyle = 1 }
			}
		},
		[81071] = {
			ID = 81071,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101961 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81069, type = 2, visualStyle = 1 },
				{ targetNode = 81070, type = 2, visualStyle = 1 }
			}
		},
		[81072] = {
			ID = 81072,
			flags = 9,
			type = 2,
			posX = 4800,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101963, 101962 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81075, type = 2, visualStyle = 1 },
				{ targetNode = 81077, type = 2, visualStyle = 1 },
				{ targetNode = 81071, type = 2, visualStyle = 1 },
				{ targetNode = 81073, type = 2, visualStyle = 1 }
			}
		},
		[81073] = {
			ID = 81073,
			flags = 9,
			type = 0,
			posX = 4800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20093, 20093, 20093, 20093 },
			entryIDs = { 101964 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81079, type = 2, visualStyle = 1 },
				{ targetNode = 81076, type = 2, visualStyle = 1 }
			}
		},
		[81074] = {
			ID = 81074,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 1800,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101965 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81073, type = 2, visualStyle = 1 },
				{ targetNode = 81076, type = 2, visualStyle = 1 },
				{ targetNode = 81077, type = 2, visualStyle = 1 },
				{ targetNode = 81075, type = 2, visualStyle = 1 }
			}
		},
		[81075] = {
			ID = 81075,
			flags = 9,
			type = 0,
			posX = 4800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20083, 20083, 20083, 20083 },
			entryIDs = { 101966 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81079, type = 2, visualStyle = 1 },
				{ targetNode = 81076, type = 2, visualStyle = 1 }
			}
		},
		[81076] = {
			ID = 81076,
			flags = 9,
			type = 2,
			posX = 5400,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101968, 101967 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81079, type = 2, visualStyle = 1 },
				{ targetNode = 81086, type = 2, visualStyle = 1 }
			}
		},
		[81077] = {
			ID = 81077,
			flags = 9,
			type = 0,
			posX = 4800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = { 20090, 20090, 20090, 20090 },
			entryIDs = { 101969 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81076, type = 2, visualStyle = 1 },
				{ targetNode = 81079, type = 2, visualStyle = 1 }
			}
		},
		[81078] = {
			ID = 81078,
			flags = 9,
			type = 2,
			posX = 5400,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101971, 101970 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {}
		},
		[81079] = {
			ID = 81079,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101972 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81081, type = 2, visualStyle = 1 },
				{ targetNode = 81078, type = 2, visualStyle = 1 },
				{ targetNode = 81080, type = 2, visualStyle = 1 }
			}
		},
		[81080] = {
			ID = 81080,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101973 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81092, type = 2, visualStyle = 1 },
				{ targetNode = 81094, type = 2, visualStyle = 1 }
			}
		},
		[81081] = {
			ID = 81081,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101974 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81098, type = 2, visualStyle = 1 },
				{ targetNode = 81094, type = 2, visualStyle = 1 },
				{ targetNode = 81080, type = 2, visualStyle = 1 }
			}
		},
		[81082] = {
			ID = 81082,
			flags = 9,
			type = 2,
			posX = 3600,
			posY = 3600,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101976, 101975 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81081, type = 2, visualStyle = 1 },
				{ targetNode = 81084, type = 2, visualStyle = 1 }
			}
		},
		[81083] = {
			ID = 81083,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 101977 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81082, type = 2, visualStyle = 1 },
				{ targetNode = 81084, type = 2, visualStyle = 1 }
			}
		},
		[81084] = {
			ID = 81084,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101978 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81098, type = 2, visualStyle = 1 },
				{ targetNode = 81100, type = 2, visualStyle = 1 }
			}
		},
		[81085] = {
			ID = 81085,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 4200,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101979 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {}
		},
		[81086] = {
			ID = 81086,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 3600,
			maxRanks = 2,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101980 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81085, type = 2, visualStyle = 1 },
				{ targetNode = 81087, type = 2, visualStyle = 1 }
			}
		},
		[81087] = {
			ID = 81087,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101981 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81088, type = 2, visualStyle = 1 }
			}
		},
		[81088] = {
			ID = 81088,
			flags = 9,
			type = 2,
			posX = 6000,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101983, 101982 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81092, type = 2, visualStyle = 1 },
				{ targetNode = 81089, type = 2, visualStyle = 1 }
			}
		},
		[81089] = {
			ID = 81089,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101984 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81091, type = 2, visualStyle = 1 }
			}
		},
		[81090] = {
			ID = 81090,
			flags = 9,
			type = 2,
			posX = 6000,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101986, 101985 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {}
		},
		[81091] = {
			ID = 81091,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101987 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81090, type = 2, visualStyle = 1 }
			}
		},
		[81092] = {
			ID = 81092,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101988 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81091, type = 2, visualStyle = 1 },
				{ targetNode = 81093, type = 2, visualStyle = 1 }
			}
		},
		[81093] = {
			ID = 81093,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101989 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81095, type = 2, visualStyle = 1 }
			}
		},
		[81094] = {
			ID = 81094,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101990 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81093, type = 2, visualStyle = 1 },
				{ targetNode = 81095, type = 2, visualStyle = 1 }
			}
		},
		[81095] = {
			ID = 81095,
			flags = 9,
			type = 2,
			posX = 4200,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101992, 101991 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {}
		},
		[81096] = {
			ID = 81096,
			flags = 9,
			type = 2,
			posX = 3600,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101994, 101993 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81095, type = 2, visualStyle = 1 }
			}
		},
		[81097] = {
			ID = 81097,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101995 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81096, type = 2, visualStyle = 1 }
			}
		},
		[81098] = {
			ID = 81098,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 4800,
			maxRanks = 2,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101996 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81094, type = 2, visualStyle = 1 },
				{ targetNode = 81097, type = 2, visualStyle = 1 },
				{ targetNode = 81099, type = 2, visualStyle = 1 }
			}
		},
		[81099] = {
			ID = 81099,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101997 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {}
		},
		[81100] = {
			ID = 81100,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 4800,
			maxRanks = 1,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 101998 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81099, type = 2, visualStyle = 1 },
				{ targetNode = 81101, type = 2, visualStyle = 1 }
			}
		},
		[81101] = {
			ID = 81101,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 5400,
			maxRanks = 2,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 101999 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81103, type = 2, visualStyle = 1 },
				{ targetNode = 81102, type = 2, visualStyle = 1 }
			}
		},
		[81102] = {
			ID = 81102,
			flags = 8,
			type = 0,
			posX = 2400,
			posY = 6600,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 102000 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {}
		},
		[81103] = {
			ID = 81103,
			flags = 8,
			type = 0,
			posX = 1800,
			posY = 6000,
			maxRanks = 1,
			conditionIDs = { 20088, 20082, 20088, 20082, 20088, 20082 },
			entryIDs = { 102001 },
			groupIDs = { 8438, 8443, 8448 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81102, type = 2, visualStyle = 1 }
			}
		},
		[81104] = {
			ID = 81104,
			flags = 8,
			type = 0,
			posX = 1800,
			posY = 4200,
			maxRanks = 2,
			conditionIDs = { 20088, 20088, 20088 },
			entryIDs = { 102002 },
			groupIDs = { 8438, 8443 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81100, type = 2, visualStyle = 1 },
				{ targetNode = 81103, type = 2, visualStyle = 1 }
			}
		},
		[81105] = {
			ID = 81105,
			flags = 8,
			type = 0,
			posX = 1800,
			posY = 3000,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102003 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81104, type = 2, visualStyle = 1 }
			}
		},
		[81106] = {
			ID = 81106,
			flags = 8,
			type = 0,
			posX = 1800,
			posY = 2400,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102004 },
			groupIDs = { 8438 },
			costs = {
				{ ID = 2786, amount = 1 }
			},
			edges = {
				{ targetNode = 81066, type = 2, visualStyle = 1 },
				{ targetNode = 81105, type = 2, visualStyle = 1 }
			}
		},
		[81467] = {
			ID = 81467,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 102428 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62167, type = 2, visualStyle = 1 }
			}
		},
		[81468] = {
			ID = 81468,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 18044, 18044, 18044 },
			entryIDs = { 102429 },
			groupIDs = { 7136, 7140 },
			costs = {
				{ ID = 2516, amount = 1 }
			},
			edges = {
				{ targetNode = 62181, type = 2, visualStyle = 1 }
			}
		},
		[81469] = {
			ID = 81469,
			flags = 1,
			type = 2,
			posX = 11998,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102431, 102430 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81487, type = 2, visualStyle = 1 },
				{ targetNode = 81489, type = 2, visualStyle = 1 }
			}
		},
		[81470] = {
			ID = 81470,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102432 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81503, type = 2, visualStyle = 1 },
				{ targetNode = 81493, type = 2, visualStyle = 1 }
			}
		},
		[81471] = {
			ID = 81471,
			flags = 0,
			type = 0,
			posX = 10798,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102433 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81472, type = 2, visualStyle = 1 }
			}
		},
		[81472] = {
			ID = 81472,
			flags = 1,
			type = 2,
			posX = 11397,
			posY = 5697,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102435, 102434 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81482, type = 2, visualStyle = 1 }
			}
		},
		[81473] = {
			ID = 81473,
			flags = 0,
			type = 0,
			posX = 13199,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102436 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81480, type = 2, visualStyle = 1 }
			}
		},
		[81474] = {
			ID = 81474,
			flags = 1,
			type = 0,
			posX = 11397,
			posY = 4498,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102437 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81488, type = 2, visualStyle = 1 },
				{ targetNode = 81471, type = 2, visualStyle = 1 }
			}
		},
		[81475] = {
			ID = 81475,
			flags = 0,
			type = 0,
			posX = 13199,
			posY = 4498,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102438 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81473, type = 2, visualStyle = 1 },
				{ targetNode = 81490, type = 2, visualStyle = 1 }
			}
		},
		[81476] = {
			ID = 81476,
			flags = 0,
			type = 0,
			posX = 11998,
			posY = 3302,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102439 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81499, type = 2, visualStyle = 1 }
			}
		},
		[81477] = {
			ID = 81477,
			flags = 0,
			type = 0,
			posX = 13198,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102440 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81496, type = 2, visualStyle = 1 },
				{ targetNode = 81504, type = 2, visualStyle = 1 }
			}
		},
		[81479] = {
			ID = 81479,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102443, 102442 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81480] = {
			ID = 81480,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102444 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81496, type = 2, visualStyle = 1 }
			}
		},
		[81481] = {
			ID = 81481,
			flags = 0,
			type = 0,
			posX = 12596,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102445 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81499, type = 2, visualStyle = 1 },
				{ targetNode = 81503, type = 2, visualStyle = 1 },
				{ targetNode = 90062, type = 2, visualStyle = 1 }
			}
		},
		[81482] = {
			ID = 81482,
			flags = 0,
			type = 0,
			posX = 11398,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102446 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81505, type = 2, visualStyle = 1 }
			}
		},
		[81483] = {
			ID = 81483,
			flags = 9,
			type = 2,
			posX = 12596,
			posY = 4498,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102448, 102447 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81490, type = 2, visualStyle = 1 }
			}
		},
		[81484] = {
			ID = 81484,
			flags = 8,
			type = 0,
			posX = 11997,
			posY = 5697,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102449 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81495, type = 2, visualStyle = 1 },
				{ targetNode = 81482, type = 2, visualStyle = 1 }
			}
		},
		[81485] = {
			ID = 81485,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4498,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102450 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81500, type = 2, visualStyle = 1 },
				{ targetNode = 81473, type = 2, visualStyle = 1 }
			}
		},
		[81486] = {
			ID = 81486,
			flags = 9,
			type = 2,
			posX = 10799,
			posY = 3901,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20144, 20152, 20144, 20152 },
			entryIDs = { 102452, 102451 },
			groupIDs = { 8477, 8478, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81471, type = 2, visualStyle = 1 },
				{ targetNode = 81474, type = 2, visualStyle = 1 }
			}
		},
		[81487] = {
			ID = 81487,
			flags = 0,
			type = 0,
			posX = 12596,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102453 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81476, type = 2, visualStyle = 1 },
				{ targetNode = 81481, type = 2, visualStyle = 1 },
				{ targetNode = 81501, type = 2, visualStyle = 1 }
			}
		},
		[81488] = {
			ID = 81488,
			flags = 8,
			type = 0,
			posX = 11998,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102454 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81472, type = 2, visualStyle = 1 }
			}
		},
		[81489] = {
			ID = 81489,
			flags = 0,
			type = 0,
			posX = 11398,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102455 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81492, type = 2, visualStyle = 1 }
			}
		},
		[81490] = {
			ID = 81490,
			flags = 0,
			type = 0,
			posX = 12596,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102456 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81484, type = 2, visualStyle = 1 },
				{ targetNode = 81477, type = 2, visualStyle = 1 },
				{ targetNode = 81497, type = 2, visualStyle = 1 }
			}
		},
		[81491] = {
			ID = 81491,
			flags = 1,
			type = 0,
			posX = 12596,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102457 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81492] = {
			ID = 81492,
			flags = 9,
			type = 2,
			posX = 11398,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102459, 102458 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81499, type = 2, visualStyle = 1 },
				{ targetNode = 81486, type = 2, visualStyle = 1 }
			}
		},
		[81493] = {
			ID = 81493,
			flags = 9,
			type = 2,
			posX = 14398,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102461, 102460 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81485, type = 2, visualStyle = 1 },
				{ targetNode = 81500, type = 2, visualStyle = 1 }
			}
		},
		[81494] = {
			ID = 81494,
			flags = 1,
			type = 2,
			posX = 13200,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102463, 102462 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81498, type = 2, visualStyle = 1 },
				{ targetNode = 81487, type = 2, visualStyle = 1 }
			}
		},
		[81495] = {
			ID = 81495,
			flags = 8,
			type = 0,
			posX = 11998,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102464 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81491, type = 2, visualStyle = 1 }
			}
		},
		[81496] = {
			ID = 81496,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102465 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81479, type = 2, visualStyle = 1 }
			}
		},
		[81497] = {
			ID = 81497,
			flags = 0,
			type = 0,
			posX = 12595,
			posY = 5697,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102466 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81504, type = 2, visualStyle = 1 },
				{ targetNode = 81495, type = 2, visualStyle = 1 },
				{ targetNode = 81491, type = 2, visualStyle = 1 }
			}
		},
		[81498] = {
			ID = 81498,
			flags = 0,
			type = 0,
			posX = 13800,
			posY = 2699,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102467 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81470, type = 2, visualStyle = 1 }
			}
		},
		[81499] = {
			ID = 81499,
			flags = 0,
			type = 0,
			posX = 11998,
			posY = 3897,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102468 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81474, type = 2, visualStyle = 1 },
				{ targetNode = 81506, type = 2, visualStyle = 1 },
				{ targetNode = 81483, type = 2, visualStyle = 1 }
			}
		},
		[81500] = {
			ID = 81500,
			flags = 8,
			type = 0,
			posX = 14398,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102469 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81480, type = 2, visualStyle = 1 }
			}
		},
		[81501] = {
			ID = 81501,
			flags = 8,
			type = 0,
			posX = 13199,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102470 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81503, type = 2, visualStyle = 1 }
			}
		},
		[81502] = {
			ID = 81502,
			flags = 0,
			type = 0,
			posX = 12596,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20144, 20157, 20144, 20157, 20144, 20157 },
			entryIDs = { 102471 },
			groupIDs = { 8477, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81469, type = 2, visualStyle = 1 },
				{ targetNode = 81494, type = 2, visualStyle = 1 }
			}
		},
		[81503] = {
			ID = 81503,
			flags = 8,
			type = 0,
			posX = 13199,
			posY = 3897,
			maxRanks = 2,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102472 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81485, type = 2, visualStyle = 1 },
				{ targetNode = 81475, type = 2, visualStyle = 1 },
				{ targetNode = 81483, type = 2, visualStyle = 1 }
			}
		},
		[81504] = {
			ID = 81504,
			flags = 0,
			type = 0,
			posX = 13199,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102473 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81491, type = 2, visualStyle = 1 }
			}
		},
		[81505] = {
			ID = 81505,
			flags = 1,
			type = 0,
			posX = 11397,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157, 20144, 20152, 20150, 20157 },
			entryIDs = { 102474 },
			groupIDs = { 8477, 8478, 8481, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81506] = {
			ID = 81506,
			flags = 8,
			type = 0,
			posX = 11998,
			posY = 4498,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20157, 20144, 20152, 20157, 20144, 20152, 20157 },
			entryIDs = { 102475 },
			groupIDs = { 8477, 8478, 8485, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81488, type = 2, visualStyle = 1 },
				{ targetNode = 81490, type = 2, visualStyle = 1 }
			}
		},
		[81507] = {
			ID = 81507,
			flags = 8,
			type = 0,
			posX = 2998,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20146, 20145, 20146, 20145, 20146, 20145, 20146, 20145 },
			entryIDs = { 102476 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81609, type = 2, visualStyle = 1 },
				{ targetNode = 81610, type = 2, visualStyle = 1 }
			}
		},
		[81508] = {
			ID = 81508,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20147, 20147, 20147, 20147 },
			entryIDs = { 102477 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81609, type = 2, visualStyle = 1 },
				{ targetNode = 81610, type = 2, visualStyle = 1 }
			}
		},
		[81509] = {
			ID = 81509,
			flags = 9,
			type = 0,
			posX = 6597,
			posY = 5696,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102478 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81626, type = 2, visualStyle = 1 }
			}
		},
		[81510] = {
			ID = 81510,
			flags = 0,
			type = 0,
			posX = 5997,
			posY = 1495,
			maxRanks = 1,
			conditionIDs = { 20156, 20156, 20156 },
			entryIDs = { 102479 },
			groupIDs = { 8480, 8486 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81601, type = 2, visualStyle = 1 },
				{ targetNode = 81602, type = 2, visualStyle = 1 }
			}
		},
		[81511] = {
			ID = 81511,
			flags = 8,
			type = 0,
			posX = 12595,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102480 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81512] = {
			ID = 81512,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102481 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81513] = {
			ID = 81513,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102482 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81521, type = 2, visualStyle = 1 }
			}
		},
		[81514] = {
			ID = 81514,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6900,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102483 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81515] = {
			ID = 81515,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102484 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81514, type = 2, visualStyle = 1 }
			}
		},
		[81516] = {
			ID = 81516,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102485 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81549, type = 2, visualStyle = 1 },
				{ targetNode = 81515, type = 2, visualStyle = 1 }
			}
		},
		[81517] = {
			ID = 81517,
			flags = 9,
			type = 2,
			posX = 14400,
			posY = 5099,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102487, 102486 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81516, type = 2, visualStyle = 1 }
			}
		},
		[81518] = {
			ID = 81518,
			flags = 8,
			type = 0,
			posX = 15000,
			posY = 4498,
			maxRanks = 2,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102488 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81517, type = 2, visualStyle = 1 }
			}
		},
		[81519] = {
			ID = 81519,
			flags = 9,
			type = 0,
			posX = 14400,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102489 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81518, type = 2, visualStyle = 1 },
				{ targetNode = 81552, type = 2, visualStyle = 1 }
			}
		},
		[81520] = {
			ID = 81520,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102490 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81552, type = 2, visualStyle = 1 }
			}
		},
		[81521] = {
			ID = 81521,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102491 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81553, type = 2, visualStyle = 1 },
				{ targetNode = 81519, type = 2, visualStyle = 1 },
				{ targetNode = 81520, type = 2, visualStyle = 1 }
			}
		},
		[81522] = {
			ID = 81522,
			flags = 9,
			type = 0,
			posX = 13200,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102492 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81523] = {
			ID = 81523,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102494, 102493 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81524] = {
			ID = 81524,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102495 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81522, type = 2, visualStyle = 1 },
				{ targetNode = 81523, type = 2, visualStyle = 1 },
				{ targetNode = 81525, type = 2, visualStyle = 1 }
			}
		},
		[81525] = {
			ID = 81525,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102497, 102496 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81551, type = 2, visualStyle = 1 },
				{ targetNode = 81541, type = 2, visualStyle = 1 }
			}
		},
		[81526] = {
			ID = 81526,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102498 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81547, type = 2, visualStyle = 1 },
				{ targetNode = 81529, type = 2, visualStyle = 1 }
			}
		},
		[81527] = {
			ID = 81527,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102499 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81528] = {
			ID = 81528,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102500 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81532, type = 2, visualStyle = 1 },
				{ targetNode = 81545, type = 2, visualStyle = 1 }
			}
		},
		[81529] = {
			ID = 81529,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102501 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81527, type = 2, visualStyle = 1 },
				{ targetNode = 81528, type = 2, visualStyle = 1 },
				{ targetNode = 81530, type = 2, visualStyle = 1 }
			}
		},
		[81530] = {
			ID = 81530,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102502 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81532, type = 2, visualStyle = 1 }
			}
		},
		[81531] = {
			ID = 81531,
			flags = 9,
			type = 0,
			posX = 11400,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102503 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81543, type = 2, visualStyle = 1 }
			}
		},
		[81532] = {
			ID = 81532,
			flags = 9,
			type = 0,
			posX = 11400,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102504 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81544, type = 2, visualStyle = 1 },
				{ targetNode = 81531, type = 2, visualStyle = 1 },
				{ targetNode = 81533, type = 2, visualStyle = 1 }
			}
		},
		[81533] = {
			ID = 81533,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102505 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81543, type = 2, visualStyle = 1 },
				{ targetNode = 81534, type = 2, visualStyle = 1 }
			}
		},
		[81534] = {
			ID = 81534,
			flags = 9,
			type = 0,
			posX = 10200,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102506 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81535, type = 2, visualStyle = 1 }
			}
		},
		[81535] = {
			ID = 81535,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102508, 102507 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81540, type = 2, visualStyle = 1 }
			}
		},
		[81536] = {
			ID = 81536,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102510, 102509 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81537] = {
			ID = 81537,
			flags = 9,
			type = 0,
			posX = 11400,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102511 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81536, type = 2, visualStyle = 1 }
			}
		},
		[81538] = {
			ID = 81538,
			flags = 9,
			type = 0,
			posX = 12000,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102512 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81539] = {
			ID = 81539,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102513 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81538, type = 2, visualStyle = 1 }
			}
		},
		[81540] = {
			ID = 81540,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102514 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81537, type = 2, visualStyle = 1 },
				{ targetNode = 81539, type = 2, visualStyle = 1 }
			}
		},
		[81541] = {
			ID = 81541,
			flags = 9,
			type = 0,
			posX = 12000,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102515 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81550, type = 2, visualStyle = 1 },
				{ targetNode = 81540, type = 2, visualStyle = 1 }
			}
		},
		[81542] = {
			ID = 81542,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102516 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81543] = {
			ID = 81543,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102518, 102517 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81535, type = 2, visualStyle = 1 },
				{ targetNode = 81541, type = 2, visualStyle = 1 },
				{ targetNode = 81542, type = 2, visualStyle = 1 }
			}
		},
		[81544] = {
			ID = 81544,
			flags = 9,
			type = 0,
			posX = 12000,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102519 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81543, type = 2, visualStyle = 1 }
			}
		},
		[81545] = {
			ID = 81545,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102521, 102520 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81553, type = 2, visualStyle = 1 },
				{ targetNode = 81524, type = 2, visualStyle = 1 },
				{ targetNode = 81544, type = 2, visualStyle = 1 }
			}
		},
		[81546] = {
			ID = 81546,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102522 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81521, type = 2, visualStyle = 1 },
				{ targetNode = 81545, type = 2, visualStyle = 1 }
			}
		},
		[81547] = {
			ID = 81547,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20148, 22786, 20148, 22786, 20148, 22786 },
			entryIDs = { 102523 },
			groupIDs = { 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81513, type = 2, visualStyle = 1 },
				{ targetNode = 81527, type = 2, visualStyle = 1 },
				{ targetNode = 81546, type = 2, visualStyle = 1 }
			}
		},
		[81548] = {
			ID = 81548,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102524 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81549] = {
			ID = 81549,
			flags = 9,
			type = 0,
			posX = 13200,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102525 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81548, type = 2, visualStyle = 1 }
			}
		},
		[81550] = {
			ID = 81550,
			flags = 8,
			type = 0,
			posX = 12599,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786, 20152, 20150, 20148, 22786 },
			entryIDs = { 102526 },
			groupIDs = { 8478, 8481, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81511, type = 2, visualStyle = 1 },
				{ targetNode = 81539, type = 2, visualStyle = 1 },
				{ targetNode = 81549, type = 2, visualStyle = 1 }
			}
		},
		[81551] = {
			ID = 81551,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 5098,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102528, 102527 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81516, type = 2, visualStyle = 1 },
				{ targetNode = 81550, type = 2, visualStyle = 1 }
			}
		},
		[81552] = {
			ID = 81552,
			flags = 9,
			type = 2,
			posX = 13800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102530, 102529 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81512, type = 2, visualStyle = 1 },
				{ targetNode = 81517, type = 2, visualStyle = 1 },
				{ targetNode = 81551, type = 2, visualStyle = 1 }
			}
		},
		[81553] = {
			ID = 81553,
			flags = 9,
			type = 0,
			posX = 13200,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20152, 20148, 22786, 20152, 20148, 22786, 20152, 20148, 22786 },
			entryIDs = { 102531 },
			groupIDs = { 8478, 8487, 8489, 9081 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81552, type = 2, visualStyle = 1 }
			}
		},
		[81554] = {
			ID = 81554,
			flags = 9,
			type = 2,
			posX = 11399,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102533, 102532 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81594, type = 2, visualStyle = 1 }
			}
		},
		[81555] = {
			ID = 81555,
			flags = 8,
			type = 0,
			posX = 12599,
			posY = 1498,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102534 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81569, type = 2, visualStyle = 1 },
				{ targetNode = 81565, type = 2, visualStyle = 1 }
			}
		},
		[81556] = {
			ID = 81556,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102535 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81585, type = 2, visualStyle = 1 }
			}
		},
		[81557] = {
			ID = 81557,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102536 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81586, type = 2, visualStyle = 1 },
				{ targetNode = 81561, type = 2, visualStyle = 1 },
				{ targetNode = 81556, type = 2, visualStyle = 1 }
			}
		},
		[81558] = {
			ID = 81558,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 5699,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102537 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81588, type = 2, visualStyle = 1 }
			}
		},
		[81559] = {
			ID = 81559,
			flags = 8,
			type = 0,
			posX = 15000,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102538 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81588, type = 2, visualStyle = 1 }
			}
		},
		[81560] = {
			ID = 81560,
			flags = 8,
			type = 0,
			posX = 15000,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102539 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81558, type = 2, visualStyle = 1 },
				{ targetNode = 81559, type = 2, visualStyle = 1 }
			}
		},
		[81561] = {
			ID = 81561,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102540 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81560, type = 2, visualStyle = 1 },
				{ targetNode = 81585, type = 2, visualStyle = 1 }
			}
		},
		[81562] = {
			ID = 81562,
			flags = 0,
			type = 0,
			posX = 14400,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102541 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81561, type = 2, visualStyle = 1 }
			}
		},
		[81563] = {
			ID = 81563,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102542 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81580, type = 2, visualStyle = 1 }
			}
		},
		[81564] = {
			ID = 81564,
			flags = 9,
			type = 2,
			posX = 13798,
			posY = 2696,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102544, 102543 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81557, type = 2, visualStyle = 1 },
				{ targetNode = 81562, type = 2, visualStyle = 1 },
				{ targetNode = 81575, type = 2, visualStyle = 1 }
			}
		},
		[81565] = {
			ID = 81565,
			flags = 8,
			type = 0,
			posX = 13198,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102545 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81564, type = 2, visualStyle = 1 },
				{ targetNode = 81568, type = 2, visualStyle = 1 }
			}
		},
		[81566] = {
			ID = 81566,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102547, 102546 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81574, type = 2, visualStyle = 1 },
				{ targetNode = 81586, type = 2, visualStyle = 1 }
			}
		},
		[81567] = {
			ID = 81567,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102548 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81566, type = 2, visualStyle = 1 }
			}
		},
		[81568] = {
			ID = 81568,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102549 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81567, type = 2, visualStyle = 1 }
			}
		},
		[81569] = {
			ID = 81569,
			flags = 8,
			type = 0,
			posX = 11998,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102550 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81568, type = 2, visualStyle = 1 },
				{ targetNode = 81572, type = 2, visualStyle = 1 }
			}
		},
		[81570] = {
			ID = 81570,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102551 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81577, type = 2, visualStyle = 1 },
				{ targetNode = 81578, type = 2, visualStyle = 1 }
			}
		},
		[81571] = {
			ID = 81571,
			flags = 9,
			type = 2,
			posX = 10799,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102553, 102552 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81570, type = 2, visualStyle = 1 }
			}
		},
		[81572] = {
			ID = 81572,
			flags = 9,
			type = 2,
			posX = 11399,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102555, 102554 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81576, type = 2, visualStyle = 1 },
				{ targetNode = 81571, type = 2, visualStyle = 1 },
				{ targetNode = 81573, type = 2, visualStyle = 1 }
			}
		},
		[81573] = {
			ID = 81573,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102556 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81574, type = 2, visualStyle = 1 }
			}
		},
		[81574] = {
			ID = 81574,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102557 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81580, type = 2, visualStyle = 1 },
				{ targetNode = 81583, type = 2, visualStyle = 1 }
			}
		},
		[81575] = {
			ID = 81575,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20154, 20154, 20154 },
			entryIDs = { 102558 },
			groupIDs = { 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81586, type = 2, visualStyle = 1 }
			}
		},
		[81576] = {
			ID = 81576,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102559 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81574, type = 2, visualStyle = 1 },
				{ targetNode = 81577, type = 2, visualStyle = 1 },
				{ targetNode = 81563, type = 2, visualStyle = 1 }
			}
		},
		[81577] = {
			ID = 81577,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102561, 102560 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81580, type = 2, visualStyle = 1 },
				{ targetNode = 81578, type = 2, visualStyle = 1 }
			}
		},
		[81578] = {
			ID = 81578,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102562 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81579, type = 2, visualStyle = 1 }
			}
		},
		[81579] = {
			ID = 81579,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102563 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81594, type = 2, visualStyle = 1 },
				{ targetNode = 81596, type = 2, visualStyle = 1 }
			}
		},
		[81580] = {
			ID = 81580,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102564 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81554, type = 2, visualStyle = 1 },
				{ targetNode = 81579, type = 2, visualStyle = 1 },
				{ targetNode = 81581, type = 2, visualStyle = 1 }
			}
		},
		[81581] = {
			ID = 81581,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102565 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81594, type = 2, visualStyle = 1 },
				{ targetNode = 81592, type = 2, visualStyle = 1 }
			}
		},
		[81582] = {
			ID = 81582,
			flags = 8,
			type = 0,
			posX = 12599,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102566 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81592, type = 2, visualStyle = 1 }
			}
		},
		[81583] = {
			ID = 81583,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102567 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81581, type = 2, visualStyle = 1 },
				{ targetNode = 81582, type = 2, visualStyle = 1 },
				{ targetNode = 81584, type = 2, visualStyle = 1 }
			}
		},
		[81584] = {
			ID = 81584,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102569, 102568 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81592, type = 2, visualStyle = 1 },
				{ targetNode = 81590, type = 2, visualStyle = 1 }
			}
		},
		[81585] = {
			ID = 81585,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102570 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81589, type = 2, visualStyle = 1 },
				{ targetNode = 81558, type = 2, visualStyle = 1 },
				{ targetNode = 81584, type = 2, visualStyle = 1 }
			}
		},
		[81586] = {
			ID = 81586,
			flags = 8,
			type = 0,
			posX = 13200,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20152, 20154, 20152, 20154, 20152, 20154 },
			entryIDs = { 102571 },
			groupIDs = { 8478, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81583, type = 2, visualStyle = 1 },
				{ targetNode = 81585, type = 2, visualStyle = 1 }
			}
		},
		[81587] = {
			ID = 81587,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102572 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81588] = {
			ID = 81588,
			flags = 8,
			type = 0,
			posX = 14400,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102573 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81587, type = 2, visualStyle = 1 }
			}
		},
		[81589] = {
			ID = 81589,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 5699,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102574 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81588, type = 2, visualStyle = 1 },
				{ targetNode = 81590, type = 2, visualStyle = 1 }
			}
		},
		[81590] = {
			ID = 81590,
			flags = 8,
			type = 0,
			posX = 13800,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102575 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81591, type = 2, visualStyle = 1 }
			}
		},
		[81591] = {
			ID = 81591,
			flags = 9,
			type = 2,
			posX = 13199,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102577, 102576 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81592] = {
			ID = 81592,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102578 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81591, type = 2, visualStyle = 1 },
				{ targetNode = 81593, type = 2, visualStyle = 1 }
			}
		},
		[81593] = {
			ID = 81593,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102579 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81594] = {
			ID = 81594,
			flags = 8,
			type = 0,
			posX = 11399,
			posY = 6299,
			maxRanks = 2,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102580 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81593, type = 2, visualStyle = 1 },
				{ targetNode = 81595, type = 2, visualStyle = 1 }
			}
		},
		[81595] = {
			ID = 81595,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102581 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {}
		},
		[81596] = {
			ID = 81596,
			flags = 8,
			type = 0,
			posX = 10200,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20152, 20150, 20154, 20152, 20150, 20154, 20152, 20150, 20154 },
			entryIDs = { 102582 },
			groupIDs = { 8478, 8481, 8484, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81595, type = 2, visualStyle = 1 }
			}
		},
		[81597] = {
			ID = 81597,
			flags = 0,
			type = 0,
			posX = 3596,
			posY = 1495,
			maxRanks = 1,
			conditionIDs = { 20149, 20157, 20159, 20149, 20157, 20159, 20149, 20157, 20159 },
			entryIDs = { 102583 },
			groupIDs = { 8479, 8480, 8485, 8488 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81599, type = 2, visualStyle = 1 },
				{ targetNode = 81598, type = 2, visualStyle = 1 }
			}
		},
		[81598] = {
			ID = 81598,
			flags = 1,
			type = 2,
			posX = 3596,
			posY = 2696,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102585, 102584 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81507, type = 2, visualStyle = 1 },
				{ targetNode = 81508, type = 2, visualStyle = 1 },
				{ targetNode = 81609, type = 2, visualStyle = 1 }
			}
		},
		[81599] = {
			ID = 81599,
			flags = 0,
			type = 0,
			posX = 4196,
			posY = 2096,
			maxRanks = 1,
			conditionIDs = { 20149, 20157, 20159, 20149, 20157, 20159, 20149, 20157, 20159 },
			entryIDs = { 102586 },
			groupIDs = { 8479, 8480, 8485, 8488 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81598, type = 2, visualStyle = 1 },
				{ targetNode = 81632, type = 2, visualStyle = 1 }
			}
		},
		[81600] = {
			ID = 81600,
			flags = 0,
			type = 0,
			posX = 4795,
			posY = 1496,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102587 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81632, type = 2, visualStyle = 1 },
				{ targetNode = 81599, type = 2, visualStyle = 1 },
				{ targetNode = 81601, type = 2, visualStyle = 1 }
			}
		},
		[81601] = {
			ID = 81601,
			flags = 0,
			type = 0,
			posX = 5395,
			posY = 2096,
			maxRanks = 1,
			conditionIDs = { 20156, 20156, 20156 },
			entryIDs = { 102588 },
			groupIDs = { 8480, 8486 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81632, type = 2, visualStyle = 1 },
				{ targetNode = 81602, type = 2, visualStyle = 1 }
			}
		},
		[81602] = {
			ID = 81602,
			flags = 0,
			type = 0,
			posX = 5997,
			posY = 2696,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 102589 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81630, type = 2, visualStyle = 1 },
				{ targetNode = 81603, type = 2, visualStyle = 1 },
				{ targetNode = 92220, type = 2, visualStyle = 1 }
			}
		},
		[81603] = {
			ID = 81603,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22872, 22871, 22872, 22871, 22872, 22871, 22872, 22871 },
			entryIDs = { 102590 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81630, type = 2, visualStyle = 1 },
				{ targetNode = 81604, type = 2, visualStyle = 1 }
			}
		},
		[81604] = {
			ID = 81604,
			flags = 0,
			type = 0,
			posX = 6597,
			posY = 3896,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102591 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81629, type = 2, visualStyle = 1 }
			}
		},
		[81605] = {
			ID = 81605,
			flags = 0,
			type = 0,
			posX = 4196,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102592 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81609, type = 2, visualStyle = 1 },
				{ targetNode = 81606, type = 2, visualStyle = 1 }
			}
		},
		[81606] = {
			ID = 81606,
			flags = 0,
			type = 0,
			posX = 4795,
			posY = 3895,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102593 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81616, type = 2, visualStyle = 1 },
				{ targetNode = 81614, type = 2, visualStyle = 1 }
			}
		},
		[81607] = {
			ID = 81607,
			flags = 1,
			type = 2,
			posX = 4196,
			posY = 5095,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102595, 102594 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81622, type = 2, visualStyle = 1 },
				{ targetNode = 81618, type = 2, visualStyle = 1 }
			}
		},
		[81608] = {
			ID = 81608,
			flags = 0,
			type = 0,
			posX = 3596,
			posY = 4496,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102596 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81613, type = 2, visualStyle = 1 }
			}
		},
		[81609] = {
			ID = 81609,
			flags = 8,
			type = 0,
			posX = 3596,
			posY = 3896,
			maxRanks = 2,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102597 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81608, type = 2, visualStyle = 1 },
				{ targetNode = 81614, type = 2, visualStyle = 1 },
				{ targetNode = 81610, type = 2, visualStyle = 1 }
			}
		},
		[81610] = {
			ID = 81610,
			flags = 8,
			type = 0,
			posX = 2996,
			posY = 4496,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102598 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81613, type = 2, visualStyle = 1 },
				{ targetNode = 81611, type = 2, visualStyle = 1 }
			}
		},
		[81611] = {
			ID = 81611,
			flags = 8,
			type = 0,
			posX = 2996,
			posY = 5096,
			maxRanks = 2,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102599 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81612, type = 2, visualStyle = 1 }
			}
		},
		[81612] = {
			ID = 81612,
			flags = 8,
			type = 0,
			posX = 2996,
			posY = 5696,
			maxRanks = 2,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102600 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81624, type = 2, visualStyle = 1 }
			}
		},
		[81613] = {
			ID = 81613,
			flags = 9,
			type = 0,
			posX = 3596,
			posY = 5096,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102601 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81612, type = 2, visualStyle = 1 },
				{ targetNode = 81622, type = 2, visualStyle = 1 }
			}
		},
		[81614] = {
			ID = 81614,
			flags = 0,
			type = 0,
			posX = 4196,
			posY = 4497,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102602 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81607, type = 2, visualStyle = 1 },
				{ targetNode = 81613, type = 2, visualStyle = 1 },
				{ targetNode = 81615, type = 2, visualStyle = 1 }
			}
		},
		[81615] = {
			ID = 81615,
			flags = 0,
			type = 0,
			posX = 4795,
			posY = 5095,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102603 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81618, type = 2, visualStyle = 1 }
			}
		},
		[81616] = {
			ID = 81616,
			flags = 1,
			type = 0,
			posX = 5395,
			posY = 4497,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102604 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81628, type = 2, visualStyle = 1 },
				{ targetNode = 81615, type = 2, visualStyle = 1 },
				{ targetNode = 81617, type = 2, visualStyle = 1 }
			}
		},
		[81617] = {
			ID = 81617,
			flags = 8,
			type = 0,
			posX = 5395,
			posY = 5096,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102606 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81627, type = 2, visualStyle = 1 },
				{ targetNode = 81618, type = 2, visualStyle = 1 }
			}
		},
		[81618] = {
			ID = 81618,
			flags = 9,
			type = 2,
			posX = 4795,
			posY = 5692,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102608, 102607 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81621, type = 2, visualStyle = 1 },
				{ targetNode = 81619, type = 2, visualStyle = 1 }
			}
		},
		[81619] = {
			ID = 81619,
			flags = 8,
			type = 0,
			posX = 5395,
			posY = 6297,
			maxRanks = 2,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102609 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81620, type = 2, visualStyle = 1 }
			}
		},
		[81620] = {
			ID = 81620,
			flags = 1,
			type = 2,
			posX = 4796,
			posY = 6897,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102611, 102610 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {}
		},
		[81621] = {
			ID = 81621,
			flags = 8,
			type = 0,
			posX = 4195,
			posY = 6297,
			maxRanks = 2,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102612 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81620, type = 2, visualStyle = 1 }
			}
		},
		[81622] = {
			ID = 81622,
			flags = 8,
			type = 0,
			posX = 3595,
			posY = 5692,
			maxRanks = 2,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102613 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81621, type = 2, visualStyle = 1 },
				{ targetNode = 81624, type = 2, visualStyle = 1 }
			}
		},
		[81623] = {
			ID = 81623,
			flags = 8,
			type = 0,
			posX = 3596,
			posY = 6897,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102614 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {}
		},
		[81624] = {
			ID = 81624,
			flags = 0,
			type = 0,
			posX = 3596,
			posY = 6297,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102615 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81623, type = 2, visualStyle = 1 }
			}
		},
		[81625] = {
			ID = 81625,
			flags = 8,
			type = 0,
			posX = 5997,
			posY = 6897,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102616 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {}
		},
		[81626] = {
			ID = 81626,
			flags = 8,
			type = 0,
			posX = 5997,
			posY = 6297,
			maxRanks = 2,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102617 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81625, type = 2, visualStyle = 1 }
			}
		},
		[81627] = {
			ID = 81627,
			flags = 9,
			type = 0,
			posX = 5997,
			posY = 5696,
			maxRanks = 1,
			conditionIDs = { 20153, 20155, 20153, 20155, 20153, 20155 },
			entryIDs = { 102618 },
			groupIDs = { 8480, 8482, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81619, type = 2, visualStyle = 1 },
				{ targetNode = 81626, type = 2, visualStyle = 1 }
			}
		},
		[81628] = {
			ID = 81628,
			flags = 9,
			type = 2,
			posX = 5997,
			posY = 5096,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102620, 102619 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81509, type = 2, visualStyle = 1 },
				{ targetNode = 81627, type = 2, visualStyle = 1 }
			}
		},
		[81629] = {
			ID = 81629,
			flags = 8,
			type = 0,
			posX = 6597,
			posY = 4495,
			maxRanks = 2,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102621 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81509, type = 2, visualStyle = 1 },
				{ targetNode = 81628, type = 2, visualStyle = 1 }
			}
		},
		[81630] = {
			ID = 81630,
			flags = 0,
			type = 0,
			posX = 5997,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20155, 20155, 20155 },
			entryIDs = { 102622 },
			groupIDs = { 8480, 8483 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81616, type = 2, visualStyle = 1 },
				{ targetNode = 81629, type = 2, visualStyle = 1 }
			}
		},
		[81631] = {
			ID = 81631,
			flags = 9,
			type = 2,
			posX = 5395,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102624, 102623 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81606, type = 2, visualStyle = 1 },
				{ targetNode = 81630, type = 2, visualStyle = 1 }
			}
		},
		[81632] = {
			ID = 81632,
			flags = 0,
			type = 0,
			posX = 4796,
			posY = 2696,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 102625 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81605, type = 2, visualStyle = 1 },
				{ targetNode = 81606, type = 2, visualStyle = 1 },
				{ targetNode = 81631, type = 2, visualStyle = 1 }
			}
		},
		[81633] = {
			ID = 81633,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20161, 20161, 20161, 20161 },
			entryIDs = { 102626 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80706, type = 2, visualStyle = 1 }
			}
		},
		[81634] = {
			ID = 81634,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20162, 20162, 20162, 20162 },
			entryIDs = { 102627 },
			groupIDs = { 8411 },
			costs = {
				{ ID = 2778, amount = 1 }
			},
			edges = {
				{ targetNode = 80706, type = 2, visualStyle = 1 }
			}
		},
		[82043] = {
			ID = 82043,
			flags = 8,
			type = 0,
			posX = 13497,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103094 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82044] = {
			ID = 82044,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103095 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82045] = {
			ID = 82045,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103096 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82080, type = 2, visualStyle = 1 },
				{ targetNode = 82065, type = 2, visualStyle = 1 }
			}
		},
		[82046] = {
			ID = 82046,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 3301,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103097 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82047] = {
			ID = 82047,
			flags = 8,
			type = 0,
			posX = 10498,
			posY = 2698,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103098 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82046, type = 2, visualStyle = 1 },
				{ targetNode = 82057, type = 2, visualStyle = 1 },
				{ targetNode = 82055, type = 2, visualStyle = 1 }
			}
		},
		[82048] = {
			ID = 82048,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 2098,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103099 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82047, type = 2, visualStyle = 1 }
			}
		},
		[82049] = {
			ID = 82049,
			flags = 8,
			type = 0,
			posX = 11697,
			posY = 1498,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103100 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82084, type = 2, visualStyle = 1 },
				{ targetNode = 82048, type = 2, visualStyle = 1 },
				{ targetNode = 82050, type = 2, visualStyle = 1 }
			}
		},
		[82050] = {
			ID = 82050,
			flags = 8,
			type = 0,
			posX = 11697,
			posY = 2098,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103101 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82051, type = 2, visualStyle = 1 }
			}
		},
		[82051] = {
			ID = 82051,
			flags = 9,
			type = 2,
			posX = 11697,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103103, 103102 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82055, type = 2, visualStyle = 1 },
				{ targetNode = 82052, type = 2, visualStyle = 1 }
			}
		},
		[82052] = {
			ID = 82052,
			flags = 9,
			type = 2,
			posX = 12298,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103105, 103104 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82082, type = 2, visualStyle = 1 },
				{ targetNode = 82054, type = 2, visualStyle = 1 }
			}
		},
		[82053] = {
			ID = 82053,
			flags = 9,
			type = 2,
			posX = 11697,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103107, 103106 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82065, type = 2, visualStyle = 1 }
			}
		},
		[82054] = {
			ID = 82054,
			flags = 8,
			type = 0,
			posX = 11697,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103108 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82053, type = 2, visualStyle = 1 }
			}
		},
		[82055] = {
			ID = 82055,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103109 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82054, type = 2, visualStyle = 1 },
				{ targetNode = 82057, type = 2, visualStyle = 1 }
			}
		},
		[82056] = {
			ID = 82056,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103110 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82062, type = 2, visualStyle = 1 },
				{ targetNode = 82065, type = 2, visualStyle = 1 }
			}
		},
		[82057] = {
			ID = 82057,
			flags = 8,
			type = 0,
			posX = 10498,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103111 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82056, type = 2, visualStyle = 1 },
				{ targetNode = 82059, type = 2, visualStyle = 1 }
			}
		},
		[82058] = {
			ID = 82058,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103112 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82061, type = 2, visualStyle = 1 }
			}
		},
		[82059] = {
			ID = 82059,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103113 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82062, type = 2, visualStyle = 1 },
				{ targetNode = 82058, type = 2, visualStyle = 1 },
				{ targetNode = 82060, type = 2, visualStyle = 1 }
			}
		},
		[82060] = {
			ID = 82060,
			flags = 8,
			type = 0,
			posX = 9299,
			posY = 5101,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103114 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82074, type = 2, visualStyle = 1 },
				{ targetNode = 82061, type = 2, visualStyle = 1 }
			}
		},
		[82061] = {
			ID = 82061,
			flags = 9,
			type = 2,
			posX = 9899,
			posY = 5699,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103116, 103115 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82074, type = 2, visualStyle = 1 },
				{ targetNode = 82072, type = 2, visualStyle = 1 }
			}
		},
		[82062] = {
			ID = 82062,
			flags = 8,
			type = 0,
			posX = 10498,
			posY = 5101,
			maxRanks = 2,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103117 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82061, type = 2, visualStyle = 1 },
				{ targetNode = 82064, type = 2, visualStyle = 1 }
			}
		},
		[82063] = {
			ID = 82063,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103118 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82071, type = 2, visualStyle = 1 }
			}
		},
		[82064] = {
			ID = 82064,
			flags = 9,
			type = 2,
			posX = 11099,
			posY = 5699,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103120, 103119 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82072, type = 2, visualStyle = 1 },
				{ targetNode = 82070, type = 2, visualStyle = 1 },
				{ targetNode = 82063, type = 2, visualStyle = 1 }
			}
		},
		[82065] = {
			ID = 82065,
			flags = 8,
			type = 0,
			posX = 11697,
			posY = 5101,
			maxRanks = 2,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103121 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82064, type = 2, visualStyle = 1 },
				{ targetNode = 82067, type = 2, visualStyle = 1 }
			}
		},
		[82066] = {
			ID = 82066,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103122 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82069, type = 2, visualStyle = 1 }
			}
		},
		[82067] = {
			ID = 82067,
			flags = 8,
			type = 0,
			posX = 12298,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103123 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82070, type = 2, visualStyle = 1 },
				{ targetNode = 82066, type = 2, visualStyle = 1 },
				{ targetNode = 82068, type = 2, visualStyle = 1 }
			}
		},
		[82068] = {
			ID = 82068,
			flags = 8,
			type = 0,
			posX = 12899,
			posY = 6301,
			maxRanks = 2,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103124 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82077, type = 2, visualStyle = 1 },
				{ targetNode = 82069, type = 2, visualStyle = 1 }
			}
		},
		[82069] = {
			ID = 82069,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103125 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82070] = {
			ID = 82070,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103126 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82069, type = 2, visualStyle = 1 },
				{ targetNode = 82071, type = 2, visualStyle = 1 }
			}
		},
		[82071] = {
			ID = 82071,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103127 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82072] = {
			ID = 82072,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103128 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82044, type = 2, visualStyle = 1 },
				{ targetNode = 82071, type = 2, visualStyle = 1 },
				{ targetNode = 82073, type = 2, visualStyle = 1 }
			}
		},
		[82073] = {
			ID = 82073,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103129 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82074] = {
			ID = 82074,
			flags = 8,
			type = 0,
			posX = 9300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103130 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82073, type = 2, visualStyle = 1 }
			}
		},
		[82075] = {
			ID = 82075,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103131 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82079, type = 2, visualStyle = 1 },
				{ targetNode = 82076, type = 2, visualStyle = 1 }
			}
		},
		[82076] = {
			ID = 82076,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103132 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82077, type = 2, visualStyle = 1 }
			}
		},
		[82077] = {
			ID = 82077,
			flags = 9,
			type = 2,
			posX = 13497,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103134, 103133 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82078] = {
			ID = 82078,
			flags = 8,
			type = 0,
			posX = 13497,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103135 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82077, type = 2, visualStyle = 1 }
			}
		},
		[82079] = {
			ID = 82079,
			flags = 9,
			type = 2,
			posX = 13497,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248, 20235, 20233, 20248 },
			entryIDs = { 103137, 103136 },
			groupIDs = { 8522, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82076, type = 2, visualStyle = 1 },
				{ targetNode = 82068, type = 2, visualStyle = 1 },
				{ targetNode = 82078, type = 2, visualStyle = 1 }
			}
		},
		[82080] = {
			ID = 82080,
			flags = 8,
			type = 0,
			posX = 12899,
			posY = 5101,
			maxRanks = 2,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103138 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82067, type = 2, visualStyle = 1 },
				{ targetNode = 82079, type = 2, visualStyle = 1 }
			}
		},
		[82081] = {
			ID = 82081,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103140, 103139 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82075, type = 2, visualStyle = 1 },
				{ targetNode = 82080, type = 2, visualStyle = 1 }
			}
		},
		[82082] = {
			ID = 82082,
			flags = 8,
			type = 0,
			posX = 12897,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20235, 20233, 20235, 20233, 20235, 20233, 20235, 20233 },
			entryIDs = { 103141 },
			groupIDs = { 8522, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82045, type = 2, visualStyle = 1 },
				{ targetNode = 82081, type = 2, visualStyle = 1 }
			}
		},
		[82083] = {
			ID = 82083,
			flags = 8,
			type = 0,
			posX = 12897,
			posY = 2697,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103142 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82043, type = 2, visualStyle = 1 },
				{ targetNode = 82052, type = 2, visualStyle = 1 },
				{ targetNode = 82082, type = 2, visualStyle = 1 }
			}
		},
		[82084] = {
			ID = 82084,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 2098,
			maxRanks = 1,
			conditionIDs = { 20235, 20235, 20235, 20235 },
			entryIDs = { 103143 },
			groupIDs = { 8522, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82083, type = 2, visualStyle = 1 }
			}
		},
		[82085] = {
			ID = 82085,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 2,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103144 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82086] = {
			ID = 82086,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103145 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82119, type = 2, visualStyle = 1 }
			}
		},
		[82087] = {
			ID = 82087,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103146 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82104, type = 2, visualStyle = 1 }
			}
		},
		[82088] = {
			ID = 82088,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103147 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82089] = {
			ID = 82089,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103148 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82117, type = 2, visualStyle = 1 }
			}
		},
		[82090] = {
			ID = 82090,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103149 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82094, type = 2, visualStyle = 1 }
			}
		},
		[82091] = {
			ID = 82091,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103151, 103150 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82094, type = 2, visualStyle = 1 },
				{ targetNode = 82093, type = 2, visualStyle = 1 }
			}
		},
		[82092] = {
			ID = 82092,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103152 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82093] = {
			ID = 82093,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103154, 103153 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82092, type = 2, visualStyle = 1 }
			}
		},
		[82094] = {
			ID = 82094,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103155 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82092, type = 2, visualStyle = 1 },
				{ targetNode = 82093, type = 2, visualStyle = 1 },
				{ targetNode = 82096, type = 2, visualStyle = 1 }
			}
		},
		[82095] = {
			ID = 82095,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103156 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82096] = {
			ID = 82096,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103157 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82095, type = 2, visualStyle = 1 }
			}
		},
		[82097] = {
			ID = 82097,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103158 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82104, type = 2, visualStyle = 1 }
			}
		},
		[82098] = {
			ID = 82098,
			flags = 8,
			type = 0,
			posX = 10499,
			posY = 2699,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103159 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82097, type = 2, visualStyle = 1 },
				{ targetNode = 82102, type = 2, visualStyle = 1 },
				{ targetNode = 82087, type = 2, visualStyle = 1 }
			}
		},
		[82099] = {
			ID = 82099,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103160 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82106, type = 2, visualStyle = 1 }
			}
		},
		[82100] = {
			ID = 82100,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103161 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82116, type = 2, visualStyle = 1 }
			}
		},
		[82101] = {
			ID = 82101,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103162 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82100, type = 2, visualStyle = 1 },
				{ targetNode = 82103, type = 2, visualStyle = 1 }
			}
		},
		[82102] = {
			ID = 82102,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103163 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82099, type = 2, visualStyle = 1 },
				{ targetNode = 82101, type = 2, visualStyle = 1 },
				{ targetNode = 82104, type = 2, visualStyle = 1 }
			}
		},
		[82103] = {
			ID = 82103,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103164 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82116, type = 2, visualStyle = 1 }
			}
		},
		[82104] = {
			ID = 82104,
			flags = 8,
			type = 0,
			posX = 10490,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103165 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82106, type = 2, visualStyle = 1 }
			}
		},
		[82105] = {
			ID = 82105,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103166 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82110, type = 2, visualStyle = 1 }
			}
		},
		[82106] = {
			ID = 82106,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103167 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82105, type = 2, visualStyle = 1 },
				{ targetNode = 82116, type = 2, visualStyle = 1 },
				{ targetNode = 82107, type = 2, visualStyle = 1 }
			}
		},
		[82107] = {
			ID = 82107,
			flags = 9,
			type = 2,
			posX = 9900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103169, 103168 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82110, type = 2, visualStyle = 1 },
				{ targetNode = 82109, type = 2, visualStyle = 1 }
			}
		},
		[82108] = {
			ID = 82108,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103170 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82109] = {
			ID = 82109,
			flags = 9,
			type = 2,
			posX = 9900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103172, 103171 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82108, type = 2, visualStyle = 1 }
			}
		},
		[82110] = {
			ID = 82110,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103173 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82109, type = 2, visualStyle = 1 },
				{ targetNode = 82108, type = 2, visualStyle = 1 },
				{ targetNode = 82109, type = 2, visualStyle = 1 },
				{ targetNode = 82112, type = 2, visualStyle = 1 }
			}
		},
		[82111] = {
			ID = 82111,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103174 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82112] = {
			ID = 82112,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103175 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82111, type = 2, visualStyle = 1 }
			}
		},
		[82113] = {
			ID = 82113,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103176 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82114] = {
			ID = 82114,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103178, 103177 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82113, type = 2, visualStyle = 1 }
			}
		},
		[82115] = {
			ID = 82115,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248, 20233, 20239, 20248 },
			entryIDs = { 103179 },
			groupIDs = { 8523, 8524, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82096, type = 2, visualStyle = 1 },
				{ targetNode = 82112, type = 2, visualStyle = 1 },
				{ targetNode = 82114, type = 2, visualStyle = 1 }
			}
		},
		[82116] = {
			ID = 82116,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103180 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82115, type = 2, visualStyle = 1 }
			}
		},
		[82117] = {
			ID = 82117,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103181 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82090, type = 2, visualStyle = 1 },
				{ targetNode = 82091, type = 2, visualStyle = 1 },
				{ targetNode = 82116, type = 2, visualStyle = 1 }
			}
		},
		[82118] = {
			ID = 82118,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3899,
			maxRanks = 2,
			conditionIDs = { 20233, 20239, 20233, 20239, 20233, 20239, 20233, 20239 },
			entryIDs = { 103182 },
			groupIDs = { 8523, 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82088, type = 2, visualStyle = 1 },
				{ targetNode = 82117, type = 2, visualStyle = 1 }
			}
		},
		[82119] = {
			ID = 82119,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103183 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82089, type = 2, visualStyle = 1 },
				{ targetNode = 82101, type = 2, visualStyle = 1 },
				{ targetNode = 82118, type = 2, visualStyle = 1 }
			}
		},
		[82120] = {
			ID = 82120,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103184 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82122, type = 2, visualStyle = 1 },
				{ targetNode = 82086, type = 2, visualStyle = 1 },
				{ targetNode = 82119, type = 2, visualStyle = 1 }
			}
		},
		[82121] = {
			ID = 82121,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103185 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82122] = {
			ID = 82122,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103186 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82119, type = 2, visualStyle = 1 },
				{ targetNode = 82102, type = 2, visualStyle = 1 },
				{ targetNode = 82121, type = 2, visualStyle = 1 }
			}
		},
		[82123] = {
			ID = 82123,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103187 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82098, type = 2, visualStyle = 1 },
				{ targetNode = 82102, type = 2, visualStyle = 1 },
				{ targetNode = 82122, type = 2, visualStyle = 1 }
			}
		},
		[82124] = {
			ID = 82124,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20239, 20239, 20239, 20239 },
			entryIDs = { 103188 },
			groupIDs = { 8524, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82085, type = 2, visualStyle = 1 },
				{ targetNode = 82120, type = 2, visualStyle = 1 },
				{ targetNode = 82123, type = 2, visualStyle = 1 }
			}
		},
		[82125] = {
			ID = 82125,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103189 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82126] = {
			ID = 82126,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103190 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82150, type = 2, visualStyle = 1 },
				{ targetNode = 82161, type = 2, visualStyle = 1 }
			}
		},
		[82127] = {
			ID = 82127,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1496,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103191 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82126, type = 2, visualStyle = 1 },
				{ targetNode = 82129, type = 2, visualStyle = 1 }
			}
		},
		[82128] = {
			ID = 82128,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103192 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82129] = {
			ID = 82129,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103193 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82150, type = 2, visualStyle = 1 },
				{ targetNode = 82128, type = 2, visualStyle = 1 },
				{ targetNode = 82131, type = 2, visualStyle = 1 }
			}
		},
		[82130] = {
			ID = 82130,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103194 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82131] = {
			ID = 82131,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103195 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82130, type = 2, visualStyle = 1 },
				{ targetNode = 82132, type = 2, visualStyle = 1 }
			}
		},
		[82132] = {
			ID = 82132,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103196 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82148, type = 2, visualStyle = 1 },
				{ targetNode = 82146, type = 2, visualStyle = 1 }
			}
		},
		[82133] = {
			ID = 82133,
			flags = 0,
			type = 0,
			posX = 11099,
			posY = 4501,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103197 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82155, type = 2, visualStyle = 1 },
				{ targetNode = 82138, type = 2, visualStyle = 1 }
			}
		},
		[82134] = {
			ID = 82134,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103198 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82136, type = 2, visualStyle = 1 }
			}
		},
		[82135] = {
			ID = 82135,
			flags = 0,
			type = 0,
			posX = 11698,
			posY = 6898,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103199 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82136] = {
			ID = 82136,
			flags = 1,
			type = 2,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103201, 103200 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82135, type = 2, visualStyle = 1 }
			}
		},
		[82137] = {
			ID = 82137,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103202 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82136, type = 2, visualStyle = 1 }
			}
		},
		[82138] = {
			ID = 82138,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103203 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82134, type = 2, visualStyle = 1 },
				{ targetNode = 82137, type = 2, visualStyle = 1 }
			}
		},
		[82139] = {
			ID = 82139,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 4501,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103204 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82138, type = 2, visualStyle = 1 },
				{ targetNode = 82144, type = 2, visualStyle = 1 }
			}
		},
		[82140] = {
			ID = 82140,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103206, 103205 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82141, type = 2, visualStyle = 1 }
			}
		},
		[82141] = {
			ID = 82141,
			flags = 0,
			type = 0,
			posX = 12899,
			posY = 6898,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103207 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82142] = {
			ID = 82142,
			flags = 1,
			type = 2,
			posX = 12299,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103209, 103208 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82141, type = 2, visualStyle = 1 }
			}
		},
		[82143] = {
			ID = 82143,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103210 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82140, type = 2, visualStyle = 1 },
				{ targetNode = 82142, type = 2, visualStyle = 1 }
			}
		},
		[82144] = {
			ID = 82144,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103211 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82143, type = 2, visualStyle = 1 }
			}
		},
		[82145] = {
			ID = 82145,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103212 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82144, type = 2, visualStyle = 1 }
			}
		},
		[82146] = {
			ID = 82146,
			flags = 0,
			type = 0,
			posX = 13499,
			posY = 3902,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103213 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82145, type = 2, visualStyle = 1 },
				{ targetNode = 82147, type = 2, visualStyle = 1 }
			}
		},
		[82147] = {
			ID = 82147,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103214 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82148] = {
			ID = 82148,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103215 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82125, type = 2, visualStyle = 1 },
				{ targetNode = 82139, type = 2, visualStyle = 1 },
				{ targetNode = 82147, type = 2, visualStyle = 1 }
			}
		},
		[82149] = {
			ID = 82149,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103216 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82159, type = 2, visualStyle = 1 },
				{ targetNode = 82148, type = 2, visualStyle = 1 }
			}
		},
		[82150] = {
			ID = 82150,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103217 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82162, type = 2, visualStyle = 1 },
				{ targetNode = 82130, type = 2, visualStyle = 1 },
				{ targetNode = 82149, type = 2, visualStyle = 1 }
			}
		},
		[82151] = {
			ID = 82151,
			flags = 1,
			type = 2,
			posX = 9900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103219, 103218 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82152, type = 2, visualStyle = 1 }
			}
		},
		[82152] = {
			ID = 82152,
			flags = 1,
			type = 2,
			posX = 10499,
			posY = 6898,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103221, 103220 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82153] = {
			ID = 82153,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103222 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82152, type = 2, visualStyle = 1 }
			}
		},
		[82154] = {
			ID = 82154,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20248 },
			entryIDs = { 103223 },
			groupIDs = { 8523, 8526, 8528, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82151, type = 2, visualStyle = 1 },
				{ targetNode = 82153, type = 2, visualStyle = 1 }
			}
		},
		[82155] = {
			ID = 82155,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103224 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82154, type = 2, visualStyle = 1 }
			}
		},
		[82156] = {
			ID = 82156,
			flags = 1,
			type = 0,
			posX = 9899,
			posY = 4497,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103225 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82155, type = 2, visualStyle = 1 }
			}
		},
		[82157] = {
			ID = 82157,
			flags = 0,
			type = 0,
			posX = 9899,
			posY = 3897,
			maxRanks = 2,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103226 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82156, type = 2, visualStyle = 1 },
				{ targetNode = 82158, type = 2, visualStyle = 1 }
			}
		},
		[82158] = {
			ID = 82158,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103227 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82159] = {
			ID = 82159,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20233, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103228 },
			groupIDs = { 8523, 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82125, type = 2, visualStyle = 1 },
				{ targetNode = 82133, type = 2, visualStyle = 1 },
				{ targetNode = 82158, type = 2, visualStyle = 1 }
			}
		},
		[82160] = {
			ID = 82160,
			flags = 0,
			type = 0,
			posX = 10499,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103229 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82157, type = 2, visualStyle = 1 },
				{ targetNode = 82159, type = 2, visualStyle = 1 }
			}
		},
		[82161] = {
			ID = 82161,
			flags = 1,
			type = 2,
			posX = 10499,
			posY = 2701,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103231, 103230 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 82160, type = 2, visualStyle = 1 },
				{ targetNode = 82162, type = 2, visualStyle = 1 }
			}
		},
		[82162] = {
			ID = 82162,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226, 20223, 20222, 20237, 20246, 20230, 20245, 20229, 20244, 20228, 20226 },
			entryIDs = { 103232 },
			groupIDs = { 8526, 8528 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[82197] = {
			ID = 82197,
			flags = 8,
			type = 0,
			posX = 1500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103274 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82198] = {
			ID = 82198,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103276, 103275 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82229, type = 2, visualStyle = 1 }
			}
		},
		[82199] = {
			ID = 82199,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20225, 20225, 20225, 20225 },
			entryIDs = { 103277 },
			groupIDs = { 8520, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82223, type = 2, visualStyle = 1 }
			}
		},
		[82200] = {
			ID = 82200,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20234, 20231, 20227, 20234, 20231, 20227, 20234, 20231, 20227, 20234, 20231, 20227, 20234, 20231, 20227 },
			entryIDs = { 103278 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82212, type = 2, visualStyle = 1 },
				{ targetNode = 91042, type = 2, visualStyle = 1 },
				{ targetNode = 91043, type = 2, visualStyle = 1 },
				{ targetNode = 91045, type = 2, visualStyle = 1 },
				{ targetNode = 91047, type = 2, visualStyle = 1 }
			}
		},
		[82201] = {
			ID = 82201,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22803, 20243, 22803, 20243, 22803, 20243, 22803, 20243, 22803 },
			entryIDs = { 103279 },
			groupIDs = { 8527, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82200, type = 2, visualStyle = 1 },
				{ targetNode = 82202, type = 2, visualStyle = 1 }
			}
		},
		[82202] = {
			ID = 82202,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20221, 20243, 20221, 20243, 20221, 20243, 20221, 20243, 20221 },
			entryIDs = { 103280 },
			groupIDs = { 8527, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82212, type = 2, visualStyle = 1 }
			}
		},
		[82203] = {
			ID = 82203,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20241, 20241, 20241, 20241, 20241 },
			entryIDs = { 103281 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82214, type = 2, visualStyle = 1 },
				{ targetNode = 82206, type = 2, visualStyle = 1 }
			}
		},
		[82204] = {
			ID = 82204,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20240, 20240, 20240, 20240, 20240 },
			entryIDs = { 103282 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82214, type = 2, visualStyle = 1 },
				{ targetNode = 82206, type = 2, visualStyle = 1 }
			}
		},
		[82205] = {
			ID = 82205,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20236, 20236, 20236, 20236, 20236 },
			entryIDs = { 103283 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82214, type = 2, visualStyle = 1 },
				{ targetNode = 82206, type = 2, visualStyle = 1 }
			}
		},
		[82206] = {
			ID = 82206,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103284 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82241, type = 2, visualStyle = 1 },
				{ targetNode = 82229, type = 2, visualStyle = 1 },
				{ targetNode = 82208, type = 2, visualStyle = 1 }
			}
		},
		[82207] = {
			ID = 82207,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103285 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82208] = {
			ID = 82208,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103286 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82207, type = 2, visualStyle = 1 },
				{ targetNode = 82242, type = 2, visualStyle = 1 }
			}
		},
		[82209] = {
			ID = 82209,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103287 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82210] = {
			ID = 82210,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103288 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82208, type = 2, visualStyle = 1 },
				{ targetNode = 82209, type = 2, visualStyle = 1 }
			}
		},
		[82211] = {
			ID = 82211,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103289 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82212] = {
			ID = 82212,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22804, 22804, 22804, 22804, 22804 },
			entryIDs = { 103290 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82210, type = 2, visualStyle = 1 },
				{ targetNode = 82211, type = 2, visualStyle = 1 },
				{ targetNode = 82214, type = 2, visualStyle = 1 }
			}
		},
		[82213] = {
			ID = 82213,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103291 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82214] = {
			ID = 82214,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 3300,
			maxRanks = 3,
			conditionIDs = {  },
			entryIDs = { 103292 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82213, type = 2, visualStyle = 1 }
			}
		},
		[82215] = {
			ID = 82215,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20247, 20247, 20247, 20247, 20247 },
			entryIDs = { 103293 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82206, type = 2, visualStyle = 1 },
				{ targetNode = 82214, type = 2, visualStyle = 1 }
			}
		},
		[82216] = {
			ID = 82216,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20224, 20224, 20224, 20224 },
			entryIDs = { 103294 },
			groupIDs = { 8519, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82203, type = 2, visualStyle = 1 },
				{ targetNode = 82204, type = 2, visualStyle = 1 },
				{ targetNode = 82205, type = 2, visualStyle = 1 },
				{ targetNode = 82215, type = 2, visualStyle = 1 }
			}
		},
		[82217] = {
			ID = 82217,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20224, 20224, 20224, 20224 },
			entryIDs = { 103295 },
			groupIDs = { 8519, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82216, type = 2, visualStyle = 1 },
				{ targetNode = 82219, type = 2, visualStyle = 1 }
			}
		},
		[82218] = {
			ID = 82218,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103296 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82219] = {
			ID = 82219,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103297 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82218, type = 2, visualStyle = 1 }
			}
		},
		[82220] = {
			ID = 82220,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20249, 20249, 20249, 20249 },
			entryIDs = { 103298 },
			groupIDs = { 8525, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82219, type = 2, visualStyle = 1 },
				{ targetNode = 82223, type = 2, visualStyle = 1 }
			}
		},
		[82221] = {
			ID = 82221,
			flags = 8,
			type = 0,
			posX = 1500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103299 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82222] = {
			ID = 82222,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103300 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82239, type = 2, visualStyle = 1 },
				{ targetNode = 82221, type = 2, visualStyle = 1 }
			}
		},
		[82223] = {
			ID = 82223,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20225, 20249, 20225, 20249, 20225, 20249, 20225, 20249 },
			entryIDs = { 103301 },
			groupIDs = { 8520, 8525, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82222, type = 2, visualStyle = 1 },
				{ targetNode = 82226, type = 2, visualStyle = 1 }
			}
		},
		[82224] = {
			ID = 82224,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103302 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82225] = {
			ID = 82225,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 3300,
			maxRanks = 3,
			conditionIDs = {  },
			entryIDs = { 103303 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82224, type = 2, visualStyle = 1 }
			}
		},
		[82226] = {
			ID = 82226,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103304 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82225, type = 2, visualStyle = 1 },
				{ targetNode = 82227, type = 2, visualStyle = 1 }
			}
		},
		[82227] = {
			ID = 82227,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103305 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82228, type = 2, visualStyle = 1 }
			}
		},
		[82228] = {
			ID = 82228,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103306 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82236, type = 2, visualStyle = 1 },
				{ targetNode = 82229, type = 2, visualStyle = 1 }
			}
		},
		[82229] = {
			ID = 82229,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103307 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82234, type = 2, visualStyle = 1 }
			}
		},
		[82230] = {
			ID = 82230,
			flags = 8,
			type = 0,
			posX = 3600,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103308 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82231, type = 2, visualStyle = 1 }
			}
		},
		[82231] = {
			ID = 82231,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103309 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82232] = {
			ID = 82232,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103310 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82231, type = 2, visualStyle = 1 }
			}
		},
		[82233] = {
			ID = 82233,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 5700,
			maxRanks = 3,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103311 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82230, type = 2, visualStyle = 1 },
				{ targetNode = 82232, type = 2, visualStyle = 1 }
			}
		},
		[82234] = {
			ID = 82234,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103312 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82233, type = 2, visualStyle = 1 },
				{ targetNode = 82235, type = 2, visualStyle = 1 }
			}
		},
		[82235] = {
			ID = 82235,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103313 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82236] = {
			ID = 82236,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103314 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82235, type = 2, visualStyle = 1 },
				{ targetNode = 82237, type = 2, visualStyle = 1 }
			}
		},
		[82237] = {
			ID = 82237,
			flags = 9,
			type = 2,
			posX = 2700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103316, 103315 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82246, type = 2, visualStyle = 1 }
			}
		},
		[82238] = {
			ID = 82238,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103317 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82237, type = 2, visualStyle = 1 }
			}
		},
		[82239] = {
			ID = 82239,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103318 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82197, type = 2, visualStyle = 1 },
				{ targetNode = 82238, type = 2, visualStyle = 1 }
			}
		},
		[82240] = {
			ID = 82240,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103319 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82241] = {
			ID = 82241,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20238, 20238, 20238, 20238 },
			entryIDs = { 103320 },
			groupIDs = { 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82240, type = 2, visualStyle = 1 },
				{ targetNode = 82242, type = 2, visualStyle = 1 }
			}
		},
		[82242] = {
			ID = 82242,
			flags = 9,
			type = 2,
			posX = 5100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103322, 103321 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82243, type = 2, visualStyle = 1 }
			}
		},
		[82243] = {
			ID = 82243,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103323 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82244, type = 2, visualStyle = 1 }
			}
		},
		[82244] = {
			ID = 82244,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103324 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82245] = {
			ID = 82245,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103325 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {}
		},
		[82246] = {
			ID = 82246,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20242, 20238, 20242, 20238, 20242, 20238, 20242, 20238 },
			entryIDs = { 103326 },
			groupIDs = { 8529, 8530, 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82245, type = 2, visualStyle = 1 }
			}
		},
		[82552] = {
			ID = 82552,
			flags = 9,
			type = 0,
			posX = 14100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103781 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82553] = {
			ID = 82553,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103787 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82554] = {
			ID = 82554,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103736, 103675 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82555] = {
			ID = 82555,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103817 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82556] = {
			ID = 82556,
			flags = 9,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103834 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82708, type = 2, visualStyle = 1 },
				{ targetNode = 82710, type = 2, visualStyle = 1 }
			}
		},
		[82557] = {
			ID = 82557,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103803 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82670, type = 2, visualStyle = 1 },
				{ targetNode = 82563, type = 2, visualStyle = 1 }
			}
		},
		[82558] = {
			ID = 82558,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103815, 103681 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82671, type = 2, visualStyle = 1 },
				{ targetNode = 82649, type = 2, visualStyle = 1 }
			}
		},
		[82559] = {
			ID = 82559,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103682 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82654, type = 2, visualStyle = 1 },
				{ targetNode = 82563, type = 2, visualStyle = 1 }
			}
		},
		[82560] = {
			ID = 82560,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103683 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82552, type = 2, visualStyle = 1 }
			}
		},
		[82561] = {
			ID = 82561,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103684 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82555, type = 2, visualStyle = 1 }
			}
		},
		[82562] = {
			ID = 82562,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103685 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82671, type = 2, visualStyle = 1 },
				{ targetNode = 82561, type = 2, visualStyle = 1 },
				{ targetNode = 82560, type = 2, visualStyle = 1 }
			}
		},
		[82563] = {
			ID = 82563,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103686 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82654, type = 2, visualStyle = 1 },
				{ targetNode = 82562, type = 2, visualStyle = 1 }
			}
		},
		[82564] = {
			ID = 82564,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103687 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82598, type = 2, visualStyle = 1 }
			}
		},
		[82566] = {
			ID = 82566,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103690 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82600, type = 2, visualStyle = 1 }
			}
		},
		[82567] = {
			ID = 82567,
			flags = 9,
			type = 2,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103692, 103691 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82572, type = 2, visualStyle = 1 },
				{ targetNode = 82585, type = 2, visualStyle = 1 }
			}
		},
		[82568] = {
			ID = 82568,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103693 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82569, type = 2, visualStyle = 1 }
			}
		},
		[82569] = {
			ID = 82569,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103694 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82570] = {
			ID = 82570,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103695 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82586, type = 2, visualStyle = 1 }
			}
		},
		[82571] = {
			ID = 82571,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103696 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82572] = {
			ID = 82572,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103697 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82571, type = 2, visualStyle = 1 }
			}
		},
		[82573] = {
			ID = 82573,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103698 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82574] = {
			ID = 82574,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103699 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82573, type = 2, visualStyle = 1 }
			}
		},
		[82575] = {
			ID = 82575,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103700 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82574, type = 2, visualStyle = 1 },
				{ targetNode = 82572, type = 2, visualStyle = 1 },
				{ targetNode = 82568, type = 2, visualStyle = 1 }
			}
		},
		[82576] = {
			ID = 82576,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103701, 108226 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82577, type = 2, visualStyle = 1 }
			}
		},
		[82577] = {
			ID = 82577,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103702 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82575, type = 2, visualStyle = 1 },
				{ targetNode = 82567, type = 2, visualStyle = 1 }
			}
		},
		[82578] = {
			ID = 82578,
			flags = 8,
			type = 0,
			posX = 12899,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103703 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82577, type = 2, visualStyle = 1 },
				{ targetNode = 82583, type = 2, visualStyle = 1 }
			}
		},
		[82579] = {
			ID = 82579,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103704 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82597, type = 2, visualStyle = 1 },
				{ targetNode = 82580, type = 2, visualStyle = 1 },
				{ targetNode = 82581, type = 2, visualStyle = 1 }
			}
		},
		[82580] = {
			ID = 82580,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103705 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82581, type = 2, visualStyle = 1 }
			}
		},
		[82581] = {
			ID = 82581,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103706 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82578, type = 2, visualStyle = 1 },
				{ targetNode = 82582, type = 2, visualStyle = 1 }
			}
		},
		[82582] = {
			ID = 82582,
			flags = 9,
			type = 2,
			posX = 14100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103708, 103707 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82583, type = 2, visualStyle = 1 }
			}
		},
		[82583] = {
			ID = 82583,
			flags = 8,
			type = 0,
			posX = 13499,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103709 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82584, type = 2, visualStyle = 1 },
				{ targetNode = 82567, type = 2, visualStyle = 1 }
			}
		},
		[82584] = {
			ID = 82584,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103710 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82585, type = 2, visualStyle = 1 },
				{ targetNode = 82586, type = 2, visualStyle = 1 }
			}
		},
		[82585] = {
			ID = 82585,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103711 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82571, type = 2, visualStyle = 1 }
			}
		},
		[82586] = {
			ID = 82586,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103712 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82570, type = 2, visualStyle = 1 }
			}
		},
		[82587] = {
			ID = 82587,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103713 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82588, type = 2, visualStyle = 1 },
				{ targetNode = 92225, type = 2, visualStyle = 1 }
			}
		},
		[82588] = {
			ID = 82588,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103715, 103714 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82564, type = 2, visualStyle = 1 }
			}
		},
		[82589] = {
			ID = 82589,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103717, 103716 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82590, type = 2, visualStyle = 1 },
				{ targetNode = 82598, type = 2, visualStyle = 1 }
			}
		},
		[82590] = {
			ID = 82590,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103718 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82566, type = 2, visualStyle = 1 },
				{ targetNode = 82599, type = 2, visualStyle = 1 }
			}
		},
		[82591] = {
			ID = 82591,
			flags = 9,
			type = 2,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103720, 103719 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82590, type = 2, visualStyle = 1 }
			}
		},
		[82592] = {
			ID = 82592,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103721 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82591, type = 2, visualStyle = 1 },
				{ targetNode = 82589, type = 2, visualStyle = 1 }
			}
		},
		[82593] = {
			ID = 82593,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103722 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82592, type = 2, visualStyle = 1 },
				{ targetNode = 92225, type = 2, visualStyle = 1 }
			}
		},
		[82594] = {
			ID = 82594,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103723 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82587, type = 2, visualStyle = 1 },
				{ targetNode = 82593, type = 2, visualStyle = 1 },
				{ targetNode = 82595, type = 2, visualStyle = 1 }
			}
		},
		[82595] = {
			ID = 82595,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103724 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82579, type = 2, visualStyle = 1 },
				{ targetNode = 82596, type = 2, visualStyle = 1 }
			}
		},
		[82596] = {
			ID = 82596,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103725 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82564, type = 2, visualStyle = 1 },
				{ targetNode = 82597, type = 2, visualStyle = 1 }
			}
		},
		[82597] = {
			ID = 82597,
			flags = 8,
			type = 0,
			posX = 12899,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 103726 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82598, type = 2, visualStyle = 1 },
				{ targetNode = 82581, type = 2, visualStyle = 1 }
			}
		},
		[82598] = {
			ID = 82598,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103727 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82599, type = 2, visualStyle = 1 },
				{ targetNode = 82576, type = 2, visualStyle = 1 },
				{ targetNode = 82578, type = 2, visualStyle = 1 }
			}
		},
		[82599] = {
			ID = 82599,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103728 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82600, type = 2, visualStyle = 1 },
				{ targetNode = 82577, type = 2, visualStyle = 1 }
			}
		},
		[82600] = {
			ID = 82600,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20299, 20298, 20299, 20298 },
			entryIDs = { 103729 },
			groupIDs = { 8543, 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82575, type = 2, visualStyle = 1 },
				{ targetNode = 82601, type = 2, visualStyle = 1 }
			}
		},
		[82601] = {
			ID = 82601,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103731 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82568, type = 2, visualStyle = 1 },
				{ targetNode = 82602, type = 2, visualStyle = 1 }
			}
		},
		[82602] = {
			ID = 82602,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103732 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 86730, type = 2, visualStyle = 1 }
			}
		},
		[82603] = {
			ID = 82603,
			flags = 9,
			type = 2,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103734, 103733 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82604] = {
			ID = 82604,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103735 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82603, type = 2, visualStyle = 1 }
			}
		},
		[82605] = {
			ID = 82605,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103737, 103676 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82606] = {
			ID = 82606,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103738 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82605, type = 2, visualStyle = 1 }
			}
		},
		[82607] = {
			ID = 82607,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103739 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82641, type = 2, visualStyle = 1 }
			}
		},
		[82608] = {
			ID = 82608,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103740 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82605, type = 2, visualStyle = 1 }
			}
		},
		[82609] = {
			ID = 82609,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103741 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82603, type = 2, visualStyle = 1 }
			}
		},
		[82610] = {
			ID = 82610,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103743, 103742 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82609, type = 2, visualStyle = 1 },
				{ targetNode = 82629, type = 2, visualStyle = 1 },
				{ targetNode = 82611, type = 2, visualStyle = 1 }
			}
		},
		[82611] = {
			ID = 82611,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103744 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82554, type = 2, visualStyle = 1 }
			}
		},
		[82612] = {
			ID = 82612,
			flags = 9,
			type = 2,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103746, 103745 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82611, type = 2, visualStyle = 1 },
				{ targetNode = 82606, type = 2, visualStyle = 1 }
			}
		},
		[82613] = {
			ID = 82613,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103747 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82614, type = 2, visualStyle = 1 }
			}
		},
		[82614] = {
			ID = 82614,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 5099,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103748 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82612, type = 2, visualStyle = 1 },
				{ targetNode = 82610, type = 2, visualStyle = 1 }
			}
		},
		[82615] = {
			ID = 82615,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103749 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82606, type = 2, visualStyle = 1 },
				{ targetNode = 82608, type = 2, visualStyle = 1 }
			}
		},
		[82616] = {
			ID = 82616,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103750 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82612, type = 2, visualStyle = 1 },
				{ targetNode = 82615, type = 2, visualStyle = 1 }
			}
		},
		[82617] = {
			ID = 82617,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103751 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82614, type = 2, visualStyle = 1 },
				{ targetNode = 82616, type = 2, visualStyle = 1 }
			}
		},
		[82618] = {
			ID = 82618,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103752 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82617, type = 2, visualStyle = 1 }
			}
		},
		[82619] = {
			ID = 82619,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103753 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82620, type = 2, visualStyle = 1 }
			}
		},
		[82620] = {
			ID = 82620,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103754 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82618, type = 2, visualStyle = 1 },
				{ targetNode = 82621, type = 2, visualStyle = 1 },
				{ targetNode = 82641, type = 2, visualStyle = 1 }
			}
		},
		[82621] = {
			ID = 82621,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103755 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82617, type = 2, visualStyle = 1 },
				{ targetNode = 82613, type = 2, visualStyle = 1 },
				{ targetNode = 82622, type = 2, visualStyle = 1 }
			}
		},
		[82622] = {
			ID = 82622,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103756 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82627, type = 2, visualStyle = 1 },
				{ targetNode = 82614, type = 2, visualStyle = 1 }
			}
		},
		[82623] = {
			ID = 82623,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103757 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82627, type = 2, visualStyle = 1 },
				{ targetNode = 82622, type = 2, visualStyle = 1 }
			}
		},
		[82624] = {
			ID = 82624,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103758 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82623, type = 2, visualStyle = 1 },
				{ targetNode = 82625, type = 2, visualStyle = 1 }
			}
		},
		[82625] = {
			ID = 82625,
			flags = 9,
			type = 2,
			posX = 10500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103760, 103759 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82626, type = 2, visualStyle = 1 }
			}
		},
		[82626] = {
			ID = 82626,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103761 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82627, type = 2, visualStyle = 1 }
			}
		},
		[82627] = {
			ID = 82627,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103762 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82610, type = 2, visualStyle = 1 },
				{ targetNode = 82628, type = 2, visualStyle = 1 }
			}
		},
		[82628] = {
			ID = 82628,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103763 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82609, type = 2, visualStyle = 1 },
				{ targetNode = 82604, type = 2, visualStyle = 1 }
			}
		},
		[82629] = {
			ID = 82629,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20295, 20299, 20288, 20295, 20299, 20288, 20295 },
			entryIDs = { 103764 },
			groupIDs = { 8543, 8544, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82554, type = 2, visualStyle = 1 }
			}
		},
		[82630] = {
			ID = 82630,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103765 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82621, type = 2, visualStyle = 1 },
				{ targetNode = 82634, type = 2, visualStyle = 1 }
			}
		},
		[82631] = {
			ID = 82631,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103766 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82630, type = 2, visualStyle = 1 },
				{ targetNode = 82632, type = 2, visualStyle = 1 }
			}
		},
		[82632] = {
			ID = 82632,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103767 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82633, type = 2, visualStyle = 1 },
				{ targetNode = 82630, type = 2, visualStyle = 1 },
				{ targetNode = 82624, type = 2, visualStyle = 1 }
			}
		},
		[82633] = {
			ID = 82633,
			flags = 9,
			type = 2,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103769, 103768 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82623, type = 2, visualStyle = 1 },
				{ targetNode = 82634, type = 2, visualStyle = 1 }
			}
		},
		[82634] = {
			ID = 82634,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103770 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82622, type = 2, visualStyle = 1 }
			}
		},
		[82635] = {
			ID = 82635,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103771 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82621, type = 2, visualStyle = 1 }
			}
		},
		[82636] = {
			ID = 82636,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103773, 103772 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82635, type = 2, visualStyle = 1 },
				{ targetNode = 82620, type = 2, visualStyle = 1 },
				{ targetNode = 82630, type = 2, visualStyle = 1 }
			}
		},
		[82637] = {
			ID = 82637,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103774 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82636, type = 2, visualStyle = 1 }
			}
		},
		[82638] = {
			ID = 82638,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103775 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82637, type = 2, visualStyle = 1 },
				{ targetNode = 82639, type = 2, visualStyle = 1 },
				{ targetNode = 82631, type = 2, visualStyle = 1 }
			}
		},
		[82639] = {
			ID = 82639,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103776 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82640, type = 2, visualStyle = 1 },
				{ targetNode = 82619, type = 2, visualStyle = 1 }
			}
		},
		[82640] = {
			ID = 82640,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20288, 20288, 20288 },
			entryIDs = { 103777 },
			groupIDs = { 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82620, type = 2, visualStyle = 1 },
				{ targetNode = 82607, type = 2, visualStyle = 1 }
			}
		},
		[82641] = {
			ID = 82641,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103779, 103778 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82617, type = 2, visualStyle = 1 },
				{ targetNode = 82642, type = 2, visualStyle = 1 }
			}
		},
		[82642] = {
			ID = 82642,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20288, 20299, 20288, 20299, 20288 },
			entryIDs = { 103780 },
			groupIDs = { 8543, 8544, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82616, type = 2, visualStyle = 1 }
			}
		},
		[82643] = {
			ID = 82643,
			flags = 9,
			type = 0,
			posX = 11699,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103782 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82644] = {
			ID = 82644,
			flags = 8,
			type = 0,
			posX = 10499,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103783 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82553, type = 2, visualStyle = 1 }
			}
		},
		[82645] = {
			ID = 82645,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103784 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82558, type = 2, visualStyle = 1 },
				{ targetNode = 82648, type = 2, visualStyle = 1 }
			}
		},
		[82646] = {
			ID = 82646,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103785 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82662, type = 2, visualStyle = 1 },
				{ targetNode = 82647, type = 2, visualStyle = 1 }
			}
		},
		[82647] = {
			ID = 82647,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103786 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82645, type = 2, visualStyle = 1 },
				{ targetNode = 82648, type = 2, visualStyle = 1 }
			}
		},
		[82648] = {
			ID = 82648,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103788 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82644, type = 2, visualStyle = 1 },
				{ targetNode = 82649, type = 2, visualStyle = 1 }
			}
		},
		[82649] = {
			ID = 82649,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103789 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82643, type = 2, visualStyle = 1 }
			}
		},
		[82650] = {
			ID = 82650,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103791, 103790 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82668, type = 2, visualStyle = 1 },
				{ targetNode = 82653, type = 2, visualStyle = 1 },
				{ targetNode = 82664, type = 2, visualStyle = 1 }
			}
		},
		[82651] = {
			ID = 82651,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103792 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82652, type = 2, visualStyle = 1 }
			}
		},
		[82652] = {
			ID = 82652,
			flags = 9,
			type = 2,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103794, 103793 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[82653] = {
			ID = 82653,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103795 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82646, type = 2, visualStyle = 1 },
				{ targetNode = 82661, type = 2, visualStyle = 1 },
				{ targetNode = 82657, type = 2, visualStyle = 1 }
			}
		},
		[82654] = {
			ID = 82654,
			flags = 9,
			type = 2,
			posX = 14100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103796, 103679 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82560, type = 2, visualStyle = 1 },
				{ targetNode = 82655, type = 2, visualStyle = 1 }
			}
		},
		[82655] = {
			ID = 82655,
			flags = 8,
			type = 0,
			posX = 14099,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103797 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82552, type = 2, visualStyle = 1 }
			}
		},
		[82656] = {
			ID = 82656,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103798 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82670, type = 2, visualStyle = 1 },
				{ targetNode = 82660, type = 2, visualStyle = 1 },
				{ targetNode = 82667, type = 2, visualStyle = 1 }
			}
		},
		[82657] = {
			ID = 82657,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103680, 103674 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82662, type = 2, visualStyle = 1 },
				{ targetNode = 82557, type = 2, visualStyle = 1 },
				{ targetNode = 82656, type = 2, visualStyle = 1 }
			}
		},
		[82658] = {
			ID = 82658,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103799 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82557, type = 2, visualStyle = 1 }
			}
		},
		[82659] = {
			ID = 82659,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103801, 103800 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82653, type = 2, visualStyle = 1 }
			}
		},
		[82660] = {
			ID = 82660,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103802 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82558, type = 2, visualStyle = 1 }
			}
		},
		[82661] = {
			ID = 82661,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103804 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82662, type = 2, visualStyle = 1 }
			}
		},
		[82662] = {
			ID = 82662,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103805 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82660, type = 2, visualStyle = 1 },
				{ targetNode = 82645, type = 2, visualStyle = 1 }
			}
		},
		[82663] = {
			ID = 82663,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103806 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82659, type = 2, visualStyle = 1 }
			}
		},
		[82664] = {
			ID = 82664,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103807 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82657, type = 2, visualStyle = 1 }
			}
		},
		[82665] = {
			ID = 82665,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103808 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82666, type = 2, visualStyle = 1 },
				{ targetNode = 82663, type = 2, visualStyle = 1 },
				{ targetNode = 82651, type = 2, visualStyle = 1 }
			}
		},
		[82666] = {
			ID = 82666,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103809 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82650, type = 2, visualStyle = 1 }
			}
		},
		[82667] = {
			ID = 82667,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103811, 103810 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82558, type = 2, visualStyle = 1 },
				{ targetNode = 82562, type = 2, visualStyle = 1 }
			}
		},
		[82668] = {
			ID = 82668,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20290, 20290, 20290 },
			entryIDs = { 103812 },
			groupIDs = { 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82658, type = 2, visualStyle = 1 },
				{ targetNode = 82669, type = 2, visualStyle = 1 },
				{ targetNode = 82657, type = 2, visualStyle = 1 }
			}
		},
		[82669] = {
			ID = 82669,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103813 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82557, type = 2, visualStyle = 1 },
				{ targetNode = 82559, type = 2, visualStyle = 1 }
			}
		},
		[82670] = {
			ID = 82670,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20299, 20290, 20299, 20290, 20299, 20290 },
			entryIDs = { 103814 },
			groupIDs = { 8543, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82562, type = 2, visualStyle = 1 }
			}
		},
		[82671] = {
			ID = 82671,
			flags = 9,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20299, 20295, 20290, 20299, 20295, 20290, 20299, 20295, 20290 },
			entryIDs = { 103816 },
			groupIDs = { 8543, 8547, 8549, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82555, type = 2, visualStyle = 1 }
			}
		},
		[82672] = {
			ID = 82672,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103818 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82673, type = 2, visualStyle = 1 }
			}
		},
		[82673] = {
			ID = 82673,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103819 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {}
		},
		[82674] = {
			ID = 82674,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103820 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {}
		},
		[82675] = {
			ID = 82675,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103821 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {}
		},
		[82676] = {
			ID = 82676,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103822 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {}
		},
		[82677] = {
			ID = 82677,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103823 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82676, type = 2, visualStyle = 1 }
			}
		},
		[82678] = {
			ID = 82678,
			flags = 9,
			type = 2,
			posX = 2700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103825, 103824 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82677, type = 2, visualStyle = 1 },
				{ targetNode = 82679, type = 2, visualStyle = 1 }
			}
		},
		[82679] = {
			ID = 82679,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103826 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82675, type = 2, visualStyle = 1 }
			}
		},
		[82680] = {
			ID = 82680,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20291, 20302, 20304, 20291, 20302, 20304, 20291, 20302, 20304, 20291 },
			entryIDs = { 103828, 103827 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82681, type = 2, visualStyle = 1 },
				{ targetNode = 82679, type = 2, visualStyle = 1 }
			}
		},
		[82681] = {
			ID = 82681,
			flags = 8,
			type = 0,
			posX = 4499,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103829 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82674, type = 2, visualStyle = 1 },
				{ targetNode = 82675, type = 2, visualStyle = 1 }
			}
		},
		[82682] = {
			ID = 82682,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20305, 20300, 20302, 20304, 20305, 20300, 20302, 20304, 20305, 20300, 20302, 20304, 20305, 20300 },
			entryIDs = { 103831, 103830 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82681, type = 2, visualStyle = 1 },
				{ targetNode = 82679, type = 2, visualStyle = 1 }
			}
		},
		[82683] = {
			ID = 82683,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103832 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82684, type = 2, visualStyle = 1 }
			}
		},
		[82684] = {
			ID = 82684,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103833 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82680, type = 2, visualStyle = 1 },
				{ targetNode = 82682, type = 2, visualStyle = 1 },
				{ targetNode = 82685, type = 2, visualStyle = 1 }
			}
		},
		[82685] = {
			ID = 82685,
			flags = 9,
			type = 0,
			posX = 5100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103835 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82686, type = 2, visualStyle = 1 },
				{ targetNode = 82681, type = 2, visualStyle = 1 }
			}
		},
		[82686] = {
			ID = 82686,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103836 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82674, type = 2, visualStyle = 1 }
			}
		},
		[82687] = {
			ID = 82687,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20302, 20304, 20302, 20304, 20302, 20304 },
			entryIDs = { 103837 },
			groupIDs = { 8542, 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82672, type = 2, visualStyle = 1 },
				{ targetNode = 82686, type = 2, visualStyle = 1 }
			}
		},
		[82688] = {
			ID = 82688,
			flags = 8,
			type = 0,
			posX = 6900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103838 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82689, type = 2, visualStyle = 1 }
			}
		},
		[82689] = {
			ID = 82689,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103839 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82709, type = 2, visualStyle = 1 }
			}
		},
		[82690] = {
			ID = 82690,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103840 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82709, type = 2, visualStyle = 1 }
			}
		},
		[82691] = {
			ID = 82691,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103841 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82690, type = 2, visualStyle = 1 },
				{ targetNode = 82692, type = 2, visualStyle = 1 },
				{ targetNode = 82689, type = 2, visualStyle = 1 }
			}
		},
		[82692] = {
			ID = 82692,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103842 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82709, type = 2, visualStyle = 1 },
				{ targetNode = 82684, type = 2, visualStyle = 1 }
			}
		},
		[82693] = {
			ID = 82693,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103843 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82694, type = 2, visualStyle = 1 }
			}
		},
		[82694] = {
			ID = 82694,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103844 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82706, type = 2, visualStyle = 1 },
				{ targetNode = 82692, type = 2, visualStyle = 1 },
				{ targetNode = 82683, type = 2, visualStyle = 1 }
			}
		},
		[82695] = {
			ID = 82695,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103845 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82703, type = 2, visualStyle = 1 },
				{ targetNode = 82556, type = 2, visualStyle = 1 }
			}
		},
		[82696] = {
			ID = 82696,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103846 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82697, type = 2, visualStyle = 1 }
			}
		},
		[82697] = {
			ID = 82697,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103847 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82680, type = 2, visualStyle = 1 },
				{ targetNode = 82682, type = 2, visualStyle = 1 },
				{ targetNode = 82678, type = 2, visualStyle = 1 }
			}
		},
		[82698] = {
			ID = 82698,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103848 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82697, type = 2, visualStyle = 1 }
			}
		},
		[82699] = {
			ID = 82699,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103849 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82706, type = 2, visualStyle = 1 },
				{ targetNode = 82698, type = 2, visualStyle = 1 },
				{ targetNode = 82696, type = 2, visualStyle = 1 }
			}
		},
		[82700] = {
			ID = 82700,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103850 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82699, type = 2, visualStyle = 1 }
			}
		},
		[82701] = {
			ID = 82701,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103851 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82716, type = 2, visualStyle = 1 },
				{ targetNode = 82700, type = 2, visualStyle = 1 },
				{ targetNode = 82720, type = 2, visualStyle = 1 }
			}
		},
		[82702] = {
			ID = 82702,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103852 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82706, type = 2, visualStyle = 1 }
			}
		},
		[82703] = {
			ID = 82703,
			flags = 9,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103853 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82693, type = 2, visualStyle = 1 },
				{ targetNode = 82708, type = 2, visualStyle = 1 },
				{ targetNode = 82716, type = 2, visualStyle = 1 }
			}
		},
		[82704] = {
			ID = 82704,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20287, 20287, 20287, 20287 },
			entryIDs = { 103854 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82703, type = 2, visualStyle = 1 }
			}
		},
		[82705] = {
			ID = 82705,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20296, 20301, 20296, 20301, 20296, 20301, 20296, 20301 },
			entryIDs = { 103855 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82703, type = 2, visualStyle = 1 }
			}
		},
		[82706] = {
			ID = 82706,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103856 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82684, type = 2, visualStyle = 1 },
				{ targetNode = 82697, type = 2, visualStyle = 1 }
			}
		},
		[82707] = {
			ID = 82707,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103858, 103857 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82716, type = 2, visualStyle = 1 }
			}
		},
		[82708] = {
			ID = 82708,
			flags = 9,
			type = 2,
			posX = 5100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103860, 103859 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82691, type = 2, visualStyle = 1 },
				{ targetNode = 82694, type = 2, visualStyle = 1 }
			}
		},
		[82709] = {
			ID = 82709,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103861 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82687, type = 2, visualStyle = 1 },
				{ targetNode = 82685, type = 2, visualStyle = 1 }
			}
		},
		[82710] = {
			ID = 82710,
			flags = 9,
			type = 2,
			posX = 6300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103862, 103678 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82689, type = 2, visualStyle = 1 },
				{ targetNode = 82691, type = 2, visualStyle = 1 }
			}
		},
		[82711] = {
			ID = 82711,
			flags = 8,
			type = 0,
			posX = 6900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103863 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82688, type = 2, visualStyle = 1 },
				{ targetNode = 82710, type = 2, visualStyle = 1 }
			}
		},
		[82712] = {
			ID = 82712,
			flags = 8,
			type = 0,
			posX = 6300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22792, 22792, 22792 },
			entryIDs = { 103864 },
			groupIDs = { 8548, 9090 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82711, type = 2, visualStyle = 1 },
				{ targetNode = 82556, type = 2, visualStyle = 1 }
			}
		},
		[82713] = {
			ID = 82713,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22791, 22792, 22791, 22792, 22791, 22792 },
			entryIDs = { 103865 },
			groupIDs = { 8548, 9089, 9090 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82695, type = 2, visualStyle = 1 },
				{ targetNode = 82712, type = 2, visualStyle = 1 }
			}
		},
		[82714] = {
			ID = 82714,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103866 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82703, type = 2, visualStyle = 1 },
				{ targetNode = 82707, type = 2, visualStyle = 1 },
				{ targetNode = 82701, type = 2, visualStyle = 1 }
			}
		},
		[82715] = {
			ID = 82715,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103867 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82695, type = 2, visualStyle = 1 },
				{ targetNode = 82714, type = 2, visualStyle = 1 },
				{ targetNode = 82705, type = 2, visualStyle = 1 },
				{ targetNode = 82704, type = 2, visualStyle = 1 }
			}
		},
		[82716] = {
			ID = 82716,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103868 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82699, type = 2, visualStyle = 1 },
				{ targetNode = 82694, type = 2, visualStyle = 1 },
				{ targetNode = 82702, type = 2, visualStyle = 1 }
			}
		},
		[82717] = {
			ID = 82717,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22790, 22791, 22790, 22791, 22790, 22791 },
			entryIDs = { 103869 },
			groupIDs = { 8548, 9088, 9089 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82714, type = 2, visualStyle = 1 },
				{ targetNode = 82718, type = 2, visualStyle = 1 }
			}
		},
		[82718] = {
			ID = 82718,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22790, 22790, 22790 },
			entryIDs = { 103870 },
			groupIDs = { 8548, 9088 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82701, type = 2, visualStyle = 1 },
				{ targetNode = 82719, type = 2, visualStyle = 1 },
				{ targetNode = 82720, type = 2, visualStyle = 1 }
			}
		},
		[82719] = {
			ID = 82719,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103871 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82720, type = 2, visualStyle = 1 }
			}
		},
		[82720] = {
			ID = 82720,
			flags = 9,
			type = 2,
			posX = 2700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 103872, 103677 },
			groupIDs = { 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82721, type = 2, visualStyle = 1 },
				{ targetNode = 82696, type = 2, visualStyle = 1 },
				{ targetNode = 82699, type = 2, visualStyle = 1 }
			}
		},
		[82721] = {
			ID = 82721,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20304, 20304, 20304 },
			entryIDs = { 103873 },
			groupIDs = { 8545, 8548 },
			costs = {
				{ ID = 2805, amount = 1 }
			},
			edges = {
				{ targetNode = 82696, type = 2, visualStyle = 1 }
			}
		},
		[86730] = {
			ID = 86730,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 20299, 20298, 20295, 20299, 20298, 20295, 20299, 20298, 20295 },
			entryIDs = { 103688, 108225 },
			groupIDs = { 8543, 8546, 8547, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {}
		},
		[88199] = {
			ID = 88199,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109831 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88202, type = 2, visualStyle = 1 },
				{ targetNode = 88235, type = 2, visualStyle = 1 }
			}
		},
		[88200] = {
			ID = 88200,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 4499,
			maxRanks = 2,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109832 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88212, type = 2, visualStyle = 1 },
				{ targetNode = 88207, type = 2, visualStyle = 1 },
				{ targetNode = 88220, type = 2, visualStyle = 1 }
			}
		},
		[88201] = {
			ID = 88201,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109833 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88209, type = 2, visualStyle = 1 },
				{ targetNode = 88216, type = 2, visualStyle = 1 },
				{ targetNode = 88232, type = 2, visualStyle = 1 }
			}
		},
		[88202] = {
			ID = 88202,
			flags = 1,
			type = 0,
			posX = 10500,
			posY = 4499,
			maxRanks = 2,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109834 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88235, type = 2, visualStyle = 1 },
				{ targetNode = 88222, type = 2, visualStyle = 1 },
				{ targetNode = 88227, type = 2, visualStyle = 1 }
			}
		},
		[88203] = {
			ID = 88203,
			flags = 0,
			type = 0,
			posX = 9899,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109835 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88199, type = 2, visualStyle = 1 },
				{ targetNode = 91048, type = 2, visualStyle = 1 }
			}
		},
		[88204] = {
			ID = 88204,
			flags = 1,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109836 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88233, type = 2, visualStyle = 1 }
			}
		},
		[88205] = {
			ID = 88205,
			flags = 1,
			type = 0,
			posX = 13500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109837 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88224, type = 2, visualStyle = 1 }
			}
		},
		[88206] = {
			ID = 88206,
			flags = 1,
			type = 2,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109839, 109838 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88228, type = 2, visualStyle = 1 },
				{ targetNode = 88214, type = 2, visualStyle = 1 },
				{ targetNode = 88204, type = 2, visualStyle = 1 }
			}
		},
		[88207] = {
			ID = 88207,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109840 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88214, type = 2, visualStyle = 1 },
				{ targetNode = 88224, type = 2, visualStyle = 1 }
			}
		},
		[88208] = {
			ID = 88208,
			flags = 1,
			type = 0,
			posX = 11100,
			posY = 3898,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109842 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88215, type = 2, visualStyle = 1 },
				{ targetNode = 88202, type = 2, visualStyle = 1 }
			}
		},
		[88209] = {
			ID = 88209,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109843 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88210, type = 2, visualStyle = 1 }
			}
		},
		[88210] = {
			ID = 88210,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109844 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88200, type = 2, visualStyle = 1 },
				{ targetNode = 88229, type = 2, visualStyle = 1 }
			}
		},
		[88211] = {
			ID = 88211,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109845 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88215, type = 2, visualStyle = 1 }
			}
		},
		[88212] = {
			ID = 88212,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109846 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88207, type = 2, visualStyle = 1 },
				{ targetNode = 88206, type = 2, visualStyle = 1 }
			}
		},
		[88213] = {
			ID = 88213,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109847 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[88214] = {
			ID = 88214,
			flags = 0,
			type = 0,
			posX = 12299,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109848 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88217, type = 2, visualStyle = 1 }
			}
		},
		[88215] = {
			ID = 88215,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109849 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88221, type = 2, visualStyle = 1 },
				{ targetNode = 88222, type = 2, visualStyle = 1 },
				{ targetNode = 88212, type = 2, visualStyle = 1 }
			}
		},
		[88216] = {
			ID = 88216,
			flags = 1,
			type = 0,
			posX = 12299,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109850 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88210, type = 2, visualStyle = 1 },
				{ targetNode = 88231, type = 2, visualStyle = 1 }
			}
		},
		[88217] = {
			ID = 88217,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109851 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[88218] = {
			ID = 88218,
			flags = 1,
			type = 0,
			posX = 9899,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109852 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88234, type = 2, visualStyle = 1 },
				{ targetNode = 88233, type = 2, visualStyle = 1 }
			}
		},
		[88219] = {
			ID = 88219,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109853 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88231, type = 2, visualStyle = 1 },
				{ targetNode = 91048, type = 2, visualStyle = 1 }
			}
		},
		[88220] = {
			ID = 88220,
			flags = 1,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109854 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88205, type = 2, visualStyle = 1 },
				{ targetNode = 88207, type = 2, visualStyle = 1 }
			}
		},
		[88221] = {
			ID = 88221,
			flags = 1,
			type = 2,
			posX = 11700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109856, 109855 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[88222] = {
			ID = 88222,
			flags = 1,
			type = 0,
			posX = 11100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109857 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88227, type = 2, visualStyle = 1 },
				{ targetNode = 88206, type = 2, visualStyle = 1 }
			}
		},
		[88223] = {
			ID = 88223,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109858 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88201, type = 2, visualStyle = 1 },
				{ targetNode = 88225, type = 2, visualStyle = 1 },
				{ targetNode = 88226, type = 2, visualStyle = 1 }
			}
		},
		[88224] = {
			ID = 88224,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109860, 109859 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88213, type = 2, visualStyle = 1 },
				{ targetNode = 88217, type = 2, visualStyle = 1 }
			}
		},
		[88225] = {
			ID = 88225,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109861 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88203, type = 2, visualStyle = 1 },
				{ targetNode = 88219, type = 2, visualStyle = 1 }
			}
		},
		[88226] = {
			ID = 88226,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109862 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88219, type = 2, visualStyle = 1 },
				{ targetNode = 88216, type = 2, visualStyle = 1 }
			}
		},
		[88227] = {
			ID = 88227,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109863 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88204, type = 2, visualStyle = 1 },
				{ targetNode = 88218, type = 2, visualStyle = 1 }
			}
		},
		[88228] = {
			ID = 88228,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109864 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[88229] = {
			ID = 88229,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109865 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88200, type = 2, visualStyle = 1 },
				{ targetNode = 88215, type = 2, visualStyle = 1 }
			}
		},
		[88231] = {
			ID = 88231,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109867 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88211, type = 2, visualStyle = 1 },
				{ targetNode = 88229, type = 2, visualStyle = 1 },
				{ targetNode = 88208, type = 2, visualStyle = 1 }
			}
		},
		[88232] = {
			ID = 88232,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109868 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88236, type = 2, visualStyle = 1 },
				{ targetNode = 88210, type = 2, visualStyle = 1 }
			}
		},
		[88233] = {
			ID = 88233,
			flags = 1,
			type = 0,
			posX = 10500,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109869 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[88234] = {
			ID = 88234,
			flags = 1,
			type = 0,
			posX = 9899,
			posY = 6899,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248, 20232, 20233, 20248 },
			entryIDs = { 109870 },
			groupIDs = { 8521, 8523, 8526, 8532 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {}
		},
		[88235] = {
			ID = 88235,
			flags = 1,
			type = 0,
			posX = 9899,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109871 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88227, type = 2, visualStyle = 1 }
			}
		},
		[88236] = {
			ID = 88236,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 20232, 20233, 20232, 20233, 20232, 20233, 20232, 20233 },
			entryIDs = { 109873, 109872 },
			groupIDs = { 8521, 8523, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88200, type = 2, visualStyle = 1 },
				{ targetNode = 88220, type = 2, visualStyle = 1 }
			}
		},
		[90062] = {
			ID = 90062,
			flags = 9,
			type = 2,
			posX = 12600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 20144, 20152, 20144, 20152, 20144, 20152 },
			entryIDs = { 111887, 111886 },
			groupIDs = { 8477, 8478, 8487 },
			costs = {
				{ ID = 2794, amount = 1 }
			},
			edges = {
				{ targetNode = 81483, type = 2, visualStyle = 1 }
			}
		},
		[90258] = {
			ID = 90258,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22743, 22745, 22747, 22743, 22745, 22747, 22743, 22745, 22747 },
			entryIDs = { 112108 },
			groupIDs = { 9027, 9028, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90365, type = 2, visualStyle = 1 }
			}
		},
		[90259] = {
			ID = 90259,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22740, 22743, 22745, 22740, 22743, 22745, 22740, 22743, 22745 },
			entryIDs = { 112109 },
			groupIDs = { 9026, 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90365, type = 2, visualStyle = 1 }
			}
		},
		[90260] = {
			ID = 90260,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112302 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90261] = {
			ID = 90261,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 900,
			maxRanks = 1,
			conditionIDs = { 22739, 22740, 22739, 22740, 22739, 22740, 22739 },
			entryIDs = { 112112 },
			groupIDs = { 9026, 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90345, type = 2, visualStyle = 1 },
				{ targetNode = 90326, type = 2, visualStyle = 1 },
				{ targetNode = 90372, type = 2, visualStyle = 1 }
			}
		},
		[90262] = {
			ID = 90262,
			flags = 8,
			type = 0,
			posX = 9300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112113 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90263] = {
			ID = 90263,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112114 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90264] = {
			ID = 90264,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112115 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90449, type = 2, visualStyle = 1 }
			}
		},
		[90265] = {
			ID = 90265,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112116 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90435, type = 2, visualStyle = 1 }
			}
		},
		[90266] = {
			ID = 90266,
			flags = 9,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112117 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90267] = {
			ID = 90267,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112119, 112118 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90444, type = 2, visualStyle = 1 }
			}
		},
		[90268] = {
			ID = 90268,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112120 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90443, type = 2, visualStyle = 1 },
				{ targetNode = 90267, type = 2, visualStyle = 1 }
			}
		},
		[90269] = {
			ID = 90269,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112121 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90290, type = 2, visualStyle = 1 }
			}
		},
		[90270] = {
			ID = 90270,
			flags = 8,
			type = 0,
			posX = 11699,
			posY = 898,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112122 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90271, type = 2, visualStyle = 1 }
			}
		},
		[90271] = {
			ID = 90271,
			flags = 8,
			type = 0,
			posX = 11705,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112123 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90276, type = 2, visualStyle = 1 },
				{ targetNode = 90278, type = 2, visualStyle = 1 },
				{ targetNode = 90273, type = 2, visualStyle = 1 }
			}
		},
		[90272] = {
			ID = 90272,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2699,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112124 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90292, type = 2, visualStyle = 1 }
			}
		},
		[90273] = {
			ID = 90273,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112125 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90272, type = 2, visualStyle = 1 },
				{ targetNode = 90274, type = 2, visualStyle = 1 }
			}
		},
		[90274] = {
			ID = 90274,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112126 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90292, type = 2, visualStyle = 1 }
			}
		},
		[90275] = {
			ID = 90275,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2699,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112127 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90290, type = 2, visualStyle = 1 }
			}
		},
		[90276] = {
			ID = 90276,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112128 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90269, type = 2, visualStyle = 1 },
				{ targetNode = 90274, type = 2, visualStyle = 1 },
				{ targetNode = 90275, type = 2, visualStyle = 1 },
				{ targetNode = 90277, type = 2, visualStyle = 1 }
			}
		},
		[90277] = {
			ID = 90277,
			flags = 9,
			type = 0,
			posX = 10800,
			posY = 2699,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112129 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90282, type = 2, visualStyle = 1 }
			}
		},
		[90278] = {
			ID = 90278,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112130 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90277, type = 2, visualStyle = 1 },
				{ targetNode = 90279, type = 2, visualStyle = 1 }
			}
		},
		[90279] = {
			ID = 90279,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112131 },
			groupIDs = { 9029, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90282, type = 2, visualStyle = 1 }
			}
		},
		[90280] = {
			ID = 90280,
			flags = 8,
			type = 0,
			posX = 9300,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112132 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90437, type = 2, visualStyle = 1 }
			}
		},
		[90281] = {
			ID = 90281,
			flags = 8,
			type = 0,
			posX = 9300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112133 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90280, type = 2, visualStyle = 1 }
			}
		},
		[90282] = {
			ID = 90282,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112134 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90286, type = 2, visualStyle = 1 },
				{ targetNode = 90281, type = 2, visualStyle = 1 },
				{ targetNode = 90284, type = 2, visualStyle = 1 }
			}
		},
		[90283] = {
			ID = 90283,
			flags = 9,
			type = 0,
			posX = 9900,
			posY = 4499,
			maxRanks = 2,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112135 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90437, type = 2, visualStyle = 1 }
			}
		},
		[90284] = {
			ID = 90284,
			flags = 9,
			type = 0,
			posX = 9900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112136 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90283, type = 2, visualStyle = 1 },
				{ targetNode = 90285, type = 2, visualStyle = 1 }
			}
		},
		[90285] = {
			ID = 90285,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112137 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90437, type = 2, visualStyle = 1 },
				{ targetNode = 90442, type = 2, visualStyle = 1 }
			}
		},
		[90286] = {
			ID = 90286,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112138 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90285, type = 2, visualStyle = 1 }
			}
		},
		[90287] = {
			ID = 90287,
			flags = 9,
			type = 2,
			posX = 12000,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112140, 112139 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90442, type = 2, visualStyle = 1 }
			}
		},
		[90288] = {
			ID = 90288,
			flags = 9,
			type = 2,
			posX = 11400,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112142, 112141 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90442, type = 2, visualStyle = 1 }
			}
		},
		[90289] = {
			ID = 90289,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112143 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90287, type = 2, visualStyle = 1 },
				{ targetNode = 90288, type = 2, visualStyle = 1 }
			}
		},
		[90290] = {
			ID = 90290,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112144 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90286, type = 2, visualStyle = 1 },
				{ targetNode = 90289, type = 2, visualStyle = 1 },
				{ targetNode = 90291, type = 2, visualStyle = 1 }
			}
		},
		[90291] = {
			ID = 90291,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112145 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90443, type = 2, visualStyle = 1 }
			}
		},
		[90292] = {
			ID = 90292,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112146 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90268, type = 2, visualStyle = 1 },
				{ targetNode = 90291, type = 2, visualStyle = 1 },
				{ targetNode = 90293, type = 2, visualStyle = 1 }
			}
		},
		[90293] = {
			ID = 90293,
			flags = 8,
			type = 0,
			posX = 14099,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112147 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90294, type = 2, visualStyle = 1 }
			}
		},
		[90294] = {
			ID = 90294,
			flags = 8,
			type = 0,
			posX = 14099,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112148 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90444, type = 2, visualStyle = 1 }
			}
		},
		[90295] = {
			ID = 90295,
			flags = 8,
			type = 0,
			posX = 11698,
			posY = 898,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112149 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90298, type = 2, visualStyle = 1 }
			}
		},
		[90296] = {
			ID = 90296,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112150 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90451, type = 2, visualStyle = 1 }
			}
		},
		[90297] = {
			ID = 90297,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112151 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90296, type = 2, visualStyle = 1 },
				{ targetNode = 90452, type = 2, visualStyle = 1 },
				{ targetNode = 90303, type = 2, visualStyle = 1 }
			}
		},
		[90298] = {
			ID = 90298,
			flags = 8,
			type = 0,
			posX = 11698,
			posY = 1497,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112152 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90305, type = 2, visualStyle = 1 },
				{ targetNode = 90297, type = 2, visualStyle = 1 },
				{ targetNode = 90299, type = 2, visualStyle = 1 }
			}
		},
		[90299] = {
			ID = 90299,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112153 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90303, type = 2, visualStyle = 1 }
			}
		},
		[90300] = {
			ID = 90300,
			flags = 9,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112154 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90312, type = 2, visualStyle = 1 }
			}
		},
		[90301] = {
			ID = 90301,
			flags = 9,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112155 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90312, type = 2, visualStyle = 1 }
			}
		},
		[90302] = {
			ID = 90302,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112156 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90312, type = 2, visualStyle = 1 }
			}
		},
		[90303] = {
			ID = 90303,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112157 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90300, type = 2, visualStyle = 1 },
				{ targetNode = 90301, type = 2, visualStyle = 1 },
				{ targetNode = 90302, type = 2, visualStyle = 1 }
			}
		},
		[90304] = {
			ID = 90304,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112158 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90309, type = 2, visualStyle = 1 }
			}
		},
		[90305] = {
			ID = 90305,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 2099,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112159 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90303, type = 2, visualStyle = 1 },
				{ targetNode = 90304, type = 2, visualStyle = 1 },
				{ targetNode = 90306, type = 2, visualStyle = 1 }
			}
		},
		[90306] = {
			ID = 90306,
			flags = 9,
			type = 0,
			posX = 9300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112160 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90309, type = 2, visualStyle = 1 }
			}
		},
		[90307] = {
			ID = 90307,
			flags = 9,
			type = 0,
			posX = 9299,
			posY = 3898,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112161 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90319, type = 2, visualStyle = 1 }
			}
		},
		[90308] = {
			ID = 90308,
			flags = 9,
			type = 0,
			posX = 10498,
			posY = 3898,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112162 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90319, type = 2, visualStyle = 1 }
			}
		},
		[90309] = {
			ID = 90309,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112163 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90320, type = 2, visualStyle = 1 },
				{ targetNode = 90307, type = 2, visualStyle = 1 },
				{ targetNode = 90308, type = 2, visualStyle = 1 },
				{ targetNode = 90312, type = 2, visualStyle = 1 }
			}
		},
		[90310] = {
			ID = 90310,
			flags = 9,
			type = 2,
			posX = 12298,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112165, 112164 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90315, type = 2, visualStyle = 1 }
			}
		},
		[90311] = {
			ID = 90311,
			flags = 9,
			type = 0,
			posX = 11698,
			posY = 4497,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112166 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90315, type = 2, visualStyle = 1 }
			}
		},
		[90312] = {
			ID = 90312,
			flags = 8,
			type = 0,
			posX = 11698,
			posY = 3898,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112167 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90310, type = 2, visualStyle = 1 },
				{ targetNode = 90311, type = 2, visualStyle = 1 },
				{ targetNode = 90313, type = 2, visualStyle = 1 }
			}
		},
		[90313] = {
			ID = 90313,
			flags = 9,
			type = 2,
			posX = 11100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112169, 112168 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90315, type = 2, visualStyle = 1 }
			}
		},
		[90314] = {
			ID = 90314,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112170 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90435, type = 2, visualStyle = 1 }
			}
		},
		[90315] = {
			ID = 90315,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112171 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90434, type = 2, visualStyle = 1 },
				{ targetNode = 90265, type = 2, visualStyle = 1 },
				{ targetNode = 90314, type = 2, visualStyle = 1 },
				{ targetNode = 90432, type = 2, visualStyle = 1 },
				{ targetNode = 90314, type = 2, visualStyle = 1 },
				{ targetNode = 90317, type = 2, visualStyle = 1 }
			}
		},
		[90316] = {
			ID = 90316,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112172 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90317] = {
			ID = 90317,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112173 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90262, type = 2, visualStyle = 1 },
				{ targetNode = 90316, type = 2, visualStyle = 1 }
			}
		},
		[90318] = {
			ID = 90318,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112174 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90317, type = 2, visualStyle = 1 }
			}
		},
		[90319] = {
			ID = 90319,
			flags = 9,
			type = 2,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112176, 112175 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90318, type = 2, visualStyle = 1 }
			}
		},
		[90320] = {
			ID = 90320,
			flags = 9,
			type = 2,
			posX = 9898,
			posY = 3897,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112177, 112111 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90319, type = 2, visualStyle = 1 }
			}
		},
		[90321] = {
			ID = 90321,
			flags = 8,
			type = 0,
			posX = 6000,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112178 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90322] = {
			ID = 90322,
			flags = 9,
			type = 0,
			posX = 3900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22741, 22743, 22745, 22741, 22743, 22745, 22741 },
			entryIDs = { 112179 },
			groupIDs = { 9027, 9028, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90323] = {
			ID = 90323,
			flags = 8,
			type = 0,
			posX = 4800,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112180 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90324] = {
			ID = 90324,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 5098,
			maxRanks = 1,
			conditionIDs = { 22740, 22743, 22745, 22740, 22743, 22745, 22740, 22743, 22745 },
			entryIDs = { 112181 },
			groupIDs = { 9026, 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90325] = {
			ID = 90325,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 900,
			maxRanks = 1,
			conditionIDs = { 22749, 22747, 22749, 22747, 22749, 22747, 22749 },
			entryIDs = { 112182 },
			groupIDs = { 9027, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90386, type = 2, visualStyle = 1 },
				{ targetNode = 90372, type = 2, visualStyle = 1 },
				{ targetNode = 90326, type = 2, visualStyle = 1 }
			}
		},
		[90326] = {
			ID = 90326,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112183 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90371, type = 2, visualStyle = 1 }
			}
		},
		[90327] = {
			ID = 90327,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 900,
			maxRanks = 1,
			conditionIDs = { 22748, 22741, 22748, 22741, 22748, 22741, 22748 },
			entryIDs = { 112184 },
			groupIDs = { 9027, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90326, type = 2, visualStyle = 1 },
				{ targetNode = 90372, type = 2, visualStyle = 1 },
				{ targetNode = 90328, type = 2, visualStyle = 1 }
			}
		},
		[90328] = {
			ID = 90328,
			flags = 9,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112185 },
			groupIDs = { 9027, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90344, type = 2, visualStyle = 1 },
				{ targetNode = 90371, type = 2, visualStyle = 1 },
				{ targetNode = 90385, type = 2, visualStyle = 1 }
			}
		},
		[90329] = {
			ID = 90329,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112186 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90344, type = 2, visualStyle = 1 }
			}
		},
		[90330] = {
			ID = 90330,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 900,
			maxRanks = 1,
			conditionIDs = { 22742, 22742, 22742, 22742 },
			entryIDs = { 112187 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90328, type = 2, visualStyle = 1 },
				{ targetNode = 90386, type = 2, visualStyle = 1 },
				{ targetNode = 90329, type = 2, visualStyle = 1 },
				{ targetNode = 90345, type = 2, visualStyle = 1 },
				{ targetNode = 90331, type = 2, visualStyle = 1 }
			}
		},
		[90331] = {
			ID = 90331,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112188 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90344, type = 2, visualStyle = 1 },
				{ targetNode = 90332, type = 2, visualStyle = 1 }
			}
		},
		[90332] = {
			ID = 90332,
			flags = 9,
			type = 2,
			posX = 5700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112190, 112189 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90336, type = 2, visualStyle = 1 }
			}
		},
		[90333] = {
			ID = 90333,
			flags = 9,
			type = 2,
			posX = 6300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22745, 22741, 22745, 22741, 22745, 22741 },
			entryIDs = { 112192, 112191 },
			groupIDs = { 9027, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90377, type = 2, visualStyle = 1 }
			}
		},
		[90334] = {
			ID = 90334,
			flags = 9,
			type = 2,
			posX = 6297,
			posY = 3298,
			maxRanks = 1,
			conditionIDs = { 22740, 22745, 22740, 22745, 22740, 22745 },
			entryIDs = { 112194, 112193 },
			groupIDs = { 9026, 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90377, type = 2, visualStyle = 1 }
			}
		},
		[90335] = {
			ID = 90335,
			flags = 9,
			type = 2,
			posX = 6300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22745, 22747, 22745, 22747, 22745, 22747 },
			entryIDs = { 112196, 112195 },
			groupIDs = { 9027, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90377, type = 2, visualStyle = 1 }
			}
		},
		[90336] = {
			ID = 90336,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112197 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90378, type = 2, visualStyle = 1 },
				{ targetNode = 90333, type = 2, visualStyle = 1 },
				{ targetNode = 90334, type = 2, visualStyle = 1 },
				{ targetNode = 90335, type = 2, visualStyle = 1 },
				{ targetNode = 90337, type = 2, visualStyle = 1 }
			}
		},
		[90337] = {
			ID = 90337,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112198 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90377, type = 2, visualStyle = 1 },
				{ targetNode = 90340, type = 2, visualStyle = 1 }
			}
		},
		[90338] = {
			ID = 90338,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22741, 22743, 22745, 22741, 22743, 22745, 22741 },
			entryIDs = { 112199 },
			groupIDs = { 9027, 9028, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90375, type = 2, visualStyle = 1 }
			}
		},
		[90339] = {
			ID = 90339,
			flags = 8,
			type = 0,
			posX = 5695,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22740, 22743, 22745, 22740, 22743, 22745, 22740, 22743, 22745 },
			entryIDs = { 112200 },
			groupIDs = { 9026, 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90375, type = 2, visualStyle = 1 }
			}
		},
		[90340] = {
			ID = 90340,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112201 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90381, type = 2, visualStyle = 1 },
				{ targetNode = 90376, type = 2, visualStyle = 1 },
				{ targetNode = 90338, type = 2, visualStyle = 1 },
				{ targetNode = 90339, type = 2, visualStyle = 1 },
				{ targetNode = 90381, type = 2, visualStyle = 1 }
			}
		},
		[90341] = {
			ID = 90341,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112202 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90381, type = 2, visualStyle = 1 }
			}
		},
		[90342] = {
			ID = 90342,
			flags = 9,
			type = 2,
			posX = 4500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112204, 112203 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90340, type = 2, visualStyle = 1 },
				{ targetNode = 90341, type = 2, visualStyle = 1 },
				{ targetNode = 90382, type = 2, visualStyle = 1 }
			}
		},
		[90343] = {
			ID = 90343,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112205 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90342, type = 2, visualStyle = 1 },
				{ targetNode = 90337, type = 2, visualStyle = 1 },
				{ targetNode = 90342, type = 2, visualStyle = 1 }
			}
		},
		[90344] = {
			ID = 90344,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112206 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90343, type = 2, visualStyle = 1 },
				{ targetNode = 90336, type = 2, visualStyle = 1 },
				{ targetNode = 90343, type = 2, visualStyle = 1 }
			}
		},
		[90345] = {
			ID = 90345,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112207 },
			groupIDs = { 9026, 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90385, type = 2, visualStyle = 1 },
				{ targetNode = 90344, type = 2, visualStyle = 1 },
				{ targetNode = 90371, type = 2, visualStyle = 1 }
			}
		},
		[90346] = {
			ID = 90346,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112208 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90355, type = 2, visualStyle = 1 },
				{ targetNode = 90353, type = 2, visualStyle = 1 },
				{ targetNode = 90355, type = 2, visualStyle = 1 },
				{ targetNode = 90353, type = 2, visualStyle = 1 }
			}
		},
		[90347] = {
			ID = 90347,
			flags = 9,
			type = 0,
			posX = 2100,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 22745, 22741, 22745, 22741, 22745, 22741 },
			entryIDs = { 112209 },
			groupIDs = { 9027, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90368, type = 2, visualStyle = 1 }
			}
		},
		[90348] = {
			ID = 90348,
			flags = 9,
			type = 2,
			posX = 2100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112211, 112210 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90352, type = 2, visualStyle = 1 },
				{ targetNode = 90370, type = 2, visualStyle = 1 },
				{ targetNode = 90350, type = 2, visualStyle = 1 }
			}
		},
		[90349] = {
			ID = 90349,
			flags = 9,
			type = 0,
			posX = 2100,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 22745, 22747, 22745, 22747, 22745, 22747 },
			entryIDs = { 112212 },
			groupIDs = { 9027, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90368, type = 2, visualStyle = 1 }
			}
		},
		[90350] = {
			ID = 90350,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112213 },
			groupIDs = { 9027, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90369, type = 2, visualStyle = 1 },
				{ targetNode = 90349, type = 2, visualStyle = 1 },
				{ targetNode = 90353, type = 2, visualStyle = 1 },
				{ targetNode = 90351, type = 2, visualStyle = 1 }
			}
		},
		[90351] = {
			ID = 90351,
			flags = 9,
			type = 2,
			posX = 1500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112215, 112214 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90368, type = 2, visualStyle = 1 }
			}
		},
		[90352] = {
			ID = 90352,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22741, 22741, 22741 },
			entryIDs = { 112216 },
			groupIDs = { 9027, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90353, type = 2, visualStyle = 1 },
				{ targetNode = 90347, type = 2, visualStyle = 1 },
				{ targetNode = 90369, type = 2, visualStyle = 1 },
				{ targetNode = 90351, type = 2, visualStyle = 1 },
				{ targetNode = 90353, type = 2, visualStyle = 1 }
			}
		},
		[90353] = {
			ID = 90353,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112217 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90367, type = 2, visualStyle = 1 },
				{ targetNode = 90361, type = 2, visualStyle = 1 },
				{ targetNode = 90368, type = 2, visualStyle = 1 },
				{ targetNode = 90354, type = 2, visualStyle = 1 }
			}
		},
		[90354] = {
			ID = 90354,
			flags = 9,
			type = 0,
			posX = 2700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22745, 22741, 22745, 22741, 22745, 22741 },
			entryIDs = { 112218 },
			groupIDs = { 9027, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90366, type = 2, visualStyle = 1 },
				{ targetNode = 90360, type = 2, visualStyle = 1 }
			}
		},
		[90355] = {
			ID = 90355,
			flags = 9,
			type = 0,
			posX = 3300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112219 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90382, type = 2, visualStyle = 1 },
				{ targetNode = 90354, type = 2, visualStyle = 1 },
				{ targetNode = 90361, type = 2, visualStyle = 1 },
				{ targetNode = 90367, type = 2, visualStyle = 1 },
				{ targetNode = 90356, type = 2, visualStyle = 1 }
			}
		},
		[90356] = {
			ID = 90356,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112220 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90360, type = 2, visualStyle = 1 }
			}
		},
		[90357] = {
			ID = 90357,
			flags = 8,
			type = 0,
			posX = 3000,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112221 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90358] = {
			ID = 90358,
			flags = 8,
			type = 0,
			posX = 3598,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112222 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90359] = {
			ID = 90359,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112223 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90357, type = 2, visualStyle = 1 },
				{ targetNode = 90358, type = 2, visualStyle = 1 }
			}
		},
		[90360] = {
			ID = 90360,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112224 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90359, type = 2, visualStyle = 1 }
			}
		},
		[90361] = {
			ID = 90361,
			flags = 8,
			type = 0,
			posX = 2698,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22740, 22745, 22740, 22745, 22740, 22745 },
			entryIDs = { 112225 },
			groupIDs = { 9026, 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90259, type = 2, visualStyle = 1 },
				{ targetNode = 90360, type = 2, visualStyle = 1 },
				{ targetNode = 90366, type = 2, visualStyle = 1 }
			}
		},
		[90362] = {
			ID = 90362,
			flags = 9,
			type = 2,
			posX = 2100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22747, 22743, 22745, 22747, 22743, 22745, 22747 },
			entryIDs = { 112227, 112226 },
			groupIDs = { 9027, 9028, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90363] = {
			ID = 90363,
			flags = 9,
			type = 2,
			posX = 2100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22741, 22743, 22745, 22741, 22743, 22745, 22741 },
			entryIDs = { 112229, 112228 },
			groupIDs = { 9027, 9028, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90364] = {
			ID = 90364,
			flags = 9,
			type = 2,
			posX = 2100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22740, 22743, 22745, 22740, 22743, 22745, 22740, 22743, 22745 },
			entryIDs = { 112231, 112230 },
			groupIDs = { 9026, 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90365] = {
			ID = 90365,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112232 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90362, type = 2, visualStyle = 1 },
				{ targetNode = 90363, type = 2, visualStyle = 1 },
				{ targetNode = 90364, type = 2, visualStyle = 1 }
			}
		},
		[90366] = {
			ID = 90366,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22743, 22745, 22741, 22743, 22745, 22741, 22743, 22745, 22741 },
			entryIDs = { 112233 },
			groupIDs = { 9027, 9028, 9031, 9034 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90365, type = 2, visualStyle = 1 }
			}
		},
		[90367] = {
			ID = 90367,
			flags = 9,
			type = 0,
			posX = 2700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22745, 22747, 22745, 22747, 22745, 22747 },
			entryIDs = { 112234 },
			groupIDs = { 9027, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90258, type = 2, visualStyle = 1 },
				{ targetNode = 90360, type = 2, visualStyle = 1 },
				{ targetNode = 90366, type = 2, visualStyle = 1 }
			}
		},
		[90368] = {
			ID = 90368,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112235 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90259, type = 2, visualStyle = 1 },
				{ targetNode = 90258, type = 2, visualStyle = 1 },
				{ targetNode = 90366, type = 2, visualStyle = 1 },
				{ targetNode = 90361, type = 2, visualStyle = 1 },
				{ targetNode = 90354, type = 2, visualStyle = 1 },
				{ targetNode = 90367, type = 2, visualStyle = 1 }
			}
		},
		[90369] = {
			ID = 90369,
			flags = 8,
			type = 0,
			posX = 2099,
			posY = 3299,
			maxRanks = 2,
			conditionIDs = { 22740, 22745, 22740, 22745, 22740, 22745 },
			entryIDs = { 112236 },
			groupIDs = { 9026, 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90368, type = 2, visualStyle = 1 }
			}
		},
		[90370] = {
			ID = 90370,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112237 },
			groupIDs = { 9026, 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90353, type = 2, visualStyle = 1 },
				{ targetNode = 90351, type = 2, visualStyle = 1 },
				{ targetNode = 90369, type = 2, visualStyle = 1 }
			}
		},
		[90371] = {
			ID = 90371,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112238 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90346, type = 2, visualStyle = 1 },
				{ targetNode = 90346, type = 2, visualStyle = 1 },
				{ targetNode = 90352, type = 2, visualStyle = 1 },
				{ targetNode = 90350, type = 2, visualStyle = 1 },
				{ targetNode = 90370, type = 2, visualStyle = 1 }
			}
		},
		[90372] = {
			ID = 90372,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112239 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90348, type = 2, visualStyle = 1 },
				{ targetNode = 90371, type = 2, visualStyle = 1 }
			}
		},
		[90373] = {
			ID = 90373,
			flags = 9,
			type = 0,
			posX = 3900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22747, 22743, 22745, 22747, 22743, 22745, 22747 },
			entryIDs = { 112240 },
			groupIDs = { 9027, 9028, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90374] = {
			ID = 90374,
			flags = 8,
			type = 0,
			posX = 5400,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112241 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90375] = {
			ID = 90375,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112242 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90321, type = 2, visualStyle = 1 },
				{ targetNode = 90374, type = 2, visualStyle = 1 }
			}
		},
		[90376] = {
			ID = 90376,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22747, 22743, 22745, 22747, 22743, 22745, 22747 },
			entryIDs = { 112243 },
			groupIDs = { 9027, 9028, 9031, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90375, type = 2, visualStyle = 1 }
			}
		},
		[90377] = {
			ID = 90377,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112244 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90340, type = 2, visualStyle = 1 },
				{ targetNode = 90338, type = 2, visualStyle = 1 },
				{ targetNode = 90339, type = 2, visualStyle = 1 },
				{ targetNode = 90376, type = 2, visualStyle = 1 }
			}
		},
		[90378] = {
			ID = 90378,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112245 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90377, type = 2, visualStyle = 1 }
			}
		},
		[90379] = {
			ID = 90379,
			flags = 8,
			type = 0,
			posX = 4200,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112246 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {}
		},
		[90380] = {
			ID = 90380,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112247 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90323, type = 2, visualStyle = 1 },
				{ targetNode = 90379, type = 2, visualStyle = 1 }
			}
		},
		[90381] = {
			ID = 90381,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22743, 22745, 22743, 22745, 22743, 22745 },
			entryIDs = { 112248 },
			groupIDs = { 9027, 9028, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90380, type = 2, visualStyle = 1 }
			}
		},
		[90382] = {
			ID = 90382,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112249 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90381, type = 2, visualStyle = 1 },
				{ targetNode = 90322, type = 2, visualStyle = 1 },
				{ targetNode = 90324, type = 2, visualStyle = 1 },
				{ targetNode = 90360, type = 2, visualStyle = 1 },
				{ targetNode = 90373, type = 2, visualStyle = 1 },
				{ targetNode = 90381, type = 2, visualStyle = 1 }
			}
		},
		[90383] = {
			ID = 90383,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22745, 22745, 22745 },
			entryIDs = { 112251, 112250 },
			groupIDs = { 9027, 9031 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90382, type = 2, visualStyle = 1 }
			}
		},
		[90384] = {
			ID = 90384,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112252 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90383, type = 2, visualStyle = 1 }
			}
		},
		[90385] = {
			ID = 90385,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112253 },
			groupIDs = { 9027 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90384, type = 2, visualStyle = 1 },
				{ targetNode = 90343, type = 2, visualStyle = 1 },
				{ targetNode = 90346, type = 2, visualStyle = 1 },
				{ targetNode = 90384, type = 2, visualStyle = 1 }
			}
		},
		[90386] = {
			ID = 90386,
			flags = 9,
			type = 0,
			posX = 3900,
			posY = 1498,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112254 },
			groupIDs = { 9027, 9033 },
			costs = {
				{ ID = 2896, amount = 1 }
			},
			edges = {
				{ targetNode = 90344, type = 2, visualStyle = 1 },
				{ targetNode = 90371, type = 2, visualStyle = 1 },
				{ targetNode = 90385, type = 2, visualStyle = 1 }
			}
		},
		[90387] = {
			ID = 90387,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112255 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90426, type = 2, visualStyle = 1 }
			}
		},
		[90388] = {
			ID = 90388,
			flags = 9,
			type = 0,
			posX = 14100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112256 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90389, type = 2, visualStyle = 1 }
			}
		},
		[90389] = {
			ID = 90389,
			flags = 9,
			type = 2,
			posX = 14100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112258, 112257 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90390] = {
			ID = 90390,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2698,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112259 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90428, type = 2, visualStyle = 1 }
			}
		},
		[90391] = {
			ID = 90391,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112260 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90425, type = 2, visualStyle = 1 }
			}
		},
		[90392] = {
			ID = 90392,
			flags = 8,
			type = 0,
			posX = 11699,
			posY = 898,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112261 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90396, type = 2, visualStyle = 1 }
			}
		},
		[90393] = {
			ID = 90393,
			flags = 8,
			type = 0,
			posX = 11999,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112262 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90408, type = 2, visualStyle = 1 }
			}
		},
		[90394] = {
			ID = 90394,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112263 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90408, type = 2, visualStyle = 1 }
			}
		},
		[90395] = {
			ID = 90395,
			flags = 8,
			type = 0,
			posX = 11699,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112264 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90399, type = 2, visualStyle = 1 },
				{ targetNode = 90429, type = 2, visualStyle = 1 },
				{ targetNode = 90393, type = 2, visualStyle = 1 },
				{ targetNode = 90394, type = 2, visualStyle = 1 }
			}
		},
		[90396] = {
			ID = 90396,
			flags = 8,
			type = 0,
			posX = 11696,
			posY = 1496,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112265 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90430, type = 2, visualStyle = 1 },
				{ targetNode = 90395, type = 2, visualStyle = 1 },
				{ targetNode = 90398, type = 2, visualStyle = 1 }
			}
		},
		[90397] = {
			ID = 90397,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 2699,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112266 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90403, type = 2, visualStyle = 1 }
			}
		},
		[90398] = {
			ID = 90398,
			flags = 8,
			type = 0,
			posX = 10799,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112267 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90397, type = 2, visualStyle = 1 },
				{ targetNode = 90399, type = 2, visualStyle = 1 }
			}
		},
		[90399] = {
			ID = 90399,
			flags = 9,
			type = 0,
			posX = 10800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112268 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90403, type = 2, visualStyle = 1 }
			}
		},
		[90400] = {
			ID = 90400,
			flags = 9,
			type = 0,
			posX = 9300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112269 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90422, type = 2, visualStyle = 1 }
			}
		},
		[90401] = {
			ID = 90401,
			flags = 9,
			type = 0,
			posX = 9898,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112270 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90421, type = 2, visualStyle = 1 }
			}
		},
		[90402] = {
			ID = 90402,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3899,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112271 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90401, type = 2, visualStyle = 1 },
				{ targetNode = 90405, type = 2, visualStyle = 1 }
			}
		},
		[90403] = {
			ID = 90403,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 3297,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112272 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90400, type = 2, visualStyle = 1 },
				{ targetNode = 90402, type = 2, visualStyle = 1 },
				{ targetNode = 90404, type = 2, visualStyle = 1 }
			}
		},
		[90404] = {
			ID = 90404,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3899,
			maxRanks = 2,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112273 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90405, type = 2, visualStyle = 1 },
				{ targetNode = 90405, type = 2, visualStyle = 1 }
			}
		},
		[90405] = {
			ID = 90405,
			flags = 9,
			type = 0,
			posX = 10499,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112274 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90421, type = 2, visualStyle = 1 }
			}
		},
		[90406] = {
			ID = 90406,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112275 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90405, type = 2, visualStyle = 1 },
				{ targetNode = 90405, type = 2, visualStyle = 1 },
				{ targetNode = 90412, type = 2, visualStyle = 1 }
			}
		},
		[90407] = {
			ID = 90407,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112276 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90412, type = 2, visualStyle = 1 }
			}
		},
		[90408] = {
			ID = 90408,
			flags = 8,
			type = 0,
			posX = 11699,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112277 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90406, type = 2, visualStyle = 1 },
				{ targetNode = 90407, type = 2, visualStyle = 1 },
				{ targetNode = 90411, type = 2, visualStyle = 1 }
			}
		},
		[90409] = {
			ID = 90409,
			flags = 8,
			type = 0,
			posX = 12898,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112278 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90410, type = 2, visualStyle = 1 }
			}
		},
		[90410] = {
			ID = 90410,
			flags = 8,
			type = 0,
			posX = 12898,
			posY = 4498,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112279 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90425, type = 2, visualStyle = 1 }
			}
		},
		[90411] = {
			ID = 90411,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112280 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90410, type = 2, visualStyle = 1 },
				{ targetNode = 90412, type = 2, visualStyle = 1 }
			}
		},
		[90412] = {
			ID = 90412,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112281 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90416, type = 2, visualStyle = 1 }
			}
		},
		[90413] = {
			ID = 90413,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112282 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90414] = {
			ID = 90414,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 6299,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112283 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90415] = {
			ID = 90415,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112285, 112284 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90413, type = 2, visualStyle = 1 },
				{ targetNode = 90414, type = 2, visualStyle = 1 }
			}
		},
		[90416] = {
			ID = 90416,
			flags = 8,
			type = 0,
			posX = 11699,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112286 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90424, type = 2, visualStyle = 1 },
				{ targetNode = 90415, type = 2, visualStyle = 1 },
				{ targetNode = 90418, type = 2, visualStyle = 1 }
			}
		},
		[90417] = {
			ID = 90417,
			flags = 9,
			type = 2,
			posX = 10500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112288, 112287 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90418] = {
			ID = 90418,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112289 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90417, type = 2, visualStyle = 1 }
			}
		},
		[90419] = {
			ID = 90419,
			flags = 9,
			type = 0,
			posX = 9300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112290 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90420] = {
			ID = 90420,
			flags = 9,
			type = 0,
			posX = 9300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112291 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90419, type = 2, visualStyle = 1 }
			}
		},
		[90421] = {
			ID = 90421,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 5099,
			maxRanks = 2,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112292 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90418, type = 2, visualStyle = 1 },
				{ targetNode = 90420, type = 2, visualStyle = 1 }
			}
		},
		[90422] = {
			ID = 90422,
			flags = 8,
			type = 0,
			posX = 9297,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112293 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90421, type = 2, visualStyle = 1 }
			}
		},
		[90423] = {
			ID = 90423,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112294 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90424] = {
			ID = 90424,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112295 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90423, type = 2, visualStyle = 1 }
			}
		},
		[90425] = {
			ID = 90425,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5099,
			maxRanks = 2,
			conditionIDs = { 22744, 22746, 22747, 22744, 22746, 22747, 22744, 22746, 22747 },
			entryIDs = { 112296 },
			groupIDs = { 9029, 9030, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90388, type = 2, visualStyle = 1 },
				{ targetNode = 90424, type = 2, visualStyle = 1 }
			}
		},
		[90426] = {
			ID = 90426,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112297 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90425, type = 2, visualStyle = 1 }
			}
		},
		[90427] = {
			ID = 90427,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112298 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90391, type = 2, visualStyle = 1 },
				{ targetNode = 90410, type = 2, visualStyle = 1 },
				{ targetNode = 90426, type = 2, visualStyle = 1 }
			}
		},
		[90428] = {
			ID = 90428,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3299,
			maxRanks = 1,
			conditionIDs = { 22746, 22747, 22746, 22747, 22746, 22747 },
			entryIDs = { 112299 },
			groupIDs = { 9029, 9032, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90387, type = 2, visualStyle = 1 },
				{ targetNode = 90409, type = 2, visualStyle = 1 },
				{ targetNode = 90427, type = 2, visualStyle = 1 }
			}
		},
		[90429] = {
			ID = 90429,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112300 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90428, type = 2, visualStyle = 1 }
			}
		},
		[90430] = {
			ID = 90430,
			flags = 8,
			type = 0,
			posX = 12599,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22747, 22747, 22747 },
			entryIDs = { 112301 },
			groupIDs = { 9029, 9033 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90390, type = 2, visualStyle = 1 },
				{ targetNode = 90429, type = 2, visualStyle = 1 }
			}
		},
		[90431] = {
			ID = 90431,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112303 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90432] = {
			ID = 90432,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112304 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90431, type = 2, visualStyle = 1 },
				{ targetNode = 90260, type = 2, visualStyle = 1 }
			}
		},
		[90433] = {
			ID = 90433,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112305 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90432, type = 2, visualStyle = 1 }
			}
		},
		[90434] = {
			ID = 90434,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112306 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90435, type = 2, visualStyle = 1 }
			}
		},
		[90435] = {
			ID = 90435,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22740, 22744, 22746, 22740, 22744, 22746, 22740, 22744, 22746 },
			entryIDs = { 112307 },
			groupIDs = { 9026, 9029, 9030, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90436] = {
			ID = 90436,
			flags = 9,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112308 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90439, type = 2, visualStyle = 1 }
			}
		},
		[90437] = {
			ID = 90437,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112309 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90438, type = 2, visualStyle = 1 },
				{ targetNode = 90438, type = 2, visualStyle = 1 },
				{ targetNode = 90436, type = 2, visualStyle = 1 },
				{ targetNode = 90438, type = 2, visualStyle = 1 }
			}
		},
		[90438] = {
			ID = 90438,
			flags = 9,
			type = 0,
			posX = 9300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112310 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90439, type = 2, visualStyle = 1 }
			}
		},
		[90439] = {
			ID = 90439,
			flags = 9,
			type = 0,
			posX = 9900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112311 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90440] = {
			ID = 90440,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112313, 112312 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90441] = {
			ID = 90441,
			flags = 9,
			type = 0,
			posX = 11690,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112314 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90263, type = 2, visualStyle = 1 },
				{ targetNode = 90266, type = 2, visualStyle = 1 },
				{ targetNode = 90440, type = 2, visualStyle = 1 }
			}
		},
		[90442] = {
			ID = 90442,
			flags = 8,
			type = 0,
			posX = 11699,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112315 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90441, type = 2, visualStyle = 1 }
			}
		},
		[90443] = {
			ID = 90443,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22746, 22741, 22746, 22741, 22746, 22741 },
			entryIDs = { 112316 },
			groupIDs = { 9029, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90442, type = 2, visualStyle = 1 },
				{ targetNode = 90444, type = 2, visualStyle = 1 }
			}
		},
		[90444] = {
			ID = 90444,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112317 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90447, type = 2, visualStyle = 1 },
				{ targetNode = 90445, type = 2, visualStyle = 1 }
			}
		},
		[90445] = {
			ID = 90445,
			flags = 9,
			type = 0,
			posX = 14100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112318 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90446, type = 2, visualStyle = 1 }
			}
		},
		[90446] = {
			ID = 90446,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112319 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {}
		},
		[90447] = {
			ID = 90447,
			flags = 9,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22744, 22746, 22741, 22744, 22746, 22741, 22744, 22746, 22741 },
			entryIDs = { 112320 },
			groupIDs = { 9029, 9030, 9032, 9034 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90446, type = 2, visualStyle = 1 }
			}
		},
		[90448] = {
			ID = 90448,
			flags = 9,
			type = 0,
			posX = 14100,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112321 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90449, type = 2, visualStyle = 1 }
			}
		},
		[90449] = {
			ID = 90449,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 4499,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112323, 112322 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90433, type = 2, visualStyle = 1 }
			}
		},
		[90450] = {
			ID = 90450,
			flags = 9,
			type = 2,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112324, 112110 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90449, type = 2, visualStyle = 1 }
			}
		},
		[90451] = {
			ID = 90451,
			flags = 9,
			type = 2,
			posX = 13499,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22740, 22746, 22740, 22746, 22740, 22746 },
			entryIDs = { 112326, 112325 },
			groupIDs = { 9026, 9029, 9032 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90450, type = 2, visualStyle = 1 },
				{ targetNode = 90264, type = 2, visualStyle = 1 },
				{ targetNode = 90312, type = 2, visualStyle = 1 },
				{ targetNode = 90448, type = 2, visualStyle = 1 },
				{ targetNode = 90450, type = 2, visualStyle = 1 }
			}
		},
		[90452] = {
			ID = 90452,
			flags = 9,
			type = 0,
			posX = 14100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22740, 22740, 22740 },
			entryIDs = { 112327 },
			groupIDs = { 9026, 9029 },
			costs = {
				{ ID = 2895, amount = 1 }
			},
			edges = {
				{ targetNode = 90451, type = 2, visualStyle = 1 }
			}
		},
		[90620] = {
			ID = 90620,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112504 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90779, type = 2, visualStyle = 1 }
			}
		},
		[90621] = {
			ID = 90621,
			flags = 8,
			type = 0,
			posX = 11410,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112505 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90767, type = 2, visualStyle = 1 }
			}
		},
		[90622] = {
			ID = 90622,
			flags = 9,
			type = 2,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112507, 112506 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90775, type = 2, visualStyle = 1 }
			}
		},
		[90623] = {
			ID = 90623,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112508 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90778, type = 2, visualStyle = 1 },
				{ targetNode = 90624, type = 2, visualStyle = 1 }
			}
		},
		[90624] = {
			ID = 90624,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112509 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90776, type = 2, visualStyle = 1 },
				{ targetNode = 90777, type = 2, visualStyle = 1 }
			}
		},
		[90625] = {
			ID = 90625,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112510 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90780, type = 2, visualStyle = 1 }
			}
		},
		[90626] = {
			ID = 90626,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3310,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112511 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90769, type = 2, visualStyle = 1 }
			}
		},
		[90627] = {
			ID = 90627,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112512 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90633, type = 2, visualStyle = 1 }
			}
		},
		[90628] = {
			ID = 90628,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112513 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90627, type = 2, visualStyle = 1 },
				{ targetNode = 90629, type = 2, visualStyle = 1 }
			}
		},
		[90629] = {
			ID = 90629,
			flags = 8,
			type = 0,
			posX = 10510,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112514 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90633, type = 2, visualStyle = 1 },
				{ targetNode = 90630, type = 2, visualStyle = 1 }
			}
		},
		[90630] = {
			ID = 90630,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112515 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90632, type = 2, visualStyle = 1 }
			}
		},
		[90631] = {
			ID = 90631,
			flags = 8,
			type = 0,
			posX = 10510,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112516 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90771, type = 2, visualStyle = 1 }
			}
		},
		[90632] = {
			ID = 90632,
			flags = 8,
			type = 0,
			posX = 10510,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112517 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90631, type = 2, visualStyle = 1 }
			}
		},
		[90633] = {
			ID = 90633,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112518 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90773, type = 2, visualStyle = 1 },
				{ targetNode = 90769, type = 2, visualStyle = 1 },
				{ targetNode = 90632, type = 2, visualStyle = 1 }
			}
		},
		[90634] = {
			ID = 90634,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 2,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112519 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90780, type = 2, visualStyle = 1 },
				{ targetNode = 90626, type = 2, visualStyle = 1 },
				{ targetNode = 90633, type = 2, visualStyle = 1 }
			}
		},
		[90635] = {
			ID = 90635,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112520 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90634, type = 2, visualStyle = 1 }
			}
		},
		[90636] = {
			ID = 90636,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112521 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90762, type = 2, visualStyle = 1 },
				{ targetNode = 90637, type = 2, visualStyle = 1 }
			}
		},
		[90637] = {
			ID = 90637,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112522 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90761, type = 2, visualStyle = 1 }
			}
		},
		[90638] = {
			ID = 90638,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112524, 112523 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {}
		},
		[90639] = {
			ID = 90639,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112525 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90638, type = 2, visualStyle = 1 }
			}
		},
		[90640] = {
			ID = 90640,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112526 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90639, type = 2, visualStyle = 1 }
			}
		},
		[90641] = {
			ID = 90641,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112527 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90678, type = 2, visualStyle = 1 }
			}
		},
		[90642] = {
			ID = 90642,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112528 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90641, type = 2, visualStyle = 1 }
			}
		},
		[90643] = {
			ID = 90643,
			flags = 8,
			type = 0,
			posX = 9300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112529 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90642, type = 2, visualStyle = 1 }
			}
		},
		[90644] = {
			ID = 90644,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112530 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90676, type = 2, visualStyle = 1 }
			}
		},
		[90645] = {
			ID = 90645,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112531 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90670, type = 2, visualStyle = 1 }
			}
		},
		[90646] = {
			ID = 90646,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112532 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90659, type = 2, visualStyle = 1 }
			}
		},
		[90647] = {
			ID = 90647,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112533 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90648, type = 2, visualStyle = 1 }
			}
		},
		[90648] = {
			ID = 90648,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112534 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90680, type = 2, visualStyle = 1 },
				{ targetNode = 90649, type = 2, visualStyle = 1 }
			}
		},
		[90649] = {
			ID = 90649,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112535 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90679, type = 2, visualStyle = 1 }
			}
		},
		[90650] = {
			ID = 90650,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112536 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90655, type = 2, visualStyle = 1 }
			}
		},
		[90651] = {
			ID = 90651,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112537 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90668, type = 2, visualStyle = 1 },
				{ targetNode = 90655, type = 2, visualStyle = 1 }
			}
		},
		[90652] = {
			ID = 90652,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112538 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90653] = {
			ID = 90653,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112539 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90652, type = 2, visualStyle = 1 }
			}
		},
		[90654] = {
			ID = 90654,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112540 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90653, type = 2, visualStyle = 1 }
			}
		},
		[90655] = {
			ID = 90655,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112541 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90654, type = 2, visualStyle = 1 }
			}
		},
		[90656] = {
			ID = 90656,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112542 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90678, type = 2, visualStyle = 1 },
				{ targetNode = 90655, type = 2, visualStyle = 1 }
			}
		},
		[90657] = {
			ID = 90657,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112543 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90650, type = 2, visualStyle = 1 },
				{ targetNode = 90651, type = 2, visualStyle = 1 },
				{ targetNode = 90656, type = 2, visualStyle = 1 }
			}
		},
		[90658] = {
			ID = 90658,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112544 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90657, type = 2, visualStyle = 1 }
			}
		},
		[90659] = {
			ID = 90659,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112545 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90649, type = 2, visualStyle = 1 },
				{ targetNode = 90658, type = 2, visualStyle = 1 },
				{ targetNode = 90662, type = 2, visualStyle = 1 }
			}
		},
		[90660] = {
			ID = 90660,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112546 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90661, type = 2, visualStyle = 1 }
			}
		},
		[90661] = {
			ID = 90661,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112547 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90671, type = 2, visualStyle = 1 },
				{ targetNode = 90662, type = 2, visualStyle = 1 }
			}
		},
		[90662] = {
			ID = 90662,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112548 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90663, type = 2, visualStyle = 1 }
			}
		},
		[90663] = {
			ID = 90663,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112549 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90669, type = 2, visualStyle = 1 },
				{ targetNode = 90668, type = 2, visualStyle = 1 }
			}
		},
		[90664] = {
			ID = 90664,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112551, 112550 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90666, type = 2, visualStyle = 1 }
			}
		},
		[90665] = {
			ID = 90665,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112552 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90666] = {
			ID = 90666,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112553 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90665, type = 2, visualStyle = 1 }
			}
		},
		[90667] = {
			ID = 90667,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112554 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90666, type = 2, visualStyle = 1 }
			}
		},
		[90668] = {
			ID = 90668,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112555 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90664, type = 2, visualStyle = 1 },
				{ targetNode = 90667, type = 2, visualStyle = 1 }
			}
		},
		[90669] = {
			ID = 90669,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112556 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90668, type = 2, visualStyle = 1 }
			}
		},
		[90670] = {
			ID = 90670,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112557 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90669, type = 2, visualStyle = 1 }
			}
		},
		[90671] = {
			ID = 90671,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112558 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90663, type = 2, visualStyle = 1 },
				{ targetNode = 90670, type = 2, visualStyle = 1 }
			}
		},
		[90672] = {
			ID = 90672,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112559 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90645, type = 2, visualStyle = 1 },
				{ targetNode = 90671, type = 2, visualStyle = 1 }
			}
		},
		[90673] = {
			ID = 90673,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112560 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90661, type = 2, visualStyle = 1 },
				{ targetNode = 90672, type = 2, visualStyle = 1 }
			}
		},
		[90674] = {
			ID = 90674,
			flags = 8,
			type = 0,
			posX = 12290,
			posY = 1490,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112561 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90646, type = 2, visualStyle = 1 },
				{ targetNode = 90660, type = 2, visualStyle = 1 },
				{ targetNode = 90673, type = 2, visualStyle = 1 }
			}
		},
		[90675] = {
			ID = 90675,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112562 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90676] = {
			ID = 90676,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112563 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90675, type = 2, visualStyle = 1 }
			}
		},
		[90677] = {
			ID = 90677,
			flags = 9,
			type = 2,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22764, 22760, 22763, 22764, 22760, 22763, 22764 },
			entryIDs = { 112565, 112564 },
			groupIDs = { 9050, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90676, type = 2, visualStyle = 1 }
			}
		},
		[90678] = {
			ID = 90678,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112566 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90644, type = 2, visualStyle = 1 },
				{ targetNode = 90677, type = 2, visualStyle = 1 }
			}
		},
		[90679] = {
			ID = 90679,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112567 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90641, type = 2, visualStyle = 1 },
				{ targetNode = 90678, type = 2, visualStyle = 1 }
			}
		},
		[90680] = {
			ID = 90680,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22760, 22763, 22760, 22763, 22760, 22763 },
			entryIDs = { 112568 },
			groupIDs = { 9050, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90642, type = 2, visualStyle = 1 },
				{ targetNode = 90679, type = 2, visualStyle = 1 }
			}
		},
		[90681] = {
			ID = 90681,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112569 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90643, type = 2, visualStyle = 1 },
				{ targetNode = 90680, type = 2, visualStyle = 1 }
			}
		},
		[90682] = {
			ID = 90682,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112570 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90648, type = 2, visualStyle = 1 },
				{ targetNode = 90681, type = 2, visualStyle = 1 }
			}
		},
		[90683] = {
			ID = 90683,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22760, 22760, 22760 },
			entryIDs = { 112571 },
			groupIDs = { 9050, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90646, type = 2, visualStyle = 1 },
				{ targetNode = 90647, type = 2, visualStyle = 1 },
				{ targetNode = 90682, type = 2, visualStyle = 1 }
			}
		},
		[90684] = {
			ID = 90684,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22768, 22768, 22768 },
			entryIDs = { 112572 },
			groupIDs = { 9047, 9055 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90742, type = 2, visualStyle = 1 }
			}
		},
		[90685] = {
			ID = 90685,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22766, 22766, 22766 },
			entryIDs = { 112573 },
			groupIDs = { 9047, 9048 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90697, type = 2, visualStyle = 1 }
			}
		},
		[90686] = {
			ID = 90686,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112574 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90695, type = 2, visualStyle = 1 }
			}
		},
		[90687] = {
			ID = 90687,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112575 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90695, type = 2, visualStyle = 1 },
				{ targetNode = 90688, type = 2, visualStyle = 1 }
			}
		},
		[90688] = {
			ID = 90688,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112576 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90694, type = 2, visualStyle = 1 }
			}
		},
		[90689] = {
			ID = 90689,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112577 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {}
		},
		[90690] = {
			ID = 90690,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112578 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90689, type = 2, visualStyle = 1 }
			}
		},
		[90691] = {
			ID = 90691,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112579 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90690, type = 2, visualStyle = 1 }
			}
		},
		[90692] = {
			ID = 90692,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112580 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90751, type = 2, visualStyle = 1 },
				{ targetNode = 90691, type = 2, visualStyle = 1 }
			}
		},
		[90693] = {
			ID = 90693,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112581 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90692, type = 2, visualStyle = 1 }
			}
		},
		[90694] = {
			ID = 90694,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112582 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90693, type = 2, visualStyle = 1 }
			}
		},
		[90695] = {
			ID = 90695,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112583 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90754, type = 2, visualStyle = 1 },
				{ targetNode = 90694, type = 2, visualStyle = 1 }
			}
		},
		[90696] = {
			ID = 90696,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112584 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90755, type = 2, visualStyle = 1 },
				{ targetNode = 90695, type = 2, visualStyle = 1 },
				{ targetNode = 90746, type = 2, visualStyle = 1 }
			}
		},
		[90697] = {
			ID = 90697,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112585 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90686, type = 2, visualStyle = 1 },
				{ targetNode = 90687, type = 2, visualStyle = 1 },
				{ targetNode = 90696, type = 2, visualStyle = 1 }
			}
		},
		[90698] = {
			ID = 90698,
			flags = 8,
			type = 0,
			posX = 9899,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112586 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90699, type = 2, visualStyle = 1 }
			}
		},
		[90699] = {
			ID = 90699,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112587 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90701, type = 2, visualStyle = 1 }
			}
		},
		[90700] = {
			ID = 90700,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112588 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90701] = {
			ID = 90701,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112589 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90700, type = 2, visualStyle = 1 },
				{ targetNode = 90703, type = 2, visualStyle = 1 }
			}
		},
		[90702] = {
			ID = 90702,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112590 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90732, type = 2, visualStyle = 1 }
			}
		},
		[90703] = {
			ID = 90703,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112591 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90702, type = 2, visualStyle = 1 },
				{ targetNode = 90708, type = 2, visualStyle = 1 }
			}
		},
		[90704] = {
			ID = 90704,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112592 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90705] = {
			ID = 90705,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112593 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90706] = {
			ID = 90706,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112594 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90705, type = 2, visualStyle = 1 }
			}
		},
		[90707] = {
			ID = 90707,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112595 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90706, type = 2, visualStyle = 1 }
			}
		},
		[90708] = {
			ID = 90708,
			flags = 8,
			type = 0,
			posX = 10499,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112596 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90704, type = 2, visualStyle = 1 },
				{ targetNode = 90707, type = 2, visualStyle = 1 }
			}
		},
		[90709] = {
			ID = 90709,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112597 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90714, type = 2, visualStyle = 1 },
				{ targetNode = 90726, type = 2, visualStyle = 1 }
			}
		},
		[90710] = {
			ID = 90710,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112598 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90709, type = 2, visualStyle = 1 },
				{ targetNode = 90712, type = 2, visualStyle = 1 }
			}
		},
		[90711] = {
			ID = 90711,
			flags = 8,
			type = 0,
			posX = 13499,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112599 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90715, type = 2, visualStyle = 1 }
			}
		},
		[90712] = {
			ID = 90712,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112600 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90711, type = 2, visualStyle = 1 },
				{ targetNode = 90714, type = 2, visualStyle = 1 }
			}
		},
		[90713] = {
			ID = 90713,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112601 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90724, type = 2, visualStyle = 1 },
				{ targetNode = 90717, type = 2, visualStyle = 1 }
			}
		},
		[90714] = {
			ID = 90714,
			flags = 8,
			type = 0,
			posX = 12899,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112602 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90713, type = 2, visualStyle = 1 },
				{ targetNode = 90715, type = 2, visualStyle = 1 }
			}
		},
		[90715] = {
			ID = 90715,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112603 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90717, type = 2, visualStyle = 1 }
			}
		},
		[90716] = {
			ID = 90716,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112604 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90717] = {
			ID = 90717,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112605 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90716, type = 2, visualStyle = 1 },
				{ targetNode = 90723, type = 2, visualStyle = 1 }
			}
		},
		[90718] = {
			ID = 90718,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112606 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90719] = {
			ID = 90719,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112607 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90720] = {
			ID = 90720,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112608 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90719, type = 2, visualStyle = 1 }
			}
		},
		[90721] = {
			ID = 90721,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112609 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90720, type = 2, visualStyle = 1 }
			}
		},
		[90722] = {
			ID = 90722,
			flags = 8,
			type = 0,
			posX = 12899,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112610 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90718, type = 2, visualStyle = 1 },
				{ targetNode = 90721, type = 2, visualStyle = 1 }
			}
		},
		[90723] = {
			ID = 90723,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112611 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90733, type = 2, visualStyle = 1 },
				{ targetNode = 90722, type = 2, visualStyle = 1 }
			}
		},
		[90724] = {
			ID = 90724,
			flags = 8,
			type = 0,
			posX = 12299,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112612 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90723, type = 2, visualStyle = 1 },
				{ targetNode = 90734, type = 2, visualStyle = 1 }
			}
		},
		[90725] = {
			ID = 90725,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112613 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90724, type = 2, visualStyle = 1 },
				{ targetNode = 90735, type = 2, visualStyle = 1 }
			}
		},
		[90726] = {
			ID = 90726,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112614 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90736, type = 2, visualStyle = 1 },
				{ targetNode = 90713, type = 2, visualStyle = 1 },
				{ targetNode = 90725, type = 2, visualStyle = 1 }
			}
		},
		[90727] = {
			ID = 90727,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112615 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90737, type = 2, visualStyle = 1 },
				{ targetNode = 90726, type = 2, visualStyle = 1 }
			}
		},
		[90728] = {
			ID = 90728,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112616 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90729] = {
			ID = 90729,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112617 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90709, type = 2, visualStyle = 1 },
				{ targetNode = 90727, type = 2, visualStyle = 1 },
				{ targetNode = 90728, type = 2, visualStyle = 1 }
			}
		},
		[90730] = {
			ID = 90730,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112618 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90731] = {
			ID = 90731,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112619 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90730, type = 2, visualStyle = 1 }
			}
		},
		[90732] = {
			ID = 90732,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22764, 22763, 22762, 22764, 22763, 22762, 22764 },
			entryIDs = { 112620 },
			groupIDs = { 9053, 9054, 9056, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90731, type = 2, visualStyle = 1 }
			}
		},
		[90733] = {
			ID = 90733,
			flags = 9,
			type = 2,
			posX = 12299,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112622, 112621 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90732, type = 2, visualStyle = 1 }
			}
		},
		[90734] = {
			ID = 90734,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112623 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90702, type = 2, visualStyle = 1 },
				{ targetNode = 90733, type = 2, visualStyle = 1 }
			}
		},
		[90735] = {
			ID = 90735,
			flags = 9,
			type = 2,
			posX = 11099,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112625, 112624 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90703, type = 2, visualStyle = 1 },
				{ targetNode = 90734, type = 2, visualStyle = 1 }
			}
		},
		[90736] = {
			ID = 90736,
			flags = 8,
			type = 0,
			posX = 11099,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22763, 22762, 22763, 22762, 22763, 22762 },
			entryIDs = { 112626 },
			groupIDs = { 9053, 9054, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90701, type = 2, visualStyle = 1 },
				{ targetNode = 90735, type = 2, visualStyle = 1 }
			}
		},
		[90737] = {
			ID = 90737,
			flags = 8,
			type = 0,
			posX = 10499,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112627 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90699, type = 2, visualStyle = 1 },
				{ targetNode = 90736, type = 2, visualStyle = 1 }
			}
		},
		[90738] = {
			ID = 90738,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112628 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90698, type = 2, visualStyle = 1 },
				{ targetNode = 90737, type = 2, visualStyle = 1 }
			}
		},
		[90739] = {
			ID = 90739,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22762, 22762, 22762 },
			entryIDs = { 112629 },
			groupIDs = { 9053, 9056 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90727, type = 2, visualStyle = 1 },
				{ targetNode = 90738, type = 2, visualStyle = 1 }
			}
		},
		[90740] = {
			ID = 90740,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22765, 22765, 22765 },
			entryIDs = { 112630 },
			groupIDs = { 9047, 9057 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90764, type = 2, visualStyle = 1 }
			}
		},
		[90741] = {
			ID = 90741,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112631 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90746, type = 2, visualStyle = 1 }
			}
		},
		[90742] = {
			ID = 90742,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112632 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90696, type = 2, visualStyle = 1 },
				{ targetNode = 90741, type = 2, visualStyle = 1 },
				{ targetNode = 90745, type = 2, visualStyle = 1 }
			}
		},
		[90743] = {
			ID = 90743,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112633 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90760, type = 2, visualStyle = 1 },
				{ targetNode = 90753, type = 2, visualStyle = 1 }
			}
		},
		[90744] = {
			ID = 90744,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112634 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90747, type = 2, visualStyle = 1 },
				{ targetNode = 90743, type = 2, visualStyle = 1 }
			}
		},
		[90745] = {
			ID = 90745,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112635 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90762, type = 2, visualStyle = 1 },
				{ targetNode = 90744, type = 2, visualStyle = 1 },
				{ targetNode = 90746, type = 2, visualStyle = 1 }
			}
		},
		[90746] = {
			ID = 90746,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112636 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90747, type = 2, visualStyle = 1 }
			}
		},
		[90747] = {
			ID = 90747,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112638, 112637 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90753, type = 2, visualStyle = 1 }
			}
		},
		[90748] = {
			ID = 90748,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112639 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {}
		},
		[90749] = {
			ID = 90749,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112640 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90748, type = 2, visualStyle = 1 }
			}
		},
		[90750] = {
			ID = 90750,
			flags = 9,
			type = 2,
			posX = 4500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112642, 112641 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {}
		},
		[90751] = {
			ID = 90751,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112643 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90750, type = 2, visualStyle = 1 }
			}
		},
		[90752] = {
			ID = 90752,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112644 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90749, type = 2, visualStyle = 1 },
				{ targetNode = 90640, type = 2, visualStyle = 1 },
				{ targetNode = 90751, type = 2, visualStyle = 1 }
			}
		},
		[90753] = {
			ID = 90753,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112645 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90752, type = 2, visualStyle = 1 }
			}
		},
		[90754] = {
			ID = 90754,
			flags = 9,
			type = 0,
			posX = 4500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112646 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90693, type = 2, visualStyle = 1 },
				{ targetNode = 90753, type = 2, visualStyle = 1 }
			}
		},
		[90755] = {
			ID = 90755,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112647 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90747, type = 2, visualStyle = 1 },
				{ targetNode = 90754, type = 2, visualStyle = 1 }
			}
		},
		[90756] = {
			ID = 90756,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112648 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {}
		},
		[90757] = {
			ID = 90757,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112649 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90756, type = 2, visualStyle = 1 }
			}
		},
		[90758] = {
			ID = 90758,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22769, 22767, 22769, 22767, 22769, 22767 },
			entryIDs = { 112650 },
			groupIDs = { 9047, 9049, 9051 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90757, type = 2, visualStyle = 1 }
			}
		},
		[90759] = {
			ID = 90759,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112651 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90749, type = 2, visualStyle = 1 },
				{ targetNode = 90758, type = 2, visualStyle = 1 }
			}
		},
		[90760] = {
			ID = 90760,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112652 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90759, type = 2, visualStyle = 1 }
			}
		},
		[90761] = {
			ID = 90761,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112653 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90760, type = 2, visualStyle = 1 }
			}
		},
		[90762] = {
			ID = 90762,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22769, 22769, 22769 },
			entryIDs = { 112654 },
			groupIDs = { 9047, 9049 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90743, type = 2, visualStyle = 1 },
				{ targetNode = 90761, type = 2, visualStyle = 1 }
			}
		},
		[90763] = {
			ID = 90763,
			flags = 9,
			type = 2,
			posX = 2700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112656, 112655 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90762, type = 2, visualStyle = 1 }
			}
		},
		[90764] = {
			ID = 90764,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112657 },
			groupIDs = { 9047 },
			costs = {
				{ ID = 2900, amount = 1 }
			},
			edges = {
				{ targetNode = 90636, type = 2, visualStyle = 1 },
				{ targetNode = 90745, type = 2, visualStyle = 1 },
				{ targetNode = 90763, type = 2, visualStyle = 1 }
			}
		},
		[90765] = {
			ID = 90765,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6910,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112658 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90766] = {
			ID = 90766,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 3,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112659 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90765, type = 2, visualStyle = 1 }
			}
		},
		[90767] = {
			ID = 90767,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 2,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112660 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90766, type = 2, visualStyle = 1 }
			}
		},
		[90768] = {
			ID = 90768,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112661 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90767, type = 2, visualStyle = 1 }
			}
		},
		[90769] = {
			ID = 90769,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112662 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90621, type = 2, visualStyle = 1 },
				{ targetNode = 90624, type = 2, visualStyle = 1 },
				{ targetNode = 90768, type = 2, visualStyle = 1 },
				{ targetNode = 90772, type = 2, visualStyle = 1 }
			}
		},
		[90770] = {
			ID = 90770,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112663 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90785, type = 2, visualStyle = 1 }
			}
		},
		[90771] = {
			ID = 90771,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112664 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90786, type = 2, visualStyle = 1 },
				{ targetNode = 90770, type = 2, visualStyle = 1 }
			}
		},
		[90772] = {
			ID = 90772,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112665 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90770, type = 2, visualStyle = 1 },
				{ targetNode = 90771, type = 2, visualStyle = 1 }
			}
		},
		[90773] = {
			ID = 90773,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112666 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90631, type = 2, visualStyle = 1 },
				{ targetNode = 90772, type = 2, visualStyle = 1 }
			}
		},
		[90774] = {
			ID = 90774,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112667 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90775] = {
			ID = 90775,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6300,
			maxRanks = 3,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112668 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90774, type = 2, visualStyle = 1 }
			}
		},
		[90776] = {
			ID = 90776,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112669 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90775, type = 2, visualStyle = 1 }
			}
		},
		[90777] = {
			ID = 90777,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112670 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90622, type = 2, visualStyle = 1 },
				{ targetNode = 90776, type = 2, visualStyle = 1 }
			}
		},
		[90778] = {
			ID = 90778,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112671 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90777, type = 2, visualStyle = 1 }
			}
		},
		[90779] = {
			ID = 90779,
			flags = 8,
			type = 0,
			posX = 12910,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112672 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90778, type = 2, visualStyle = 1 }
			}
		},
		[90780] = {
			ID = 90780,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22761, 22763, 22761, 22763 },
			entryIDs = { 112673 },
			groupIDs = { 9052, 9053, 9054 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90769, type = 2, visualStyle = 1 },
				{ targetNode = 90623, type = 2, visualStyle = 1 },
				{ targetNode = 90779, type = 2, visualStyle = 1 }
			}
		},
		[90781] = {
			ID = 90781,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112674 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90620, type = 2, visualStyle = 1 },
				{ targetNode = 90780, type = 2, visualStyle = 1 }
			}
		},
		[90782] = {
			ID = 90782,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112675 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90625, type = 2, visualStyle = 1 },
				{ targetNode = 90781, type = 2, visualStyle = 1 }
			}
		},
		[90783] = {
			ID = 90783,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22761, 22761, 22761 },
			entryIDs = { 112676 },
			groupIDs = { 9052, 9053 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90635, type = 2, visualStyle = 1 },
				{ targetNode = 90628, type = 2, visualStyle = 1 },
				{ targetNode = 90782, type = 2, visualStyle = 1 }
			}
		},
		[90784] = {
			ID = 90784,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112677 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {}
		},
		[90785] = {
			ID = 90785,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6300,
			maxRanks = 3,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112678 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90784, type = 2, visualStyle = 1 }
			}
		},
		[90786] = {
			ID = 90786,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22761, 22763, 22764, 22761, 22763, 22764, 22761, 22763, 22764 },
			entryIDs = { 112679 },
			groupIDs = { 9052, 9053, 9054, 9058 },
			costs = {
				{ ID = 2899, amount = 1 }
			},
			edges = {
				{ targetNode = 90785, type = 2, visualStyle = 1 }
			}
		},
		[90912] = {
			ID = 90912,
			flags = 0,
			type = 0,
			posX = 16640,
			posY = -320,
			maxRanks = 0,
			conditionIDs = {  },
			entryIDs = { 112820 },
			groupIDs = {  },
			costs = {},
			edges = {}
		},
		[90913] = {
			ID = 90913,
			flags = 9,
			type = 2,
			posX = 10800,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112822, 112821 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91026, type = 2, visualStyle = 1 }
			}
		},
		[90914] = {
			ID = 90914,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112823 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91028, type = 2, visualStyle = 1 }
			}
		},
		[90915] = {
			ID = 90915,
			flags = 0,
			type = 0,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112824 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91013, type = 2, visualStyle = 1 },
				{ targetNode = 90916, type = 2, visualStyle = 1 }
			}
		},
		[90916] = {
			ID = 90916,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112825 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91012, type = 2, visualStyle = 1 },
				{ targetNode = 90917, type = 2, visualStyle = 1 }
			}
		},
		[90917] = {
			ID = 90917,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112826 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91011, type = 2, visualStyle = 1 },
				{ targetNode = 90918, type = 2, visualStyle = 1 }
			}
		},
		[90918] = {
			ID = 90918,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112827 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90920, type = 2, visualStyle = 1 }
			}
		},
		[90919] = {
			ID = 90919,
			flags = 8,
			type = 0,
			posX = 12300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112828 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90920] = {
			ID = 90920,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112829 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90919, type = 2, visualStyle = 1 }
			}
		},
		[90921] = {
			ID = 90921,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112830 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90922] = {
			ID = 90922,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112831 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91026, type = 2, visualStyle = 1 },
				{ targetNode = 91013, type = 2, visualStyle = 1 },
				{ targetNode = 90921, type = 2, visualStyle = 1 }
			}
		},
		[90923] = {
			ID = 90923,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112832 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91015, type = 2, visualStyle = 1 }
			}
		},
		[90924] = {
			ID = 90924,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112833 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90925] = {
			ID = 90925,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112834 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90924, type = 2, visualStyle = 1 },
				{ targetNode = 91015, type = 2, visualStyle = 1 },
				{ targetNode = 91028, type = 2, visualStyle = 1 }
			}
		},
		[90926] = {
			ID = 90926,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112836, 112835 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90927] = {
			ID = 90927,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112837 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90926, type = 2, visualStyle = 1 }
			}
		},
		[90928] = {
			ID = 90928,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112838 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90929] = {
			ID = 90929,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112839 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90927, type = 2, visualStyle = 1 },
				{ targetNode = 90928, type = 2, visualStyle = 1 }
			}
		},
		[90930] = {
			ID = 90930,
			flags = 8,
			type = 0,
			posX = 2100,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112840 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90931] = {
			ID = 90931,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112841 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90932, type = 2, visualStyle = 1 }
			}
		},
		[90932] = {
			ID = 90932,
			flags = 9,
			type = 2,
			posX = 3900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112843, 112842 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90933] = {
			ID = 90933,
			flags = 8,
			type = 0,
			posX = 3900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112844 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 91004, type = 2, visualStyle = 1 },
				{ targetNode = 90936, type = 2, visualStyle = 1 }
			}
		},
		[90934] = {
			ID = 90934,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112845 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90996, type = 2, visualStyle = 1 },
				{ targetNode = 90996, type = 2, visualStyle = 1 }
			}
		},
		[90935] = {
			ID = 90935,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112846 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 91002, type = 2, visualStyle = 1 },
				{ targetNode = 90934, type = 2, visualStyle = 1 }
			}
		},
		[90936] = {
			ID = 90936,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112847 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 91003, type = 2, visualStyle = 1 },
				{ targetNode = 90935, type = 2, visualStyle = 1 }
			}
		},
		[90937] = {
			ID = 90937,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112848 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90936, type = 2, visualStyle = 1 }
			}
		},
		[90938] = {
			ID = 90938,
			flags = 8,
			type = 0,
			posX = 3300,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112849 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90932, type = 2, visualStyle = 1 },
				{ targetNode = 90937, type = 2, visualStyle = 1 },
				{ targetNode = 90940, type = 2, visualStyle = 1 }
			}
		},
		[90939] = {
			ID = 90939,
			flags = 0,
			type = 0,
			posX = 2100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112850 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90993, type = 2, visualStyle = 1 }
			}
		},
		[90940] = {
			ID = 90940,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112851 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90939, type = 2, visualStyle = 1 },
				{ targetNode = 90994, type = 2, visualStyle = 1 }
			}
		},
		[90941] = {
			ID = 90941,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 2100,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 112852 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90930, type = 2, visualStyle = 1 },
				{ targetNode = 90938, type = 2, visualStyle = 1 },
				{ targetNode = 90940, type = 2, visualStyle = 1 }
			}
		},
		[90942] = {
			ID = 90942,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22778, 22778 },
			entryIDs = { 112853 },
			groupIDs = { 9074, 9075, 9078 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90941, type = 2, visualStyle = 1 }
			}
		},
		[90943] = {
			ID = 90943,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22780, 22780 },
			entryIDs = { 112854 },
			groupIDs = { 9071, 9074, 9078 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90950, type = 2, visualStyle = 1 }
			}
		},
		[90944] = {
			ID = 90944,
			flags = 9,
			type = 2,
			posX = 5100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112856, 112855 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90946, type = 2, visualStyle = 1 }
			}
		},
		[90945] = {
			ID = 90945,
			flags = 1,
			type = 2,
			posX = 5700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112858, 112857 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90946] = {
			ID = 90946,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112859 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90945, type = 2, visualStyle = 1 },
				{ targetNode = 91000, type = 2, visualStyle = 1 }
			}
		},
		[90947] = {
			ID = 90947,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112860 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90946, type = 2, visualStyle = 1 }
			}
		},
		[90948] = {
			ID = 90948,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112861 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90944, type = 2, visualStyle = 1 },
				{ targetNode = 90947, type = 2, visualStyle = 1 }
			}
		},
		[90949] = {
			ID = 90949,
			flags = 0,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112862 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90950] = {
			ID = 90950,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 2100,
			maxRanks = 2,
			conditionIDs = {  },
			entryIDs = { 112863 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90948, type = 2, visualStyle = 1 },
				{ targetNode = 91006, type = 2, visualStyle = 1 },
				{ targetNode = 90949, type = 2, visualStyle = 1 }
			}
		},
		[90951] = {
			ID = 90951,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112864 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90989, type = 2, visualStyle = 1 },
				{ targetNode = 90953, type = 2, visualStyle = 1 }
			}
		},
		[90952] = {
			ID = 90952,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112865 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90987, type = 2, visualStyle = 1 }
			}
		},
		[90953] = {
			ID = 90953,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112866 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90952, type = 2, visualStyle = 1 },
				{ targetNode = 90955, type = 2, visualStyle = 1 }
			}
		},
		[90954] = {
			ID = 90954,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112867 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90957, type = 2, visualStyle = 1 }
			}
		},
		[90955] = {
			ID = 90955,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112868 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90954, type = 2, visualStyle = 1 },
				{ targetNode = 90987, type = 2, visualStyle = 1 },
				{ targetNode = 90956, type = 2, visualStyle = 1 }
			}
		},
		[90956] = {
			ID = 90956,
			flags = 1,
			type = 2,
			posX = 13500,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112870, 112869 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90957, type = 2, visualStyle = 1 }
			}
		},
		[90957] = {
			ID = 90957,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112871 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90964, type = 2, visualStyle = 1 },
				{ targetNode = 90958, type = 2, visualStyle = 1 }
			}
		},
		[90958] = {
			ID = 90958,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112872 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90984, type = 2, visualStyle = 1 },
				{ targetNode = 90963, type = 2, visualStyle = 1 },
				{ targetNode = 90959, type = 2, visualStyle = 1 }
			}
		},
		[90959] = {
			ID = 90959,
			flags = 8,
			type = 0,
			posX = 12900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112873 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90962, type = 2, visualStyle = 1 }
			}
		},
		[90960] = {
			ID = 90960,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112875, 112874 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90961] = {
			ID = 90961,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112876 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90962] = {
			ID = 90962,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112877 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90960, type = 2, visualStyle = 1 },
				{ targetNode = 90961, type = 2, visualStyle = 1 }
			}
		},
		[90963] = {
			ID = 90963,
			flags = 8,
			type = 0,
			posX = 13500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112878 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90962, type = 2, visualStyle = 1 }
			}
		},
		[90964] = {
			ID = 90964,
			flags = 8,
			type = 0,
			posX = 14100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112879 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90963, type = 2, visualStyle = 1 }
			}
		},
		[90965] = {
			ID = 90965,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112880 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90985, type = 2, visualStyle = 1 }
			}
		},
		[90966] = {
			ID = 90966,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112881 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90965, type = 2, visualStyle = 1 },
				{ targetNode = 90986, type = 2, visualStyle = 1 },
				{ targetNode = 90972, type = 2, visualStyle = 1 }
			}
		},
		[90967] = {
			ID = 90967,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112882 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90971, type = 2, visualStyle = 1 }
			}
		},
		[90968] = {
			ID = 90968,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112883 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90967, type = 2, visualStyle = 1 },
				{ targetNode = 90970, type = 2, visualStyle = 1 }
			}
		},
		[90969] = {
			ID = 90969,
			flags = 0,
			type = 0,
			posX = 9900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112884 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90977, type = 2, visualStyle = 1 }
			}
		},
		[90970] = {
			ID = 90970,
			flags = 9,
			type = 2,
			posX = 9900,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112886, 112885 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90969, type = 2, visualStyle = 1 },
				{ targetNode = 90978, type = 2, visualStyle = 1 },
				{ targetNode = 90971, type = 2, visualStyle = 1 }
			}
		},
		[90971] = {
			ID = 90971,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112887 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90977, type = 2, visualStyle = 1 },
				{ targetNode = 90972, type = 2, visualStyle = 1 }
			}
		},
		[90972] = {
			ID = 90972,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112888 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90985, type = 2, visualStyle = 1 },
				{ targetNode = 90976, type = 2, visualStyle = 1 }
			}
		},
		[90973] = {
			ID = 90973,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112889 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90981, type = 2, visualStyle = 1 }
			}
		},
		[90974] = {
			ID = 90974,
			flags = 0,
			type = 0,
			posX = 9300,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112890 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90975, type = 2, visualStyle = 1 }
			}
		},
		[90975] = {
			ID = 90975,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112891 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90981, type = 2, visualStyle = 1 }
			}
		},
		[90976] = {
			ID = 90976,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112892 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90973, type = 2, visualStyle = 1 },
				{ targetNode = 90984, type = 2, visualStyle = 1 },
				{ targetNode = 90975, type = 2, visualStyle = 1 }
			}
		},
		[90977] = {
			ID = 90977,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112893 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90974, type = 2, visualStyle = 1 },
				{ targetNode = 90976, type = 2, visualStyle = 1 }
			}
		},
		[90978] = {
			ID = 90978,
			flags = 8,
			type = 0,
			posX = 9300,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112894 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90977, type = 2, visualStyle = 1 }
			}
		},
		[90979] = {
			ID = 90979,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112895 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90980] = {
			ID = 90980,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112896 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90981] = {
			ID = 90981,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112897 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90980, type = 2, visualStyle = 1 },
				{ targetNode = 90982, type = 2, visualStyle = 1 }
			}
		},
		[90982] = {
			ID = 90982,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112898 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[90983] = {
			ID = 90983,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112899 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90960, type = 2, visualStyle = 1 },
				{ targetNode = 90979, type = 2, visualStyle = 1 },
				{ targetNode = 90982, type = 2, visualStyle = 1 }
			}
		},
		[90984] = {
			ID = 90984,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22784, 22782, 22784 },
			entryIDs = { 112900 },
			groupIDs = { 9070, 9073, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90983, type = 2, visualStyle = 1 }
			}
		},
		[90985] = {
			ID = 90985,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112901 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90984, type = 2, visualStyle = 1 }
			}
		},
		[90986] = {
			ID = 90986,
			flags = 0,
			type = 0,
			posX = 12300,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112902 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90958, type = 2, visualStyle = 1 },
				{ targetNode = 90985, type = 2, visualStyle = 1 }
			}
		},
		[90987] = {
			ID = 90987,
			flags = 0,
			type = 0,
			posX = 12900,
			posY = 3900,
			maxRanks = 2,
			conditionIDs = { 22784, 22779, 22784, 22779 },
			entryIDs = { 112903 },
			groupIDs = { 9070, 9076, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90957, type = 2, visualStyle = 1 },
				{ targetNode = 90986, type = 2, visualStyle = 1 }
			}
		},
		[90988] = {
			ID = 90988,
			flags = 1,
			type = 2,
			posX = 11700,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112905, 112904 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90966, type = 2, visualStyle = 1 },
				{ targetNode = 90971, type = 2, visualStyle = 1 },
				{ targetNode = 90987, type = 2, visualStyle = 1 }
			}
		},
		[90989] = {
			ID = 90989,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112906 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90988, type = 2, visualStyle = 1 }
			}
		},
		[90990] = {
			ID = 90990,
			flags = 0,
			type = 0,
			posX = 11100,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112907 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90968, type = 2, visualStyle = 1 },
				{ targetNode = 90989, type = 2, visualStyle = 1 }
			}
		},
		[90991] = {
			ID = 90991,
			flags = 0,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22784, 22784 },
			entryIDs = { 112908 },
			groupIDs = { 9070, 9076 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90951, type = 2, visualStyle = 1 },
				{ targetNode = 90990, type = 2, visualStyle = 1 }
			}
		},
		[90992] = {
			ID = 90992,
			flags = 9,
			type = 2,
			posX = 2100,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112910, 112909 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90993] = {
			ID = 90993,
			flags = 8,
			type = 0,
			posX = 2700,
			posY = 4500,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112911 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90935, type = 2, visualStyle = 1 },
				{ targetNode = 90992, type = 2, visualStyle = 1 }
			}
		},
		[90994] = {
			ID = 90994,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112912 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90993, type = 2, visualStyle = 1 }
			}
		},
		[90995] = {
			ID = 90995,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112913 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90996] = {
			ID = 90996,
			flags = 0,
			type = 0,
			posX = 2700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112914 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90995, type = 2, visualStyle = 1 }
			}
		},
		[90997] = {
			ID = 90997,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112915 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[90998] = {
			ID = 90998,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112916 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90997, type = 2, visualStyle = 1 }
			}
		},
		[90999] = {
			ID = 90999,
			flags = 8,
			type = 0,
			posX = 5100,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112917 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90998, type = 2, visualStyle = 1 }
			}
		},
		[91000] = {
			ID = 91000,
			flags = 0,
			type = 0,
			posX = 5100,
			posY = 5100,
			maxRanks = 2,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112918 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90929, type = 2, visualStyle = 1 },
				{ targetNode = 90999, type = 2, visualStyle = 1 }
			}
		},
		[91001] = {
			ID = 91001,
			flags = 9,
			type = 2,
			posX = 3300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112920, 112919 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {}
		},
		[91002] = {
			ID = 91002,
			flags = 0,
			type = 0,
			posX = 3300,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22783, 22781, 22783, 22781 },
			entryIDs = { 112921 },
			groupIDs = { 9072, 9074, 9077 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90927, type = 2, visualStyle = 1 },
				{ targetNode = 91001, type = 2, visualStyle = 1 }
			}
		},
		[91003] = {
			ID = 91003,
			flags = 1,
			type = 2,
			posX = 3900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112923, 112922 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90929, type = 2, visualStyle = 1 },
				{ targetNode = 91002, type = 2, visualStyle = 1 }
			}
		},
		[91004] = {
			ID = 91004,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22783, 22783 },
			entryIDs = { 112924 },
			groupIDs = { 9072, 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 91000, type = 2, visualStyle = 1 },
				{ targetNode = 91003, type = 2, visualStyle = 1 }
			}
		},
		[91005] = {
			ID = 91005,
			flags = 8,
			type = 0,
			posX = 4500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112925 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 91004, type = 2, visualStyle = 1 }
			}
		},
		[91006] = {
			ID = 91006,
			flags = 0,
			type = 0,
			posX = 4500,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112926 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90932, type = 2, visualStyle = 1 },
				{ targetNode = 90948, type = 2, visualStyle = 1 },
				{ targetNode = 91005, type = 2, visualStyle = 1 }
			}
		},
		[91007] = {
			ID = 91007,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112927 },
			groupIDs = { 9074 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 90938, type = 2, visualStyle = 1 },
				{ targetNode = 90931, type = 2, visualStyle = 1 },
				{ targetNode = 91006, type = 2, visualStyle = 1 }
			}
		},
		[91008] = {
			ID = 91008,
			flags = 0,
			type = 0,
			posX = 3900,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = {  },
			entryIDs = { 112928 },
			groupIDs = { 9074, 9078 },
			costs = {
				{ ID = 2904, amount = 1 }
			},
			edges = {
				{ targetNode = 91007, type = 2, visualStyle = 1 }
			}
		},
		[91009] = {
			ID = 91009,
			flags = 8,
			type = 0,
			posX = 12000,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112929 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91032, type = 2, visualStyle = 1 },
				{ targetNode = 91010, type = 2, visualStyle = 1 }
			}
		},
		[91010] = {
			ID = 91010,
			flags = 9,
			type = 2,
			posX = 12300,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112931, 112930 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[91011] = {
			ID = 91011,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112932 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90920, type = 2, visualStyle = 1 },
				{ targetNode = 91010, type = 2, visualStyle = 1 }
			}
		},
		[91012] = {
			ID = 91012,
			flags = 0,
			type = 0,
			posX = 12600,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112933 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91011, type = 2, visualStyle = 1 }
			}
		},
		[91013] = {
			ID = 91013,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112934 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91012, type = 2, visualStyle = 1 },
				{ targetNode = 91025, type = 2, visualStyle = 1 }
			}
		},
		[91014] = {
			ID = 91014,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112935 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91013, type = 2, visualStyle = 1 }
			}
		},
		[91015] = {
			ID = 91015,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112936 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90915, type = 2, visualStyle = 1 },
				{ targetNode = 90922, type = 2, visualStyle = 1 },
				{ targetNode = 91014, type = 2, visualStyle = 1 }
			}
		},
		[91016] = {
			ID = 91016,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112937 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91015, type = 2, visualStyle = 1 }
			}
		},
		[91017] = {
			ID = 91017,
			flags = 8,
			type = 0,
			posX = 12600,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112938 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90923, type = 2, visualStyle = 1 },
				{ targetNode = 90925, type = 2, visualStyle = 1 },
				{ targetNode = 91016, type = 2, visualStyle = 1 }
			}
		},
		[91018] = {
			ID = 91018,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112939 },
			groupIDs = { 9070, 9078, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91017, type = 2, visualStyle = 1 },
				{ targetNode = 91030, type = 2, visualStyle = 1 },
				{ targetNode = 91019, type = 2, visualStyle = 1 }
			}
		},
		[91019] = {
			ID = 91019,
			flags = 9,
			type = 2,
			posX = 11700,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112941, 112940 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[91020] = {
			ID = 91020,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112942 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91036, type = 2, visualStyle = 1 },
				{ targetNode = 91022, type = 2, visualStyle = 1 }
			}
		},
		[91021] = {
			ID = 91021,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112943 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91034, type = 2, visualStyle = 1 }
			}
		},
		[91022] = {
			ID = 91022,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112944 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91035, type = 2, visualStyle = 1 },
				{ targetNode = 91021, type = 2, visualStyle = 1 }
			}
		},
		[91023] = {
			ID = 91023,
			flags = 9,
			type = 2,
			posX = 11100,
			posY = 6300,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112946, 112945 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[91024] = {
			ID = 91024,
			flags = 8,
			type = 0,
			posX = 11400,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112947 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91023, type = 2, visualStyle = 1 },
				{ targetNode = 91032, type = 2, visualStyle = 1 }
			}
		},
		[91025] = {
			ID = 91025,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112948 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91009, type = 2, visualStyle = 1 },
				{ targetNode = 91024, type = 2, visualStyle = 1 }
			}
		},
		[91026] = {
			ID = 91026,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 4500,
			maxRanks = 2,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112949 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91025, type = 2, visualStyle = 1 },
				{ targetNode = 91036, type = 2, visualStyle = 1 }
			}
		},
		[91027] = {
			ID = 91027,
			flags = 8,
			type = 0,
			posX = 9900,
			posY = 3900,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112950 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91020, type = 2, visualStyle = 1 },
				{ targetNode = 91026, type = 2, visualStyle = 1 }
			}
		},
		[91028] = {
			ID = 91028,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 3300,
			maxRanks = 2,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112951 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90913, type = 2, visualStyle = 1 },
				{ targetNode = 90922, type = 2, visualStyle = 1 },
				{ targetNode = 91027, type = 2, visualStyle = 1 }
			}
		},
		[91029] = {
			ID = 91029,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112952 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91028, type = 2, visualStyle = 1 }
			}
		},
		[91030] = {
			ID = 91030,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 2100,
			maxRanks = 1,
			conditionIDs = { 22785, 22785 },
			entryIDs = { 112953 },
			groupIDs = { 9070, 9079 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 90914, type = 2, visualStyle = 1 },
				{ targetNode = 90925, type = 2, visualStyle = 1 },
				{ targetNode = 91029, type = 2, visualStyle = 1 }
			}
		},
		[91031] = {
			ID = 91031,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112954 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[91032] = {
			ID = 91032,
			flags = 8,
			type = 0,
			posX = 11700,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112955 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91031, type = 2, visualStyle = 1 }
			}
		},
		[91033] = {
			ID = 91033,
			flags = 8,
			type = 0,
			posX = 11100,
			posY = 6900,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112956 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {}
		},
		[91034] = {
			ID = 91034,
			flags = 8,
			type = 0,
			posX = 10500,
			posY = 6300,
			maxRanks = 2,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112957 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91033, type = 2, visualStyle = 1 }
			}
		},
		[91035] = {
			ID = 91035,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5700,
			maxRanks = 1,
			conditionIDs = { 22782, 22785, 22779, 22782, 22785, 22779 },
			entryIDs = { 112958 },
			groupIDs = { 9070, 9073, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91023, type = 2, visualStyle = 1 },
				{ targetNode = 91034, type = 2, visualStyle = 1 }
			}
		},
		[91036] = {
			ID = 91036,
			flags = 8,
			type = 0,
			posX = 10800,
			posY = 5100,
			maxRanks = 1,
			conditionIDs = { 22785, 22779, 22785, 22779 },
			entryIDs = { 112959 },
			groupIDs = { 9070, 9079, 9080 },
			costs = {
				{ ID = 2903, amount = 1 }
			},
			edges = {
				{ targetNode = 91035, type = 2, visualStyle = 1 }
			}
		},
		[91040] = {
			ID = 91040,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22794, 22794, 22794, 22794, 22794 },
			entryIDs = { 112963 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82200, type = 2, visualStyle = 1 }
			}
		},
		[91041] = {
			ID = 91041,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22795, 22795, 22795, 22795, 22795 },
			entryIDs = { 112964 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82200, type = 2, visualStyle = 1 }
			}
		},
		[91042] = {
			ID = 91042,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22793, 22793, 22793, 22793, 22793 },
			entryIDs = { 112965 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82210, type = 2, visualStyle = 1 },
				{ targetNode = 82211, type = 2, visualStyle = 1 },
				{ targetNode = 82214, type = 2, visualStyle = 1 }
			}
		},
		[91043] = {
			ID = 91043,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22796, 22796, 22796, 22796, 22796 },
			entryIDs = { 112966 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82210, type = 2, visualStyle = 1 },
				{ targetNode = 82211, type = 2, visualStyle = 1 },
				{ targetNode = 82214, type = 2, visualStyle = 1 }
			}
		},
		[91044] = {
			ID = 91044,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22798, 22798, 22798, 22798, 22798 },
			entryIDs = { 112967 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82200, type = 2, visualStyle = 1 }
			}
		},
		[91045] = {
			ID = 91045,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22797, 22797, 22797, 22797, 22797 },
			entryIDs = { 112968 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82210, type = 2, visualStyle = 1 },
				{ targetNode = 82211, type = 2, visualStyle = 1 },
				{ targetNode = 82214, type = 2, visualStyle = 1 }
			}
		},
		[91046] = {
			ID = 91046,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 1500,
			maxRanks = 1,
			conditionIDs = { 22801, 22799, 22801, 22799, 22801, 22799, 22801, 22799, 22801, 22799 },
			entryIDs = { 112969 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82200, type = 2, visualStyle = 1 }
			}
		},
		[91047] = {
			ID = 91047,
			flags = 8,
			type = 0,
			posX = 5700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 22802, 22800, 22802, 22800, 22802, 22800, 22802, 22800, 22802, 22800 },
			entryIDs = { 112970 },
			groupIDs = { 8531 },
			costs = {
				{ ID = 2801, amount = 1 }
			},
			edges = {
				{ targetNode = 82211, type = 2, visualStyle = 1 },
				{ targetNode = 82210, type = 2, visualStyle = 1 },
				{ targetNode = 82214, type = 2, visualStyle = 1 }
			}
		},
		[91048] = {
			ID = 91048,
			flags = 0,
			type = 0,
			posX = 10500,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 20232, 20232, 20232, 20232 },
			entryIDs = { 109841 },
			groupIDs = { 8521, 8526 },
			costs = {
				{ ID = 2800, amount = 1 }
			},
			edges = {
				{ targetNode = 88202, type = 2, visualStyle = 1 },
				{ targetNode = 88208, type = 2, visualStyle = 1 }
			}
		},
		[92219] = {
			ID = 92219,
			flags = 9,
			type = 2,
			posX = 13200,
			posY = 5400,
			maxRanks = 1,
			conditionIDs = { 20084, 20092, 20094, 20084, 20092, 20094, 20084, 20092, 20094 },
			entryIDs = { 101816, 114291 },
			groupIDs = { 8441, 8444, 8445, 8446 },
			costs = {
				{ ID = 2785, amount = 1 }
			},
			edges = {
				{ targetNode = 80950, type = 2, visualStyle = 1 },
				{ targetNode = 80951, type = 2, visualStyle = 1 }
			}
		},
		[92220] = {
			ID = 92220,
			flags = 8,
			type = 0,
			posX = 6600,
			posY = 3300,
			maxRanks = 1,
			conditionIDs = { 22873, 22873, 22873, 22873 },
			entryIDs = { 114292 },
			groupIDs = { 8480 },
			costs = {
				{ ID = 2795, amount = 1 }
			},
			edges = {
				{ targetNode = 81604, type = 2, visualStyle = 1 }
			}
		},
		[92225] = {
			ID = 92225,
			flags = 9,
			type = 0,
			posX = 11700,
			posY = 2700,
			maxRanks = 1,
			conditionIDs = { 20298, 20298, 20298 },
			entryIDs = { 108225 },
			groupIDs = { 8546, 8550 },
			costs = {
				{ ID = 2804, amount = 1 }
			},
			edges = {
				{ targetNode = 82564, type = 2, visualStyle = 1 },
				{ targetNode = 82589, type = 2, visualStyle = 1 }
			}
		},
	}
	for _,node in pairs(nodes) do
		for _,edge in ipairs(node.edges) do
			local target = nodes[edge.targetNode];
			target.incomingEdges = target.incomingEdges or {};
			target.incomingEdges[#target.incomingEdges+1] = node.ID;
		end
	end
	function Internal.GetTraitInfoVersion()
		return traitInfoVersion;
	end
	function Internal.GetTreeInfoBySpecID(specID)
		local result = BtWLoadoutsTraitsInfo.trees[specID] or trees[specID];
		result.buttonSize = 40;
		result.minZoom = 0.75;
		result.maxZoom = 0.75;
		return result;
	end
	function Internal.GetNodeInfo(nodeID)
		return nodes[nodeID];
	end
	function Internal.GetNodeInfoBySpecID(specID, nodeID)
		local tree = Internal.GetTreeInfoBySpecID(specID);
		local result = BtWLoadoutsTraitsInfo.nodes[nodeID] and CopyTable(BtWLoadoutsTraitsInfo.nodes[nodeID], false) or nodes[nodeID];
		if not result then
			error("Missing Node " .. nodeID);
		end
		result.isVisible = tree.visibleNodes[nodeID] and true or false;
		if tContains(tree.grantedNodes, nodeID) then
			result.activeRank = result.maxRanks;
			result.currentRank = result.maxRanks;
		else
			result.activeRank = 0;
			result.currentRank = 0;
		end
		result.ranksPurchased = 0;
		if not result.activeEntry and #result.entryIDs == 1 then
			result.activeEntry = {
				entryID = result.entryIDs[1],
				rank = 1,
			}
		end
		if result.edgesBySpecID and result.edgesBySpecID[specID] then
			result.visibleEdges = result.edgesBySpecID[specID];
		else
			result.visibleEdges = {}
			for _,edge in ipairs(result.edges) do
				if tree.visibleNodes[edge.targetNode] then
					result.visibleEdges[#result.visibleEdges+1] = edge
				end
			end
		end
		return result;
	end
	function Internal.UpdateTraitInfoFromPlayer()
		if not C_ClassTalents then
			return
		end

		local specID = GetSpecializationInfo(GetSpecialization());
		local configID = C_ClassTalents.GetActiveConfigID();
        local configInfo = C_Traits.GetConfigInfo(configID);
        local treeID = configInfo.treeIDs[1];
		local tree = C_Traits.GetTreeInfo(configID, treeID);
		local nodeIDs = C_Traits.GetTreeNodes(treeID);
		local currencies = C_Traits.GetTreeCurrencyInfo(configID, treeID, true);
		local incomingEdgesByNodeID = {}

		local conditions = setmetatable({}, {
			__index = function (self, key)
				if type(key) == "number" then
					local result = C_Traits.GetConditionInfo(configID, key)
					self[key] = result;
					return result;
				end
			end
		});

		local savedTree = Internal.GetTreeInfoBySpecID(specID)
		for _,gate in ipairs(tree.gates) do
			local condInfo = conditions[gate.conditionID];
			gate.traitCurrencyID = condInfo.traitCurrencyID;

			local found = false;
			for _,savedGate in ipairs(savedTree.gates) do
				if savedGate.conditionID == gate.conditionID then
					found = true;
					gate.spentAmountRequired = savedGate.spentAmountRequired;
					break;
				end
			end

			-- Gates arent compatible with saved version so we cant get the spentAmountRequired
			-- without a lot of extra effort so we will just fail for now
			if not found then
				return;
			end
		end

		tree.hideSingleRankNumbers = nil;
		tree.buttonSize = nil;
		tree.maxZoom = nil;
		tree.minZoom = nil;

		for _,currency in ipairs(currencies) do
			if UnitLevel("player") ~= 70 then
				local found = false;
				for _,savedCurrency in ipairs(savedTree.currencies) do
					if savedCurrency.traitCurrencyID == currency.traitCurrencyID then
						found = true;
						currency.maxQuantity = savedCurrency.maxQuantity;
						break;
					end
				end

				-- Although currencies have all the data we store their maxQuantity is incorrect on non max level characters
				if not found then
					return;
				end
			end

			currency.quantity = nil;
			currency.spent = nil;
		end

		tree.nodes = nodeIDs;
		tree.currencies = currencies;

		local visibleNodes = {};
		local grantedNodes = {};

		for _,nodeID in ipairs(nodeIDs) do
			local nodeInfo = C_Traits.GetNodeInfo(configID, nodeID);
			if nodeInfo and nodeInfo.isVisible then
				visibleNodes[nodeID] = true;

				for _,condID in ipairs(nodeInfo.conditionIDs) do
					local condInfo = conditions[condID];
					if condInfo.ranksGranted and (condInfo.specSetID == nil or C_SpecializationInfo.MatchesCurrentSpecSet(condInfo.specSetID)) then
						grantedNodes[#grantedNodes+1] = nodeID;
					end
				end

				if not incomingEdgesByNodeID[nodeID] then
					incomingEdgesByNodeID[nodeID] = {};
				end

				nodeInfo.canPurchaseRank = nil;
				nodeInfo.canRefundRank = nil;
				nodeInfo.isAvailable = nil;
				nodeInfo.isCascadeRepurchasable = nil;
				nodeInfo.isVisible = nil;
				nodeInfo.meetsEdgeRequirements = nil;
				
				nodeInfo.activeRank = nil;
				nodeInfo.currentRank = nil;
				nodeInfo.ranksPurchased = nil;
				nodeInfo.activeEntry = nil;
				nodeInfo.entryIDsWithCommittedRanks = nil;

				for _,edge in ipairs(nodeInfo.visibleEdges) do
					edge.isActive = nil;
					
					if not incomingEdgesByNodeID[edge.targetNode] then
						incomingEdgesByNodeID[edge.targetNode] = {};
					end
					incomingEdgesByNodeID[edge.targetNode][#incomingEdgesByNodeID[edge.targetNode]+1] = nodeID;
				end

				local savedNodeInfo = Internal.GetNodeInfo(nodeID);
				if not savedNodeInfo then
					return
				end

				nodeInfo.edges = savedNodeInfo.edges;

				nodeInfo.edgesBySpecID = savedNodeInfo and savedNodeInfo.edgesBySpecID or {};
				nodeInfo.edgesBySpecID[specID] = nodeInfo.visibleEdges;

				nodeInfo.incomingEdges = savedNodeInfo.incomingEdges;
				nodeInfo.incomingEdgesBySpecID = savedNodeInfo and savedNodeInfo.incomingEdgesBySpecID or {};
				nodeInfo.incomingEdgesBySpecID[specID] = incomingEdgesByNodeID[nodeID];

				nodeInfo.visibleEdges = nil;
				
				local costs = C_Traits.GetNodeCost(configID, nodeID);
				nodeInfo.costs = costs;

				BtWLoadoutsTraitsInfo.nodes[nodeID] = nodeInfo;
			end
		end

		tree.visibleNodes = visibleNodes;
		tree.grantedNodes = grantedNodes;

		BtWLoadoutsTraitsInfo.trees[specID] = tree;
	end
end
function Internal.GetCharacterInfo(character)
	return BtWLoadoutsCharacterInfo and BtWLoadoutsCharacterInfo[character];
end
function Internal.GetFormattedCharacterName(slug, includeRealm)
	local characterInfo = Internal.GetCharacterInfo(slug)
	if characterInfo then
		local classColor = C_ClassColor.GetClassColor(characterInfo.class)
		if includeRealm then
			return format("%s - %s", classColor:WrapTextInColorCode(characterInfo.name), characterInfo.realm)
		else
			return classColor:WrapTextInColorCode(characterInfo.name)
		end
	end
	return slug
end
local characterIteratorTemp = {}
function Internal.CharacterIterator()
	wipe(characterIteratorTemp);
	for character in pairs(BtWLoadoutsCharacterInfo or {}) do
		characterIteratorTemp[#characterIteratorTemp+1] = character
	end
	table.sort(characterIteratorTemp, function (a, b)
		return a < b
	end)
	return ipairs(characterIteratorTemp)
end
-- EnumerateRealms
do
	local unique, list = {}, {}
	function Internal.EnumerateRealms()
		wipe(unique)
		wipe(list)
		for _,character in pairs(BtWLoadoutsCharacterInfo or {}) do
			unique[character.realm] = true
		end
		for realm in pairs(unique) do
			list[#list+1] = realm
		end
		table.sort(list, function (a, b)
			return a < b
		end)
		return ipairs(list)
	end
end
-- EnumerateCharactersForRealm
do
	local list = {}
	function Internal.EnumerateCharactersForRealm(realm)
		wipe(list)
		for slug,character in pairs(BtWLoadoutsCharacterInfo or {}) do
			if character.realm == realm then
				list[#list+1] = slug
			end
		end
		table.sort(list, function (a, b)
			return a < b
		end)
		return ipairs(list)
	end
end
function Internal.DeleteCharacter(slug)
	if Internal.Call("CHARACTER_DELETE", slug) then
		BtWLoadoutsCharacterInfo[slug] = nil
	end
	BtWLoadoutsFrame:Update();
end
function Internal.UpdatePlayerInfo()
    local name, realm = UnitFullName("player");
    local class = select(2, UnitClass("player"));
    local race = select(3, UnitRace("player"));
    local sex = UnitSex("player") - 2;

    BtWLoadoutsCharacterInfo[realm .. "-" .. name] = {name = name, realm = GetRealmName(), class = class, race = race, sex = sex};
end
-- Checks if the player can switch to specID, used to check if loadouts are valid
function Internal.CanSwitchToSpecialization(specID)
	local playerClass = select(2, UnitClass("player"));
	local specClass = select(6, GetSpecializationInfoByID(specID));
	if playerClass ~= specClass then
		return false
	end
	local specIndex = GetSpecialization()
	if specIndex == nil then
		return false
	end

	if select(2, GetInstanceInfo()) == "arena" then
		-- Can not switch specs in arena
		return GetSpecializationInfo(specIndex) == specID
	elseif select(2, GetInstanceInfo()) == "battleground" then
		-- You can only switch specs in bgs unless you go from or to healer
		local currentRole = GetSpecializationRole(specIndex)
		local targetRole = GetSpecializationRoleByID(specID)

		return (currentRole == targetRole) or not (currentRole == "HEALER" or targetRole == "HEALER")
	end

	return true
end
function Internal.HasJailersChains()
	return GetPlayerAuraBySpellID(338906) ~= nil
end